/************************************************************************************/
/* file - ASSETPropertyManager.java                                                 */
/* --------------------------------                                                 */
/* This class has become the parent class for managing the properties of the ASSET  */
/* System and ASSET Manager. Initially there was a class named PropertyManager that */
/* was specific to both applications yet when it came time to incorporate the client*/
/* API into the ASSET Manager we were getting name conflicts since both property    */
/* manager classes were named the same thing.                                       */
/* --------------------------------                                                 */
/* NIST Self-Assessment Tool                                                        */
/* Author - Mark McLarnon                                                           */
/* --------------------------------                                                 */
/* Users of this class should be aware that the ASSET Manager and ASSET client each */
/* have sub-classed this class in order to make the file name of the properties file*/
/* specific to that application.                                                    */
/************************************************************************************/
import java.io.*;
import java.util.*;

public class ASSETPropertyManager { 
    private Properties sat_properties = new Properties();
    private String properties_path    = "";
    private ASSET parent = null;
    
    public ASSETPropertyManager(ASSET parent) {
        try {
            this.parent = parent;            
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public void loadProperties() {
        try {
            sat_properties.load(new FileInputStream(this.getPropertyPath()));
        }catch (FileNotFoundException e) {
            this.parent.displayErrorDialog("\nERROR: cannot locate properties file: " + this.getPropertyPath() +"\nBe sure this file is in the program directory.");
            e.printStackTrace();
            System.exit(1);
        }catch (Exception e) {
            this.parent.displayErrorDialog("\nERROR: cannot load existing properties file: " + this.getPropertyPath());
            e.printStackTrace();
            System.exit(1);
        }
    }
    
    public static ASSETPropertyManager initializePropertyManager(ASSET parent) {
        return new ASSETPropertyManager(parent);
    }
    
    public void saveProperties() {
        try {
            sat_properties.store(new FileOutputStream(this.getPropertyPath()), "ASSET Properties");            
        }catch (Exception e) {
            this.parent.displayErrorDialog("ERROR: could not save properties file!");
            e.printStackTrace();
        }
    }    
    
    public void flushProperties() {
        this.saveProperties();
        this.loadProperties();
    }
    
    public String getProperty(String property) {
        if (property != null) {
            return sat_properties.getProperty(property);
        }
        return null;
    }

    public void setPropertyPath(String path) {
        this.properties_path = path;
    }
    
    public String getPropertyPath() {
        return properties_path;
    }
    
    public boolean addProperty(String key, String value) {
        boolean flag = true;
        try {
            this.sat_properties.setProperty(key, value); 
            this.flushProperties();
        }catch (Exception e) {
            e.printStackTrace();
            flag = false;
        }
        return flag;
    }    
}/* end class ASSETPropertyManager() */