/****************************************************************************************/
/* file - AssessmentImporter.java							*/
/* ------------------------------							*/
/* This class implements the assessmetn import process for both System and Manager. An  */
/* import file must contain well-formed XML because the DOMParser class from the Xerces */
/* XML parser is used to read the information from this file to insert into the database*/
/* ------------------------------							*/
/* Author - Mark McLarnon								*/
/****************************************************************************************/
import java.sql.*;
import java.util.*;
import javax.swing.*;
import org.xml.sax.*;
import org.apache.xerces.dom.*;
import org.apache.xerces.parsers.*;
import org.w3c.dom.*;

public class AssessmentImporter extends Thread {
    
    ASSET parent = null;
    String file_name = "";
    String active_assessment_id = "";
    String system_name = "";
    DOMParser parser = new DOMParser();
    Document imported_assessment = null;
    
    private AssessmentImporter(ASSET parent, String file_name) {
        this.setParent(parent);
        this.setFileName(file_name);  
    }
    
    public static AssessmentImporter spawnAssessmentImporter(ASSET parent, String file_name) {
        return new AssessmentImporter(parent, file_name);
    }
    
    public String getSystemName() {
        return this.system_name;    
    }
    
    public void setSystemName(String name) {
        this.system_name = name;    
    }
    
    public String getActiveAssessmentID() {
        return this.active_assessment_id;    
    }
    
    public void setActiveAssessmentID(String new_id) {
        this.active_assessment_id = new_id;    
    }
    
    public void setFileName(String new_file) {
        this.file_name = new_file;
    }
    
    public String getFileName() {
        return this.file_name;    
    }
    
    public void setParent(ASSET new_parent) {
        this.parent = new_parent;
    }
    
	private Vector processMultiLevelSubTree(NodeList tree_list, String sub_child_name) {
	    Vector result_arrays = new Vector();
	    Vector single_result_array = null;
	    Element sub_tree_parent = null;
	    NodeList sub_trees = null;
	    try {
	        sub_tree_parent = (Element) tree_list.item(0);
	        sub_trees = sub_tree_parent.getElementsByTagName(sub_child_name);
	        for (int i = 0; i < sub_trees.getLength(); i++) {
	            result_arrays.addElement(processSingleSubTree(sub_trees.item(i)));
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return result_arrays;
	}/* end method processMultiLevelSubTree() */

	// This handy method will create a vector of values that were extracted from
	// and XML document subtree that contains all leaves and no sub-trees of its
	// own.
	// NOTE - this is an overloaded version of processSingleSubTree(NodeList) 
	//        that appears below
	private Vector processSingleSubTree(Node tree) {
        Vector temp = new Vector();
        Node tree_child = null;
        NodeList tree_node_list = null;
        NodeList tree_node_children = null;
        Node attribute = null; 
        try {                                  
            if (tree.getNodeType() == Node.ELEMENT_NODE) {
                tree_node_list = tree.getChildNodes();
            }
            for (int i = 0; i < tree_node_list.getLength(); i++) {
                tree_child = tree_node_list.item(i);
                tree_node_children = tree_child.getChildNodes();

                if (tree_node_children.getLength() != 0) {
                   attribute = tree_node_children.item(0);
                   temp.addElement(attribute.getNodeValue().trim());                   
                }
            }
        }catch (Exception e) {
           e.printStackTrace();
        }
        return temp;
	}/* end overloaded method processSystem() */	
		
	// This handy method will create a vector of values that were extracted from
	// and XML document subtree that contains all leaves and no sub-trees of its
	// own.
	private Vector processSingleSubTree(NodeList tree_list) {
        Vector temp = new Vector();
        Node tree = null;
        Node tree_child = null;
        NodeList tree_node_list = null;
        NodeList tree_node_children = null;
        Node attribute = null; 
        try {            
            tree = tree_list.item(0);                        
            if (tree.getNodeType() == Node.ELEMENT_NODE) {
                tree_node_list = tree.getChildNodes();
            }
            for (int i = 0; i < tree_node_list.getLength(); i++) {
                tree_child = tree_node_list.item(i);
                tree_node_children = tree_child.getChildNodes();

                if (tree_node_children.getLength() != 0) {
                   attribute = tree_node_children.item(0);
                   temp.addElement(attribute.getNodeValue().trim());                   
                }
            }
        }catch (Exception e) {
           e.printStackTrace();
        }
        return temp;
	}/* end method processSystem() */    
    
	// The main method that imports assessment data from the XML exports into the
	// SAT Admin database. Since there can be multiple assessments within 1 export
	// file this method will be called for each XML DOM Element instance of 
	// assessment found in the specified import file. 
	private boolean processAssessment(Element assessment) {
	    boolean success = false;
	    CallableStatement save_new_component = null;
	    CallableStatement save_new_assessment = null;
	    CallableStatement save_criticalities = null;
	    CallableStatement connected_system = null;
        CallableStatement  save_question_block = null;
        CallableStatement assessors = null;
	    Connection conn1 = null;
	    
	    Vector system_results = null;
	    Vector assessor_list = null;
	    Vector criticalities = null;
	    Vector conn_systems = null;
	    Vector policy = null;
	    Vector critical_elem = null;
	    Vector questions = null;
	    Vector temp_buffer = null;
	    
	    String assessment_name = "";
	    String start_date = "";
	    String primary_assessor = "";
	    String bookmark = "";
	    String system_number = "";
	    int completed = 0;	  
	    int progress = 0;
	    try {	        
	        system_results = this.processSingleSubTree(assessment.getElementsByTagName("system"));
	    	this.setSystemName((String) system_results.elementAt(0));       	    
            assessment_name = (this.getTextValueFromNode(assessment.getElementsByTagName("assessmentname"))).trim();
        	this.setActiveAssessmentID(assessment_name);
        	start_date = (this.getTextValueFromNode(assessment.getElementsByTagName("startdate"))).trim();       	       	        	        
            completed = Integer.parseInt(this.getTextValueFromNode(assessment.getElementsByTagName("completed")));
            bookmark = this.getTextValueFromNode(assessment.getElementsByTagName("bookmark"));
            primary_assessor = (this.getTextValueFromNode(assessment.getElementsByTagName("primary_assessor"))).trim();
            progress = Integer.parseInt(this.getTextValueFromNode(assessment.getElementsByTagName("progress")));
            system_number = ((String) system_results.elementAt(1));

            assessor_list = this.processMultiLevelSubTree(assessment.getElementsByTagName("assessors"), "assessor");
            criticalities = this.processSingleSubTree(assessment.getElementsByTagName("criticalities"));
            conn_systems = this.processMultiLevelSubTree(assessment.getElementsByTagName("connectedsystems"), "component");
            policy = this.processMultiLevelSubTree(assessment.getElementsByTagName("policy"), "objective");
            critical_elem = this.processMultiLevelSubTree(assessment.getElementsByTagName("critical"), "element");
            questions = this.processMultiLevelSubTree(assessment.getElementsByTagName("questions"), "question");

            conn1 = this.parent.connectionGenerator();
            save_new_assessment = conn1.prepareCall("{call save_assessment (?, ?, ?, ?, ?, ?)}");	        	    
	        save_new_assessment.setString(1, assessment_name);
	        save_new_assessment.setString(2, start_date);
	        save_new_assessment.setInt(3, completed);
	        save_new_assessment.setString(4, bookmark);
	        save_new_assessment.setString(5, primary_assessor);	
	        save_new_assessment.setInt(6, progress);
	        save_new_assessment.executeUpdate();
	        conn1.close();
	        
	        conn1 = this.parent.connectionGenerator();
            save_new_component = conn1.prepareCall("{call save_component (?, ?, ?, ?, ?, ?)}");	    
	        save_new_component.setString(1, system_number);
	        save_new_component.setString(2, assessment_name);
	        save_new_component.setString(3, ((String) system_results.elementAt(2)));
	        save_new_component.setString(4, ((String) system_results.elementAt(0)));
	        save_new_component.setString(5, ((String) system_results.elementAt(3)));
	        save_new_component.setString(6, ((String) system_results.elementAt(4)));	        
	        save_new_component.executeUpdate();
            conn1.close();

            for (int i = 0; i < assessor_list.size(); i++) {
                temp_buffer = (Vector) assessor_list.elementAt(i);
                for (int j = 0; j < temp_buffer.size(); j++) {
                    conn1 = this.parent.connectionGenerator();            
                    assessors = conn1.prepareCall("{call save_new_assessor(?, ?, ?, ?)}");
                    assessors.setString(1, ((String) temp_buffer.elementAt(0)));
                    assessors.setString(2, ((String) temp_buffer.elementAt(1)));
                    assessors.setString(3, ((String) temp_buffer.elementAt(2)));
                    assessors.setString(4, "N/A");
                    assessors.executeUpdate();
                    conn1.close();
                }
            }
            
            conn1 = this.parent.connectionGenerator();	    
            save_criticalities = conn1.prepareCall("{call save_component_criticalities (?, ?, ?, ?, ?) }");
            save_criticalities.setString(1, assessment_name);
            save_criticalities.setString(2, system_number);            
            save_criticalities.setString(3, ((String) criticalities.elementAt(0)));
            save_criticalities.setString(4, ((String) criticalities.elementAt(1)));
            save_criticalities.setString(5, ((String) criticalities.elementAt(2)));            
            save_criticalities.executeUpdate();
            conn1.close();
            
            // Change Control:
            // 03/19/02 - Added insertion of assessment_id into parameter list when
            //            saving connected system information.
            for (int i = 0; i < conn_systems.size(); i++) {
                temp_buffer = (Vector) conn_systems.elementAt(i);
                for (int j = 0; j < temp_buffer.size(); j++) {
                    conn1 = this.parent.connectionGenerator();	
                    connected_system = conn1.prepareCall("{call save_connected_components (?, ?, ?, ?, ?)}");
                    connected_system.setString(1, assessment_name);
                    connected_system.setString(2, system_number);
                    connected_system.setString(3, ((String) temp_buffer.elementAt(0)));                
                    connected_system.setInt(4, Integer.parseInt(((String) temp_buffer.elementAt(1))));
                    connected_system.setString(5, ((String) temp_buffer.elementAt(2)));                
                    connected_system.executeUpdate(); 
                    conn1.close();
                }
            }
          
	        StringTokenizer parser = null;	
	        for (int i = 0; i < policy.size(); i++) {
                temp_buffer = (Vector) policy.elementAt(i);
                System.out.println((String) temp_buffer.elementAt(0));
                System.out.println((String) temp_buffer.elementAt(1));
                parser = new StringTokenizer((String) temp_buffer.elementAt(0), ".");
                conn1 = this.parent.connectionGenerator();
                save_question_block = conn1.prepareCall("{call insert_assessment_question_response (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)}");
                save_question_block.setString(1, assessment_name);                
                save_question_block.setInt(2, Integer.parseInt(parser.nextToken()));
                save_question_block.setInt(3, Integer.parseInt(parser.nextToken()));
                save_question_block.setInt(4, Integer.parseInt(parser.nextToken()));                
                save_question_block.setInt(5, 0);
                save_question_block.setInt(6, Integer.parseInt((String) temp_buffer.elementAt(1)));
                save_question_block.setInt(7, 0);
                save_question_block.setInt(8, 0);
                save_question_block.setInt(9, 0);
                save_question_block.setInt(10, 0);                
                save_question_block.setInt(11, 0);
                save_question_block.setString(12, "");                               
                save_question_block.setInt(13, 0);
                save_question_block.setInt(14, 0);
                save_question_block.setString(15, ""); 
                save_question_block.setInt(16, 1);
                save_question_block.executeUpdate();
                conn1.close();
            }
            
            save_question_block = null;
	        for (int i = 0; i < critical_elem.size(); i++) {
                temp_buffer = (Vector) critical_elem.elementAt(i);
                parser = new StringTokenizer((String) temp_buffer.elementAt(0), ".");
                conn1 = this.parent.connectionGenerator();
                save_question_block = conn1.prepareCall("{call insert_assessment_question_response (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)}");
                save_question_block.setString(1, assessment_name);                
                save_question_block.setInt(2, Integer.parseInt(parser.nextToken()));
                save_question_block.setInt(3, Integer.parseInt(parser.nextToken()));
                save_question_block.setInt(4, Integer.parseInt(parser.nextToken()));                
                save_question_block.setInt(5, 0);
                save_question_block.setInt(6, Integer.parseInt((String) temp_buffer.elementAt(1)));
                save_question_block.setInt(7, Integer.parseInt((String) temp_buffer.elementAt(2)));
                save_question_block.setInt(8, Integer.parseInt((String) temp_buffer.elementAt(3)));
                save_question_block.setInt(9, Integer.parseInt((String) temp_buffer.elementAt(4)));
                save_question_block.setInt(10, Integer.parseInt((String) temp_buffer.elementAt(5)));                
                save_question_block.setInt(11, 0);
                save_question_block.setString(12, "");                               
                save_question_block.setInt(13, 0);
                save_question_block.setInt(14, 0);
                save_question_block.setString(15, ""); 
                save_question_block.setInt(16, 1);
                save_question_block.executeUpdate();
                conn1.close();
            }
            
            save_question_block = null;
            Connection conn2 = null;
            CallableStatement assessor_sp = null;
            int major = 0;
            int minor = 0;
            int num = 0;
	        for (int i = 0; i < questions.size(); i++) {
                temp_buffer = (Vector) questions.elementAt(i);
                parser = new StringTokenizer((String) temp_buffer.elementAt(0), ".");
                major = Integer.parseInt(parser.nextToken());
                minor = Integer.parseInt(parser.nextToken());
                num = Integer.parseInt(parser.nextToken());
                System.out.println((String) temp_buffer.elementAt(0));
                conn1 = this.parent.connectionGenerator();
                conn2 = this.parent.connectionGenerator();
                save_question_block = conn1.prepareCall("{call insert_assessment_question_response (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)}");
                assessor_sp = conn2.prepareCall("{call save_answered_question (?, ?, ?, ?, ?, ?)}");
                save_question_block.setString(1, assessment_name);                
                save_question_block.setInt(2, major);
                save_question_block.setInt(3, minor);
                save_question_block.setInt(4, num);                
                save_question_block.setInt(5, 0);
                save_question_block.setInt(6, Integer.parseInt((String) temp_buffer.elementAt(1)));
                save_question_block.setInt(7, Integer.parseInt((String) temp_buffer.elementAt(2)));
                save_question_block.setInt(8, Integer.parseInt((String) temp_buffer.elementAt(3)));
                save_question_block.setInt(9, Integer.parseInt((String) temp_buffer.elementAt(4)));
                save_question_block.setInt(10, Integer.parseInt((String) temp_buffer.elementAt(5)));                
                save_question_block.setInt(11, Integer.parseInt((String) temp_buffer.elementAt(6)));
                // Insert Comments field fom XML file, be sure to remove whitespace
                save_question_block.setString(12, ((String) temp_buffer.elementAt(7)).trim());                               
                save_question_block.setInt(13, Integer.parseInt((String) temp_buffer.elementAt(8)));
                save_question_block.setInt(14, Integer.parseInt((String) temp_buffer.elementAt(9)));
                save_question_block.setString(15, ((String) temp_buffer.elementAt(10)).trim());
                save_question_block.setInt(16, Integer.parseInt((String) temp_buffer.elementAt(11)));
                save_question_block.executeUpdate();
                System.out.println((String) temp_buffer.elementAt(12));
                assessor_sp.setString(1, (String) temp_buffer.elementAt(12));
                assessor_sp.setString(2, assessment_name);
                assessor_sp.setInt(3, major);
                assessor_sp.setInt(4, minor);
                assessor_sp.setInt(5, num);
                assessor_sp.setInt(6, 0);
                assessor_sp.executeUpdate();
                conn2.close();
                conn1.close();
            }        
            success = true;
	    }catch (Exception e) {
	        success = false;
	        this.parent.displayErrorDialog("ERROR! Could not import assessment, please try again.\nThe text of the error is:\n" + e.toString());            
	        e.printStackTrace();
	        System.exit(1);
	    }
	    return success;
	}/* end method processAssessment() */        
        
	private String getTextValueFromNode(NodeList node_list) {
	    StringBuffer mem_buffer = new StringBuffer("");
        Node node = null;
	    NodeList child_values = null;
	    Node child = null;
	    try {
	        node = node_list.item(0);
            child_values = node.getChildNodes();

            if (child_values.getLength() != 0) {
               child = child_values.item(0);
               mem_buffer.append(child.getNodeValue().trim());
                   
            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return mem_buffer.toString();
	}
        
	void importAssessment(String file_name) {
	    Element assessment = null;
	    boolean result = false;
	    try {
	        this.parser.parse(file_name);
	        imported_assessment = this.parser.getDocument();
	        Element root = imported_assessment.getDocumentElement();
	        
	        NodeList assessments = root.getElementsByTagName("assessment");
	        this.parent.setStatusMsg("Importing assessment");
	        for (int i = 0; i < assessments.getLength(); i++) {	            
	            assessment = (Element) assessments.item(i);
	            
	            result = this.processAssessment(assessment);
	            if (!result) {
	                this.parent.displayStatusDialog("Assessment " + (i + 1) + " was not imported!");
	            }
	        }
	        this.parent.setStatusMsg("For help, press F1");
	    }catch (Exception e) {
	        e.printStackTrace();
	        this.parent.displayErrorDialog("The system could not parse the XML file you supplied! Please try again");
	    }
	}/* end method importAssessment() */
      
        
    public void run() {
        this.importAssessment(this.getFileName());
        this.parent.displayStatusDialog("Assessment import completed successfully!");
    }
}