/************************************************************************/
/* file - Assessor.java                                                 */
/* --------------------                                                 */
/* This class represents the encapsulation of a component assessor      */
/* It was done this way to allow the SAT Client to track a large number */
/* of assessors concurrently and due to the fact that each assessor     */
/* is represented by several pieces of information.                     */
/* --------------------                                                 */
/* NIST Self-Assessment Tool                                            */
/* Author - Mark McLarnon                                               */
/* --------------------                                                 */
/* Change Control:                                                      */
/* 02/13/02: Added Serializable interface to allow Assessor to be Serial*/
/*           izable. This allows assessment data to be saved locally    */
/* 03/12/02: Added data vector to assessor class to allow program to    */
/*           get information about assessor in form of Vector, used to  */
/*           help sort tables                                           */
/************************************************************************/
import java.io.Serializable;
import java.util.Vector;

public class Assessor implements Serializable {
 
    private Assessor() {            
		//{{INIT_CONTROLS
		//}}
	}
    
    public static Assessor createNewAssessor() {
        return new Assessor();
    }

    private Assessor(String full_name, String email, String exten, boolean p_assessor) {
        this.data_record.addElement(new Boolean(p_assessor));   
        this.setFullName(full_name);
        this.data_record.addElement(full_name);
        this.setEmail(email);
        this.data_record.addElement(email);
        this.setExtension(exten);
        this.data_record.addElement(exten);
        this.setPrimaryAssessor(p_assessor);
    }

    private Assessor(String name, String email) {
        this.data_record.addElement(new Boolean(true));
        this.setFullName(name);
        this.data_record.addElement(full_name);
        this.setEmail(email);
        this.data_record.addElement(email);
        this.data_record.addElement("");
        this.setPrimaryAssessor(true);        
    }
    
    public Vector getDataVector() {
        return this.data_record;    
    }
    
    public static Assessor createNewAssessor(String full_name, String email, String exten, boolean p_assessor) {
        return new Assessor(full_name, email, exten, p_assessor);
    }
    
    public static Assessor createNewPrimaryAssessor(String name, String email) {
        return new Assessor(name, email);
    }
    
    private void setFullName(String name) {
        if ((name != null) && (name.length() < maximum_field_length)) {
            this.full_name = name;
        }
    }
    
    private void setEmail(String email) {
        if ((email != null) && (email.length() < maximum_field_length)) {
            this.email = email;
        }
    }
    
    private void setExtension(String extn) {
        if ((extn != null) && (extn.length() < maximum_field_length)) {
            this.extension = extn;
        }
    }
    
    public void setPrimaryAssessor(boolean primary) {
        this.primary_assessor = primary;
        if (primary_assessor == false) {
            this.data_record.setElementAt(new Boolean(false), 0);
        }else {
            this.data_record.setElementAt(new Boolean(true), 0);   
        }
        
    }
    
    // Change Control:
    // 03/14/02 - Had to change setPrimaryAssessor() to public so that when an old
    //            assessment was loaded the person who logged into the tool could be
    //            added as an assessor but not the primary assessor since that was
    //            set when the assessment was started previously        
    public void togglePrimaryAssessor() {
        this.data_record.setElementAt(new Boolean(false), 0);   
    }
    
    public String getFullName() {
        return this.full_name;
    }
    
    public String getEmail() {
        return this.email;
    }
    
    public String getExtension() {
        return this.extension;
    }
    
    public boolean getPrimary() {
        return this.primary_assessor;
    }
    
    private String full_name = "";
    private String email     = "";
    private String extension = "NA";
    private boolean primary_assessor = false;        
    
    private int maximum_field_length = 200;
    
    Vector data_record = new Vector();
	//{{DECLARE_CONTROLS
	//}}
	
} /* end class Assessor() */