/*********************************************************************************/
/* file - LogWindow.java                                                         */
/* ---------------------                                                         */
/* This file is the Log viewer for the NIST SAT Client. It is designed to allow  */
/* users to view the log of activities of the SAT client during its usage. It    */
/* will allow users to open previously created log files and view them while the */
/* client is running but will always default to opening the current log file.    */
/* ---------------------                                                         */
/* NIST Security Self-Assessment Tool                                            */
/* Author - Mark McLarnon                                                        */
/* ---------------------                                                         */
/* Change Control:                                                               */
/* 02/13/02 - Added code to call the Open Log Dialog box                         */
/*********************************************************************************/
import java.awt.datatransfer.*;
import java.awt.event.*;
import java.awt.*;
import javax.swing.*;
import java.text.DecimalFormat;
import java.util.zip.*;
import java.util.*;
import com.symantec.itools.javax.swing.borders.EmptyBorder;
import com.symantec.itools.javax.swing.icons.ImageIcon;
import com.symantec.itools.javax.swing.borders.BevelBorder;
import java.io.*;

public class LogWindow extends javax.swing.JFrame {
    
	public LogWindow() {
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setJMenuBar(Log_menu);
		setTitle("NIST Security Self-Assessment Log Viewer");
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BorderLayout(0,0));
		setSize(561,532);
		setVisible(false);
		JPanel1.setLayout(new BoxLayout(JPanel1,BoxLayout.X_AXIS));
		getContentPane().add(BorderLayout.CENTER, JPanel1);
		log_text_scroll_pane.setOpaque(true);
		JPanel1.add(log_text_scroll_pane);
		log_text_pane.setText("No log opened");
		log_text_pane.setLineWrap(true);
		log_text_pane.setWrapStyleWord(true);
		log_text_pane.setBorder(bevelBorder1);
		log_text_pane.setToolTipText("Shows the contents of the current log buffer");
		log_text_scroll_pane.getViewport().add(log_text_pane);
		log_text_pane.setBounds(0,0,558,494);
		button_panel.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		getContentPane().add(BorderLayout.SOUTH, button_panel);
		export_button.setText("Export Log");
		export_button.setActionCommand("Export Log");
		export_button.setToolTipText("Export log contents to text file");
		export_button.setMnemonic((int)'E');
		button_panel.add(export_button);
		exit_button.setText("Exit");
		exit_button.setActionCommand("Exit");
		exit_button.setToolTipText("Exit Log Viewer");
		exit_button.setMnemonic((int)'X');
		button_panel.add(exit_button);
		//$$ Log_menu.move(0,533);
		fileMenu.setText("File");
		fileMenu.setActionCommand("File");
		fileMenu.setBorderPainted(false);
		fileMenu.setMnemonic((int)'F');
		Log_menu.add(fileMenu);
		openLogMenuItem.setText("Open");
		openLogMenuItem.setActionCommand("Open");
		openLogMenuItem.setBorderPainted(false);
		openLogMenuItem.setMnemonic((int)'O');
		fileMenu.add(openLogMenuItem);
		saveLogMenuItem.setText("Save");
		saveLogMenuItem.setActionCommand("Save");
		saveLogMenuItem.setBorderPainted(false);
		saveLogMenuItem.setMnemonic((int)'S');
		fileMenu.add(saveLogMenuItem);
		fileMenu.add(JSeparator1);
		exitLogMenuItem.setText("Exit");
		exitLogMenuItem.setActionCommand("Exit");
		exitLogMenuItem.setBorderPainted(false);
		exitLogMenuItem.setMnemonic((int)'X');
		fileMenu.add(exitLogMenuItem);
		editMenu.setText("Edit");
		editMenu.setActionCommand("Edit");
		editMenu.setBorderPainted(false);
		editMenu.setMnemonic((int)'E');
		Log_menu.add(editMenu);
		cutMenuItem.setText("Cut");
		cutMenuItem.setActionCommand("Cut");
		cutMenuItem.setBorderPainted(false);
		cutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		cutMenuItem.setMnemonic((int)'U');
		editMenu.add(cutMenuItem);
		copyMenuItem.setText("Copy");
		copyMenuItem.setActionCommand("Copy");
		copyMenuItem.setBorderPainted(false);
		copyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		copyMenuItem.setMnemonic((int)'C');
		editMenu.add(copyMenuItem);
		pasteMenuItem.setText("Paste");
		pasteMenuItem.setActionCommand("Paste");
		pasteMenuItem.setBorderPainted(false);
		pasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		pasteMenuItem.setMnemonic((int)'P');
		editMenu.add(pasteMenuItem);
		editMenu.add(JSeparator2);
		selectAllMenuItem.setText("Select All");
		selectAllMenuItem.setActionCommand("Select All");
		selectAllMenuItem.setBorderPainted(false);
		selectAllMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.Event.SHIFT_MASK|java.awt.Event.CTRL_MASK));
		selectAllMenuItem.setMnemonic((int)'S');
		editMenu.add(selectAllMenuItem);
		log_text_border.setInsets(new java.awt.Insets(5,5,5,5));
		//$$ log_text_border.move(48,533);
		try {
			saveIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/save.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ saveIcon.move(72,533);
		try {
			openIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/open.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ openIcon.move(96,533);
		try {
			copyIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/copy.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ copyIcon.move(120,533);
		try {
			cutIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/cut.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ cutIcon.move(144,533);
		try {
			pasteIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/paste.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ pasteIcon.move(168,533);
		try {
			helpIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/about.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ helpIcon.move(192,533);
		//$$ text_popup.move(216,533);
		popup_cut_menuItem.setText("Cut");
		popup_cut_menuItem.setActionCommand("Cut");
		popup_cut_menuItem.setBorderPainted(false);
		popup_cut_menuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		popup_cut_menuItem.setMnemonic((int)'C');
		text_popup.add(popup_cut_menuItem);
		popup_copy_menuItem.setText("Copy");
		popup_copy_menuItem.setActionCommand("Copy");
		popup_copy_menuItem.setBorderPainted(false);
		popup_copy_menuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		popup_copy_menuItem.setMnemonic((int)'O');
		text_popup.add(popup_copy_menuItem);
		popup_paste_menuItem.setText("Paste");
		popup_paste_menuItem.setActionCommand("Paste");
		popup_paste_menuItem.setBorderPainted(false);
		popup_paste_menuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		popup_paste_menuItem.setMnemonic((int)'P');
		text_popup.add(popup_paste_menuItem);
		text_popup.add(JSeparator3);
		clearWindowMenuItem.setText("Clear");
		clearWindowMenuItem.setActionCommand("Clear");
		clearWindowMenuItem.setBorderPainted(false);
		clearWindowMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.ALT_MASK));
		clearWindowMenuItem.setMnemonic((int)'C');
		text_popup.add(clearWindowMenuItem);
		bevelBorder1.setBevelType(javax.swing.border.BevelBorder.LOWERED);
		//$$ bevelBorder1.move(240,533);
		cutMenuItem.setIcon(cutIcon);
		pasteMenuItem.setIcon(pasteIcon);
		saveLogMenuItem.setIcon(saveIcon);
		export_button.setIcon(saveIcon);
		copyMenuItem.setIcon(copyIcon);
		openLogMenuItem.setIcon(openIcon);
		//}}

		//{{INIT_MENUS
		//}}
	
		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		exit_button.addActionListener(lSymAction);
		selectAllMenuItem.addActionListener(lSymAction);
		exitLogMenuItem.addActionListener(lSymAction);
		cutMenuItem.addActionListener(lSymAction);
		copyMenuItem.addActionListener(lSymAction);
		pasteMenuItem.addActionListener(lSymAction);
		popup_cut_menuItem.addActionListener(lSymAction);
		popup_copy_menuItem.addActionListener(lSymAction);
		popup_paste_menuItem.addActionListener(lSymAction);
		saveLogMenuItem.addActionListener(lSymAction);
		export_button.addActionListener(lSymAction);
		clearWindowMenuItem.addActionListener(lSymAction);
		openLogMenuItem.addActionListener(lSymAction);
		//}}
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));
        
	    this.log_text_pane.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            text_popup.show(log_text_pane, me.getX(), me.getY());  
		        }
		    }      
		 });
		
		this.clipboard = this.getToolkit().getSystemClipboard();
		open.setModal(false);
		open.setSaveDirectory("logs");
	}/* LogWindow() default constructor  */

	public LogWindow(String sTitle) {
		this();
		setTitle(sTitle);
	}
	
	private void openNewLog() {
	    try {
	        open.fillSaveTableZippedEntries();
            open.fillSaveUnzippedEntriesTable();
            open.setTables();
            open.parent = this;
            open.show();
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public static void main(String[] args) {
	    (new LogWindow()).setVisible(true);    
	}
	
	public void setTitle_textModified() {
	    try {
	        this.setTitle(this.getTitle() + "*");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets and menu bar
		Insets insets = getInsets();
		javax.swing.JMenuBar menuBar = getRootPane().getJMenuBar();
		int menuBarHeight = 0;
		if (menuBar != null)
			menuBarHeight = menuBar.getPreferredSize().height;
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height + menuBarHeight);
	}

    public void exitApplication() {
        try {
            System.exit(0);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void log(String log_text) {
        StringBuffer log_entry = new StringBuffer("");
        try {
            log_entry.append(this.getTimeStamp()+ ":" + this.getServiceName() + " " + log_text);
            this.current_log.addElement(this.getTimeStamp()+ ":" + this.getServiceName() + " " + log_text);
            if (this.isVisible()) {
                this.displayLogBuffer();  
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void clearLogScreen() {
        this.log_text_pane.setText("");
    }
    
    public void displayLogBuffer() {
        try {
            this.clearLogScreen();
            for (int i = 0; i < this.current_log.size(); i++) {
                this.log_text_pane.append((String) this.current_log.elementAt(i) + "\n");
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public String getTimeStamp() {
        StringBuffer time_stamp = new StringBuffer("");
        try {
            GregorianCalendar calendar = new GregorianCalendar();
            DecimalFormat twoDigitFormat = new DecimalFormat();
	        twoDigitFormat.setMinimumIntegerDigits(2);

            int hour = calendar.get(calendar.HOUR_OF_DAY);
	        int minute = calendar.get(calendar.MINUTE);
	        int second = calendar.get(calendar.SECOND);
	        int milli_second = calendar.get(calendar.MILLISECOND);
	        String milli = "";
	        if ((twoDigitFormat.format(milli_second)).length() < 3) {
	            milli = "0" + new String(twoDigitFormat.format(milli_second)).toString();
	        }
            time_stamp.append(twoDigitFormat.format((hour)) + ":"  + twoDigitFormat.format((minute)) + ":"  + twoDigitFormat.format((second)) + "."  + milli);
        }catch (Exception e) {
            e.printStackTrace();
        }
        return time_stamp.toString();
    }

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	javax.swing.JScrollPane log_text_scroll_pane = new javax.swing.JScrollPane();
	javax.swing.JTextArea log_text_pane = new javax.swing.JTextArea();
	javax.swing.JPanel button_panel = new javax.swing.JPanel();
	javax.swing.JButton export_button = new javax.swing.JButton();
	javax.swing.JButton exit_button = new javax.swing.JButton();
	javax.swing.JMenuBar Log_menu = new javax.swing.JMenuBar();
	javax.swing.JMenu fileMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem openLogMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem saveLogMenuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator1 = new javax.swing.JSeparator();
	javax.swing.JMenuItem exitLogMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenu editMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem cutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem copyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem pasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator2 = new javax.swing.JSeparator();
	javax.swing.JMenuItem selectAllMenuItem = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.borders.EmptyBorder log_text_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon saveIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon openIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon copyIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon cutIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon pasteIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon helpIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	javax.swing.JPopupMenu text_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem popup_cut_menuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem popup_copy_menuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem popup_paste_menuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator3 = new javax.swing.JSeparator();
	javax.swing.JMenuItem clearWindowMenuItem = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.borders.BevelBorder bevelBorder1 = new com.symantec.itools.javax.swing.borders.BevelBorder();
	//}}
	OpenLogDialog open = new OpenLogDialog();
	Vector current_log = new Vector();
    Clipboard clipboard = null;
    String service_name = "";
	//{{DECLARE_MENUS
	//}}

    public String getServiceName() {
        return this.service_name;
    }

    public void setServiceName(String name) {
        this.service_name = name;
    }

    private void selectAllText() {
        try {
            this.log_text_pane.select(0, (this.log_text_pane.getText()).length());
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    private String getSelectedText() {
        String selected_text = "";
        try {
            selected_text = this.log_text_pane.getSelectedText();
        }catch (Exception e) {
            e.printStackTrace();
        }
        return selected_text;
    }
    
    private void copyText() {
        try {
            this.log_text_pane.copy();
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void cutText() {
        try {
            this.log_text_pane.cut();
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void pasteText() {
        try {
            this.log_text_pane.paste();
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	class SymAction implements java.awt.event.ActionListener {
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == exit_button)
				exitButton_actionPerformed(event);
			else if (object == selectAllMenuItem)
				selectAllMenuItem_actionPerformed(event);
			else if (object == exitLogMenuItem)
				exitLogMenuItem_actionPerformed(event);
			else if (object == cutMenuItem)
				cutMenuItem_actionPerformed(event);
			else if (object == copyMenuItem)
				copyMenuItem_actionPerformed(event);
			else if (object == pasteMenuItem)
				pasteMenuItem_actionPerformed(event);
			else if (object == popup_cut_menuItem)
				popupCutMenuItem_actionPerformed(event);
			else if (object == popup_copy_menuItem)
				popupCopyMenuItem_actionPerformed(event);
			else if (object == popup_paste_menuItem)
				popupPasteMenuItem_actionPerformed(event);
			else if (object == saveLogMenuItem)
				saveLogMenuItem_actionPerformed(event);
			else if (object == export_button)
				exportButton_actionPerformed(event);
			else if (object == clearWindowMenuItem)
				clearWindowMenuItem_actionPerformed(event);
			else if (object == openLogMenuItem)
				openLogMenuItem_actionPerformed(event);
		}
	}/* end inner class SymAction() */

	void exitButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		exit_button_actionPerformed_Interaction1(event);
	}

	void exit_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.dispose();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}


	void selectAllMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		selectAllMenuItem_actionPerformed_Interaction1(event);
	}

	void selectAllMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.selectAllText();
		} catch (java.lang.Exception e) {
		
		}
	}

	void exitLogMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		exitLogMenuItem_actionPerformed_Interaction1(event);
	}

	void exitLogMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.exitApplication();
		}catch (java.lang.Exception e) {
		   ;    
		}
	}

	void cutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		cutMenuItem_actionPerformed_Interaction1(event);
	}

	void cutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.cutText();
		} catch (java.lang.Exception e) {
		    ;
		}
	}

	void copyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		copyMenuItem_actionPerformed_Interaction1(event);
	}

	void copyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.copyText();
		} catch (java.lang.Exception e) {
		
		}
	}

	void pasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		pasteMenuItem_actionPerformed_Interaction1(event);
	}

	void pasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.pasteText();
		} catch (java.lang.Exception e) {
		
		}
	}

	void popupCutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		popup_cut_menuItem_actionPerformed_Interaction1(event);
	}

	void popup_cut_menuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.cutText();
		} catch (java.lang.Exception e) {
		}
	}

	void popupCopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		popup_copy_menuItem_actionPerformed_Interaction1(event);
	}

	void popup_copy_menuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.copyText();
		}catch (java.lang.Exception e) {
		    ;
		}
	}

	void popupPasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		popup_paste_menuItem_actionPerformed_Interaction1(event);
	}

	void popup_paste_menuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.pasteText();
		} catch (java.lang.Exception e) {
		    ;
		}
	}

	void saveLogMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		saveLogMenuItem_actionPerformed_Interaction1(event);
	}

	void saveLogMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			// saveLogDialog Create and show as non-modal
			{
				saveLogDialog saveLogDialog1 = new saveLogDialog();
				saveLogDialog1.setID(this.getServiceName());
				saveLogDialog1.setLogText(this.current_log);
				saveLogDialog1.setModal(false);
				saveLogDialog1.show();
			}
		} catch (java.lang.Exception e) {
		
		}
	}

	void exportButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		export_button_actionPerformed_Interaction1(event);
	}

	void export_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			// saveLogDialog Create and show as non-modal
			{
				saveLogDialog saveLogDialog1 = new saveLogDialog();
				saveLogDialog1.setID(this.getServiceName());
				saveLogDialog1.setLogText(this.current_log);
				saveLogDialog1.setModal(false);			
				saveLogDialog1.show();
			}
		} catch (java.lang.Exception e) {
		
		}
	}

	void clearWindowMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		clearWindowMenuItem_actionPerformed_Interaction1(event);
	}

	void clearWindowMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.clearLogScreen();
		}catch (java.lang.Exception e) {
		  ;
		}
	}

	void openLogMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		openLogMenuItem_actionPerformed_Interaction1(event);
	}

	void openLogMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.openNewLog();
		} catch (java.lang.Exception e) {
		    ;
		}
	}
} /* end class LogWindow() */