/****************************************************************************/
/* file - OpenLogDialog.java                                                */
/* -------------------------                                                */
/* This file creates and displays the open dialog for the LogViewer         */
/* -------------------------                                                */
/* NIST Self-Assessment Tool                                                */
/* Author - Mark McLarnon                                                   */
/* -------------------------                                                */
/* Change Control:                                                          */
/* 02/14/02 - Added code to get a selected row from the compressed/uncmrp   */
/*            table and open the selected log.                              */
/****************************************************************************/
import java.awt.*;
import javax.swing.*;
import java.io.*;
import java.util.*;
import java.awt.event.*;
import java.util.zip.*;
import com.symantec.itools.javax.swing.models.StringTableModel;

public class OpenLogDialog extends javax.swing.JDialog {
	
	public OpenLogDialog(Frame parent) {
		super(parent);
		
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setTitle("Open Log");
		setResizable(false);
		getContentPane().setLayout(null);
		setSize(395,223);
		setVisible(false);
		getContentPane().add(JTabbedPane1);
		JTabbedPane1.setBounds(12,12,374,174);
		JTabbedPane1.add(JScrollPane1);
		JScrollPane1.setBounds(2,24,369,147);
		JScrollPane1.getViewport().add(compressed_log_table);
		compressed_log_table.setBounds(0,0,366,0);
		JTabbedPane1.add(JScrollPane2);
		JScrollPane2.setBounds(2,24,369,147);
		JScrollPane2.getViewport().add(uncompressed_log_table);
		uncompressed_log_table.setBounds(0,0,366,0);
		JTabbedPane1.setSelectedIndex(0);
		JTabbedPane1.setTitleAt(0,"Compressed Logs");
		JTabbedPane1.setTitleAt(1,"Uncompressed Logs");
		//$$ uncompressedLogsModel.move(0,207);
		//$$ compressedLogsModel.move(24,207);
		JButton1.setText("Open");
		JButton1.setMnemonic((int)'O');
		getContentPane().add(JButton1);
		JButton1.setBounds(95,192,84,26);
		JButton2.setText("Cancel");
		JButton2.setMnemonic((int)'C');
		getContentPane().add(JButton2);
		JButton2.setBounds(215,192,84,26);
		//$$ stringTableModel1.move(0,207);
		//$$ stringTableModel2.move(24,207);
		//}}
	
		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		JButton2.addActionListener(lSymAction);
		//}}
		this.uncompressed_log_table.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {                         
		        getSelectedLogToOpen(me); 
		    }      
		 });
		
        this.compressed_log_table.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {                         
		        getSelectedZippedLogToOpen(me); 
		    }      
		 });
		
	    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));
   	}
	
    public static boolean isZipped(String file_name) {
	    StringTokenizer parser = new StringTokenizer(file_name, ".");
	    boolean flag = false;
	    try {
	        if (parser != null) {
	            System.out.println(parser.nextToken());
	            if (parser.nextToken().equals("zip")) {
	                flag = true;
	                return flag;
	            }
	        }else {
	            System.out.println("could not parse: " + file_name);    
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return flag;
	}

	public void fillSaveTableZippedEntries() {
	    File log = null;
	    String base_path = "";
	    try {
	        base_path = System.getProperty("user.dir") + File.separator + this.save_directory;
	        log = new File(base_path);
	        if (log != null) {
	            String[] logs = log.list();
	            for (int i = 0; i < logs.length; i++) {
                    log = new File(logs[i]);
                    if ((isZipped(logs[i]))) {
	                    this.compressedLogsModel.addRow((log.getName() + ", " + new Date(log.lastModified()).toString()));
                        this.compressedLogsModel.fireTableChanged(null);
	                }else {

	                }
	            }
	        }else {
	            System.err.println("Cannot list saved zipped logs, save directory was null!");    
	        }
	    }catch (Exception e) {
	        System.err.println("ERROR: when completing zipped save log entry table!");	        
	        e.printStackTrace();
	    }
	}
	
	public void openLog(String log_file_name) {
        StringBuffer buffer = new StringBuffer("");
        String temp = "";
	    try {
	        File log_to_open = new File(log_file_name);
	        if (! (isZipped(log_file_name))) {
	            System.out.println("about to open un-compressed log: " + log_file_name);    
	            BufferedReader input = new BufferedReader(new FileReader(log_file_name));
	            while ((temp = input.readLine()) != null) {
	                buffer.append(temp + "\n");
	            }
	            input.close();
	            parent.log_text_pane.setText(buffer.toString());
	        }else {
	            System.out.println("about to open compressed log " + log_file_name);
                this.parent.log_text_pane.setText(this.dumpZipEntry(log_file_name));
	        }
	        this.setVisible(false);
	    }catch (Exception e) {
	        e.printStackTrace();    
	    }
	}
	
	public String dumpZipEntry(String file_name) {
	    StringBuffer buffer = new StringBuffer("");
	    try {
	        FileInputStream fis = new FileInputStream(file_name);
            BufferedInputStream bis = new BufferedInputStream(fis);
            ZipInputStream zis = new ZipInputStream(bis);
            ZipEntry ze = zis.getNextEntry();
            int size = (int) ze.getSize();
            System.out.println("name reported as " + ze.getName());
            byte[] b = new byte[size];
            
            zis.read(b, 0, size);
            buffer.append(new String(b));
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return buffer.toString();
	}
	
	public void fillSaveUnzippedEntriesTable() {
	    File log = null;
	    try {
	        log = new File(System.getProperty("user.dir") + File.separator + this.save_directory);
	        if (log != null) {
	            String[] logs = log.list();
	            if (logs.length <= 1) {
	                System.out.println("saved logs directory was listed as having no entries!");
	            }
	            for (int i = 0; i < logs.length; i++) {
                    log = new File(logs[i]);
                    if (!(isZipped(logs[i]))) {
	                    this.uncompressedLogsModel.addRow((log.getName() + ", " + new Date(log.lastModified()).toString()));
                        this.uncompressedLogsModel.fireTableChanged(null);
	                }
	            }
	        }else {
	            System.err.println("cannot list saved logs to open, save directory was null!");    
	        }
	    }catch (Exception e) {
	        System.err.println("ERROR: when completing unzipped save log entry table!");
	        e.printStackTrace();
	    }
	}	
	
	public void getSelectedLogToOpen(MouseEvent e) {
	    String row_selected = "";
        StringTokenizer parser = null;
	    try {
	        if (e.getClickCount() == 2) {
	            row_selected = this.uncompressedLogsModel.getRow(this.uncompressed_log_table.rowAtPoint(e.getPoint()));
                parser = new StringTokenizer(row_selected, ",");
                this.openLog(System.getProperty("user.dir") + File.separator + this.save_directory + File.separator + parser.nextToken());                
	        }
	    }catch (Exception ex) {
	        ex.printStackTrace();
	    }
	}
	
	public void getSelectedZippedLogToOpen(MouseEvent e) {
	    String row_selected = "";
        StringTokenizer parser = null;
	    try {
	        if (e.getClickCount() == 2) {
	            row_selected = this.compressedLogsModel.getRow(this.compressed_log_table.rowAtPoint(e.getPoint()));
                parser = new StringTokenizer(row_selected, ",");
                this.openLog(System.getProperty("user.dir") + File.separator + this.save_directory + File.separator + parser.nextToken());                
	        }
	    }catch (Exception ex) {
	        ex.printStackTrace();
	    }
	}
	
	public void setTables() {
	    try {
	        this.uncompressedLogsModel.setColumnHeaders("Log, Last Edit Date");
	        this.compressedLogsModel.setColumnHeaders("Log, Last Edit Date");
	        
	        this.compressed_log_table.setModel(this.compressedLogsModel);
            this.uncompressed_log_table.setModel(this.uncompressedLogsModel);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	public OpenLogDialog() {
		this((Frame)null);
	}

	public OpenLogDialog(String sTitle) {
		this();
		setTitle(sTitle);
	}

	static public void main(String args[]) {
		(new OpenLogDialog()).setVisible(true);
	}

	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JTable compressed_log_table = new javax.swing.JTable();
	javax.swing.JScrollPane JScrollPane2 = new javax.swing.JScrollPane();
	javax.swing.JTable uncompressed_log_table = new javax.swing.JTable();
	com.symantec.itools.javax.swing.models.StringTableModel uncompressedLogsModel = new com.symantec.itools.javax.swing.models.StringTableModel();
	com.symantec.itools.javax.swing.models.StringTableModel compressedLogsModel = new com.symantec.itools.javax.swing.models.StringTableModel();
	javax.swing.JButton JButton1 = new javax.swing.JButton();
	javax.swing.JButton JButton2 = new javax.swing.JButton();
	//}}
    String save_directory = "";
    LogWindow parent = null;
    
    private String getSaveDirectory() {
        return this.save_directory;    
    }
    
    public void setSaveDirectory(String new_directory) {
        try {
            this.save_directory = new_directory;    
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	class SymAction implements java.awt.event.ActionListener {
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == JButton2)
				JButton2_actionPerformed(event);
		}
	}/* end inner class SymAction() */

	void JButton2_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		JButton2_actionPerformed_Interaction1(event);
	}

	void JButton2_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.setVisible(false);
		} catch (java.lang.Exception e) {
		    ;
		}
	}
}/* end class OpenLogDialog() */