/********************************************************************************/
/* file - ProgressDialog.java                                                   */
/* --------------------------                                                   */
/* This class is the progress bar and message dialog for any operation that will*/
/* take more than a few seconds such as rebuilding the question map or computing*/
/* critical elements for each section.                                          */
/* --------------------------                                                   */
/* NIST Self-Assessment Tool                                                    */
/* Author - Mark McLarnon                                                       */
/********************************************************************************/
import java.awt.*;
import javax.swing.*;
import com.symantec.itools.javax.swing.JWrappingLabel;
import com.symantec.itools.javax.swing.borders.EtchedBorder;

public class ProgressDialog extends javax.swing.JDialog {
    
	public ProgressDialog(Frame parent) {
		super(parent);
		
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setTitle("Busy...");
		setResizable(false);
		getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.X_AXIS));
		setSize(430,156);
		setVisible(false);
		JPanel1.setBorder(etchedBorder1);
		JPanel1.setLayout(null);
		getContentPane().add(JPanel1);
		try {
			status_busy_message.setText("Please hold...");
		}
		catch(java.beans.PropertyVetoException e) { }
		JPanel1.add(status_busy_message);
		status_busy_message.setFont(new Font("SansSerif", Font.PLAIN, 12));
		status_busy_message.setBounds(12,16,408,68);
		progress_bar.setStringPainted(true);
		JPanel1.add(progress_bar);
		progress_bar.setBounds(12,96,408,24);
		//$$ etchedBorder1.move(0,157);
		//}}
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));
        this.resetProgress();
	}

	public ProgressDialog()
	{
		this((Frame)null);
	}

	public ProgressDialog(String sTitle)
	{
		this();
		setTitle(sTitle);
	}
	
	public void setStatusBusyMessage(String msg) {
	    try {
	        this.status_busy_message.setText(msg);
	        this.redraw();
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void clear() {
        try {
            this.resetProgress();
            this.setStatusBusyMessage("");
            this.redraw();
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
	
	public void resetProgress() {
	    try {
	        this.progress_bar.setValue(0);
	    }catch (Exception e) {
            e.printStackTrace();
        }
	}

    public void redraw() {
        try {
            Graphics a = this.status_busy_message.getGraphics();
            this.status_busy_message.update(a);
            Graphics b = this.progress_bar.getGraphics();
            this.progress_bar.update(b);
            Graphics c = JPanel1.getGraphics();
            JPanel1.update(c);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public synchronized void setNormalizedProgress(int value) {
        float progress = (float) value / this.getProgressMax();
        int prog = (int) (progress * 100);
        this.progress_bar.setValue(prog);

        this.redraw();
    }
    
    public void setProgressMax(int max) {
        this.progress_max = max;
    }
    
    public int getProgressMax() {
        return this.progress_max;    
    }

	public void addNotify()
	{
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	com.symantec.itools.javax.swing.JWrappingLabel status_busy_message = new com.symantec.itools.javax.swing.JWrappingLabel();
	javax.swing.JProgressBar progress_bar = new javax.swing.JProgressBar();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	//}}
    int progress_max = 0;
} /* end class ProgressDialog() */