/****************************************************************************/
/* file - AdminLoginDialog.java                                             */
/* -----------------------                                                  */
/* This field is the login screen for the SAT Client. It is responsible for */
/* obtaining the Name and email address of hte primary assessor. Any time a */
/* new assessment is created after the primary user is logged in, they are  */
/* always added to the list of assessors as the primary assessor.           */
/* -----------------------                                                  */
/* Author - Mark McLarnon                                                   */
/* -----------------------                                                  */
/* National Institute of Standards and Technology                           */
/* NIST Security Self-Assessment Tool                                       */
/****************************************************************************/
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.symantec.itools.javax.swing.borders.BevelBorder;

public class AdminLoginDialog extends javax.swing.JDialog {
	
	public AdminLoginDialog(Frame parent) {
		super(parent);
		
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setTitle("NIST ASSET Manager Login 1.04");
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.Y_AXIS));
		setSize(320,197);
		setVisible(false);
		bevelBorder1.setBevelType(javax.swing.border.BevelBorder.LOWERED);
		//$$ bevelBorder1.move(0,222);
		JPanel3.setBorder(bevelBorder1);
		JPanel3.setLayout(null);
		getContentPane().add(JPanel3);
		JPanel3.setBackground(new java.awt.Color(204,204,204));
		JLabel1.setText("Name*:");
		JPanel3.add(JLabel1);
		JLabel1.setForeground(java.awt.Color.black);
		JLabel1.setBounds(12,30,108,23);
		JLabel2.setText("EMail Address:");
		JPanel3.add(JLabel2);
		JLabel2.setForeground(java.awt.Color.black);
		JLabel2.setBounds(12,80,108,23);
		JPanel3.add(user_name);
		user_name.setBounds(120,30,192,23);
		JPanel3.add(email_addr);
		email_addr.setBounds(120,80,192,23);
		JButton1.setText("Continue");
		JButton1.setActionCommand("Continue...");
		JButton1.setMnemonic((int)'C');
		JPanel3.add(JButton1);
		JButton1.setBounds(48,144,96,28);
		JButton2.setText("Cancel");
		JButton2.setActionCommand("Cancel");
		JButton2.setMnemonic((int)'A');
		JPanel3.add(JButton2);
		JButton2.setBounds(192,144,96,28);
		error_msg.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		JPanel3.add(error_msg);
		error_msg.setForeground(java.awt.Color.red);
		error_msg.setBounds(22,0,288,28);
		error_msg.setVisible(false);
		help_link.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		help_link.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		help_link.setText("Help");
		JPanel3.add(help_link);
		help_link.setForeground(java.awt.Color.blue);
		help_link.setFont(new Font("Dialog", Font.PLAIN, 12));
		help_link.setBounds(254,181,60,12);
		JLabel3.setText("*Your user name is case sensitive");
		JPanel3.add(JLabel3);
		JLabel3.setForeground(java.awt.Color.black);
		JLabel3.setFont(new Font("Dialog", Font.BOLD, 11));
		JLabel3.setBounds(13,110,288,26);
		//}}
	
		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		JButton1.addActionListener(lSymAction);
		JButton2.addActionListener(lSymAction);
		SymMouse aSymMouse = new SymMouse();
		help_link.addMouseListener(aSymMouse);
		SymKey aSymKey = new SymKey();
		email_addr.addKeyListener(aSymKey);
		JButton1.addKeyListener(aSymKey);
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));
	}

    private void openParentHelp() {
        this.parent.openManagerHelp();    
    }

	public AdminLoginDialog()
	{
		this((Frame)null);
	}

    public AdminLoginDialog(SATAdmin client_parent) {
       this(); 
       try {            
            this.parent = client_parent;    
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public void resetFields() {
        try {
            this.user_name.setText("");
            this.email_addr.setText("");
            this.user_name.requestDefaultFocus();
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	public AdminLoginDialog(String sTitle) {
		this();
		setTitle(sTitle);
	}
	
	public void proceed() {
	    try {
            this.setVisible(false);
            this.parent.setPrimaryAssessor(Assessor.createNewPrimaryAssessor(this.user_name.getText(), this.email_addr.getText()));
            this.parent.setVisible(true);
            this.parent.buildMenu();
	        this.dispose();	    
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void disposeAllResources() {
	    try {
	        this.parent.dispose();
	        System.exit(0);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	
	}

	public void addNotify()
	{
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}
	
	private void proceedKeyEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.proceed();
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}	

    public boolean enforceLogin() {
        boolean flag = true;
        try {
            if ((this.user_name == null) || (this.user_name.getText().length() == 0)) {
                this.setErrorMessage("You must enter a user name!");
                flag = false;
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
    }
    
    public void setErrorMessage(String msg) {
        try {

            if (msg != null) {
                this.error_msg.setText(msg);
                this.error_msg.setVisible(true);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	com.symantec.itools.javax.swing.borders.BevelBorder bevelBorder1 = new com.symantec.itools.javax.swing.borders.BevelBorder();
	javax.swing.JPanel JPanel3 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel1 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JTextField user_name = new javax.swing.JTextField();
	javax.swing.JTextField email_addr = new javax.swing.JTextField();
	javax.swing.JButton JButton1 = new javax.swing.JButton();
	javax.swing.JButton JButton2 = new javax.swing.JButton();
	javax.swing.JLabel error_msg = new javax.swing.JLabel();
	javax.swing.JLabel help_link = new javax.swing.JLabel();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	//}}
    SATAdmin parent = null;
    Assessor primary = null;
    AdminLoginDialog login = null;
    
	class SymAction implements java.awt.event.ActionListener {
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == JButton1)
				JButton1_actionPerformed(event);
			else if (object == JButton2)
				JButton2_actionPerformed(event);
		}
	}

	void JButton1_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		boolean flag = JButton1_actionPerformed_Interaction2(event);
		if (flag) {
		    JButton1_actionPerformed_Interaction1(event);			 
		}
		
	}

	void JButton1_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.proceed();
		} catch (java.lang.Exception e) {
		}
	}

	void JButton2_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		JButton2_actionPerformed_Interaction1(event);
	}

	void JButton2_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.disposeAllResources();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	boolean JButton1_actionPerformed_Interaction2(java.awt.event.ActionEvent event)
	{	    
		boolean flag = false;
		try {
			flag = this.enforceLogin();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
		return flag;
	}

	public void paintLabel(JLabel checkbox) {
        try {
            Font f = new Font("Dialog", Font.PLAIN, 12);
			checkbox.setForeground(Color.red);
			checkbox.setFont(f);
			this.setCursor(new Cursor(Cursor.HAND_CURSOR));
			checkbox.repaint();
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
	
	public void unpaintLabel(JLabel box) {
	    try {
	        box.setFont(new Font("Dialog", Font.PLAIN, 12));
			box.setForeground(Color.blue);
		    this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
			box.repaint();
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}


	class SymMouse extends java.awt.event.MouseAdapter
	{
		public void mouseClicked(java.awt.event.MouseEvent event)
		{
			Object object = event.getSource();
			if (object == help_link)
				helpLink_mouseClicked(event);
		}

		public void mouseExited(java.awt.event.MouseEvent event)
		{
			Object object = event.getSource();
			if (object == help_link)
				helpLink_mouseExited(event);
		}

		public void mouseEntered(java.awt.event.MouseEvent event)
		{
			Object object = event.getSource();
			if (object == help_link)
				helpLink_mouseEntered(event);
		}
	}

	void helpLink_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		help_link_mouseEntered_Interaction1(event);
	}

	void help_link_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(help_link);
		} catch (java.lang.Exception e) {
		}
	}

	void helpLink_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		help_link_mouseExited_Interaction1(event);
	}

	void help_link_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(help_link);
		} catch (java.lang.Exception e) {
		}
	}

	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == JButton1)
				JButton1_keyTyped(event);
			else if (object == email_addr)
				emailAddr_keyTyped(event);
		}

		public void keyPressed(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == email_addr)
				emailAddr_keyPressed(event);
		}
	}

	void emailAddr_keyPressed(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
	}

	void JButton1_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		JButton1_keyTyped_Interaction1(event);
	}

	void JButton1_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void emailAddr_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		email_addr_keyTyped_Interaction1(event);
	}

	void email_addr_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void helpLink_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		help_link_mouseClicked_Interaction1(event);
	}

	void help_link_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.openParentHelp();
		} catch (java.lang.Exception e) {
		}
	}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == AdminLoginDialog.this)
				AdminLoginDialog_windowClosing(event);
		}
	}

    // This code will close the ASSET Manager application when the close button
    // is clicked on the ASSET Manager login dialog. Added 5/01/02
	void AdminLoginDialog_windowClosing(java.awt.event.WindowEvent event)
	{
		// to do: code goes here.
		System.exit(0);
	}
} /* end class AdminLoginDialog() */