/********************************************************************************/
/* file - AssessmentFrame.java                                                  */
/* ---------------------------                                                  */
/* This class implements the functionality to import/compare/analyze assessments*/
/* It uses the JFileChooser and XML to import assessments and JTables to do     */
/* comparisons based on certain rows that the user will choose n                */
/* ---------------------------                                                  */
/* NIST Self-Assessment Tool                                                    */
/* Author - Mark McLarnon                                                       */
/* ---------------------------                                                  */
/* References:                                                                  */
/* http://www.xml-zone.com/articles/pm020101/pm020101-1.asp                     */
/* http://www.xml.com/1999/09/conformance/reports/report-xml4j-val.html         */
/* http://developer.java.sun.com/developer/TechTips/2000/tt0627.html            */
/* http://www7.software.ibm.com/vad.nsf/Data/Document2329                       */
/* http://www2.gol.com/users/tame/swing/examples/JTableExamples5.html           */
/* http://www.esus.com/javaindex/j2se/jdk1.2/javaxswing/editableatomiccontrols/ */
/* jtable/jtablesortrows.html                                                   */
/* ---------------------------                                                  */
/* Change Control:                                                              */
/* 03/11/02 - Changed importing of assessments so that when determining the ass */
/*            name, the XML parser looks for assessmentname instead of 'name' as*/
/*            it used to.                                                       */
/* 05/08/02 - Added code to maximize the window when user deiconfies the frame  */
/* 05/09/02 - Added action handlers for toolbar buttons to handle when enter    */
/*            key is pressed.                                                   */
/*          - Removed ability to maximize the Internal Frame, this played havoc */
/*            with the search parameters panel component sizes and spacing. Now */
/*            manually capturing window resize events (like with the program    */
/*            starts unmaximized.)                                              */
/*          - Disabled search text box when executing date search. And enabled  */
/*            text box again when reset button is pressed.                      */
/* 05/21/02 - Added enter key action handler for search and reset buttons.      */
/********************************************************************************/
import java.util.Date;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.table.*;
import java.util.*;
import java.sql.*;
import java.io.*;
import org.xml.sax.*;
import org.apache.xerces.dom.*;
import org.apache.xerces.parsers.*;
import org.w3c.dom.*;
import com.symantec.itools.javax.swing.models.StringTableModel;
import com.symantec.itools.javax.swing.JToolBarSeparator;
import com.symantec.itools.javax.swing.icons.ImageIcon;
import com.symantec.itools.javax.swing.JWrappingLabel;
import com.symantec.itools.javax.swing.borders.EmptyBorder;
import com.symantec.itools.javax.swing.models.StringComboBoxModel;
import com.symantec.itools.javax.swing.borders.EtchedBorder;
    
public class AssessmentFrame extends javax.swing.JInternalFrame {
    
	public AssessmentFrame() {
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setIconifiable(true);
		setTitle("Search Assessments");
		setAlignmentY(0.0F);
		setAlignmentX(0.0F);
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BorderLayout(0,0));
		getContentPane().setBackground(java.awt.Color.lightGray);
		setSize(618,508);
		setVisible(false);
		JPanel6.setBorder(etchedBorder1);
		JPanel6.setLayout(new GridLayout(1,1,0,0));
		getContentPane().add(BorderLayout.NORTH, JPanel6);
		JToolBar1.setAlignmentY(0.478261F);
		JPanel6.add(JToolBar1);
		newAssessmentButton.setNextFocusableComponent(import_assessment_button);
		newAssessmentButton.setDefaultCapable(false);
		newAssessmentButton.setToolTipText("<html>Start new assessment</html>");
		newAssessmentButton.setMnemonic((int)'N');
		JToolBar1.add(newAssessmentButton);
		import_assessment_button.setNextFocusableComponent(viewButton);
		import_assessment_button.setDefaultCapable(false);
		import_assessment_button.setToolTipText("<html>Import new assessment information</html>");
		import_assessment_button.setMnemonic((int)'I');
		JToolBar1.add(import_assessment_button);
		viewButton.setNextFocusableComponent(deleteButton);
		viewButton.setDefaultCapable(false);
		viewButton.setToolTipText("<html>Open selected assessment</html>");
		viewButton.setMnemonic((int)'V');
		JToolBar1.add(viewButton);
		deleteButton.setNextFocusableComponent(refreshButton);
		deleteButton.setDefaultCapable(false);
		deleteButton.setToolTipText("<html>Delete the selected assessment</html>");
		deleteButton.setMnemonic((int)'D');
		JToolBar1.add(deleteButton);
		JToolBar1.add(JToolBarSeparator2);
		refreshButton.setNextFocusableComponent(toggleButton);
		refreshButton.setDefaultCapable(false);
		refreshButton.setToolTipText("<html>Refresh original assessment data</html>");
		refreshButton.setMnemonic((int)'R');
		JToolBar1.add(refreshButton);
		toggleButton.setNextFocusableComponent(exportButton);
		toggleButton.setDefaultCapable(false);
		toggleButton.setToolTipText("<html>Select all results</html>");
		toggleButton.setMnemonic((int)'T');
		JToolBar1.add(toggleButton);
		exportButton.setNextFocusableComponent(open_reports_button);
		exportButton.setDefaultCapable(false);
		exportButton.setToolTipText("<html>Save/export results to your hard drive</html>");
		exportButton.setMnemonic((int)'E');
		JToolBar1.add(exportButton);
		open_reports_button.setNextFocusableComponent(helpButton);
		open_reports_button.setDefaultCapable(false);
		open_reports_button.setToolTipText("<html>Opens reporting only on those assessments you set as active</html>");
		open_reports_button.setMnemonic((int)'G');
		JToolBar1.add(open_reports_button);
		JToolBar1.add(JToolBarSeparator1);
		helpButton.setDefaultCapable(false);
		helpButton.setToolTipText("<html>Open help files</html>");
		helpButton.setMnemonic((int)'H');
		JToolBar1.add(helpButton);
		assessment_parent_panel.setLayout(new BorderLayout(0,0));
		getContentPane().add(BorderLayout.CENTER, assessment_parent_panel);
		assessment_parent_panel.add(BorderLayout.CENTER, JTabbedPane1);
		search_parameters_parent_panel.setBorder(etchedBorder1);
		search_parameters_parent_panel.setLayout(new BorderLayout(0,0));
		JTabbedPane1.add(search_parameters_parent_panel);
		search_parameters_parent_panel.setBounds(2,24,613,450);
		search_parameters_parent_panel.setVisible(false);
		JPanel4.setBorder(search_label_border);
		JPanel4.setLayout(new BoxLayout(JPanel4,BoxLayout.X_AXIS));
		search_parameters_parent_panel.add(BorderLayout.NORTH, JPanel4);
		JTextPane1.setText("Enter your search criteria (use a * and the \"All fields\" choice in the \"Choose Field\" box to return all records):");
		JPanel4.add(JTextPane1);
		JTextPane1.setBackground(new java.awt.Color(204,204,204));
		search_query_and_parameters_panel.setBorder(criteriaBorder);
		search_query_and_parameters_panel.setLayout(new BorderLayout(0,15));
		search_parameters_parent_panel.add(BorderLayout.CENTER, search_query_and_parameters_panel);
		JPanel19.setAlignmentY(0.473684F);
		JPanel19.setLayout(new BoxLayout(JPanel19,BoxLayout.X_AXIS));
		search_query_and_parameters_panel.add(BorderLayout.NORTH, JPanel19);
		searchQuery.setToolTipText("<html>Enter the keywords you wish to search the assessment database<br>with in this field</html>");
		JPanel19.add(searchQuery);
		search_parameters_panel.setLayout(new GridLayout(2,1,0,0));
		search_query_and_parameters_panel.add(BorderLayout.CENTER, search_parameters_panel);
		search_parameters_panel.add(JTabbedPane2);
		JPanel1.setAlignmentY(0.497382F);
		JPanel1.setBorder(etchedBorder1);
		JPanel1.setLayout(new BoxLayout(JPanel1,BoxLayout.X_AXIS));
		JTabbedPane2.add(JPanel1);
		JPanel1.setBounds(2,24,514,128);
		JPanel1.setVisible(false);
		basic_pane.setBorder(search_params_border);
		basic_pane.setLayout(new GridLayout(4,3,10,0));
		JPanel1.add(basic_pane);
		JLabel3.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JLabel3.setText("Choose Field:");
		basic_pane.add(JLabel3);
		JLabel3.setForeground(java.awt.Color.black);
		tableFieldBox.setModel(resultsFieldsModel);
		basic_pane.add(tableFieldBox);
		basic_pane.add(JLabel5);
		JLabel2.setText("Search by start date:");
		basic_pane.add(JLabel2);
		JLabel2.setForeground(java.awt.Color.black);
		JPanel11.setLayout(new BorderLayout(0,0));
		basic_pane.add(JPanel11);
		JPanel11.add(BorderLayout.CENTER, first_date);
		JPanel21.setLayout(new FlowLayout(FlowLayout.CENTER,5,0));
		basic_pane.add(JPanel21);
		basic_pane.add(JLabel6);
		JPanel20.setLayout(new FlowLayout(FlowLayout.CENTER,5,0));
		basic_pane.add(JPanel20);
		beforeRadioButton.setText("Before");
		beforeRadioButton.setActionCommand("Before");
		beforeRadioButton.setSelected(true);
		JPanel20.add(beforeRadioButton);
		afterRadioButton.setText("After");
		afterRadioButton.setActionCommand("After");
		JPanel20.add(afterRadioButton);
		basic_pane.add(JLabel7);
		JLabel4.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
		JLabel4.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JLabel4.setText("Limit Results Returned:");
		JLabel4.setAlignmentX(0.5F);
		basic_pane.add(JLabel4);
		JLabel4.setForeground(java.awt.Color.black);
		limit_results_field.setText("Unlimited");
		limit_results_field.setToolTipText("<html>Determines the limit of results you want to return from your<br>search</html>");
		basic_pane.add(limit_results_field);
		basic_pane.add(JLabel8);
		JTabbedPane2.setSelectedIndex(0);
		JTabbedPane2.setSelectedComponent(JPanel1);
		JTabbedPane2.setTitleAt(0,"Parameters");
		JPanel27.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		search_parameters_panel.add(JPanel27);
		JPanel7.setLayout(new BorderLayout(0,0));
		search_parameters_parent_panel.add(BorderLayout.SOUTH, JPanel7);
		JPanel14.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel7.add(BorderLayout.SOUTH, JPanel14);
		search_button.setText("Search");
		search_button.setActionCommand("Search");
		search_button.setToolTipText("<html>Submit a search query to the database</html>");
		search_button.setMnemonic((int)'S');
		JPanel14.add(search_button);
		reset_button.setText("Reset");
		reset_button.setActionCommand("Reset");
		reset_button.setToolTipText("<html>Reset all fields</html>");
		reset_button.setMnemonic((int)'R');
		JPanel14.add(reset_button);
		JPanel3.setLayout(new BorderLayout(0,0));
		JTabbedPane1.add(JPanel3);
		JPanel3.setBounds(2,24,613,450);
		JPanel3.setVisible(false);
		JPanel5.setLayout(new BoxLayout(JPanel5,BoxLayout.X_AXIS));
		JPanel3.add(BorderLayout.CENTER, JPanel5);
		results_scroll_pane.setOpaque(true);
		results_scroll_pane.setToolTipText("<html>Displays summary of all assessments you are examining</html>");
		JPanel5.add(results_scroll_pane);
		results_table.setRowHeight(65);
		results_scroll_pane.getViewport().add(results_table);
		results_table.setBounds(0,0,610,0);
		JTabbedPane1.setSelectedIndex(1);
		JTabbedPane1.setSelectedComponent(JPanel3);
		JTabbedPane1.setTitleAt(0,"Search Assessments");
		JTabbedPane1.setTitleAt(1,"Results");
		try {
			imageIcon1.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/refresh.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon1.move(0,504);
		//$$ etchedBorder1.move(0,468);
		try {
			deleteAssessmentIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/delete.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ deleteAssessmentIcon.move(120,460);
		try {
			newIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/new.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ newIcon.move(360,460);
		try {
			imageIcon4.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/print.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon4.move(72,460);
		try {
			imageIcon2.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/checkbox.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon2.move(24,460);
		imageIcon3.setImageObserver(viewButton);
		try {
			imageIcon3.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/examine.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon3.move(48,460);
		try {
			helpIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/about.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ helpIcon.move(72,460);
		try {
			importIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/open.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ importIcon.move(96,460);
		{
			String[] tempString = new String[4];
			tempString[0] = "Choose type";
			tempString[1] = "Before";
			tempString[2] = "After";
			tempString[3] = "Between";
			date_type_model.setItems(tempString);
		}
		//$$ date_type_model.move(360,460);
		//$$ assessmentTablePopup.move(120,460);
		asmntShowInfoDialog.setText("Show Info");
		asmntShowInfoDialog.setActionCommand("Show Info");
		assessmentTablePopup.add(asmntShowInfoDialog);
		asmntSaveResultsMenuItem.setText("Export Results");
		asmntSaveResultsMenuItem.setActionCommand("Print Results");
		assessmentTablePopup.add(asmntSaveResultsMenuItem);
		assessmentTablePopup.add(JSeparator1);
		asmntDeleteMenuItem.setText("Delete assessment");
		asmntDeleteMenuItem.setActionCommand("Delete assessment");
		assessmentTablePopup.add(asmntDeleteMenuItem);
		try {
			saveIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/save.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ saveIcon.move(168,460);
		criteriaBorder.setInsets(new java.awt.Insets(0,45,0,45));
		//$$ criteriaBorder.move(192,460);
		search_label_border.setInsets(new java.awt.Insets(30,30,0,0));
		//$$ search_label_border.move(216,460);
		{
			String[] tempString = new String[5];
			tempString[0] = "All fields";
			tempString[1] = "System Name";
			tempString[2] = "System Number";
			tempString[3] = "Location";
			tempString[4] = "Primary Assessor";
			resultsFieldsModel.setItems(tempString);
		}
		//$$ resultsFieldsModel.move(240,460);
		{
			String[] tempString = new String[3];
			tempString[0] = "Leave alone";
			tempString[1] = "Less Than";
			tempString[2] = "Greater Than";
			result_limit_choose_type.setItems(tempString);
		}
		//$$ result_limit_choose_type.move(288,460);
		search_params_border.setInsets(new java.awt.Insets(25,10,25,10));
		//$$ search_params_border.move(312,460);
		try {
			reportIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/report.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ reportIcon.move(336,460);
		import_assessment_button.setIcon(importIcon);
		tableFieldBox.setSelectedIndex(0);
		toggleButton.setIcon(imageIcon2);
		refreshButton.setIcon(imageIcon1);
		viewButton.setIcon(imageIcon3);
		helpButton.setIcon(helpIcon);
		open_reports_button.setIcon(reportIcon);
		newAssessmentButton.setIcon(newIcon);
		exportButton.setIcon(saveIcon);
		deleteButton.setIcon(deleteAssessmentIcon);
		//}}
		editor.setHorizontalAlignment(JLabel.CENTER);
	
		//{{REGISTER_LISTENERS
		SymInternalFrame lSymInternalFrame = new SymInternalFrame();
		this.addInternalFrameListener(lSymInternalFrame);
		SymAction lSymAction = new SymAction();
		SymMouse aSymMouse = new SymMouse();
		refreshButton.addActionListener(lSymAction);
		viewButton.addActionListener(lSymAction);
		toggleButton.addActionListener(lSymAction);
		import_assessment_button.addActionListener(lSymAction);
		this.results_table.addMouseListener(aSymMouse);
		exportButton.addActionListener(lSymAction);
		reset_button.addActionListener(lSymAction);
		search_button.addActionListener(lSymAction);
		limit_results_field.addMouseListener(aSymMouse);
		asmntShowInfoDialog.addActionListener(lSymAction);
		open_reports_button.addActionListener(lSymAction);
		deleteButton.addActionListener(lSymAction);
		beforeRadioButton.addActionListener(lSymAction);
		afterRadioButton.addActionListener(lSymAction);
		newAssessmentButton.addActionListener(lSymAction);
		asmntSaveResultsMenuItem.addActionListener(lSymAction);
		asmntDeleteMenuItem.addActionListener(lSymAction);
		helpButton.addActionListener(lSymAction);
		SymKey aSymKey = new SymKey();
		newAssessmentButton.addKeyListener(aSymKey);
		viewButton.addKeyListener(aSymKey);
		import_assessment_button.addKeyListener(aSymKey);
		deleteButton.addKeyListener(aSymKey);
		SymComponent aSymComponent = new SymComponent();
		this.addComponentListener(aSymComponent);
		reset_button.addKeyListener(aSymKey);
		SymMouseMotion aSymMouseMotion = new SymMouseMotion();
		this.addMouseMotionListener(aSymMouseMotion);
		search_button.addKeyListener(aSymKey);
		//}}	
		this.choose_first_date = HTMLLabel.createNewHTMLLabel("Choose date");
		this.choose_first_date.addMouseListener(aSymMouse);
		this.JPanel21.add(this.choose_first_date);
		
		this.prgMonitor = new ProgressDialog();
		this.setTableColumnHeaders();
		
		
		this.prgMonitor.setProgressMax(this.assessment_count);
								
		this.fileChooser.setDialogTitle("Choose XML Assessment Results File");
		this.fileChooser.setCurrentDirectory((new File(System.getProperty("user.dir"))).getParentFile());
		this.fileChooser.addChoosableFileFilter(new XMLFilter());
		
		this.JTabbedPane1.setSelectedIndex(0);
		this.setConversionTables();
		this.prepareResultsTable();
	}/* end default constructor AssessmentFrame() */
    
    public String getFullPath(String local_path) {
        StringBuffer file_name = new StringBuffer("");
        try {
            file_name.append((symantec.itools.net.RelativeURL.getURL(local_path)).toString());
        }catch (Exception e) {
            e.printStackTrace();
        }
        return file_name.toString();
    }	
    
    private void execute(String cmd) {
        try {
             Runtime subsystem = Runtime.getRuntime();
             if (this.checkDefaultBrowserSet()) {
                 subsystem.exec(cmd);
             }else {
                ChooseBrowserWizard wiz = ChooseBrowserWizard.spawnNewChooseBrowserWizard(this.parent, this.parent.getPropertyManager());                
             }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public boolean checkDefaultBrowserSet() {
        boolean flag = true;
        try {
            if (this.parent.getPropertyManager().getProperty("sat.help.defaultbrowser") == null) {
                flag = false;
            }
            
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
    }    
	
    public void openAssessmentHelp() {
        this.execute(this.parent.getPropertyManager().getProperty("sat.help.defaultbrowser") + " " + this.getFullPath(this.parent.getPropertyManager().getProperty("sat.manager.help.assessmentdocument")));        
    }	
	
	private void openNewAssessment() {
	    try {
	        this.parent.startNewAssessment();    
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// This method is designed to open an assessment that is returned in a search of the 
	// database and the user has clicked on the select checkbox. It uses the asset.jar 
	// component and AssessmentWindow class.
	// ---------------
	// Change Control:
	// 05/19/02 - Added code to warn the user if they did not select any assessments with the 
	//            checkboxes.
	private void openOldAssessment() {
	    boolean  assessment_selected = false;
	    try {
	        if (this.resultsModel_clone == null) {
	            for (int i = 0; i < (this.resultsModel.getDataVector()).size(); i++) {
                    Boolean cmp = (Boolean) this.resultsModel.getValueAt(i, 5);
                    if (cmp.booleanValue()) {
                        assessment_selected = true;
                        this.parent.setStatusMsg("Opening selected assessment now, please hold.");
    	                this.parent.openOldAssessment((String) this.results_cache.elementAt(i), (String) ((Vector) this.resultsModel.getDataVector().elementAt(0)).elementAt(0));                    
                    }
	            }                    
	        }else {
	            for (int i = 0; i < (this.resultsModel_clone.getDataVector()).size(); i++) {
                    Boolean cmp = (Boolean) this.resultsModel_clone.getValueAt(i, 5);
                    if (cmp.booleanValue()) {
                        assessment_selected = true;
                        this.parent.setStatusMsg("Opening selected assessment now, please hold.");
    	                this.parent.openOldAssessment((String) this.results_cache.elementAt(i), (String) ((Vector) this.resultsModel.getDataVector().elementAt(0)).elementAt(0));                    
                    }
	            }	            
	        }
	        if (assessment_selected == false) {
	            this.parent.displayErrorDialog("You must select at least one assessment to open!");
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method openOldAssessment() */
	
	void setColumnWidths() {
	    try {
	       this.results_table.getColumn("Select").setWidth(30);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// This method is responsible for opening the reporting frame from within the 
	// AssessmentWindow class. It will call the database stored procedure
	// set_active_assessments in order to set the active field of each record in the 
	// relevant data tables.
	// ---------------
	// Change Control:
	// 05/09/02 - Added code to set a boolean state variable that determines if any
	//            assessments have been selected with the checkbox column in the search
	//            results table. This way if no checkboxes are selected the state variable
	//            reads false and the stored procedure is not called.
	//          - Added call to getOperationMode() before data model is examined for
	//            selected assessments. This is done so that if a user presses the 
	//            reporting button before they submit a search the reporting window 
	//            will open without error.
	public void openReportingFrame() {
	    StringBuffer assessment_ids = new StringBuffer("");
	    StringBuffer component_numbers = new StringBuffer("");
	    Connection conn = this.parent.connectionGenerator();
        CallableStatement update_query = null;
        StringBuffer sql = null;
        Vector selected_ids = new Vector();
        Vector selected_num = new Vector();
        int subset_count = 0;
	    try {
	        this.parent.setStatusModeMsg("RPRT");
	        this.parent.setStatusMsg("Opening reporting frame now.");
	        assessment_ids.append("(");
	        component_numbers.append("(");
	        if (this.getOperationMode()) {
	            if (this.resultsModel_clone == null) {
	                for (int i = 0; i < (this.resultsModel.getDataVector()).size(); i++) {
                        Boolean cmp = (Boolean) this.resultsModel.getValueAt(i, 5);
                        if (cmp.booleanValue()) {
                            this.setSubSetSelected(true);
                            subset_count++;
                            selected_ids.addElement((String) this.results_cache.elementAt(i));
                            selected_num.addElement((String) this.resultsModel.getValueAt(i, 1));
                        }
	                }
	            }else {
	                for (int i = 0; i < (this.resultsModel_clone.getDataVector()).size(); i++) {
                        Boolean cmp = (Boolean) this.resultsModel_clone.getValueAt(i, 5);
                        if (cmp.booleanValue()) {
                            this.setSubSetSelected(true);
                            subset_count++;
                            selected_ids.addElement((String) this.results_cache.elementAt(i));
                            selected_num.addElement((String) this.resultsModel_clone.getValueAt(i, 1));
                        }
	                }	                
	            }
	            
                if (subset_count == 0) {
                    this.setSubSetSelected(false);
                    if (this.resultsModel_clone != null) {
                        this.setSubSetSelected(true);
                        {
                            this.parent.displayStatusDialog("Because you previously refreshed your search results data set, and\nhave not selected any subset now to report on, all assessments\nshown will be set as active for reporting. To reset the search\nwindow to its default state press the RESET button or execute\nanother search.");    
                        }
                        for (int i = 0; i < (this.resultsModel_clone.getDataVector()).size(); i++) {
                            this.resultsModel_clone.setValueAt(new Boolean(true), i, 5);
                            this.setSubSetSelected(true);
                            selected_ids.addElement((String) this.results_cache.elementAt(i));
                            selected_num.addElement((String) this.resultsModel_clone.getValueAt(i, 1));
	                    }
                    }
                }	            
	            
	            for (int i = 0; i < selected_ids.size(); i++) {
	                if (i > 0) {
	                    assessment_ids.append(", ");
	                    component_numbers.append(", ");	                    
	                }
	                assessment_ids.append("'" + (String) selected_ids.elementAt(i) + "'");
                    component_numbers.append("'" + (String) selected_num.elementAt(i) + "'");	                
	            }
	        }
	        assessment_ids.append(")");
	        component_numbers.append(")");
            
            if (this.getSubsetSelected()) {
                this.internal_setCursor("wait");
                this.parent.setStatusModeMsg("BUSY");
                this.parent.setStatusMsg("Creating assessment data subset for reporting now, please hold");
                update_query = conn.prepareCall("{call set_active_assessments (?)}");
                update_query.setString(1, assessment_ids.toString());
                update_query.executeUpdate();
                conn.close();
                this.parent.setStatusMsg("Almost completed creating assessment data subset for reporting");            
                conn = this.parent.connectionGenerator();
                update_query = conn.prepareCall("{call set_active_components (?)}");
                update_query.setString(1, component_numbers.toString());
                update_query.executeUpdate();
                conn.close();
                this.internal_setCursor("default");
                this.parent.setStatusModeMsg("");
                this.parent.setStatusMsg("");
            }else {
                this.resetActiveAssessments();    
            }
            
            this.parent.openReportingFrame();
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("ERROR while setting active assessments! The text of the error is:\n" + e.toString());
	        this.parent.setStatusModeMsg("ASMNT");
	        this.parent.setStatusMsg("");
	        e.printStackTrace();
	    }
	}/* end method openReportingFrame() */
		
		
	private void setConversionTables() {
	    try {	        
	        this.result_fields.put(this.resultsFieldsModel.get(1), "component_name");
	        this.result_fields.put(this.resultsFieldsModel.get(2), "component_num");
	        this.result_fields.put(this.resultsFieldsModel.get(3), "location");
	        this.result_fields.put(this.resultsFieldsModel.get(4), "primary_assessor");
	    }catch (Exception e) {
	        e.printStackTrace();	    }
	}/* end method setConversionTables() */
	
	// This method is responsible for preparing the results table, this includes 
	// setting the columns, and adding the sort capability to them. Before any data
	// is actually set within the table model this.resultsModel (an instance of
	// SortableTableModel) the table model is cleared. 
	private void prepareResultsTable() {
	    try {
	        Boolean checkbox_value = null;
	        
	        this.resultsModel.setColumnIdentifiers(this.result_table_headers);
	        
	        this.resultsModel.setDataVector(new Vector(), this.result_table_headers);
	        
	        DefaultCellEditor checkBoxEditor = new DefaultCellEditor(this.editor);
	        this.results_table.setModel(this.resultsModel);
	        
		    this.results_table.getColumn("Select").setCellRenderer(new CheckBoxRenderer());
		    this.results_table.getColumn("Select").setCellEditor(new DefaultCellEditor(this.editor));	        
  	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method prepareResultsTable() */

	private void initializeResultsTable() {
	    try {
	        Boolean checkbox_value = null;
	        
	        this.resultsModel.setColumnIdentifiers(this.result_table_headers);	        
	        DefaultCellEditor checkBoxEditor = new DefaultCellEditor(this.editor);
	        this.results_table.setModel(this.resultsModel);
	        
		    this.results_table.getColumn("Select").setCellRenderer(new CheckBoxRenderer());
		    this.results_table.getColumn("Select").setCellEditor(new DefaultCellEditor(this.editor));	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
		
	void showImportDialog() {
        StringTokenizer parser = null;
	    try {
	        int ret_val = this.fileChooser.showOpenDialog(this);
	        if (ret_val == this.fileChooser.APPROVE_OPTION) {
	            File assessment_file = this.fileChooser.getSelectedFile();
	            parser = new StringTokenizer(assessment_file.toString(), ".");
	            if (parser.countTokens() > 1 && (assessment_file.toString()).indexOf(".xml") != -1) {
	                if (assessment_file.exists()) {
	    	            int reply = JOptionPane.showConfirmDialog(this, 
	    	                                          ("Do you want to import the information\nin " + assessment_file.toString() + "\ninto the assessment database?\nPlease be aware that this operation may take a few minutes." ), 
	    	                                          "Import Assessments" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);	        	        
                        if (reply == JOptionPane.YES_OPTION) {
	                        AssessmentImporter import_thread = AssessmentImporter.spawnAssessmentImporter(this.parent, assessment_file.toString());
                            import_thread.run();
	                    }	                    
	                    Graphics g = this.getGraphics();
	                    this.update(g);
	                }else {
	                    this.parent.displayErrorDialog("The file you have specified: " + assessment_file.toString() + " does not exist!");    
	                    this.showImportDialog();
	                }
	            }else {
                    this.showImportDialog();
	            }
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}
	
	// Static utility method to obtain the full pathname to an instance of the
	// class File that was created with the JFileChooser dialog.
	// Variables:
	// @file - holds the reference to the current instance of class File that is
	//         to be tested. Each successive time the method is called in recur
	//         @file holds a refernce to the prior call's parent
	// @filename_buffer - holds the string converted names of each instance of 
	//                    class File. Since the calls are made in reverse order
	//                    each time a new addition is to be made to the buffer
	//                    it must be re-arranged. The first time this method is
    //                    called this var holds the value of the current directory
	static String getFullFileName(File file, StringBuffer filename_buffer) {
	    try {
	        // Implement the base case where the next parent of file is null
	        // this means we have reached the top of the directory tree.
	        if ((filename_buffer.toString().length() > 1) && (file.getParent() != null)) {	            // To prevent a slash from being inserted after the file name check to 
	            // see if the file name buffer has anything in it yet. If so then
	            // go ahead and insert the slash else don't
	            filename_buffer = new StringBuffer(file.getName() + File.separator + filename_buffer.toString());
	        }else {
	            filename_buffer = new StringBuffer(file.getName());	        
	        }
	        if (file.getParent() == null) {
                return filename_buffer.toString();
	        }
	        return getFullFileName(file.getParentFile(), filename_buffer);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return null;
	}
	
	// This method deletes selected assessments. There are two ways in which to 
	// delete assessments. A user can select a row via mouse click or can select 
	// a row by clicking the select checkboxes in the 6th column.
	// ---------------
	// Change Control:
	// 05/19/02 - Added code to warn the user if they did not check any of the select boxes
	//            but still pressed the delete button.
	public void deleteSavedAssessment() {
	    CallableStatement delete_sp = null;
	    Connection conn = null;
        String system_name = "";
        String timestamp   = "";
        int selected_row = 0; 
        int original_vector_size = 0;
        boolean assessments_selected = false;
        Boolean cmp = null;
	    try {	       			
	        if (this.resultsModel_clone == null) {
			    original_vector_size = (this.resultsModel.getDataVector()).size();
			}else {
			    original_vector_size = (this.resultsModel_clone.getDataVector()).size();    
			}
		
	        for (int i = 0; i < original_vector_size; i++) {
	            if (this.resultsModel_clone == null) {
			        cmp = (Boolean) this.resultsModel.getValueAt(i, 5);
			    }else {
			        cmp = (Boolean) this.resultsModel_clone.getValueAt(i, 5);    
			    }

                if (cmp.booleanValue()) { 
                    assessments_selected = true;
                    if (this.resultsModel_clone == null) {
	                    system_name = (String) ((Vector) (this.resultsModel.getDataVector()).elementAt(i)).elementAt(0);
	                    timestamp = (String) ((Vector) (this.resultsModel.getDataVector()).elementAt(i)).elementAt(3);                			             
			        }else {
	                    system_name = (String) ((Vector) (this.resultsModel_clone.getDataVector()).elementAt(i)).elementAt(0);
	                    timestamp = (String) ((Vector) (this.resultsModel_clone.getDataVector()).elementAt(i)).elementAt(3);                			             			            
			        }
                    int reply = JOptionPane.showConfirmDialog(this, 
	    	                              "Are you sure you want to delete assessment for " + system_name + " ?", 
	    	                              "Delete Assessment?" , 
	    	                              JOptionPane.YES_NO_OPTION, 
	    	                              JOptionPane.QUESTION_MESSAGE);
	                if (reply == JOptionPane.YES_OPTION) {
	                    conn = this.parent.connectionGenerator();
	                    delete_sp = conn.prepareCall("{call delete_saved_assessment (?, ?, ?)}");
                        delete_sp.setString(1, (String) this.results_cache.elementAt(i));
                        delete_sp.setString(2, system_name);
                        delete_sp.setString(3, timestamp);
                        delete_sp.executeUpdate();
                        // Remove row i from the table. Originally this removed row
                        // 'selectedrow' from the table.
                        if (this.resultsModel_clone == null) {
                            this.resultsModel.removeRow(i);

			            }else {
			                this.resultsModel_clone.removeRow(i);
			            } 
                        {
                            this.parent.displayStatusDialog("Assessment for " + system_name + " deleted.");
                        }
                        this.results_cache.remove( i );
                        conn.close();
                        i--;
                        original_vector_size--;
                    }
                }
	        }  
	        if (assessments_selected == false) {
	            this.parent.displayErrorDialog("You must select one or more assessments to delete first!");
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	        this.parent.displayErrorDialog("ERROR: cannot delete selected assessment!");
	    }	    
	}/* end method deleteSavedAssessment() */
		
	public void setTableColumnHeaders() {	    
	    try {
	        this.result_table_headers.addElement("System");
	        this.result_table_column_map.put("System", new Integer(0));
	        this.result_table_headers.addElement("System Number");
	        this.result_table_column_map.put("System Number", new Integer(1));
	        this.result_table_headers.addElement("Location");
	        this.result_table_column_map.put("Location", new Integer(2));
	        this.result_table_headers.addElement("Start Date");
	        this.result_table_column_map.put("Start Date", new Integer(3));
	        this.result_table_headers.addElement("Primary Assessor");
	        this.result_table_column_map.put("Primary Assessor", new Integer(4));
	        this.result_table_headers.addElement("Select");
	        this.result_table_column_map.put("Select", new Integer(5));
	        this.resultsModel.setColumnIdentifiers(this.result_table_headers);	        	       
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method setTableColumnHeaders() */
		
	// This method is designed to set all the assessments returned frm a search 
	// as selected. This will be what is used to create a subset of the assessments
	// in the database with which to report upon.
	void toggleSelectedAssessments() {
	    try {
	        if (this.resultsModel_clone == null) {
	            for (int i = 0; i < (this.resultsModel.getDataVector()).size(); i++) {
                    Boolean cmp = (Boolean) this.resultsModel.getValueAt(i, 5);
                    this.resultsModel.setValueAt(new Boolean(true), i, 5);
	            }
	        }else {
	            for (int i = 0; i < (this.resultsModel_clone.getDataVector()).size(); i++) {
                    Boolean cmp = (Boolean) this.resultsModel_clone.getValueAt(i, 5);
                    this.resultsModel_clone.setValueAt(new Boolean(true), i, 5);
	            }	            
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
		
	// This method is responsible for removing those assessment result rows that are not marked
	// as selected with the selection checkbox. This method makes use of resultsModel_clone instance
	// of DefaultTableModel.
	// ---------------
	// Change Control:
	// 05/29/02 - Added the ability for a user to press the refresh button multiple times each 
	//            time removing those assessments that are not selected with the checkbox
	// 06/03/02 - Added code that resets the state of a subset of search results being selected to
	//            false each time the user presses the refresh button.
	void analyzeAssessments() {
	    Boolean cmp = null;
	    Vector new_data_model = null;
	    try {
	        this.setSubSetSelected(false);
	        if (((resultsModel_clone != null) && ((((DefaultTableModel) this.results_table.getModel()).getDataVector()).size() > 0)) || ((resultsModel_clone == null) && (resultsModel.getDataVector()).size() > 0)) {      
	            if (this.resultsModel_clone == null) {
	                // The assessment summary tab was selected so trim down the assessment 
	                // summary tab
	                this.resultsModel_clone = new DefaultTableModel();
	                this.resultsModel_clone.setColumnIdentifiers(this.result_table_headers);
	                for (int i = 0; i < (this.resultsModel.getDataVector()).size(); i++) {
	                    cmp = (Boolean) this.resultsModel.getValueAt(i, 5);
                        if (cmp.booleanValue()) {
                            this.resultsModel_clone.addRow((Vector) (this.resultsModel.getDataVector()).elementAt(i));
                            this.resultsModel.setValueAt(new Boolean(false), i, 5);
                        }  
	                }
	            }else {
	                int size = (this.resultsModel_clone.getDataVector()).size();
	                for (int i = 0; i < size; i++) {
	                    cmp = (Boolean) this.resultsModel_clone.getValueAt(i, 5);
                        if (!cmp.booleanValue()) {
                            this.resultsModel_clone.removeRow(i);
                            i--;
                            size--;
                        }else {
                            this.resultsModel_clone.setValueAt(new Boolean(false), i, 5);    
                        }
	                }	            
	            }
	            this.results_table.setModel(this.resultsModel_clone);
		        this.results_table.getColumn("Select").setCellRenderer(new CheckBoxRenderer());
		        this.results_table.getColumn("Select").setCellEditor(new DefaultCellEditor(this.editor));
		    }else {
		        this.parent.displayErrorDialog("There are no search results to remove!");    
		    }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method analyzeAssessments() */
		
	class SymAction implements java.awt.event.ActionListener {
	    
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == refreshButton)
				refreshButton_actionPerformed(event);
			else if (object == toggleButton)
				toggleButton_actionPerformed(event);
			else if (object == import_assessment_button)
				importAssessmentButton_actionPerformed(event);
			else if (object == exportButton)
				exportButton_actionPerformed(event);
			if (object == reset_button)
				reset_button_actionPerformed(event);
			else if (object == search_button)
				search_button_actionPerformed(event);
			else if (object == asmntShowInfoDialog)
				asmntShowInfoDialog_actionPerformed(event);
			if (object == open_reports_button)
				openReportsButton_actionPerformed(event);
			else if (object == deleteButton)
				deleteButton_actionPerformed(event);
			else if (object == beforeRadioButton)
				beforeRadioButton_actionPerformed(event);
			else if (object == afterRadioButton)
				afterRadioButton_actionPerformed(event);
			else if (object == newAssessmentButton)
				newAssessmentButton_actionPerformed(event);
			else if (object == viewButton)
				viewButton_actionPerformed(event);
			else if (object == asmntSaveResultsMenuItem)
				asmntSaveResultsMenuItem_actionPerformed(event);
			else if (object == asmntDeleteMenuItem)
				asmntDeleteMenuItem_actionPerformed(event);
			else if (object == helpButton)
				helpButton_actionPerformed(event);	
		}
	}/* end internal class SymAction() */
    
    public AssessmentFrame(ASSET parent_frame) {
		this();		
		this.parent = parent_frame;
		this.computeQuestionCount();
	}

	public AssessmentFrame(String sTitle) {
		this();
		setTitle(sTitle);
	}	
    
    // This method interprets the search parameters to submit a search query to the
    // database. It uses the stored procedure getSavedAssessments which is an inner
    // join on the assessment table and component table based on assessment_id
    // -----------
    // References:
    // http://www.tek-tips.com/gfaqs.cfm/spid/183/sfid/761 - Stored Procedure, sp_execsql
    // ---------------
    // Change Control:
    // 05/08/02 - Added code to check that when the search limit field was not set to "unlimited" 
    //            they must also check that it was not set to no value at all.
    // 05/09/02 - Added code to verify that when a user chooses the Search All Fields choice they
    //            must enter the * in the text box or they will recieve an error.
    // 06/03/02 - Added code to reset all assessments in database as active each time the search
    //            button is pressed. (by calling resetActiveAssessments() method)
    public void processSearchParameters() throws IllegalArgumentException {
        try {
            this.setOperationMode(true);            
            this.clearResultsTable();
	        DefaultCellEditor checkBoxEditor = new DefaultCellEditor(this.editor);            
            String selected_field = (String) this.tableFieldBox.getSelectedItem();
            if (this.searchQuery.getText().length() < 1 && this.tableFieldBox.isEnabled()) {
                throw new IllegalArgumentException("No search query defined!");
            }
            if ((! this.limit_results_field.getText().equalsIgnoreCase("Unlimited")) && (this.limit_results_field.getText().length() > 0)) {
                int result_set_limit = Integer.parseInt(this.limit_results_field.getText());
                this.setResultSetLimit(result_set_limit);
            }
            
            if (this.tableFieldBox.isEnabled() && this.tableFieldBox.getSelectedIndex() == 0 && !(this.searchQuery.getText().equalsIgnoreCase("*"))) {
                throw new IllegalArgumentException("You cannot return all records without\nentering the '*' character in the query box!");
            }
            
            if (this.searchQuery.getText().equals("*") && (this.tableFieldBox.getSelectedIndex() == 0)) { 
                this.tableFieldBox.setSelectedIndex(0);
                this.searchQuery.setText("");
                this.fillTable();                
                Graphics g = this.JPanel3.getGraphics();
                this.JPanel3.update(g);                    
            }else if (! this.tableFieldBox.isEnabled()) {
                this.tableFieldBox.setSelectedIndex(0);
                this.searchQuery.setText("");
                this.executeDateSearch();
                Graphics g = this.JPanel3.getGraphics();
                this.JPanel3.update(g);                  
            }else {                               
                this.executeDynamicSearch(); 
                this.tableFieldBox.setSelectedIndex(0);
                Graphics g = this.JPanel3.getGraphics();
                this.JPanel3.update(g);  
                this.searchQuery.setText("");                                               
            }
            {
                this.resetSearchPanelDuringSearch();
            }
            this.JTabbedPane1.setSelectedIndex(1);  
        }catch (NumberFormatException e) {
            this.parent.displayErrorDialog("You have defined an invalid limit on your result set!");
        }catch (IllegalArgumentException e) {
            this.parent.displayErrorDialog("You must enter information to search on! The text of the error is:\n" + e.toString());
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method processSearchParameters() */

	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();
		super.addNotify();
		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;
		// Adjust size of frame according to the insets and menu bar
		Insets insets = getInsets();
		javax.swing.JMenuBar menuBar = getRootPane().getJMenuBar();
		int menuBarHeight = 0;
		if (menuBar != null)
			menuBarHeight = menuBar.getPreferredSize().height;
		int offset = 0;
		Component comp[] = getComponents();
		for(int i = 0; i < comp.length; ++i) {
			if (comp[i] instanceof javax.swing.JRootPane)
				continue;
			offset += comp[i].getPreferredSize().height;
		}
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height + menuBarHeight + offset);
	}/* end method addNotify() */

	public void computeQuestionCount() {
        CallableStatement current_count = null;
	    ResultSet count = null;
	    Vector table_row = new Vector();
        Connection conn = this.parent.connectionGenerator();
	    try {
	       conn = this.parent.connectionGenerator();
           this.internal_setCursor("wait"); 
            
           current_count =  conn.prepareCall("{call get_assessment_count}");
           count = current_count.executeQuery();
           count.next();
           this.assessment_count = count.getInt("AssessmentCount");
           conn.close(); 
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	      
	}	
	
	// This method is designed to clear the JTable that holds search results. If 
	// this is not done, each time a search is executed the information returned 
	// from the database will be added on to what is already there.
	private void clearResultsTable() {
        try {
            this.results_cache = new Vector();
            this.resultsModel.setDataVector(new Vector(), this.result_table_headers);
		    this.results_table.getColumn("Select").setCellRenderer(new CheckBoxRenderer());
		    this.results_table.getColumn("Select").setCellEditor(new DefaultCellEditor(this.editor));            
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
	
	// This method is called when a user chooses to search the assessments table 
	// based on a specific field.
	private void executeDynamicSearch() {
        CallableStatement dynamic_search = null;
        ResultSet search_results = null;
        Vector table_row = new Vector();
        Connection conn = this.parent.connectionGenerator();        
	    try {		        
	        this.internal_setCursor("wait");
	        this.results_cache = new Vector();
	        this.clearResultsTable();
	        this.parent.setStatusModeMsg("SEARCH");
	        this.parent.setStatusMsg("Please hold, connecting to database for information regarding all gathered assessments");
	        this.prgMonitor.setVisible(true);
	        dynamic_search = conn.prepareCall("{call search_saved_assessments(?, ?) }");    
            dynamic_search.setString(1, (String) this.result_fields.get((String) this.tableFieldBox.getSelectedItem()));
            dynamic_search.setString(2, this.searchQuery.getText());            
            search_results = dynamic_search.executeQuery();
            
            this.crawlResultSet(search_results);
        
	        conn.close();
	        this.prgMonitor.setVisible(false);
	        this.parent.setStatusMsg("");
	        this.internal_setCursor("default");            
	    }catch (SQLException e) {
	        e.printStackTrace();
	        this.parent.displayErrorDialog("Your search query was improperly formatted! Please try again");
	        this.searchQuery.setText("");
	        this.parent.setStatusMsg("");
	        this.JTabbedPane1.setSelectedIndex(0);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// Encapsulation method for querying a result set of assessment records. This 
	// method is called by all methods which implement searching within the user 
	// inteface.
	// ---------------
	// Change Control:
    // 05/08/02 - Changed code to verify result set limit check. Before this iteration the
    //            result set was configured to not add any more results to the search result set
    //            when the return count was greater than the result set limit. This limit was 
    //            set to -1 by default. Naturally this won't work for conditional numerical
    //            comparisons. Instead it was decided to use a boolean variable to indicate if
    //            a result set limit had actually been set.	
	private void crawlResultSet(ResultSet results) {
	    int progress = 0;
	    String component_name = "";
	    String component_num = "";
	    String component_location = "";
	    String component_type = "";
	    String component_assessment_obj = "";
	    String assessment_id = "";
	    String start_timestamp = "";
	    String completed = "";
        String bookmark = "";
	    String primary_assessor = "";
	    Vector table_row = null;
	    int result_count = 0;
	    try {
	        this.prgMonitor.setStatusBusyMessage("Please hold, accessing completed assessment list");
	        this.prgMonitor.setVisible(true);
            
            if (results.next()) {
	            table_row = new Vector();
	            component_name = (results.getString("component_name")).trim();
	            component_num = (results.getString("component_num")).trim();
	            component_location = (results.getString("component_location")).trim();
	            component_type = (results.getString("component_type")).trim();
	            component_assessment_obj = (results.getString("component_assessment_obj")).trim();
	            assessment_id = (results.getString("id")).trim();
	            this.results_cache.addElement(assessment_id);
	            start_timestamp = (results.getString("start_timestamp")).trim();
	            if (results.getInt("completed") == 1) {
	                completed = "Yes";
	            }else {
	                completed = "No"; 
	            }
	            bookmark = results.getString("bookmark");
	            primary_assessor = (results.getString("primary_assessor")).trim();
	            
	            table_row.addElement(component_name);
	            table_row.addElement(component_num);
	            table_row.addElement(component_location);
	            table_row.addElement(start_timestamp);
	            table_row.addElement(primary_assessor);
	            table_row.addElement(new Boolean(false));
	            if (!this.getLimitSet()) {
                     this.resultsModel.addRow(table_row);
	            }else {
	                if (result_count <= this.getResultSetLimit()) {
	                    this.resultsModel.addRow(table_row);	               
	                }	                
	            }
	            result_count++;
	            progress++;
	            this.prgMonitor.setNormalizedProgress(progress);                            
            }else {
                this.parent.displayErrorDialog("No results were returned from your serach!");    
                this.JTabbedPane1.setSelectedIndex(0);
            }
            
            while (results.next()) {
	            table_row = new Vector();
	            component_name = (results.getString("component_name")).trim();
	            component_num = (results.getString("component_num")).trim();
	            component_location = (results.getString("component_location")).trim();
	            component_type = (results.getString("component_type")).trim();
	            component_assessment_obj = (results.getString("component_assessment_obj")).trim();
	            assessment_id = (results.getString("id")).trim();
	            this.results_cache.addElement(assessment_id);
	            start_timestamp = (results.getString("start_timestamp")).trim();
	            if (results.getInt("completed") == 1) {
	                completed = "Yes";
	            }else {
	                completed = "No"; 
	            }
	            bookmark = results.getString("bookmark");
	            primary_assessor = (results.getString("primary_assessor")).trim();
	            
	            table_row.addElement(component_name);
	            table_row.addElement(component_num);
	            table_row.addElement(component_location);
	            table_row.addElement(start_timestamp);
	            table_row.addElement(primary_assessor);
	            table_row.addElement(new Boolean(false));
	            if (!this.getLimitSet()) {
                     this.resultsModel.addRow(table_row);
	            }else {
	                if (result_count <= this.getResultSetLimit()) {
	                    this.resultsModel.addRow(table_row);	               
	                }	                
	            }
	            result_count++;	               
	            progress++;
	            this.prgMonitor.setNormalizedProgress(progress);            
            }

	        this.prgMonitor.setVisible(false);
	        this.prgMonitor.dispose();
            this.initializeResultsTable();
	    }catch (Exception e) {
	        e.printStackTrace();
	        this.parent.setStatusMsg("");
	    }
	}/* end method crawlResultSet() */

	// This method is responsible for crawling a JDBC ResultSet object for responses
	// from a date query. Thanks a great deal to the Calendar bean from IBM AlphaWorks
	// providing the very well designed date selection utility.
	// ---------------
    // Change Control:
    // 05/08/02 - Changed code to verify result set limit check. Before this iteration the
    //            result set was configured to not add any more results to the search result set
    //            when the return count was greater than the result set limit. This limit was 
    //            set to -1 by default. Naturally this won't work for conditional numerical
    //            comparisons. Instead it was decided to use a boolean variable to indicate if
    //            a result set limit had actually been set.
	private void crawlResultSetForDates(ResultSet results) {
	    int progress = 0;
	    String component_name = "";
	    String component_num = "";
	    String component_location = "";
	    String component_type = "";
	    String component_assessment_obj = "";
	    String assessment_id = "";
	    String start_timestamp = "";
	    String completed = "";
        String bookmark = "";
	    String primary_assessor = "";
	    Vector table_row = null;
        Date search_date = null;
        Date comparison_date = null; 
        int result_count = 0;
	    try {
	        this.prgMonitor.setStatusBusyMessage("Please hold, accessing completed assessment list");
	        this.prgMonitor.setVisible(true);
            
            if (results.next()) {
	            table_row = new Vector();
	            component_name = (results.getString("component_name")).trim();
	            component_num = (results.getString("component_num")).trim();
	            component_location = (results.getString("component_location")).trim();
	            component_type = (results.getString("component_type")).trim();
	            component_assessment_obj = (results.getString("component_assessment_obj")).trim();
	            assessment_id = (results.getString("id")).trim();
	            this.results_cache.addElement(assessment_id);
	            start_timestamp = (results.getString("start_timestamp")).trim();
	            if (results.getInt("completed") == 1) {
	                completed = "Yes";
	            }else {
	                completed = "No"; 
	            }
	            bookmark = results.getString("bookmark");
	            primary_assessor = (results.getString("primary_assessor")).trim();
                search_date = new Date(this.first_date.getText());
	            comparison_date = new Date(start_timestamp);
	            System.out.println(search_date.toString());
	            System.out.println(comparison_date.toString());
	            if (((search_date.after(comparison_date) && this.beforeRadioButton.isSelected())) || ((search_date.before(comparison_date) && this.afterRadioButton.isSelected()))) {
	                table_row.addElement(component_name);
	                table_row.addElement(component_num);
	                table_row.addElement(component_location);
	                table_row.addElement(start_timestamp);
	                table_row.addElement(primary_assessor);
	                table_row.addElement(new Boolean(false));
	                if (!this.getLimitSet()) {
                        this.resultsModel.addRow(table_row);
	                }else {
	                    if (result_count <= this.getResultSetLimit()) {
	                        this.resultsModel.addRow(table_row);	               
	                    }	                
	                }
	                result_count++;	                    
	                progress++;
	                this.prgMonitor.setNormalizedProgress(progress);                            
	            }
            }else {
                this.parent.displayErrorDialog("No results were returned from your serach!");    
                this.JTabbedPane1.setSelectedIndex(0);
            }
            
            while (results.next()) {
	            table_row = new Vector();
	            component_name = (results.getString("component_name")).trim();
	            component_num = (results.getString("component_num")).trim();
	            component_location = (results.getString("component_location")).trim();
	            component_type = (results.getString("component_type")).trim();
	            component_assessment_obj = (results.getString("component_assessment_obj")).trim();
	            assessment_id = (results.getString("id")).trim();
	            this.results_cache.addElement(assessment_id);
	            start_timestamp = (results.getString("start_timestamp")).trim();
	            if (results.getInt("completed") == 1) {
	                completed = "Yes";
	            }else {
	                completed = "No"; 
	            }
	            bookmark = results.getString("bookmark");
	            primary_assessor = (results.getString("primary_assessor")).trim();
	            if (this.tableFieldBox.isEnabled() == false) {
                    search_date = new Date(this.first_date.getText());
	                comparison_date = new Date(start_timestamp);
	                if ((search_date.after(comparison_date) && this.beforeRadioButton.isSelected()) || (search_date.before(comparison_date) && this.afterRadioButton.isSelected())) {	            
	                    table_row.addElement(component_name);
	                    table_row.addElement(component_num);
	                    table_row.addElement(component_location);
	                    table_row.addElement(start_timestamp);
	                    table_row.addElement(primary_assessor);
	                    table_row.addElement(new Boolean(false));
	                    if (!this.getLimitSet()) {
                             this.resultsModel.addRow(table_row);
	                    }else {
	                        if (result_count <= this.getResultSetLimit()) {
	                            this.resultsModel.addRow(table_row);	               
	                        }	                
	                    }
	                    result_count++;	  	               
	                    progress++;
	                    this.prgMonitor.setNormalizedProgress(progress);            
	                }
	            }
            }
	        this.prgMonitor.setVisible(false);
	        this.prgMonitor.dispose();
            this.initializeResultsTable();
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method crawlResultSetForDates() */	
	
    // The sole purpose of this method is to extract ALL of the information from the
    // database table of assessments. It is called from the processSearchParameters 
    // method.
	private void fillTable() {
        CallableStatement current_questions = null;
	    ResultSet questions = null;
	    Vector table_row = new Vector();
        Connection conn = this.parent.connectionGenerator();
        int progress = 0;
        int result_count = 0;
	    try {	        
	       this.internal_setCursor("wait");
	       this.results_cache = new Vector();
	       this.clearResultsTable();
	       this.parent.setStatusModeMsg("SEARCH");
	       this.parent.setStatusMsg("Please hold, connecting to database for information regarding all gathered assessments");
	       current_questions =  conn.prepareCall("{call get_saved_assessments}");
	       questions = current_questions.executeQuery();
	       
	       this.crawlResultSet(questions);
        
	       conn.close();
	       this.parent.setStatusMsg("");
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }    
	}/* end method fillTable() */
	
	private void executeDateSearch() {
        CallableStatement current_questions = null;
	    ResultSet questions = null;
	    Vector table_row = new Vector();
        Connection conn = this.parent.connectionGenerator();
        int progress = 0;
	    try {	        
	       this.internal_setCursor("wait");
	       this.results_cache = new Vector();
	       this.clearResultsTable();
	       this.parent.setStatusModeMsg("SEARCH");
	       this.parent.setStatusMsg("Please hold, connecting to database for information regarding all gathered assessments");
	       current_questions =  conn.prepareCall("{call get_saved_assessments}");
	       questions = current_questions.executeQuery();
	       
	       this.crawlResultSetForDates(questions);
        
	       conn.close();
	       this.parent.setStatusMsg("");
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }    
	}/* end method fillTable() */	
	
	// This method is designed to encapsulate changing the cursor type
	// it is used to show the user that an action is occurring that needs 
	// to pause for.
	private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("hand")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.HAND_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
            e.printStackTrace();
	    }
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JPanel JPanel6 = new javax.swing.JPanel();
	javax.swing.JToolBar JToolBar1 = new javax.swing.JToolBar();
	javax.swing.JButton newAssessmentButton = new javax.swing.JButton();
	javax.swing.JButton import_assessment_button = new javax.swing.JButton();
	javax.swing.JButton viewButton = new javax.swing.JButton();
	javax.swing.JButton deleteButton = new javax.swing.JButton();
	com.symantec.itools.javax.swing.JToolBarSeparator JToolBarSeparator2 = new com.symantec.itools.javax.swing.JToolBarSeparator();
	javax.swing.JButton refreshButton = new javax.swing.JButton();
	javax.swing.JButton toggleButton = new javax.swing.JButton();
	javax.swing.JButton exportButton = new javax.swing.JButton();
	javax.swing.JButton open_reports_button = new javax.swing.JButton();
	com.symantec.itools.javax.swing.JToolBarSeparator JToolBarSeparator1 = new com.symantec.itools.javax.swing.JToolBarSeparator();
	javax.swing.JButton helpButton = new javax.swing.JButton();
	javax.swing.JPanel assessment_parent_panel = new javax.swing.JPanel();
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JPanel search_parameters_parent_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel4 = new javax.swing.JPanel();
	javax.swing.JTextPane JTextPane1 = new javax.swing.JTextPane();
	javax.swing.JPanel search_query_and_parameters_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel19 = new javax.swing.JPanel();
	javax.swing.JTextField searchQuery = new javax.swing.JTextField();
	javax.swing.JPanel search_parameters_panel = new javax.swing.JPanel();
	javax.swing.JTabbedPane JTabbedPane2 = new javax.swing.JTabbedPane();
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	javax.swing.JPanel basic_pane = new javax.swing.JPanel();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	javax.swing.JComboBox tableFieldBox = new javax.swing.JComboBox();
	javax.swing.JLabel JLabel5 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel11 = new javax.swing.JPanel();
	javax.swing.JTextField first_date = new javax.swing.JTextField();
	javax.swing.JPanel JPanel21 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel6 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel20 = new javax.swing.JPanel();
	javax.swing.JRadioButton beforeRadioButton = new javax.swing.JRadioButton();
	javax.swing.JRadioButton afterRadioButton = new javax.swing.JRadioButton();
	javax.swing.JLabel JLabel7 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel4 = new javax.swing.JLabel();
	javax.swing.JTextField limit_results_field = new javax.swing.JTextField();
	javax.swing.JLabel JLabel8 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel27 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel7 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel14 = new javax.swing.JPanel();
	javax.swing.JButton search_button = new javax.swing.JButton();
	javax.swing.JButton reset_button = new javax.swing.JButton();
	javax.swing.JPanel JPanel3 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel5 = new javax.swing.JPanel();
	javax.swing.JScrollPane results_scroll_pane = new javax.swing.JScrollPane();
	javax.swing.JTable results_table = new javax.swing.JTable();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon1 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon deleteAssessmentIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon newIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon4 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon2 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon3 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon helpIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon importIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.models.StringComboBoxModel date_type_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	javax.swing.JPopupMenu assessmentTablePopup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem asmntShowInfoDialog = new javax.swing.JMenuItem();
	javax.swing.JMenuItem asmntSaveResultsMenuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator1 = new javax.swing.JSeparator();
	javax.swing.JMenuItem asmntDeleteMenuItem = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.icons.ImageIcon saveIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EmptyBorder criteriaBorder = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder search_label_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel resultsFieldsModel = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.models.StringComboBoxModel result_limit_choose_type = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.borders.EmptyBorder search_params_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon reportIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	//}}
	boolean subset_selected = false;
	boolean window_resized = false;
	boolean limit_set = false;
	HTMLLabel choose_first_date = null;
	HTMLLabel choose_second_date = new HTMLLabel();
	boolean operation_mode = false;
	Vector results_cache = new Vector();
	ReportingFrame rFrame  = null;
    SortableTableModel resultsModel = new SortableTableModel() {
      public Class getColumnClass(int col) {
          switch (col) {
              case  5: return Boolean.class;          
              default: return Object.class;        
          } 
      }      
      
      public boolean isCellEditable(int row, int col) {        
          switch (col) {
              case  5: return true;
              default: return false;
          }
      }
      
      public void setValueAt(Object obj, int row, int col) {
          switch (col) {
              case  5: super.setValueAt(new Boolean(obj.toString()), row, col); 
              return;          
              default: super.setValueAt(obj, row, col); return;        
          }
      }
    };        
        
    SortableTableModel showFieldsModel = new SortableTableModel() {        
      public Class getColumnClass(int col) {
          switch (col) {
              case  0: return String.class;
              case  1: return Boolean.class;          
              default: return Object.class;        
          } 
      }      
      
      public boolean isCellEditable(int row, int col) {        
          switch (col) {
              case  1: return true;
              default: return false;
          }
      }
      
      public void setValueAt(Object obj, int row, int col) {
          switch (col) {
              case  1: super.setValueAt(new Boolean(obj.toString()), row, col); 
              return;          
              default: super.setValueAt(obj, row, col); return;        
          }
      }
    };
    
    Vector result_table_headers = new Vector();
    
    Hashtable result_table_column_map = new Hashtable();
    
    DefaultTableModel resultsModel_clone = null;
    ASSET parent = null;
    int assessment_count = 0;
    ProgressDialog prgMonitor = null;
    DOMParser parser = new DOMParser();
    Vector table_row = new Vector();

    Document imported_assessment = null;
    
    JFileChooser fileChooser = new JFileChooser();
    JFileChooser fileSaver = new JFileChooser();
    JCheckBox editor = new JCheckBox();
    
    Hashtable result_fields = new Hashtable();

    int result_set_limit = 0;
    
    private boolean getSubsetSelected() {
        return this.subset_selected;
    }
    
    private void setSubSetSelected(boolean flag) {
        this.subset_selected = flag;
    }
    
    private boolean getWindowResized() {
        return this.window_resized;    
    }
    
    private void setWindowResized(boolean flag) {
        window_resized = flag;        
    }
    
    private boolean getLimitSet() {
        return this.limit_set;    
    }
    
    private void setLimitSet(boolean flag) {
        this.limit_set = flag;    
    }
    
    public void setResultSetLimit(int new_limit) {
        this.result_set_limit = new_limit;   
    }
    
    public int getResultSetLimit() {
        return this.result_set_limit;    
    }
    
    public void setOperationMode(boolean flag) {
        this.operation_mode = flag;    
    }
    
    public boolean getOperationMode() {
        return this.operation_mode;    
    }
    
    // This method will export the results of the selected table (either 
    // assessment or system summary tab) to a csv file that can be imported 
    // into your basic office applications such as Excell or Access
    // References:
    // 1. http://www.esus.com/javaindex/j2se/jdk1.2/javaxswing/
    //    editableatomiccontrols/jfilechooser/jfilechoosersave.html
    void saveFile() {
        File save_target = null;
        try {
            if (this.getOperationMode()) {
                fileSaver.setDialogTitle("Save Summary Results File");
                fileSaver.addChoosableFileFilter(new CSVFilter());
                int choice = fileSaver.showSaveDialog(this);
                if (choice == fileSaver.APPROVE_OPTION) {
                     save_target = fileSaver.getSelectedFile();
                     PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter(save_target)));
                     DefaultTableModel test_model = (DefaultTableModel) this.results_table.getModel();
                     Vector temp_row = null;
                     StringBuffer output = new StringBuffer("");
                     String nl = System.getProperty("line.separator");
                     for (int n = 0; n < this.result_table_headers.size() - 1; n++) {
                         output.append((String) this.result_table_headers.elementAt(n));
                         if (n < this.result_table_headers.size() - 2) {
                             output.append(", ");
                         }                        
                     }                     
                     output.append(nl);
                     out.println(output.toString());
                     for (int i = 0; i < (test_model.getDataVector()).size(); i++) {
                         temp_row = (Vector) (test_model.getDataVector()).elementAt(i);
                         output = new StringBuffer("");
                         for (int j = 0; j < temp_row.size() - 1; j++) {
                             output.append((String) temp_row.elementAt(j));
                             if (j < temp_row.size() - 2) {
                                output.append(", ");
                             }                            
                         }
                         output.append(nl);
                         out.println(output.toString());
                    }
                    out.close();
                    this.parent.displayStatusDialog("Results exported successfully!");
                }
            }else {
                this.parent.displayErrorDialog("You need to perform a search on assessment results in order to save them!");    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method saveFile() */
        
	class SymInternalFrame implements javax.swing.event.InternalFrameListener {
	    
		public void internalFrameOpened(javax.swing.event.InternalFrameEvent event) {
		    CallableStatement query = null;
            Connection conn = parent.connectionGenerator();
		    try {
	    	    internal_setCursor("wait");	 
	    	    parent.setStatusMsg("Reseting active assessments now, please hold");
	    	    query = conn.prepareCall("{call rpt_reset_active_assessments}");
	    	    query.executeUpdate();
	    	    parent.setStatusMsg("");
	    	    internal_setCursor("default");
            }catch (Exception e) {
                e.printStackTrace();
            }
		}

		public void internalFrameDeiconified(javax.swing.event.InternalFrameEvent event)
		{
		    parent.setStatusModeMsg("SEARCH");
		    AssessmentFrame_internalFrameDeiconified(event);
		    AssessmentFrame_internalFrameDeiconified(event);
		}

		public void internalFrameIconified(javax.swing.event.InternalFrameEvent event)
		{
		    parent.setStatusModeMsg("Idle...");		    
		}

		public void internalFrameDeactivated(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosed(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosing(javax.swing.event.InternalFrameEvent event)
		{
			Object object = event.getSource();
			if (object == AssessmentFrame.this)
				AssessmentFrame_internalFrameClosing(event);
		}

		public void internalFrameActivated(javax.swing.event.InternalFrameEvent event)
		{
		}
	}/* end internal class SymInternalFrame() */

	void AssessmentFrame_internalFrameClosing(javax.swing.event.InternalFrameEvent event) {
		// to do: code goes here.
		this.setVisible(false);
	}
	
	public void finalize() throws Throwable {
		//{{CLEANUP
		//}}
		
		super.finalize();
	}

    // Reference:
    // http://developer.java.sun.com/developer/qow/archive/34/
	class SymMouse extends java.awt.event.MouseAdapter {	    
		public void mouseExited(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == choose_first_date) {
			    choose_first_date.rollover_exit();   
			}
		}

		public void mouseEntered(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == choose_first_date) {
			    choose_first_date.rollover_enter();   
			}			
		}
		
		public void mousePressed(java.awt.event.MouseEvent event) {
		    Object object = event.getSource();
		}
		
		public void mouseReleased(java.awt.event.MouseEvent event) {
		    Object object = event.getSource();
		}
		
		public void mouseClicked(java.awt.event.MouseEvent event) {
		    Object object = event.getSource();
		    if (object == results_table) {
		        if (SwingUtilities.isRightMouseButton(event)) {              
		            assessmentTablePopup.show(results_table, event.getX(), event.getY());
		        }		          
		    }
			if (object == limit_results_field)
			    limitResultsField_mouseClicked(event);
			if (object == choose_first_date) {
			    tableFieldBox.setSelectedIndex(0);
			    showDateChooser("first");
			}
		}
	}/* end internal class SymMouse() */
	
	// This method is responsible for showing the DateChooserDialog which houses the IBM
	// Calendar bean. When the DateChooserDialog is displayed the other search options must
	// be disabled until the reset button is displayed.
	private void showDateChooser(String type) {
	    try {
	        this.searchQuery.setText("");
	        this.tableFieldBox.setEnabled(false);
	        this.parent.setStatusModeMsg("DATE");
	        this.parent.setStatusMsg("Opening date chooser dialog now.");
			this.searchQuery.setText("Executing date search, press reset to return to normal");
            this.searchQuery.setEnabled(false);
			DateChooser diag = new DateChooser(this, type);
			int x = this.assessment_parent_panel.getX() + this.search_parameters_parent_panel.getX() + this.search_query_and_parameters_panel.getX() + this.search_parameters_panel.getX() + this.JPanel21.getX() + this.choose_first_date.getWidth();
            int y = this.getY() + this.assessment_parent_panel.getY() + this.search_parameters_parent_panel.getY() + this.search_query_and_parameters_panel.getY() + this.search_parameters_panel.getY() + this.basic_pane.getY();
            diag.setLocation(x, y);
	        diag.setVisible(true);   
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void resetActiveAssessments() {
		CallableStatement query = null;
        Connection conn = parent.connectionGenerator();	  	    
	    try {
	    	internal_setCursor("wait");	 
	    	parent.setStatusMsg("Reseting active assessments now, please hold");
	    	query = conn.prepareCall("{call rpt_reset_active_assessments}");
	    	query.executeUpdate();
	    	parent.setStatusMsg("");
	    	internal_setCursor("default");				        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// This method is the encapsulation of all the actions that must be performed 
	// on the AssessmentWindow class in order to reset it to its initial state 
	// after performing a search so that another search can be performed.
	// ---------------
	// Change Control:
	// 06/03/02 - Removed code to set active assessments in database to separate method
	//            resetActiveAssessments()
	public void resetSearchPanel() {
		CallableStatement query = null;
        Connection conn = parent.connectionGenerator();	    
	    try {
	        internal_setCursor("wait");	 
	        this.parent.setStatusModeMsg("BUSY");
	        this.parent.setStatusMsg("Reseting search parameters now, please hold");
	        this.setOperationMode(false);
	        this.setSubSetSelected(false);
	        this.resultsModel_clone = null;
	        this.prepareResultsTable();
			first_date.setText("");
			searchQuery.setText("");
			searchQuery.setEnabled(true);
			JTabbedPane2.setSelectedIndex(0);
			tableFieldBox.setSelectedIndex(0);
			limit_results_field.setText("");
			
			this.resetActiveAssessments();
	        this.parent.setStatusModeMsg("SEARCH");
	        this.parent.setStatusMsg("");			
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method resetSerachPanel() */
	
	public void resetSearchPanelDuringSearch() {
		CallableStatement query = null;
        Connection conn = parent.connectionGenerator();	    
	    try {
	        internal_setCursor("wait");	 
	        this.parent.setStatusModeMsg("BUSY");
	        this.parent.setStatusMsg("Reseting search parameters now, please hold");
	        this.setSubSetSelected(false);
	        this.resultsModel_clone = null;

			first_date.setText("");
			searchQuery.setText("");
			searchQuery.setEnabled(true);
			JTabbedPane2.setSelectedIndex(0);
			tableFieldBox.setSelectedIndex(0);
			limit_results_field.setText("");
			
			this.resetActiveAssessments();
	        this.parent.setStatusModeMsg("SEARCH");
	        this.parent.setStatusMsg("");			
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method resetSerachPanel() */
	
	
	public void showInfoDialog() {
	    try {
	        int row = this.results_table.getSelectedRow();
	        if (row != -1) {
		        this.parent.setStatusMsg("Opening assessment information dialog now, please hold.");
		        AssessmentInfoDialog diag = AssessmentInfoDialog.showInfoDialog((String) this.results_cache.elementAt(row), this);
	            diag.setVisible(true);
	            this.parent.setStatusMsg("");
	        }else {
	            this.parent.displayErrorDialog("You must select a valid assessment before you can display its information!");    
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void paintLabel(JComponent checkbox) {
        try {           
            Font f = new Font("Dialog", Font.PLAIN, 12);
			checkbox.setForeground(Color.blue);
			checkbox.setFont(f);
			this.setCursor(new Cursor(Cursor.HAND_CURSOR));
			checkbox.repaint();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
	}
	
	public void unpaintLabel(JComponent box) {
	    try {
	        box.setFont(new Font("Dialog", Font.PLAIN, 12));
			box.setForeground(Color.black);
			this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
			box.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}	

	void refreshButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		refreshButton_actionPerformed_Interaction1(event);
	}
	
	// Change Control:
	// 03-08-02 - Added boolean flag operation_mode to indicate if the user was in the
	//            search mode or analysis mode. This will prevent refresh action from 
	//            executing unless the user is in operation_mode true
	void refreshButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		Boolean checkbox_value = null;
		try {
		    if (this.getOperationMode()) {
			    this.analyzeAssessments();
			    
	            this.resultsModel.setColumnIdentifiers(this.result_table_headers);	        
	            DefaultCellEditor checkBoxEditor = new DefaultCellEditor(this.editor);
	        
		        this.results_table.getColumn("Select").setCellRenderer(new CheckBoxRenderer());
		        this.results_table.getColumn("Select").setCellEditor(new DefaultCellEditor(this.editor));	        	        	        	        
			}else {
			    this.parent.displayErrorDialog("You must submit search query before you can execute this action!");
			}		    
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void toggleButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		toggleButton_actionPerformed_Interaction1(event);
	}

    // Change Control:
    // 03-08-02 - see viewButton_actionPerformed_Interaction1(java.awt.event.ActionEvent)
    //            method
    // 05/19/02 - Removed refernce to JTable.getSelectedRow() this was the old method of
    //            selecting rows in the table.
	void toggleButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.getOperationMode()) {
			    this.toggleSelectedAssessments();
			}else {
			    this.parent.displayErrorDialog("You must submit search query before you can execute this action!");			    
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void importAssessmentButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		import_assessment_button_actionPerformed_Interaction1(event);
	}

	void import_assessment_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.showImportDialog();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void exportButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		exportButton_actionPerformed_Interaction1(event);
	}
	
    // Change Control:
    // 03-08-02 - see viewButton_actionPerformed_Interaction1(java.awt.event.ActionEvent)
    //            method
	void exportButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.getOperationMode()) {
			    this.saveFile();
			}else {
			    this.parent.displayErrorDialog("You must submit search query before you can execute this action!");			    			    
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void reset_button_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
		this.tableFieldBox.setEnabled(true);	 
        this.resetSearchPanel();
	}

	void search_button_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		search_button_actionPerformed_Interaction1(event);
	}

	void search_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.processSearchParameters();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void limitResultsField_mouseClicked(java.awt.event.MouseEvent event) {
		// to do: code goes here.
			 
		limit_results_field_mouseClicked_Interaction1(event);
	}

	void limit_results_field_mouseClicked_Interaction1(java.awt.event.MouseEvent event) {
		try {
			// limit_results_field Selects all the text
			// Modified - only select all of the text when the click count
			//            equals 2
			if (event.getClickCount() == 2) {
			    limit_results_field.selectAll();
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void asmntShowInfoDialog_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		asmntShowInfoDialog_actionPerformed_Interaction1(event);
	}

	void asmntShowInfoDialog_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.showInfoDialog();
		} catch (java.lang.Exception e) {
		}
	}

	void openReportsButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		open_reports_button_actionPerformed_Interaction1(event);
	}

	void open_reports_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openReportingFrame();
		} catch (java.lang.Exception e) {
		}
	}

	void deleteButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		deleteButton_actionPerformed_Interaction1(event);
	}

	void deleteButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.getOperationMode()) {
		        this.internal_setCursor("wait");
		        this.parent.setStatusMsg("Deleting selected assessment now, please hold.");
			    this.deleteSavedAssessment();
			    this.parent.setStatusMsg("");
			    this.internal_setCursor("default");
			}else {
			    this.parent.displayErrorDialog("You must selecte an assessment before you attempt to delete one!");    
			}
		} catch (java.lang.Exception e) {
		}
	}

	void beforeRadioButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		beforeRadioButton_actionPerformed_Interaction1(event);
	}

	void beforeRadioButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			afterRadioButton.setSelected(false);
		} catch (java.lang.Exception e) {
		}
	}

	void afterRadioButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		afterRadioButton_actionPerformed_Interaction1(event);
	}

	void afterRadioButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			beforeRadioButton.setSelected(false);
		} catch (java.lang.Exception e) {
		}
	}

	void newAssessmentButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		newAssessmentButton_actionPerformed_Interaction1(event);
	}

	void newAssessmentButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openNewAssessment();
		} catch (java.lang.Exception e) {
		}
	}

	void viewButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		viewButton_actionPerformed_Interaction1(event);
	}

	void viewButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openOldAssessment();
		} catch (java.lang.Exception e) {
		}
	}

	void asmntSaveResultsMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		asmntSaveResultsMenuItem_actionPerformed_Interaction1(event);
	}

	void asmntSaveResultsMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.saveFile();
		} catch (java.lang.Exception e) {
		}
	}

	void asmntDeleteMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		asmntDeleteMenuItem_actionPerformed_Interaction1(event);
	}

	void asmntDeleteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.deleteSavedAssessment();
		} catch (java.lang.Exception e) {
		}
	}

	void helpButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		helpButton_actionPerformed_Interaction1(event);
	}

	void helpButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openAssessmentHelp();
		} catch (java.lang.Exception e) {
		}
	}

    // This method is designed to maximize the the Assessment frame when it is deiconified
    // which is when the user clicks on the icon that represents the minimized Assessment
    // window to "restore" its original size.
	void AssessmentFrame_internalFrameDeiconified(javax.swing.event.InternalFrameEvent event)
	{
		// to do: code goes here.
		try {
		    setVisible(true);
		    setMaximum(true);
		    setWindowResized(true);
		}catch (Exception e) {
		    e.printStackTrace();
		}
	}
	
	private void newAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.openNewAssessment();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}
	
	private void importAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.showImportDialog();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}
	
	private void searchButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.processSearchParameters();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}
	
	private void resetButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.resetSearchPanel();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}		
	
	private void deleteAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.deleteSavedAssessment();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}	

	private void viewAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.openOldAssessment();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }	    
	}
	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == newAssessmentButton)
				newAssessmentButton_keyTyped(event);
			else if (object == viewButton)
				viewButton_keyTyped(event);
			else if (object == import_assessment_button)
				importAssessmentButton_keyTyped(event);
			else if (object == deleteButton)
				deleteButton_keyTyped(event);
			else if (object == reset_button)
				resetButton_keyTyped(event);
			else if (object == search_button)
				searchButton_keyTyped(event);
		}
	}

	void newAssessmentButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		newAssessmentButton_keyTyped_Interaction1(event);
	}

	void newAssessmentButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.newAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void viewButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		viewButton_keyTyped_Interaction1(event);
	}

	void viewButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.viewAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void importAssessmentButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		import_assessment_button_keyTyped_Interaction1(event);
	}

	void import_assessment_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.importAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void deleteButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		deleteButton_keyTyped_Interaction1(event);
	}

	void deleteButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.deleteAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	class SymComponent extends java.awt.event.ComponentAdapter
	{
		public void componentResized(java.awt.event.ComponentEvent event)
		{
			Object object = event.getSource();
			if (object == AssessmentFrame.this)
				AssessmentFrame_componentResized(event);
		}
	}

	void AssessmentFrame_componentResized(java.awt.event.ComponentEvent event)
	{
		// to do: code goes here.
		if (! this.getWindowResized()) {
		    this.setWindowResized(true);
		    this.basic_pane.setLayout(new GridLayout(4,3,10,0));
		}else {
		    this.setWindowResized(false);    
		    this.basic_pane.setLayout(new GridLayout(4,3,10,15));
		}
	}
	
	private void searchKeyEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.processSearchParameters();   
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void resetKeyEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.resetSearchPanel();   
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}	

	void resetButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		reset_button_keyTyped_Interaction1(event);
			 
		reset_button_keyTyped_Interaction2(event);
	}

	void reset_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.resetKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	class SymMouseMotion extends java.awt.event.MouseMotionAdapter
	{
		public void mouseMoved(java.awt.event.MouseEvent event)
		{
			Object object = event.getSource();
			if (object == AssessmentFrame.this)
				AssessmentFrame_mouseMoved(event);
		}
	}

	void AssessmentFrame_mouseMoved(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
	}

	void searchButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		search_button_keyTyped_Interaction1(event);
	}

	void search_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.searchKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void reset_button_keyTyped_Interaction2(java.awt.event.KeyEvent event)
	{
		try {
			this.resetButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
}/* end class AssessmentFrame() */