/***************************************************************************/
/* file - MenuCellRendererer.java                                          */
/* --------------------------------                                        */
/* This class provides the custom rendering for the menu options on the SAT*/
/* Admin tool. It uses the icons that are found in the images directory.   */
/* --------------------------------                                        */
/* Author - Mark McLarnon                                                  */
/* With Contributions: Nobuo Tamemasa                                      */
/* http://www.codeguru.com/java/articles/141.shtml                         */
/***************************************************************************/
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.io.File;
import javax.swing.*;
import javax.swing.tree.*;
import com.symantec.itools.javax.swing.*;
import com.sun.java.swing.*;

class MenuCellRenderer extends JPanel implements TreeCellRenderer {
    
    private ImageIcon newImage     = null;
    private ImageIcon defaultImage     = null;
    private ImageIcon findImage      = null;
    private ImageIcon questionImage    = null;
    private ImageIcon assessmentsImage = null;
    private ImageIcon reportImage = null;
    private ImageIcon addImage = null;
    private ImageIcon helpImage = null;
    
    protected JLabel       icon;
    protected TreeTextArea text;

    public MenuCellRenderer() {
        try {
           setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
           this.setBackground(Color.white);
           icon = new JLabel();
           add(icon);
           add(Box.createHorizontalStrut(4));
           add(text  = new TreeTextArea());

            newImage     = new ImageIcon("images" + File.separator + "new.gif");
            defaultImage     = new ImageIcon("images" + File.separator + "folder.gif");
            findImage      = new ImageIcon("images" + File.separator + "find16.gif");
            questionImage    = new ImageIcon("images" + File.separator + "default.gif");
            reportImage      = new ImageIcon("images" + File.separator + "report.gif");
            helpImage        = new ImageIcon("images" + File.separator + "about.gif");
        }catch (Exception e) {
            e.printStackTrace();    
        }
    }

    public Component getTreeCellRendererComponent(JTree tree, Object value,
        boolean isSelected, boolean expanded, boolean leaf, int row, boolean hasFocus) {
        tree.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.HAND_CURSOR));
        
        String  stringValue = tree.convertValueToText(value, isSelected,
                        expanded, leaf, row, hasFocus);
        setEnabled(tree.isEnabled());
        text.setText(stringValue);
        text.setSelect(isSelected);
        text.setFocus(hasFocus);
        
        if (stringValue.equals("Search for assessments")) {
            icon.setIcon(findImage);
        }else if (stringValue.equals("Create new assessment")) {
            icon.setIcon(newImage);
        }else if (stringValue.equals("Generate reports")) {
            icon.setIcon(reportImage);
        }else if (stringValue.equals("Help")) {
            icon.setIcon(helpImage);
        }else if (stringValue.equals("Change default browser")) {
            icon.setIcon(helpImage);
        }else if (stringValue.equals("About ASSET Manager")) {
            icon.setIcon(helpImage);
        }else {
            icon.setIcon(defaultImage);
        } 
        tree.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
        return this;
    }
            
    public Dimension getPreferredSize() {
        Dimension iconD = icon.getPreferredSize();
        Dimension textD = text.getPreferredSize();
        int height = iconD.height < textD.height ?
                 textD.height : iconD.height;
        return new Dimension(iconD.width + textD.width, height);
    }
   
    public void setBackground(Color color) {
        super.setBackground(color);
    }
    
    class TreeTextArea extends JTextArea {
        Dimension preferredSize;
    
        public TreeTextArea() {
            setLineWrap(true);
            setWrapStyleWord(true);
            setOpaque(true);
        }
    
        public void setBackground(Color color) {
            super.setBackground(color);
        }   
 
        public void setPreferredSize(Dimension d) {
            if (d != null) {
                preferredSize = d;
            }
        }
 
        public Dimension getPreferredSize() {
            return preferredSize;
        }

        public void setText(String str) {
            FontMetrics fm = getToolkit().getFontMetrics(getFont());
            BufferedReader br = new BufferedReader(new StringReader(str));
            String line;
            int maxWidth = 0,lines = 0;
            try {
                while ((line = br.readLine()) != null) {
                    int width = SwingUtilities.computeStringWidth(fm,line);
                    if (maxWidth < width) {
                        maxWidth = width;
                    }
                    lines++;
                }
            } catch (IOException ex) {
                ex.printStackTrace();
            }   
            lines = (lines < 1) ? 1: lines;  
            int height = fm.getHeight() * lines;
            setPreferredSize(new Dimension(maxWidth +6,height));
            super.setText(str);
        }
    
        void setSelect(boolean isSelected) {
            Color bColor;
            if (isSelected) {
                bColor = UIManager.getColor("Tree.selectionBackground");
            } else {
                bColor = UIManager.getColor("Tree.textBackground");
            }
            super.setBackground(bColor);
        }
    
        void setFocus(boolean hasFocus) {
            if (hasFocus) {
                Color lineColor = UIManager.getColor("Tree.selectionBorderColor");
                setBorder(BorderFactory.createLineBorder(lineColor));
            } else {
                setBorder(BorderFactory.createEmptyBorder(1,1,1,1));
            }      
        }
    }/* end inner class TreeTextArea() */  
    
} /* end class MenuCellRenderer() */