/********************************************************************************/
/* file - ReportingFrame.java                                                   */
/* --------------------------                                                   */
/* This class implements the user interface for presenting reports within the   */
/* administration tool. The significant part of this class is that it can       */
/* perform all of the reports that the client reporting class can perform in    */
/* addition to the administration reports.                                      */
/* --------------------------                                                   */
/* NIST Self-Assessment Tool                                                    */
/* Author - Mark McLarnon                                                       */
/* --------------------------                                                   */
/* Change Control:                                                              */
/* 05/09/02 - Added tab key actions to cycle between buttons on the toolbar.    */
/*          - Added action handlers for enter key being pressed on the buttons  */
/*            on the toolbar.                                                   */
/********************************************************************************/
import java.awt.*;
import javax.swing.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.table.*;
import java.sql.*;
import java.io.*;
import com.symantec.itools.javax.swing.borders.EmptyBorder;
import com.symantec.itools.javax.swing.icons.ImageIcon;
import com.symantec.itools.javax.swing.borders.EtchedBorder;
import com.symantec.itools.javax.swing.JChart;
import com.symantec.itools.javax.swing.models.StringComboBoxModel;
import com.symantec.itools.javax.swing.models.StringTableModel;
import com.symantec.itools.javax.swing.borders.BevelBorder;
import com.symantec.itools.javax.swing.JSplitPaneWrapper;
import com.symantec.itools.javax.swing.actions.JActionButton;
import com.symantec.itools.javax.swing.JWrappingLabel;


public class ReportingFrame extends javax.swing.JInternalFrame implements ASSETChild {

	public ReportingFrame() {
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setIconifiable(true);
		setTitle("ASSET Reporting");
		setAlignmentY(0.0F);
		try {
			setSelected(true);
		}
		catch(java.beans.PropertyVetoException e) { }
		setClosable(true);
		setToolTipText("<html>ASSET System Reporting Window</html>");
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.X_AXIS));
		setSize(725,473);
		try {
			reportIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/report.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ reportIcon.move(24,474);
		JPanel1.setLayout(new BorderLayout(0,0));
		getContentPane().add(JPanel1);
		JScrollPane1.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
		JScrollPane1.setOpaque(true);
		JPanel1.add(BorderLayout.CENTER, JScrollPane1);
		JPanel3.setAlignmentY(0.0F);
		JPanel3.setLayout(new BorderLayout(0,0));
		JScrollPane1.getViewport().add(JPanel3);
		JPanel3.setBounds(0,0,722,470);
		JPanel16.setAlignmentY(0.444444F);
		JPanel16.setLayout(new BoxLayout(JPanel16,BoxLayout.X_AXIS));
		JPanel3.add(BorderLayout.NORTH, JPanel16);
		JToolBar1.setAlignmentY(0.478261F);
		JPanel16.add(JToolBar1);
		exportResultsButton.setNextFocusableComponent(setActiveAssessmentButton);
		exportResultsButton.setDefaultCapable(false);
		exportResultsButton.setToolTipText("<html>Save results to file</html>");
		JToolBar1.add(exportResultsButton);
		setActiveAssessmentButton.setNextFocusableComponent(helpButton);
		setActiveAssessmentButton.setDefaultCapable(false);
		setActiveAssessmentButton.setToolTipText("<html>Set active assessment</html>");
		JToolBar1.add(setActiveAssessmentButton);
		helpButton.setActionCommand("creatingreports");
		helpButton.setDefaultCapable(false);
		helpButton.setToolTipText("<html>Open help on reporting</html>");
		JToolBar1.add(helpButton);
		JPanel3.add(BorderLayout.CENTER, JTabbedPane1);
		adminReports.setBorder(etchedBorder1);
		adminReports.setToolTipText("<html>Shows the manager reports you can execute</html>");
		adminReports.setLayout(new BoxLayout(adminReports,BoxLayout.X_AXIS));
		JTabbedPane1.add(adminReports);
		adminReports.setBounds(2,24,717,416);
		adminReports.setVisible(false);
		JPanel33.setLayout(new GridLayout(10,1,0,0));
		adminReports.add(JPanel33);
		JLabel22.setText("Available Reports:");
		JPanel33.add(JLabel22);
		JLabel22.setForeground(java.awt.Color.black);
		report1_panel.setLayout(new BorderLayout(0,0));
		JPanel33.add(report1_panel);
		JLabel23.setText(" ");
		report1_panel.add(BorderLayout.WEST, JLabel23);
		report2_panel.setLayout(new BorderLayout(0,0));
		JPanel33.add(report2_panel);
		JLabel24.setText(" ");
		report2_panel.add(BorderLayout.WEST, JLabel24);
		report3_panel.setLayout(new BorderLayout(0,0));
		JPanel33.add(report3_panel);
		JLabel25.setText(" ");
		report3_panel.add(BorderLayout.WEST, JLabel25);
		report4_panel.setLayout(new BorderLayout(0,0));
		JPanel33.add(report4_panel);
		JLabel26.setText(" ");
		report4_panel.add(BorderLayout.WEST, JLabel26);
		JPanel34.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		adminReports.add(JPanel34);
		clientReports.setAlignmentY(0.0F);
		clientReports.setBorder(etchedBorder1);
		clientReports.setLayout(new BoxLayout(clientReports,BoxLayout.X_AXIS));
		JTabbedPane1.add(clientReports);
		clientReports.setBounds(2,24,717,416);
		clientReports.setVisible(false);
		clientReports.add(JSplitPaneWrapper1);
		JPanel17.setAlignmentY(0.497959F);
		JPanel17.setLayout(new BoxLayout(JPanel17,BoxLayout.X_AXIS));
		JSplitPaneWrapper1.add(JPanel17);
		JPanel17.setBounds(1,1,171,410);
		JPanel14.setLayout(new GridLayout(7,1,0,0));
		JPanel17.add(JPanel14);
		JPanel10.setLayout(new FlowLayout(FlowLayout.LEFT,0,9));
		JPanel14.add(JPanel10);
		JLabel6.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		JLabel6.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JLabel6.setText("Active System Information:");
		JPanel10.add(JLabel6);
		JLabel6.setForeground(java.awt.Color.black);
		JPanel11.setLayout(new GridLayout(2,1,0,0));
		JPanel14.add(JPanel11);
		JLabel4.setText("System Name:");
		JPanel11.add(JLabel4);
		JLabel4.setForeground(java.awt.Color.black);
		JLabel4.setFont(new Font("Dialog", Font.BOLD, 12));
		system_name_label.setText("No active system specified");
		JPanel11.add(system_name_label);
		system_name_label.setForeground(java.awt.Color.black);
		system_name_label.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel25.setLayout(new GridLayout(2,1,0,0));
		JPanel14.add(JPanel25);
		JLabel14.setText("System Number:");
		JPanel25.add(JLabel14);
		JLabel14.setForeground(java.awt.Color.black);
		system_number_field.setText("No number specified");
		JPanel25.add(system_number_field);
		system_number_field.setForeground(java.awt.Color.black);
		system_number_field.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel12.setLayout(new GridLayout(2,1,0,0));
		JPanel14.add(JPanel12);
		JLabel7.setText("Assessment Start Date:");
		JPanel12.add(JLabel7);
		JLabel7.setForeground(java.awt.Color.black);
		JLabel7.setFont(new Font("Dialog", Font.BOLD, 12));
		system_date_label.setText("No date specified");
		JPanel12.add(system_date_label);
		system_date_label.setForeground(java.awt.Color.black);
		system_date_label.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel18.setLayout(new GridLayout(2,1,0,0));
		JPanel14.add(JPanel18);
		JLabel8.setText("System Identifier:");
		JPanel18.add(JLabel8);
		JLabel8.setForeground(java.awt.Color.black);
		JLabel8.setFont(new Font("Dialog", Font.BOLD, 12));
		try {
			system_id_label.setText("No identifier specified");
		}
		catch(java.beans.PropertyVetoException e) { }
		JPanel18.add(system_id_label);
		change_active_system_button_panel.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel14.add(change_active_system_button_panel);
		JButton1.setText("Change Active System");
		JButton1.setActionCommand("Change Active System");
		change_active_system_button_panel.add(JButton1);
		JPanel2.setBorder(report_pane_border);
		JPanel2.setToolTipText("<html>Shows the system reports you can execute</html>");
		JPanel2.setLayout(new BoxLayout(JPanel2,BoxLayout.X_AXIS));
		JSplitPaneWrapper1.add(JPanel2);
		JPanel2.setBounds(182,1,530,410);
		JPanel4.setLayout(new GridLayout(6,1,0,0));
		JPanel2.add(JPanel4);
		JLabel1.setIconTextGap(0);
		JLabel1.setText("Available Reports:");
		JPanel4.add(JLabel1);
		JLabel1.setForeground(java.awt.Color.black);
		JPanel9.setLayout(new BorderLayout(0,0));
		JPanel4.add(JPanel9);
		JLabel5.setText(" ");
		JPanel9.add(BorderLayout.WEST, JLabel5);
		JPanel8.setLayout(new BorderLayout(0,0));
		JPanel4.add(JPanel8);
		JLabel2.setText(" ");
		JPanel8.add(BorderLayout.WEST, JLabel2);
		JPanel6.setLayout(new BorderLayout(0,0));
		JPanel4.add(JPanel6);
		JLabel3.setText(" ");
		JPanel6.add(BorderLayout.WEST, JLabel3);
		JPanel13.setLayout(new BorderLayout(0,0));
		JPanel4.add(JPanel13);
		JLabel9.setText(" ");
		JPanel13.add(BorderLayout.WEST, JLabel9);
		JPanel5.setLayout(new FlowLayout(FlowLayout.CENTER,0,0));
		JPanel2.add(JPanel5);
		results_panel.setLayout(new BorderLayout(0,0));
		JTabbedPane1.add(results_panel);
		results_panel.setBounds(2,24,717,416);
		results_panel.setVisible(false);
		JPanel20.setBorder(report_header_border);
		JPanel20.setToolTipText("<html>Report headers are listed here</html>");
		JPanel20.setLayout(new GridLayout(2,2,0,5));
		results_panel.add(BorderLayout.NORTH, JPanel20);
		JPanel21.setLayout(new BorderLayout(0,0));
		JPanel20.add(JPanel21);
		JLabel11.setText("Report:  ");
		JPanel21.add(BorderLayout.WEST, JLabel11);
		JLabel11.setForeground(java.awt.Color.black);
		JPanel21.add(BorderLayout.CENTER, report_name);
		report_name.setForeground(java.awt.Color.black);
		report_name.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel28.setLayout(new BorderLayout(0,0));
		JPanel20.add(JPanel28);
		JLabel16.setText("Today\'s Date:  ");
		JPanel28.add(BorderLayout.WEST, JLabel16);
		JLabel16.setForeground(java.awt.Color.black);
		JPanel28.add(BorderLayout.CENTER, report_generated_date);
		report_generated_date.setForeground(java.awt.Color.black);
		report_generated_date.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel29.setLayout(new BorderLayout(0,0));
		JPanel20.add(JPanel29);
		JLabel19.setText("Totals:  ");
		JPanel29.add(BorderLayout.WEST, JLabel19);
		JLabel19.setForeground(java.awt.Color.black);
		JPanel29.add(BorderLayout.CENTER, totals_label);
		totals_label.setForeground(java.awt.Color.black);
		totals_label.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel26.setLayout(new BorderLayout(0,0));
		JPanel20.add(JPanel26);
		JLabel17.setText("Generated By:  ");
		JPanel26.add(BorderLayout.WEST, JLabel17);
		JLabel17.setForeground(java.awt.Color.black);
		JPanel26.add(BorderLayout.CENTER, primary_assessor);
		primary_assessor.setForeground(java.awt.Color.black);
		primary_assessor.setFont(new Font("Dialog", Font.PLAIN, 12));
		JScrollPane2.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		JScrollPane2.setOpaque(true);
		JScrollPane2.setToolTipText("<html>Shows the results of the report you chose</html>");
		results_panel.add(BorderLayout.CENTER, JScrollPane2);
		report_table.setPreferredScrollableViewportSize(new java.awt.Dimension(450,300));
		JScrollPane2.getViewport().add(report_table);
		report_table.setBounds(0,0,699,0);
		JTabbedPane1.setSelectedIndex(1);
		JTabbedPane1.setSelectedComponent(clientReports);
		JTabbedPane1.setTitleAt(0,"Manager Reports");
		JTabbedPane1.setTitleAt(1,"System Reports");
		JTabbedPane1.setTitleAt(2,"Tabular Output");
		report_title_label_border.setInsets(new java.awt.Insets(10,10,0,0));
		//$$ report_title_label_border.move(0,474);
		report_pane_border.setInsets(new java.awt.Insets(0,15,0,0));
		//$$ report_pane_border.move(24,474);
		try {
			saveIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/save.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ saveIcon.move(48,474);
		report_header_border.setInsets(new java.awt.Insets(10,10,0,0));
		//$$ report_header_border.move(72,474);
		try {
			helpIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/about.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ helpIcon.move(240,474);
		try {
			imageIcon1.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/preview.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon1.move(96,474);
		//$$ etchedBorder1.move(120,474);
		{
			String[] tempString = new String[2];
			tempString[0] = "Bar Graph";
			tempString[1] = "Pie Chart";
			graphic_report_style.setItems(tempString);
		}
		//$$ graphic_report_style.move(144,474);
		//$$ chart_data_model.move(168,474);
		try {
			imageIcon2.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/open.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ imageIcon2.move(192,474);
		emptyBorder1.setInsets(new java.awt.Insets(0,4,4,0));
		//$$ emptyBorder1.move(216,474);
		helpButton.setIcon(helpIcon);
		exportResultsButton.setIcon(saveIcon);
		JLabel5.setIcon(reportIcon);
		setActiveAssessmentButton.setIcon(imageIcon2);
		JLabel25.setIcon(reportIcon);
		JLabel26.setIcon(reportIcon);
		JLabel24.setIcon(reportIcon);
		JLabel23.setIcon(reportIcon);
		JLabel3.setIcon(reportIcon);
		JLabel9.setIcon(reportIcon);
		JLabel2.setIcon(reportIcon);
		//}}	
		this.admin_system_summary = HTMLLabel.createNewHTMLLabel("Summary of all Systems");
		this.admin_system_summary.addMouseListener(aSymMouse);
		this.report1_panel.add(BorderLayout.CENTER, admin_system_summary);
		
		this.admin_type_summary = HTMLLabel.createNewHTMLLabel("Summary of System Types");
		this.admin_type_summary.addMouseListener(aSymMouse);
		this.report2_panel.add(BorderLayout.CENTER, this.admin_type_summary);
		
		this.admin_sensitivity_summary = HTMLLabel.createNewHTMLLabel("Summary of Systems by Sensitivity");
		this.admin_sensitivity_summary.addMouseListener(aSymMouse);
		this.report3_panel.add(BorderLayout.CENTER, this.admin_sensitivity_summary);
		
		this.admin_org_summary = HTMLLabel.createNewHTMLLabel("Summary of Systems by Organization");
		this.admin_org_summary.addMouseListener(aSymMouse);
		this.report4_panel.add(BorderLayout.CENTER, this.admin_org_summary);
		
		this.na_summary = HTMLLabel.createNewHTMLLabel("List of non-applicable questions");
        this.na_summary.addMouseListener(aSymMouse);
        this.JPanel8.add(BorderLayout.CENTER, this.na_summary);
        
        this.assessment_summary = HTMLLabel.createNewHTMLLabel("List of risk based decisions");
        this.assessment_summary.addMouseListener(aSymMouse);
        this.JPanel6.add(BorderLayout.CENTER, this.assessment_summary); 

        this.topic_summary = HTMLLabel.createNewHTMLLabel("Summary of topic areas by levels of effectiveness");
        this.topic_summary.addMouseListener(aSymMouse);
        this.JPanel9.add(BorderLayout.CENTER, this.topic_summary);         

        this.system_summary = HTMLLabel.createNewHTMLLabel("System Summary");
        this.system_summary.addMouseListener(aSymMouse);
        this.JPanel13.add(BorderLayout.CENTER, this.system_summary);         
        
        this.buildReportMap();  
        this.buildITSAFMap();
        this.prgMonitor = new ProgressDialog();        
	
		//{{REGISTER_LISTENERS
		SymInternalFrame lSymInternalFrame = new SymInternalFrame();
		this.addInternalFrameListener(lSymInternalFrame);
		SymAction lSymAction = new SymAction();
		setActiveAssessmentButton.addActionListener(lSymAction);
		exportResultsButton.addActionListener(lSymAction);
		JButton1.addActionListener(lSymAction);
		helpButton.addActionListener(lSymAction);
		SymChange lSymChange = new SymChange();
		JTabbedPane1.addChangeListener(lSymChange);
		SymKey aSymKey = new SymKey();
		exportResultsButton.addKeyListener(aSymKey);
		setActiveAssessmentButton.addKeyListener(aSymKey);
		helpButton.addKeyListener(aSymKey);
		//}}
		this.JTabbedPane1.setSelectedIndex(0);
		fileSaver.addChoosableFileFilter(new TXTFilter());
	}/* end default constructor ReportingFrame() */
	
    public String getFullPath(String local_path) {
        StringBuffer file_name = new StringBuffer("");
        try {
            file_name.append((symantec.itools.net.RelativeURL.getURL(local_path)).toString());
        }catch (Exception e) {
            e.printStackTrace();
        }
        return file_name.toString();
    }	
    
    private void execute(String cmd) {
        try {
            
             Runtime subsystem = Runtime.getRuntime();
             if (this.checkDefaultBrowserSet()) {
                 subsystem.exec(cmd);
             }else {
                ChooseBrowserWizard wiz = ChooseBrowserWizard.spawnNewChooseBrowserWizard(this.parent, this.parent.getPropertyManager());                
             }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public boolean checkDefaultBrowserSet() {
        boolean flag = true;
        try {
            if (this.parent.getPropertyManager().getProperty("sat.help.defaultbrowser") == null) {
                flag = false;
            }
            
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
    }    
	
    public void openAssessmentHelp() {
        this.execute(this.parent.getPropertyManager().getProperty("sat.help.defaultbrowser") + " " + this.getFullPath(this.parent.getPropertyManager().getProperty("sat.manager.help.reportingdocument")));        
    }	
	
	// THis method forces the repaint of the entire instance of ReportingFrame. It
	// is designed to guard against the case when a user quickly switches between
	// tabs and causes overlap in the painting of the tabs.
	private void forceRepaint() {
	    try {
	        Graphics g = this.getGraphics();
	        this.update(g);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void parentApplicationClosing() {
        CallableStatement query = null;
        Connection conn = this.parent.connectionGenerator();
	    try {
	        if (this.isReportActive()) {
	    	    int reply = JOptionPane.showConfirmDialog(this, 
                    "Do you want to save your active report?", 
                    "Save Active Report?" , 
                    JOptionPane.YES_NO_OPTION, 
                    JOptionPane.QUESTION_MESSAGE);
                   
                if (reply == JOptionPane.YES_OPTION) {
                    this.saveFile();
                }
	    	}
	    	this.internal_setCursor("wait");	 
	    	this.parent.setStatusMsg("Reseting active assessments now, please hold");
	    	query = conn.prepareCall("{call rpt_reset_active_assessments}");
	    	query.executeUpdate();
	    	this.parent.setStatusMsg("");
	    	this.internal_setCursor("default");
	    	
	    	this.dispose();
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method parentApplicationClosing() */
	
    public boolean getSupportsSave() {
        return true;    
    }
	
	public void store() {
	    this.parent.displayErrorDialog("There is no data to store in the database");    
	}
	
	public void saveLocally() {
	    this.saveFile();   
	}
	
	private void buildITSAFMap() {
	    try {
	        this.itsaf_map.put(new Integer(1), "Policy");
	        this.itsaf_map.put(new Integer(2), "Procedures");
	        this.itsaf_map.put(new Integer(3), "Implemented");
	        this.itsaf_map.put(new Integer(4), "Tested");
	        this.itsaf_map.put(new Integer(5), "Integrated");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void buildReportMap() {
	    try {
            this.report_map.put("Summary of topic areas by levels of effectiveness", "get_policy_results_and_text");
	        this.report_map.put("List of non-applicable questions", "get_na_questions");
	        this.report_map.put("List of risk based decisions", "get_rbdm_questions");
	        this.report_map.put("System Summary", "get_summary_question_results");  	        
	        this.report_map.put("Summary of all Systems", "get_all_assessment_information");
	        this.report_map.put("Summary of System Types", "get_systems_by_type");
	        this.report_map.put("Summary of Systems by Sensitivity", "get_system_sensitivity");
	        this.report_map.put("Summary of Systems by Organization", "get_system_organization");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	  
	private void setReportHeadersToAdminSystemSummary() {
	    this.table_headers = new Vector();
	    this.table_headers.addElement("Name");
	    this.table_headers.addElement("Number");
	    this.table_headers.addElement("Type");
	    this.table_headers.addElement("Organization");
	    this.table_headers.addElement("Primary Assessor");
	    this.table_headers.addElement("Confidentiality");
	    this.table_headers.addElement("Integrity");
	    this.table_headers.addElement("Availability");
	    this.table_headers.addElement("Risk Management");
	    this.table_headers.addElement("Review of Security Controls");
	    this.table_headers.addElement("Life Cycle");
	    this.table_headers.addElement("Authorize Processing (Certification and Accreditation)");
	    this.table_headers.addElement("System Security Plan");
	    this.table_headers.addElement("Personnel Security");
	    this.table_headers.addElement("Physical Security");
	    this.table_headers.addElement("Production, Input/Output Controls");
	    this.table_headers.addElement("Contingency Planning");
	    this.table_headers.addElement("Hardware and Systems Software Maintenance");
	    this.table_headers.addElement("Data Integrity");
	    this.table_headers.addElement("Documentation");
	    this.table_headers.addElement("Security Awareness, Training, and Education");
	    this.table_headers.addElement("Incident Response Capability");
	    this.table_headers.addElement("Identification and Authentication");
	    this.table_headers.addElement("Logical Access Controls");
	    this.table_headers.addElement("Audit Trails");
	    this.table_headers.addElement("Completed?");
	}
	  
	private void setReportHeadersToAdminSystemType() {
	    this.table_headers = new Vector();   
	    this.table_headers.addElement("Name");
	    this.table_headers.addElement("Number");
	    this.table_headers.addElement("Type");

	}
	
	private void setReportHeadersToAdminSystemSensivity() {
	    this.table_headers = new Vector();
	    this.table_headers.addElement("Name");
	    this.table_headers.addElement("Number");
	    this.table_headers.addElement("Confidentiality");
	    this.table_headers.addElement("Integrity");
	    this.table_headers.addElement("Availability");
	}
	
	private void setReportHeadersToAdminSystemOrganization() {
	    this.table_headers = new Vector();
	    this.table_headers.addElement("Name");
	    this.table_headers.addElement("Number");
	    this.table_headers.addElement("Organization");
	}	
	  
    private void setReportHeadersToSystemSummary() {
        try {
            this.table_headers = new Vector();
            this.table_headers.addElement("Question #");
            this.table_headers.addElement("Question Text");
            this.table_headers.addElement("Level Reached");
            this.table_headers.addElement("N/A");
            this.table_headers.addElement("Risk Based Decision?");
            this.table_headers.addElement("Comments");
            this.table_headers.addElement("Answered By");
            this.table_headers.addElement("Completed?");
            this.table_headers.addElement("Refer To");
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }	    
    
    private void setReportHeadersToTopicAreaSummary() {
        try {
            this.table_headers = new Vector();
            this.table_headers.addElement("Topic #");
            this.table_headers.addElement("Topic Area");
            this.table_headers.addElement("Level");                        
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }
    	    
    private void setReportHeadersToNAQuestionsSummary() {
        try {
            this.table_headers = new Vector();
            this.table_headers.addElement("Question #");
            this.table_headers.addElement("Question Text");
            this.table_headers.addElement("Comments");                        
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }
    
    private void setReportHeadersToRiskBasedQuestionsSummary() {
        try {
            this.table_headers = new Vector();
            this.table_headers.addElement("Question Number");
            this.table_headers.addElement("Question Text");
            this.table_headers.addElement("Comments");
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }  

    private void clearReportHeaders() {
        try {
            this.report_name.setText("");
            this.report_generated_date.setText("");
            this.totals_label.setText("");
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }

	public void clearResultsTable() {
        try {
            this.clearReportHeaders();
            this.report_model.setDataVector(new Vector(), this.table_headers);
            this.prepareResultsTable();
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
		
	public void setPrimaryAssessor(String assessor_name) {
	    try {
	        this.primary_assessor.setText(assessor_name);    
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// This method is designed to encapsulate changing the cursor type
	// it is used to show the user that an action is occurring that needs 
	// to pause for.
	private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
		
    public void prepareResultsTable() {
        try {
            this.report_model.setColumnIdentifiers(this.table_headers);
            this.report_table.setModel(this.report_model);          
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
		
	// This method builds the reports for the ASSET Manager. NOTE That the ASSET 
	// Manager reports require no parameter within the call to their associated 
	// stored procedure this means that the call to the stored procedures must 
	// be re-initialized.
	// ---------------
	// Change Control:
	// 05/09/02 - Added code to change the resize method of the results table 
	//            when the user selects the summary of all systems report, this 
	//            is the report that has a large number of columns. When the 
	//            method is executed first the resize method is set to auto 
	//            resize all columns and then when the summary of all systems 
	//            report is executed, this is when the resize method is turned 
	//            off.
    // 05/10/02 - Added in call to String.trim() method to ensure that the 
    //            infamous ... does not appear anywhere for values of the 
    //            summary of all systems report.
    public void buildSummaryReport(String report_type) {
        CallableStatement query = null;
        CallableStatement second_query = null;
        ResultSet query_result = null;
        ResultSet second_query_result = null;
        CallableStatement subr_ques = null;
        ResultSet subordinate_ques_results = null;
        Connection conn = null;
        Vector table_row = new Vector();
        StringBuffer id = new StringBuffer("");
        StringBuffer number = new StringBuffer(""); 
        StringBuffer temp = new StringBuffer("");
        StringBuffer temp2 = new StringBuffer("");
        String text = ""; 
        int major = 0;
        int minor = 0;
        int num = 0;   
        int completed = 0;
        int policy_level1 = 0;
        int level1_total = 0;
        int level2_total = 0;
        int level3_total = 0;
        int level4_total = 0;
        int level5_total = 0;
        int question_count = 0;
        try {
            this.report_table.setAutoResizeMode(this.report_table.AUTO_RESIZE_ALL_COLUMNS);
            this.prgMonitor.clear();
            this.prgMonitor.setProgressMax(100);
            this.prgMonitor.setVisible(true);
            this.internal_setCursor("wait");
            this.toggleOperationMode();
            this.clearResultsTable();
            this.parent.setStatusMsg("Building report now, please hold");
                        
            conn = this.parent.connectionGenerator();
            if (conn != null) {
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "(?)}");                        
            }else {
                this.parent.setStatusModeMsg("ERROR");
                this.parent.setStatusMsg("Cannot connect to ASSET Manager database, destroying report now!");
                {
                    this.parent.displayErrorDialog("Could not establish a valid connection to the database!\n ASSET Manager will now terminate.");
                }
                this.parent.setStatusModeMsg("Idle...");
                this.parent.setStatusMsg("");                
                System.exit(1);
            }
            this.report_generated_date.setText(new java.util.Date().toString());              
            
            this.setReportActive(true);
            this.primary_assessor.setText(this.creator.getFullName());
            if (report_type.equals("Summary of all Systems")) {
                this.parent.setStatusMsg("Building report now, please hold!!");
                this.prgMonitor.setStatusBusyMessage("Building summary of all systems now, please hold.");
                this.report_name.setText("Summary of all Systems");
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "}");
                
                this.setReportHeadersToAdminSystemSummary();
                this.prepareResultsTable();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "}");
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(37);   
                Connection conn2 = null;
                while (query_result.next()) {
                    table_row = new Vector();
                    number = new StringBuffer("");   
                    id = new StringBuffer((query_result.getString("assessment_id")).trim());
                    if (query_result.getInt("completed") == 1) {
                        text = "Yes";
                    }else {
                        text = "No";    
                    } 
                    
                    number.append((query_result.getString("primary_assessor")).trim());
                    temp = new StringBuffer((query_result.getString("component_num")).trim());
                    
                    temp2 = new StringBuffer((query_result.getString("location")).trim());
                    
                    table_row.addElement((query_result.getString("component_name")).trim());
                    table_row.addElement(temp.toString());
                    table_row.addElement((query_result.getString("component_type")).trim());
                    table_row.addElement(temp2.toString());
                    table_row.addElement(number.toString());
                    table_row.addElement((query_result.getString("confidentiality")).trim());
                    table_row.addElement((query_result.getString("integrity")).trim());
                    table_row.addElement((query_result.getString("availability")).trim());
                    // Begin Section To Compute Results of Topic Areas
                    conn2 = this.parent.connectionGenerator();
                    second_query = conn2.prepareCall("{call get_policy_results_and_text (?)}");
                    second_query.setString(1, id.toString());
                    second_query_result = second_query.executeQuery();
                    while (second_query_result.next()) {
                        Connection conn3 = this.parent.connectionGenerator();
                        number = new StringBuffer("");    
                        major = second_query_result.getInt("major_section");
                        minor = second_query_result.getInt("minor_section");
                        num = second_query_result.getInt("question_number");
                        number.append(major + "." + minor + "." + num);
                        policy_level1 = second_query_result.getInt("level1");
                        if (policy_level1 != 0) {
                            subr_ques = conn3.prepareCall("{call get_question_results_per_policy(?, ?)}");
                            subr_ques.setString(1, id.toString());
                            subr_ques.setInt(2, major);
                            subordinate_ques_results = subr_ques.executeQuery();
                    
                            level1_total = 0;
                            level2_total = 0;
                            level3_total = 0;
                            level4_total = 0;
                            level5_total = 0;
                            int na = 0;
                            question_count = 0;
                            while (subordinate_ques_results.next()) {
                                level1_total += subordinate_ques_results.getInt("level1");
                                level2_total += subordinate_ques_results.getInt("level2");
                                level3_total += subordinate_ques_results.getInt("level3");
                                level4_total += subordinate_ques_results.getInt("level4");
                                level5_total += subordinate_ques_results.getInt("level5");
                                na += subordinate_ques_results.getInt("na");
                                question_count++;
                            }
                            if (question_count != na) {
                                question_count = question_count - na;
                            }else {
                                question_count = 1;    
                            }                       
                    
                            if (level1_total >= question_count) {
                                if (level2_total >= question_count) {
                                    if (level3_total >= question_count) {
                                        if (level4_total >= question_count) {
                                            if (level5_total >= question_count) {
                                                table_row.addElement((String) this.itsaf_map.get(new Integer(5)));   
                                            }else {
                                                table_row.addElement((String) this.itsaf_map.get(new Integer(4)));    
                                            }
                                        }else {
                                            table_row.addElement((String) this.itsaf_map.get(new Integer(3)));
                                        }
                                    }else {
                                        table_row.addElement((String) this.itsaf_map.get(new Integer(2)));
                                    }
                                }else {
                                    table_row.addElement((String) this.itsaf_map.get(new Integer(1)));
                                }
                            }else {
                                if (question_count > 1) {
                                    table_row.addElement("None");    
                                }else {
                                    table_row.addElement((String) this.itsaf_map.get(new Integer(1)));
                                }
                            }                                        
                        }else {
                            table_row.addElement("None"); 
                        }
                        if (question_count == 0) {
                            table_row.addElement("None"); 
                        }
                    }
                    conn2.close();
                    // End section to compute results of topic areas
                    table_row.addElement(text);
                    this.report_model.addRow(table_row);
                    this.report_table.setAutoResizeMode(this.report_table.AUTO_RESIZE_OFF);
                }                
                this.prgMonitor.setNormalizedProgress(70);                
            }
            
            if (report_type.equals("Summary of System Types")) {
                this.prgMonitor.setStatusBusyMessage("Building summary of system types, please hold.");
                this.report_name.setText("Summary of System Types");
                this.setReportHeadersToAdminSystemType();
                
                this.prepareResultsTable();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "}");
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(37);   
                while (query_result.next()) {
                    table_row = new Vector();
                    number = new StringBuffer("");
                    number.append(query_result.getString("component_num").trim());
                    text = query_result.getString("component_name").trim();
                    table_row.addElement(text);
                    table_row.addElement(number.toString());                    
                    table_row.addElement(query_result.getString("component_type"));
                    this.report_model.addRow(table_row);
                }
                this.prgMonitor.setNormalizedProgress(70);
            }
            
            if (report_type.equals("Summary of Systems by Sensitivity")) {
                this.prgMonitor.setStatusBusyMessage("Building summary of system sensitivities now, please hold.");
                this.report_name.setText("Summary of Systems by Sensitivity");
                this.setReportHeadersToAdminSystemSensivity();
                
                this.prepareResultsTable();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "}");
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(40);
                while (query_result.next()) {
                    table_row = new Vector();
                    number = new StringBuffer("");
                    number.append(query_result.getString("component_num").trim());
                    text = query_result.getString("component_name").trim();
                    table_row.addElement(text);
                    table_row.addElement(number.toString());
                    table_row.addElement(query_result.getString("confidentiality"));
                    table_row.addElement(query_result.getString("integrity"));
                    table_row.addElement(query_result.getString("availability"));
                    
                    this.report_model.addRow(table_row);
                }   
                this.prgMonitor.setNormalizedProgress(70);
            }
            
            if (report_type.equals("Summary of Systems by Organization")) {
                this.prgMonitor.setStatusBusyMessage("Building summary of topics areas report now, please hold");
                this.report_name.setText("Summary of Systems by Organization");
                this.setReportHeadersToAdminSystemOrganization();
                
                this.prepareResultsTable();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "}");
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(35); 
                while (query_result.next()) {
                    table_row = new Vector();
                    number = new StringBuffer("");
                    number.append(query_result.getString("component_num").trim());
                    text = query_result.getString("component_name").trim();
                    table_row.addElement(text);
                    table_row.addElement(number.toString());
                    table_row.addElement(query_result.getString("location").trim());
                    
                    this.report_model.addRow(table_row);
                } 
                this.prgMonitor.setNormalizedProgress(70);
            }
            
            if (report_type.equals("Summary of topic areas by levels of effectiveness")) {
                this.prgMonitor.setStatusBusyMessage("Building summary of topics areas report now, please hold");
                
                this.report_name.setText("Summary of topic areas by level of effectiveness");   
                query.setString(1, this.getActiveAssessment());
                this.setReportHeadersToTopicAreaSummary();
                this.report_model.setColumnIdentifiers(this.table_headers);
                this.report_table.setModel(this.report_model);          
                
                TableColumnModel model = report_table.getColumnModel();
                for (int i = 0; i < (this.table_headers).size(); i++) {
                    (model.getColumn(i)).setHeaderRenderer(renderer);
                }                
                JTableHeader header = report_table.getTableHeader();
                header.addMouseListener(new HeaderListener(header,renderer));  
                
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(50);                  
                                
                while (query_result.next()) {
                    Connection conn2 = this.parent.connectionGenerator();
                    table_row = new Vector();
                    number = new StringBuffer("");    
                    text = query_result.getString("question_text");
                    major = query_result.getInt("major_section");
                    minor = query_result.getInt("minor_section");
                    num = query_result.getInt("question_number");
                    number.append(major + "." + minor + "." + num);
                    table_row.addElement(number.toString());                                        
                    table_row.addElement(text);
                    policy_level1 = query_result.getInt("level1");
                    if (policy_level1 != 0) {
                        System.out.println("NOw examining question results for control objective #" + major);
                        subr_ques = conn2.prepareCall("{call get_question_results_per_policy(?, ?)}");
                        subr_ques.setString(1, this.getActiveAssessment());
                        subr_ques.setInt(2, major);
                        subordinate_ques_results = subr_ques.executeQuery();
                    
                        level1_total = 0;
                        level2_total = 0;
                        level3_total = 0;
                        level4_total = 0;
                        level5_total = 0;                    
                        int na = 0;
                        question_count = 0;
                        while (subordinate_ques_results.next()) {
                            level1_total += subordinate_ques_results.getInt("level1");
                            level2_total += subordinate_ques_results.getInt("level2");
                            level3_total += subordinate_ques_results.getInt("level3");
                            level4_total += subordinate_ques_results.getInt("level4");
                            level5_total += subordinate_ques_results.getInt("level5");
                            na += subordinate_ques_results.getInt("na");
                            question_count++;
                        }
                        System.out.println("Count before" + question_count);
                        if (question_count != na) {
                            question_count = question_count - na;
                            System.out.println("Count after" + question_count);
                        }else {
                            question_count = 1;    
                        }                       
                    
                        if (level1_total >= question_count) {
                            if (level2_total >= question_count) {
                                if (level3_total >= question_count) {
                                    if (level4_total >= question_count) {
                                        if (level5_total >= question_count) {
                                            table_row.addElement((String) this.itsaf_map.get(new Integer(5)));   
                                        }else {
                                            table_row.addElement((String) this.itsaf_map.get(new Integer(4)));    
                                        }
                                    }else {
                                         table_row.addElement((String) this.itsaf_map.get(new Integer(3)));
                                    }
                                }else {
                                    table_row.addElement((String) this.itsaf_map.get(new Integer(2)));
                                }
                            }else {
                                table_row.addElement((String) this.itsaf_map.get(new Integer(1)));
                            }
                        }else {
                            if (question_count > 1) {
                                table_row.addElement("None");    
                            }else {
                                table_row.addElement((String) this.itsaf_map.get(new Integer(1)));
                            }
                        }                                        

                        this.report_model.addRow(table_row);
                        conn2.close();
                    }else {
                        table_row.addElement("None"); 
                        this.report_model.addRow(table_row);
                    }
                }
            }
            
            if (report_type.equals("System Summary")) {
                conn = this.parent.connectionGenerator();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "(?)}"); 
                query.setString(1, this.getActiveAssessment());

                this.report_name.setText("System Summary");    
                this.prgMonitor.setStatusBusyMessage("Build system summary report now, please hold");                
                this.setReportHeadersToSystemSummary();
                this.report_model.setColumnIdentifiers(this.table_headers);
                this.report_table.setModel(this.report_model);
                
                
                TableColumnModel model = report_table.getColumnModel();
                for (int i = 0; i < (this.table_headers).size(); i++) {
                    (model.getColumn(i)).setHeaderRenderer(renderer);
                }                
                JTableHeader header = report_table.getTableHeader();
                header.addMouseListener(new HeaderListener(header,renderer));                

                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(50);  
                String full_name = "";
                String txt = "";
                String cmnts = "";
                int level1 = 0;
                int level2 = 0;
                int level3 = 0;
                int level4 = 0;
                int level5 = 0;
                int na = 0;
                int rbdm = 0;
                int ar = 0;
                String reviewer = "N/A";               
                while (query_result.next()) {
                    number = new StringBuffer("");
                    table_row = new Vector();
                    txt = query_result.getString("question_text");
                    number.append(query_result.getInt("major_section") + "." + query_result.getInt("minor_section") + "." + query_result.getInt("question_number"));
                    table_row.addElement(number.toString());
                    table_row.addElement(txt.trim());
                    level1 = query_result.getInt("level1");
                    level2 = query_result.getInt("level2");
                    level3 = query_result.getInt("level3");
                    level4 = query_result.getInt("level4");
                    level5 = query_result.getInt("level5");
                    rbdm = query_result.getInt("rbdm");
                    cmnts = (query_result.getString("cmnts")).trim();
                    ar = query_result.getInt("ar");
                    na = query_result.getInt("na");
                    if (ar == 1) {
                        reviewer = (query_result.getString("reviewer")).trim();
                    }  else reviewer = "N/A";
                    
                    completed = query_result.getInt("completed");
                    full_name = (query_result.getString("full_name")).trim();
                    if (level1 != 0 && na == 0) {
                        if (level2 != 0) {
                            if (level3 != 0) {
                                if (level4 != 0) {
                                    if (level5 != 0) {
                                        table_row.addElement((String) this.itsaf_map.get(new Integer(5)));
                                    }else {
                                        table_row.addElement((String) this.itsaf_map.get(new Integer(4)));    
                                    }
                                }else {
                                    table_row.addElement((String) this.itsaf_map.get(new Integer(3)));    
                                }
                            }else {
                                table_row.addElement((String) this.itsaf_map.get(new Integer(2)));       
                            }
                        }else {
                            table_row.addElement((String) this.itsaf_map.get(new Integer(1)));   
                        }
                    }else {
                        table_row.addElement("None");    
                    }
                    if (na == 1) {
                        table_row.addElement("Yes");
                    }else {
                        table_row.addElement("No");    
                    }
                    if (rbdm == 1) {
                        table_row.addElement("Yes");
                    }else {
                        table_row.addElement("No");
                    }
                    table_row.addElement(cmnts);
                    table_row.addElement(full_name);
                    if (completed == 1) {
                        table_row.addElement("Yes");
                    }else {
                        table_row.addElement("No");
                    }
                    table_row.addElement(reviewer);
                    this.report_model.addRow(table_row);
                }
                
            }
            if (report_type.equals("List of non-applicable questions")) {
                conn = this.parent.connectionGenerator();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "(?)}"); 
                query.setString(1, this.getActiveAssessment());
                System.out.println("active assessment is " + this.getActiveAssessment() +"end of string");             
                
                this.report_name.setText("List of non-applicable questions");                              
                this.prgMonitor.setStatusBusyMessage("Build summary report of non-applicable questions now, please hold");
                this.setReportHeadersToNAQuestionsSummary();
                this.report_model.setColumnIdentifiers(this.table_headers);
                this.report_table.setModel(this.report_model);
                
                TableColumnModel model = report_table.getColumnModel();
                for (int i = 0; i < (this.table_headers).size(); i++) {
                    (model.getColumn(i)).setHeaderRenderer(renderer);
                }                
                JTableHeader header = report_table.getTableHeader();
                header.addMouseListener(new HeaderListener(header,renderer));                
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery();
                this.prgMonitor.setNormalizedProgress(50);
                int component_num = 0;
                String loc = "";
              
                while (query_result.next()) {
                    number = new StringBuffer("");
                    table_row = new Vector();
                    text = query_result.getString("question_text").trim();
                    number.append(query_result.getInt("major_section") + "." + query_result.getInt("minor_section") + "." + query_result.getInt("question_number"));
                    table_row.addElement(number.toString());
                    table_row.addElement(text);
                    table_row.addElement(query_result.getString("cmnts"));
                    this.report_model.addRow(table_row);
                }
                this.prgMonitor.setNormalizedProgress(70);                
            }
            
            if (report_type.equals("List of risk based decisions")) {                
                conn = this.parent.connectionGenerator();
                query = conn.prepareCall("{call " + (String) this.report_map.get(report_type) + "(?)}"); 
                query.setString(1, this.getActiveAssessment());                
                
                this.prgMonitor.setStatusBusyMessage("Build summary report of all risk based decisions now, please hold");
                this.report_name.setText("Summary of risk based decisions");
                this.setReportHeadersToRiskBasedQuestionsSummary();
                this.report_model.setColumnIdentifiers(this.table_headers);
                this.report_table.setModel(this.report_model);
                
                TableColumnModel model = report_table.getColumnModel();
                for (int i = 0; i < (this.table_headers).size(); i++) {
                    (model.getColumn(i)).setHeaderRenderer(renderer);
                }                
                JTableHeader header = report_table.getTableHeader();
                header.addMouseListener(new HeaderListener(header,renderer));                
                this.prgMonitor.setNormalizedProgress(20);
                query_result = query.executeQuery(); 
                String component_name = "";
                String assessment_id = "";
                String start_date = "";              
                while (query_result.next()) {
                    number = new StringBuffer("");
                    table_row = new Vector();
                    text = query_result.getString("question_text").trim();
                    number.append(query_result.getInt("major_section") + "." + query_result.getInt("minor_section") + "." + query_result.getInt("question_number"));
                    table_row.addElement(number.toString());
                    table_row.addElement(text);
                    table_row.addElement(query_result.getString("cmnts"));
                    this.report_model.addRow(table_row);
                }
            }
            
            conn.close();
            this.internal_setCursor("default");
            this.parent.setStatusMsg("");
            this.totals_label.setText((this.report_model.getDataVector().size()) + " records returned");
            this.report_table.setModel(this.report_model);
            this.prgMonitor.setNormalizedProgress(90);
            this.JTabbedPane1.setSelectedIndex(2);
            this.prgMonitor.setNormalizedProgress(100);
            this.prgMonitor.setVisible(false);
        }catch (SQLException e) {            
            e.printStackTrace();
            this.parent.displayErrorDialog("ERROR building report! ASSET Manager could not connect to the database. The text of the error is:\n" + e.toString());
        }catch (Exception e) {            
            e.printStackTrace();
            this.parent.displayErrorDialog("ERROR building report! The text of the error is:\n" + e.toString());
        }
    }/* end method buildSummaryReport() */

    public void renderReport(String html) {
        try {
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static ReportingFrame spawnReportingWindow(ASSET parent) {
        parent.setStatusModeMsg(" RPRT ");
        return new ReportingFrame(parent);        
    }

	public ReportingFrame(String sTitle) {
		this();
		setTitle(sTitle);
	}
	
	public ReportingFrame(ASSET parent) {
    	this();
	    try {		   
		    this.parent = parent;
		    this.setVisible(true);
		}catch (Exception e) {
		    e.printStackTrace();
		}
	}	
	
	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets and menu bar
		Insets insets = getInsets();
		javax.swing.JMenuBar menuBar = getRootPane().getJMenuBar();
		int menuBarHeight = 0;
		if (menuBar != null)
			menuBarHeight = menuBar.getPreferredSize().height;
		int offset = 0;
		Component comp[] = getComponents();
		for(int i = 0; i < comp.length; ++i) {
			if (comp[i] instanceof javax.swing.JRootPane)
				continue;
			offset += comp[i].getPreferredSize().height;
		}
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height + menuBarHeight + offset);
	}

    class HeaderListener extends MouseAdapter {
        JTableHeader   header;    
        SortButtonRenderer renderer;      
    
        HeaderListener(JTableHeader header,SortButtonRenderer renderer) {      
            this.header   = header;      
            this.renderer = renderer;
        }
    
        public void mousePressed(MouseEvent e) {
            boolean isAscent = false;  
            int col = header.columnAtPoint(e.getPoint());
            int sortCol = header.getTable().convertColumnIndexToModel(col);
            renderer.setPressedColumn(col);
            renderer.setSelectedColumn(col);
            header.repaint();
            if (header.getTable().isEditing()) {
                header.getTable().getCellEditor().stopCellEditing();
            }                
            if (SortButtonRenderer.DOWN == renderer.getState(col)) {        
                isAscent = true;      
            }else {
                isAscent = false;
            }
            ((SortableTableModel)header.getTable().getModel()).sortByColumn(sortCol, isAscent);        
        } 
     
        public void mouseReleased(MouseEvent e) {      
    
            int col = header.columnAtPoint(e.getPoint());      
            renderer.setPressedColumn(-1);
                // clear      
            header.repaint();    
        }  
    }/* end internal class HeaderListener() */

	class SymMouse extends java.awt.event.MouseAdapter {
		public void mouseExited(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == admin_system_summary) 
			    admin_system_summary.rollover_exit();
			if (object == admin_type_summary) 
			   admin_type_summary.rollover_exit();
			if (object == admin_sensitivity_summary) 
			    admin_sensitivity_summary.rollover_exit();
			if (object == admin_org_summary) 
			    admin_org_summary.rollover_exit();			    
		    if (object == na_summary)
		        na_summary.rollover_exit();	
		    if (object == assessment_summary)
		        assessment_summary.rollover_exit();			        
		    if (object == topic_summary)
		        topic_summary.rollover_exit();	
		    if (object == system_summary)
		        system_summary.rollover_exit();			        		        
		}

		public void mouseEntered(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == admin_system_summary) 
			    admin_system_summary.rollover_enter();
			if (object == admin_type_summary) 
			    admin_type_summary.rollover_enter();
			if (object == admin_sensitivity_summary) 
			    admin_sensitivity_summary.rollover_enter();
			if (object == admin_org_summary) 
			    admin_org_summary.rollover_enter();				    
			if (object == na_summary)
		        na_summary.rollover_enter();
		    if (object == assessment_summary)
		        assessment_summary.rollover_enter();			        
		    if (object == topic_summary)
		        topic_summary.rollover_enter();
		    if (object == system_summary)
		        system_summary.rollover_enter();			        		        		        
		}
		
		public void mouseClicked(java.awt.event.MouseEvent event) {
		    Object object = event.getSource();
		    if (object == admin_system_summary) {
		        buildSummaryReport(admin_system_summary.getPlainText());    
		    }
		    if (object == admin_type_summary) {
		        buildSummaryReport(admin_type_summary.getPlainText());   
		    }
		    
		    if (object == admin_sensitivity_summary) {
		        buildSummaryReport(admin_sensitivity_summary.getPlainText());
		    }
		    
		    if (object == admin_org_summary) {
		        buildSummaryReport(admin_org_summary.getPlainText());
		    }	
		    
			if (object == na_summary) {
			    if (getActiveAssessment().length() > 1) {
			        buildSummaryReport(na_summary.getPlainText());
			    }else {
			        displayErrorDialog("You must select an active assessment first!");
			    }
			}
			if (object == assessment_summary) {
			    if (getActiveAssessment().length() > 1) {
			        buildSummaryReport(assessment_summary.getPlainText());
			    }else {
			        displayErrorDialog("You must select an active assessment first!");
			    }
			}
			if (object == topic_summary) {
			    if (getActiveAssessment().length() > 1) {
			        buildSummaryReport(topic_summary.getPlainText());
			    }else {
			        displayErrorDialog("You must select an active assessment first!");
			    }
			}
			if (object == system_summary) {
			    if (getActiveAssessment().length() > 1) {
			        buildSummaryReport(system_summary.getPlainText());
			    }else {
                    displayErrorDialog("You must select an active assessment first!");
			    }
			}						
		}
	}/* end internal class SymMouse() */	

    public String getActiveAssessment() {
        return this.active_assessment;    
    }
    
    // This method will export the results of the selected table (either 
    // assessment or system summary tab) to a csv file that can be imported 
    // into your basic office applications such as Excell or Access
    // References:
    // 1. http://www.esus.com/javaindex/j2se/jdk1.2/javaxswing/
    //    editableatomiccontrols/jfilechooser/jfilechoosersave.html
    void saveFile() {
        File save_target = null;
        try {
            fileSaver.setDialogTitle("Save Summary Results File");            
            int choice = fileSaver.showSaveDialog(this);
            if (choice == fileSaver.APPROVE_OPTION) {
                 save_target = fileSaver.getSelectedFile();
                 PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter(save_target)));
                 DefaultTableModel test_model = (DefaultTableModel) this.report_table.getModel();
                 Vector temp_row = null;
                 StringBuffer output = new StringBuffer("");
                 out.println("Report Name\t" + this.report_name.getText() + "\tToday's Date\t" + this.report_generated_date.getText());
                 out.println("Totals\t" + this.totals_label.getText() + "\tPrimary Assessor\t" + this.primary_assessor.getText());                 
                 out.println("");
                 String nl = System.getProperty("line.separator");
                 for (int n = 0; n < this.table_headers.size(); n++) {
                     output.append((String) this.table_headers.elementAt(n));
                     if (n < this.table_headers.size() - 1) {
                        output.append("\t");
                     }                        
                 }                     
                 output.append(nl);
                 out.println(output.toString());
                 for (int i = 0; i < (test_model.getDataVector()).size(); i++) {
                     temp_row = (Vector) (test_model.getDataVector()).elementAt(i);
                     output = new StringBuffer("");
                     for (int j = 0; j < temp_row.size(); j++) {
                         output.append((String) temp_row.elementAt(j));
                         if (j < temp_row.size() - 1) {
                            output.append("\t");
                         }                            
                     }
                     output.append(nl);
                     out.println(output.toString());
                 }
                 out.close();
                 this.displayStatusDialog("Results exported successfully!");
            }else {
                System.out.println("user pressed cancel when trying to export results");    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method saveFile() */
    
    public void setReportActive(boolean flag) {
        this.report_active = flag;        
    }
    
    public boolean isReportActive() {
        return this.report_active;
    }
    
	private void displayStatusDialog(String msg) {
        try {
            JOptionPane.showMessageDialog(this, msg, "System Message:", JOptionPane.INFORMATION_MESSAGE);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }    

	private void displayErrorDialog(String msg) {
        try {
            JOptionPane.showMessageDialog(this, msg, "Error:", JOptionPane.ERROR_MESSAGE);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }    
    
    public void setActiveAssessment(String new_active) {
        this.active_assessment = new_active;
        try {
            this.system_id_label.setText(this.active_assessment);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setActiveName(String name) {
        this.system_name_label.setText(name);
    }
    
    public void setActiveNumber(String name) {
        this.system_number_field.setText(name);
    }
    
    public void setActiveDate(String date) {
        this.system_date_label.setText(date);    
    }

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	com.symantec.itools.javax.swing.icons.ImageIcon reportIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JPanel JPanel3 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel16 = new javax.swing.JPanel();
	javax.swing.JToolBar JToolBar1 = new javax.swing.JToolBar();
	javax.swing.JButton exportResultsButton = new javax.swing.JButton();
	javax.swing.JButton setActiveAssessmentButton = new javax.swing.JButton();
	javax.swing.JButton helpButton = new javax.swing.JButton();
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JPanel adminReports = new javax.swing.JPanel();
	javax.swing.JPanel JPanel33 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel22 = new javax.swing.JLabel();
	javax.swing.JPanel report1_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel23 = new javax.swing.JLabel();
	javax.swing.JPanel report2_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel24 = new javax.swing.JLabel();
	javax.swing.JPanel report3_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel25 = new javax.swing.JLabel();
	javax.swing.JPanel report4_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel26 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel34 = new javax.swing.JPanel();
	javax.swing.JPanel clientReports = new javax.swing.JPanel();
	com.symantec.itools.javax.swing.JSplitPaneWrapper JSplitPaneWrapper1 = new com.symantec.itools.javax.swing.JSplitPaneWrapper();
	javax.swing.JPanel JPanel17 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel14 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel10 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel6 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel11 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel4 = new javax.swing.JLabel();
	javax.swing.JLabel system_name_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel25 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel14 = new javax.swing.JLabel();
	javax.swing.JLabel system_number_field = new javax.swing.JLabel();
	javax.swing.JPanel JPanel12 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel7 = new javax.swing.JLabel();
	javax.swing.JLabel system_date_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel18 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel8 = new javax.swing.JLabel();
	com.symantec.itools.javax.swing.JWrappingLabel system_id_label = new com.symantec.itools.javax.swing.JWrappingLabel();
	javax.swing.JPanel change_active_system_button_panel = new javax.swing.JPanel();
	javax.swing.JButton JButton1 = new javax.swing.JButton();
	javax.swing.JPanel JPanel2 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel4 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel1 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel9 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel5 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel8 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel6 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel13 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel9 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel5 = new javax.swing.JPanel();
	javax.swing.JPanel results_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel20 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel21 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel11 = new javax.swing.JLabel();
	javax.swing.JLabel report_name = new javax.swing.JLabel();
	javax.swing.JPanel JPanel28 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel16 = new javax.swing.JLabel();
	javax.swing.JLabel report_generated_date = new javax.swing.JLabel();
	javax.swing.JPanel JPanel29 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel19 = new javax.swing.JLabel();
	javax.swing.JLabel totals_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel26 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel17 = new javax.swing.JLabel();
	javax.swing.JLabel primary_assessor = new javax.swing.JLabel();
	javax.swing.JScrollPane JScrollPane2 = new javax.swing.JScrollPane();
	javax.swing.JTable report_table = new javax.swing.JTable();
	com.symantec.itools.javax.swing.borders.EmptyBorder report_title_label_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder report_pane_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon saveIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EmptyBorder report_header_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon helpIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon1 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel graphic_report_style = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.models.StringTableModel chart_data_model = new com.symantec.itools.javax.swing.models.StringTableModel();
	com.symantec.itools.javax.swing.icons.ImageIcon imageIcon2 = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder1 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	//}}
	Assessor creator = null;
	SortButtonRenderer renderer = new SortButtonRenderer();
	boolean report_active = false;
	Hashtable itsaf_map = new Hashtable();
	boolean operation_mode = false;
	JFileChooser fileSaver = new JFileChooser();
	String active_assessment = "";
	SymAction lSymAction = new SymAction();
	ProgressDialog prgMonitor = null;
	SortableTableModel report_model = new SortableTableModel() {
	    public boolean isCellEditable(int row, int column) {
            return false;
        }	    	    
	};
	Vector table_headers = new Vector();
	SymMouse aSymMouse = new SymMouse();
    JFileChooser savedDialog = new JFileChooser();
    HTMLLabel component_summary = null;
    HTMLLabel area_summary = null;
    HTMLLabel na_summary = null;
    HTMLLabel admin_system_summary = null;
    HTMLLabel admin_type_summary = null;
    HTMLLabel assessment_summary = null;
    HTMLLabel type_summary = null;
    HTMLLabel admin_sensitivity_summary = null;
    HTMLLabel topic_summary = null;
    HTMLLabel admin_org_summary = null;
    HTMLLabel system_summary = null;
    ASSET parent = null;
    AssessmentChooser chooser = null;
    Hashtable report_map = new Hashtable();
	
	public void setReportCreator(Assessor creator) {
	    this.creator = creator; 
	    System.out.println("set report creator");
	}
	
	public void toggleOperationMode() {
	    this.operation_mode = true;    
	}
	
	public boolean getOperationMode() {
	    return this.operation_mode;    
	}
	
	public void finalize() throws Throwable {
		//{{CLEANUP
		//}}		
		super.finalize();
	}

    public void showAssessmentChooserDialog() {
        try {
            if (chooser == null) {
                chooser = AssessmentChooser.spawnNewAssessmentChooser(this);                
            }
            chooser.setVisible(true);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	class SymAction implements java.awt.event.ActionListener {
	    
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == setActiveAssessmentButton)
				setActiveAssessmentButton_actionPerformed(event);
			else if (object == exportResultsButton)
				exportResultsButton_actionPerformed(event);
			else if (object == JButton1)
				JButton1_actionPerformed(event);
			else if (object == helpButton)
				helpButton_actionPerformed(event);
		}
	}/* end internal class SymAction() */

	class SymInternalFrame implements javax.swing.event.InternalFrameListener {
	    
		public void internalFrameOpened(javax.swing.event.InternalFrameEvent event) {
		}

		public void internalFrameDeiconified(javax.swing.event.InternalFrameEvent event) {
			Object object = event.getSource();
			if (object == ReportingFrame.this)
				ReportingFrame_internalFrameDeiconified(event);
		}

		public void internalFrameIconified(javax.swing.event.InternalFrameEvent event)
		{
			Object object = event.getSource();
			if (object == ReportingFrame.this)
				ReportingFrame_internalFrameIconified(event);
		}

		public void internalFrameDeactivated(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosed(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosing(javax.swing.event.InternalFrameEvent event)
		{
		    parentApplicationClosing();
		    parent.setStatusModeMsg("Idle...");	    
		}

		public void internalFrameActivated(javax.swing.event.InternalFrameEvent event) {
		
		}
	}

	void ReportingFrame_internalFrameIconified(javax.swing.event.InternalFrameEvent event)
	{
		// to do: code goes here.
		try {
		    setMaximum(false);		
		}catch (Exception e) {
		    e.printStackTrace();
		}
		this.parent.setStatusModeMsg("Idle...");
	}

	// This is the action handler method for when the user deiconifies the reporting
	// frame. 
	// --------------
	// Change Control:
	// 05/10/02 - Added call to set the size of the frame to maxiumum when the user
	//             deiconifies the frame.
	void ReportingFrame_internalFrameDeiconified(javax.swing.event.InternalFrameEvent event) {
		// to do: code goes here.
		this.parent.setStatusModeMsg("RPRT");
		try {
            setMaximum(true);
            JTabbedPane1.setSelectedIndex(0);
        }catch (Exception e) {
            e.printStackTrace();
        }
	}

	void setActiveAssessmentButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		setActiveAssessmentButton_actionPerformed_Interaction1(event);
	}

	void setActiveAssessmentButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.showAssessmentChooserDialog();
		} catch (java.lang.Exception e) {
		}
	}

	void exportResultsButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		exportResultsButton_actionPerformed_Interaction1(event);
	}

	void exportResultsButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
		    if (this.getOperationMode()) {
			    this.saveFile();
			}else {
			    this.displayErrorDialog("You must generate report results before you can export anything to a flat file!");    
			}
		} catch (java.lang.Exception e) {
		}
	}

	void JButton1_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		JButton1_actionPerformed_Interaction1(event);
	}

	void JButton1_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.showAssessmentChooserDialog();
		} catch (java.lang.Exception e) {
		}
	}

	void helpButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		helpButton_actionPerformed_Interaction1(event);
	}

	void helpButton_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    this.parent.setStatusMsg("Opening reporting window now, please hold");
			this.openAssessmentHelp();
			this.parent.setStatusMsg("");
		} catch (java.lang.Exception e) {
		}
	}

	class SymChange implements javax.swing.event.ChangeListener
	{
		public void stateChanged(javax.swing.event.ChangeEvent event)
		{
			Object object = event.getSource();
			if (object == JTabbedPane1)
				JTabbedPane1_stateChanged(event);
		}
	}

	void JTabbedPane1_stateChanged(javax.swing.event.ChangeEvent event)
	{
		// to do: code goes here.
			 
		JTabbedPane1_stateChanged_Interaction1(event);
	}

	void JTabbedPane1_stateChanged_Interaction1(javax.swing.event.ChangeEvent event)
	{
		try {
			this.forceRepaint();
		} catch (java.lang.Exception e) {
		}
	}
	
	private void exportButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        if (this.getOperationMode()) {
			        this.saveFile();
			    }else {
			        this.displayErrorDialog("You must generate report results before you can export anything to a flat file!");    
			    }                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
	
	private void setActiveAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.showAssessmentChooserDialog();                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
	}	
	
	private void openHelpButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.openAssessmentHelp();                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
	}		

	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == exportResultsButton)
				exportResultsButton_keyTyped(event);
			else if (object == setActiveAssessmentButton)
				setActiveAssessmentButton_keyTyped(event);
			else if (object == helpButton)
				helpButton_keyTyped(event);
		}
	}

	void exportResultsButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		exportResultsButton_keyTyped_Interaction1(event);
	}

	void exportResultsButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.exportButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void setActiveAssessmentButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		setActiveAssessmentButton_keyTyped_Interaction1(event);
	}

	void setActiveAssessmentButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.setActiveAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void helpButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		helpButton_keyTyped_Interaction1(event);
	}

	void helpButton_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.openHelpButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
}/* end class ReportingFrame() */