/********************************************************************************/
/* file - AddAssessorDialog.java                                                */
/* -----------------------------                                                */
/* This is the class that gathers the appropriate information together to       */
/* represent an assessor of a component for the NIST Self-Assessment Tool.      */
/* It can use either a brand new assessor (entered in on the first tab) or a    */
/* pre-existing assessor, chosen from the second tab.                           */
/* -----------------------------                                                */
/* NIST Self-Assessment Tool                                                    */
/* Author - Mark McLarnon                                                       */
/* -----------------------------                                                */
/* References:                                                                  */
/* http://www.jguru.com/faq/view.jsp?EID=316478                                 */
/* -----------------------------                                                */
/* Change Control:                                                              */
/* 04/17/02 - Added code to capture when enter key was pressed on cancel button */
/*            this would have the added effect of when the cancel button was    */
/*            actually pressed disposing the window.                            */
/* 05/30/02 - Added code to allow users to press enter key on old assessor table*/
/*            and enter the information in the text boxes on the front page.    */
/* 06/10/02 - Added call to fillTable() to remedy situation when call is made to*/
/*            alternate constructor AddAssessorDialog(ASSET, boolean) instead of*/
/*            intended constructor                                              */
/********************************************************************************/
import java.awt.datatransfer.*;
import java.awt.event.*;
import java.awt.*;
import java.sql.*;
import javax.swing.*;
import java.util.*;
import com.symantec.itools.javax.swing.borders.BevelBorder;
import com.symantec.itools.javax.swing.borders.EtchedBorder;
import com.symantec.itools.javax.swing.models.StringTableModel;

public class AddAssessorDialog extends javax.swing.JDialog {
    
	public AddAssessorDialog(Frame parent) {
		super(parent);
		
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setTitle("Add Assessor Information:");
		setResizable(false);
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BorderLayout(0,0));
		setSize(370,247);
		setVisible(false);
		//$$ name_text_popup.move(24,252);
		namecutMenuItem.setText("Cut");
		namecutMenuItem.setActionCommand("Cut");
		namecutMenuItem.setBorderPainted(false);
		namecutMenuItem.setMnemonic((int)'U');
		name_text_popup.add(namecutMenuItem);
		namecopyMenuItem.setText("Copy");
		namecopyMenuItem.setActionCommand("Copy");
		namecopyMenuItem.setBorderPainted(false);
		namecopyMenuItem.setMnemonic((int)'C');
		name_text_popup.add(namecopyMenuItem);
		namepasteMenuItem.setText("Paste");
		namepasteMenuItem.setActionCommand("Paste");
		namepasteMenuItem.setBorderPainted(false);
		namepasteMenuItem.setMnemonic((int)'P');
		name_text_popup.add(namepasteMenuItem);
		//$$ number_text_popup.move(24,216);
		numbercutMenuItem.setText("Cut");
		numbercutMenuItem.setActionCommand("Cut");
		numbercutMenuItem.setBorderPainted(false);
		numbercutMenuItem.setMnemonic((int)'U');
		number_text_popup.add(numbercutMenuItem);
		numbercopyMenuItem.setText("Copy");
		numbercopyMenuItem.setActionCommand("Copy");
		numbercopyMenuItem.setBorderPainted(false);
		numbercopyMenuItem.setMnemonic((int)'C');
		number_text_popup.add(numbercopyMenuItem);
		numberpasteMenuItem.setText("Paste");
		numberpasteMenuItem.setActionCommand("Paste");
		numberpasteMenuItem.setBorderPainted(false);
		numberpasteMenuItem.setMnemonic((int)'P');
		number_text_popup.add(numberpasteMenuItem);
		//$$ email_text_popup.move(0,216);
		emailcutMenuItem.setText("Cut");
		emailcutMenuItem.setActionCommand("Cut");
		emailcutMenuItem.setBorderPainted(false);
		emailcutMenuItem.setMnemonic((int)'U');
		email_text_popup.add(emailcutMenuItem);
		emailcopyMenuItem.setText("Copy");
		emailcopyMenuItem.setActionCommand("Copy");
		emailcopyMenuItem.setBorderPainted(false);
		emailcopyMenuItem.setMnemonic((int)'C');
		email_text_popup.add(emailcopyMenuItem);
		emailpasteMenuItem.setText("Paste");
		emailpasteMenuItem.setActionCommand("Paste");
		emailpasteMenuItem.setBorderPainted(false);
		emailpasteMenuItem.setMnemonic((int)'P');
		email_text_popup.add(emailpasteMenuItem);
		JPanel3.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		getContentPane().add(BorderLayout.SOUTH, JPanel3);
		add_assessor_button.setText("Add Assessor");
		add_assessor_button.setActionCommand("Add Assessor");
		add_assessor_button.setNextFocusableComponent(cancel_button);
		add_assessor_button.setToolTipText("<html>Press this button to add the current assessor\'s information to the active assessment</html>");
		add_assessor_button.setMnemonic((int)'A');
		JPanel3.add(add_assessor_button);
		cancel_button.setText("Cancel");
		cancel_button.setActionCommand("Cancel");
		cancel_button.setNextFocusableComponent(new_assessor_panel);
		cancel_button.setToolTipText("<html>Press this button to cancel this action and continue</html>");
		cancel_button.setMnemonic((int)'C');
		JPanel3.add(cancel_button);
		getContentPane().add(BorderLayout.CENTER, JTabbedPane1);
		new_assessor_panel.setNextFocusableComponent(old_assessor_panel);
		new_assessor_panel.setBorder(etchedBorder1);
		new_assessor_panel.setLayout(null);
		JTabbedPane1.add(new_assessor_panel);
		new_assessor_panel.setBounds(2,24,365,185);
		new_assessor_panel.setVisible(false);
		JLabel1.setText("Full Name:");
		new_assessor_panel.add(JLabel1);
		JLabel1.setForeground(java.awt.Color.black);
		JLabel1.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel1.setBounds(12,41,58,15);
		JLabel2.setText("Phone Number:");
		new_assessor_panel.add(JLabel2);
		JLabel2.setForeground(java.awt.Color.black);
		JLabel2.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel2.setBounds(12,88,87,15);
		JLabel3.setText("EMail:");
		new_assessor_panel.add(JLabel3);
		JLabel3.setForeground(java.awt.Color.black);
		JLabel3.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel3.setBounds(12,137,33,15);
		name_field.setNextFocusableComponent(number_field);
		name_field.setToolTipText("<html>Enter the full name of the assessor here</html>");
		new_assessor_panel.add(name_field);
		name_field.setBounds(120,36,226,25);
		number_field.setNextFocusableComponent(email_field);
		number_field.setToolTipText("<html>Enter the phone number or extension of the assessor here</html>");
		new_assessor_panel.add(number_field);
		number_field.setBounds(120,84,226,25);
		email_field.setNextFocusableComponent(add_assessor_button);
		email_field.setToolTipText("<html>Enter the email address of the assessor here</html>");
		new_assessor_panel.add(email_field);
		email_field.setBounds(120,132,226,25);
		error_msg.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		error_msg.setText("Error:");
		new_assessor_panel.add(error_msg);
		error_msg.setForeground(java.awt.Color.red);
		error_msg.setFont(new Font("Dialog", Font.BOLD, 12));
		error_msg.setBounds(12,6,100,24);
		error_msg.setVisible(false);
		old_assessor_panel.setLayout(new BoxLayout(old_assessor_panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(old_assessor_panel);
		old_assessor_panel.setBounds(2,24,365,185);
		old_assessor_panel.setVisible(false);
		JScrollPane1.setOpaque(true);
		old_assessor_panel.add(JScrollPane1);
		existing_assessors.setModel(current_assessors_table_model);
		existing_assessors.setNextFocusableComponent(add_assessor_button);
		existing_assessors.setToolTipText("<html>Shows a list of all assessors used to date.</html>");
		JScrollPane1.getViewport().add(existing_assessors);
		existing_assessors.setBounds(0,0,362,0);
		JTabbedPane1.setSelectedIndex(0);
		JTabbedPane1.setSelectedComponent(new_assessor_panel);
		JTabbedPane1.setTitleAt(0,"Add New Assessor");
		JTabbedPane1.setTitleAt(1,"Add Existing Assessor");
		//$$ etchedBorder1.move(0,276);
		//$$ current_assessors_table_model.move(0,248);
		//}}
	
		//{{REGISTER_LISTENERS
		SymMouse aSymMouse = new SymMouse();
		name_field.addMouseListener(aSymMouse);
		number_field.addMouseListener(aSymMouse);
		email_field.addMouseListener(aSymMouse);
		SymAction lSymAction = new SymAction();
		cancel_button.addActionListener(lSymAction);
		add_assessor_button.addActionListener(lSymAction);
		this.namecutMenuItem.addActionListener(lSymAction);
		this.namecopyMenuItem.addActionListener(lSymAction);
		this.namepasteMenuItem.addActionListener(lSymAction);
		this.numbercutMenuItem.addActionListener(lSymAction);
		this.numbercopyMenuItem.addActionListener(lSymAction);
		this.numberpasteMenuItem.addActionListener(lSymAction);
		this.emailcutMenuItem.addActionListener(lSymAction);
		this.emailcopyMenuItem.addActionListener(lSymAction);
		this.emailpasteMenuItem.addActionListener(lSymAction);
		SymKey aSymKey = new SymKey();
		email_field.addKeyListener(aSymKey);
		add_assessor_button.addKeyListener(aSymKey);
		cancel_button.addKeyListener(aSymKey);
		existing_assessors.addKeyListener(aSymKey);
		//}}

		this.name_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            name_text_popup.show(name_field, me.getX(), me.getY());  
		        }
		    }      
		 });
		this.number_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {
		            number_field.select(0, number_field.getText().length());
		            number_text_popup.show(number_field, me.getX(), me.getY());  
		        }
		    }      
		 });
		this.email_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            email_text_popup.show(email_field, me.getX(), me.getY());  
		        }
		    }      
		 });
		 this.existing_assessors.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
                if (me.getClickCount() == 2) {
                    usePreExistingAssessor(me);
                }
		    }      
		 }); 
		this.clipboard = this.getToolkit().getSystemClipboard();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));
        
        this.assessor_table_headers = "Assessor, Email, Phone";
        this.current_assessors_table_model.setColumnHeaders(this.assessor_table_headers);
        this.new_assessor_panel.requestFocus();
	}/* end constructor AddAssessorDialog(Frame) */

    // This code is the action handler when the user chooses a row from the table of
    // pre-existing assessors. Then have the option of either clicking once and pressing
    // the add button or then can double click on the table with their mouse.
    // ---------------
    // Change Control:
    // 04/17/02 - Added code to check if param @me was null. If it was null then the
    //            user got to this method by only singly clicking on the table instead
    //            of double clicking on it.
    private void usePreExistingAssessor(MouseEvent me) {
        StringTokenizer parser = null;
        int selected_row = 0;
        try {        
            if (me != null) {
                selected_row = this.existing_assessors.rowAtPoint(me.getPoint());
            }else {
                selected_row = this.existing_assessors.getSelectedRow();
            }
            parser = new StringTokenizer(this.current_assessors_table_model.getRow(selected_row), ","); 
            this.name_field.setText(parser.nextToken());
            this.email_field.setText(parser.nextToken());
            this.number_field.setText(parser.nextToken());         
            this.JTabbedPane1.setSelectedIndex(0);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void setErrorMessage(String msg) {
        this.error_msg.setText("ERROR: " + msg);
        this.error_msg.setVisible(true);
    }
    
    private void hideErrorMessage() {
        this.error_msg.setText("");
        this.error_msg.setVisible(false);
    }

	public AddAssessorDialog() {
		this((Frame)null);
	}
	
	public AddAssessorDialog(AssessmentWindow parent) {
        this();
        this.parent = parent;
        this.fillTable();
	}
	
	public AddAssessorDialog(AssessmentWindow parent, boolean flag) {
        this();
        this.parent = parent;
        this.post_info = flag;
        this.fillTable();
	}
	
	private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}	
	
	private boolean assessorExists(String fullName) {
        boolean flag = false;
        String cmp_row = "";
        StringTokenizer parser = null;
        try {
            for (int i = 0; i < this.current_assessors_table_model.getNumRows(); i++) {
                cmp_row = this.current_assessors_table_model.getRow(i);
                parser = new StringTokenizer(cmp_row, ",");                
                if (parser.nextToken().equals(fullName)) {
                    flag = true;
                    return flag;
                }
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
	}
	
	private void fillTable() {
        CallableStatement current_assessors = null;
	    StringBuffer assessor_record = new StringBuffer("");
	    ResultSet assessors = null;
	    try {
	       this.internal_setCursor("wait"); 
	       if (this.parent.conn != null) { 
	           current_assessors =  this.parent.conn.prepareCall("{call get_stored_assessors}");
	           assessors = current_assessors.executeQuery();
	       }	       
	       while (assessors.next()) {
	           assessor_record = new StringBuffer("");
	           assessor_record.append((assessors.getString("full_name")).trim() + ", ");
	           assessor_record.append((assessors.getString("email")).trim() + ", ");
	           assessor_record.append((assessors.getString("phone")).trim());
	           this.current_assessors_table_model.addRow(assessor_record.toString());
	           this.current_assessors_table_model.fireTableChanged(null);
	       }
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	public String assemebleNewAssessor() {
        StringBuffer assessor = new StringBuffer();
        try {
            assessor.append("N, ");
            assessor.append(name_field.getText() + ", ");
            assessor.append(email_field.getText() + ", ");
            assessor.append(number_field.getText());
        }catch (Exception e) {
            e.printStackTrace();
        }
        return assessor.toString();
	}

    // This is the method that will return to class AssessmentWindow, it is called when the
    // user has chosen the assessor that they want to add and is ready to proceed.
    // First the user must be added to the assessors table then the name must be inserted
    // into the drop-down boxes on the question tab that allows a user to select who has 
    // answered or will be answering a new question.
    // Change Control:
    public void addAssessor() {
    	  
		String  assName = name_field.getText();
		
    	if (  assName != null &&  assName.trim().length() != 0  )
    	{  
    	
        try {
            Assessor assessor = Assessor.createNewAssessor(name_field.getText(), email_field.getText(), number_field.getText(), false);                
            parent.addAssessor(assessor.getDataVector());  
            if (this.post_info) {
                parent.assembleNewAssessorPostInfoGather(name_field.getText());
                parent.assembleNewReviewerPostInfoGather(name_field.getText());
            }
            this.setVisible(false);               
        }catch (Exception e) {
            e.printStackTrace();
        }
        
    	}
        
    }/* end method addAssessor() */

	private void proceedKeyEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        if (this.JTabbedPane1.getSelectedIndex() == 0) {
			        this.addAssessor();
			    }else {
                    this.usePreExistingAssessor(null);
                    this.addAssessor();
			    }
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	public AddAssessorDialog(String sTitle) {
		this();
		setTitle(sTitle);
	}

	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JPopupMenu name_text_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem namecutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem namecopyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem namepasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu number_text_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem numbercutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem numbercopyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem numberpasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu email_text_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem emailcutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem emailcopyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem emailpasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPanel JPanel3 = new javax.swing.JPanel();
	javax.swing.JButton add_assessor_button = new javax.swing.JButton();
	javax.swing.JButton cancel_button = new javax.swing.JButton();
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JPanel new_assessor_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel1 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	javax.swing.JTextField name_field = new javax.swing.JTextField();
	javax.swing.JTextField number_field = new javax.swing.JTextField();
	javax.swing.JTextField email_field = new javax.swing.JTextField();
	javax.swing.JLabel error_msg = new javax.swing.JLabel();
	javax.swing.JPanel old_assessor_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JTable existing_assessors = new javax.swing.JTable();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.models.StringTableModel current_assessors_table_model = new com.symantec.itools.javax.swing.models.StringTableModel();
	//}}
	String assessor_table_headers = "";
    AssessmentWindow parent = null;
    Clipboard clipboard = null;
    boolean post_info = false;
    
	class SymMouse extends java.awt.event.MouseAdapter {
	    
		public void mouseClicked(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == name_field)
				nameField_mouseClicked(event);
			else if (object == number_field)
				numberField_mouseClicked(event);
			else if (object == email_field)
				emailField_mouseClicked(event);
		}
	}/* end class SymMouse() */

	void nameField_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		name_field_mouseClicked_Interaction1(event);
	}

	void name_field_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			// name_field Selects all the text
			name_field.selectAll();
		} catch (java.lang.Exception e) {
		}
	}

	void numberField_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		number_field_mouseClicked_Interaction1(event);
	}

	void number_field_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			// number_field Selects all the text
			number_field.selectAll();
		} catch (java.lang.Exception e) {
		}
	}

	void emailField_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		email_field_mouseClicked_Interaction2(event);
	}

	void email_field_mouseClicked_Interaction2(java.awt.event.MouseEvent event)
	{
		try {
			// email_field Selects all the text
			email_field.selectAll();
		} catch (java.lang.Exception e) {
		}
	}

	class SymAction implements java.awt.event.ActionListener {
	    
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == cancel_button)
				cancelButton_actionPerformed(event);
			if (object == namecutMenuItem)
				namecutMenuItem_actionPerformed(event);
			else if (object == namecopyMenuItem)
				namecopyMenuItem_actionPerformed(event);
			else if (object == namepasteMenuItem)
				namepasteMenuItem_actionPerformed(event);
			else if (object == numbercutMenuItem)
				numbercutMenuItem_actionPerformed(event);
			else if (object == numbercopyMenuItem)
				numbercopyMenuItem_actionPerformed(event);
			else if (object == numberpasteMenuItem)
				numberpasteMenuItem_actionPerformed(event);
			else if (object == emailcutMenuItem)
				emailcutMenuItem_actionPerformed(event);
			else if (object == emailcopyMenuItem)
				emailcopyMenuItem_actionPerformed(event);
			else if (object == emailpasteMenuItem)
				emailpasteMenuItem_actionPerformed(event);
			else if (object == add_assessor_button)
				addAssessorButton_actionPerformed(event);
		}/* end inner-class method actionPerformed() */
	}/* end inner-class SymAction() */
	
	void namecutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_cut = new StringSelection(this.name_field.getText());
        this.clipboard.setContents(data_to_cut, data_to_cut);
        this.name_field.setText("");
	}
	
	void namecopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_copy = new StringSelection(this.name_field.getText());
        this.clipboard.setContents(data_to_copy, data_to_copy);	
	}
	
	void namepasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        Transferable clipData = clipboard.getContents(this);
        String s;
        try {
            s = (String)(clipData.getTransferData(DataFlavor.stringFlavor));
        }catch (Exception e) {
            s = e.toString();
        }
        this.name_field.setText(s);
	}
	
	void numbercutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_cut = new StringSelection(this.number_field.getText());
        this.clipboard.setContents(data_to_cut, data_to_cut);
        this.number_field.setText("");
	}
	
	void numbercopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_copy = new StringSelection(this.number_field.getText());
        this.clipboard.setContents(data_to_copy, data_to_copy);	
	}
	
	void numberpasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        Transferable clipData = clipboard.getContents(this);
        String s;
        try {
            s = (String)(clipData.getTransferData(DataFlavor.stringFlavor));
        }catch (Exception e) {
            s = e.toString();
        }  	
        this.number_field.setText(s);
	}
	
	void emailcutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_cut = new StringSelection(this.email_field.getText());
        this.clipboard.setContents(data_to_cut, data_to_cut);
        this.email_field.setText("");
	}
	
	void emailcopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        StringSelection data_to_copy = new StringSelection(this.email_field.getText());
        this.clipboard.setContents(data_to_copy, data_to_copy);		
	}
	
	void emailpasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
        Transferable clipData = clipboard.getContents(this);
        String s;
        try {
            s = (String)(clipData.getTransferData(DataFlavor.stringFlavor));
        }catch (Exception e) {
            s = e.toString();
        }
        this.email_field.setText(s);
	}	

	void cancelButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		cancel_button_actionPerformed_Interaction2(event);
	}

	void cancel_button_actionPerformed_Interaction2(java.awt.event.ActionEvent event)
	{
		try {
			this.dispose();
		} catch (java.lang.Exception e) {
		}
	}

	void addAssessorButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
        this.hideErrorMessage();			 
		add_assessor_button_actionPerformed_Interaction1(event);
	}

    // This method is the action handler for when the add assessor button is pressed
    // It is designed to call the method addAssessor to pass the chosen/entered
    // assessor information back to the calling instance of AssessmentWindow()
    // ---------------
    // Change Control:
    // 04/17/02 - Added code to check to see if the user was looking at the pre-existing
    //            assessors table instead of the text boxes to add a new assessor
    //            If the user is looking at the first tab then the program proceeds 
    //            ahead just as it did before, yet if they are looking at the table
    //            on the second tab then the information on the first tab is automatically
    //            filled in for them and the program proceeds ahead as normal.
	void add_assessor_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.JTabbedPane1.getSelectedIndex() == 0) {
			    this.addAssessor();
			}else {
                this.usePreExistingAssessor(null);
                this.addAssessor();
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == email_field)
				emailField_keyTyped(event);
			else if (object == add_assessor_button)
				addAssessorButton_keyTyped(event);
			else if (object == cancel_button)
				cancelButton_keyTyped(event);
			else if (object == existing_assessors)
				existingAssessors_keyTyped(event);
		}
	}

	void emailField_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		email_field_keyTyped_Interaction1(event);
	}

	void email_field_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void addAssessorButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		add_assessor_button_keyTyped_Interaction1(event);
	}

	void add_assessor_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
    private void proceedKeyCancelButtonPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.dispose();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }	
    
    private void oldAssessorEnterButtonPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.usePreExistingAssessor(null);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }    

	void cancelButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		cancel_button_keyTyped_Interaction1(event);
	}

	void cancel_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyCancelButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void existingAssessors_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		existing_assessors_keyTyped_Interaction1(event);
	}

	void existing_assessors_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.oldAssessorEnterButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
}/* end class AddAssessorDialog() */