/****************************************************************************/
/* file - AddSystemDialog.java                                              */
/* ---------------------------                                              */
/* this class allows a user to define all of the connected systems to a sys */
/* being assessed with the Self-Assessment Tool.                            */
/* ---------------------------                                              */
/* NIST Self-Assessment Tool                                                */
/* Author - Mark McLarnon                                                   */
/* ---------------------------                                              */
/* Change Control:                                                          */
/* 02/13/02 - Added code to request focus for System name text field when   */
/*            the dialog is first opened                                    */
/*            Reference - http://www.codeguru.com/java/articles/446.shtml   */
/* 04/17/02 - Added code to capture when enter key was pressed on cancel    */
/*            button this would have the added effect of when the cancel    */
/*            button was actually pressed disposing the window.             */
/* 06/11/02 - Added code to render first column of existing system table    */
/*            (system name) uneditable.                                     */
/****************************************************************************/
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;
import java.sql.*;
import javax.swing.table.*;
import com.symantec.itools.javax.swing.borders.BevelBorder;
import com.symantec.itools.javax.swing.models.StringComboBoxModel;
import com.symantec.itools.javax.swing.borders.EtchedBorder;
import com.symantec.itools.javax.swing.models.StringTableModel;

public class AddSystemDialog extends javax.swing.JDialog {
    
	public AddSystemDialog(Frame parent) {
		super(parent);
		
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setTitle("Add Connected System:");
		setResizable(false);
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(null);
		setSize(469,283);
		setVisible(false);
		bevelBorder1.setBevelType(javax.swing.border.BevelBorder.LOWERED);
		//$$ bevelBorder1.move(0,180);
		{
			String[] tempString = new String[3];
			tempString[0] = "Choose a response...";
			tempString[1] = "Yes";
			tempString[2] = "No";
			boundary_controls_effective_choices.setItems(tempString);
		}
		//$$ boundary_controls_effective_choices.move(24,180);
		getContentPane().add(JTabbedPane1);
		JTabbedPane1.setBounds(0,0,468,240);
		new_system_panel.setBorder(etchedBorder1);
		new_system_panel.setLayout(null);
		JTabbedPane1.add(new_system_panel);
		new_system_panel.setBounds(2,24,463,213);
		new_system_panel.setVisible(false);
		JLabel1.setText("System Name:");
		new_system_panel.add(JLabel1);
		JLabel1.setForeground(java.awt.Color.black);
		JLabel1.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel1.setBounds(12,36,96,24);
		JLabel2.setText("Boundary Controls Effective?");
		new_system_panel.add(JLabel2);
		JLabel2.setForeground(java.awt.Color.black);
		JLabel2.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel2.setBounds(12,72,168,24);
		JLabel3.setText("Planned Action if Not:");
		new_system_panel.add(JLabel3);
		JLabel3.setForeground(java.awt.Color.black);
		JLabel3.setFont(new Font("Dialog", Font.BOLD, 12));
		JLabel3.setBounds(12,108,156,24);
		conn_system_name.setNextFocusableComponent(boundary_controls_eff_choice);
		conn_system_name.setToolTipText("<html>Enter the name of the connected system you are defining in this field</html>");
		new_system_panel.add(conn_system_name);
		conn_system_name.setBounds(190,36,266,24);
		boundary_controls_eff_choice.setModel(boundary_controls_effective_choices);
		boundary_controls_eff_choice.setNextFocusableComponent(planned_action_field);
		boundary_controls_eff_choice.setToolTipText("<html>Denote with a yes or no if the boundary controls of the system in question are effective or not</html>");
		new_system_panel.add(boundary_controls_eff_choice);
		boundary_controls_eff_choice.setBounds(190,72,180,24);
		JScrollPane1.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		JScrollPane1.setOpaque(true);
		new_system_panel.add(JScrollPane1);
		JScrollPane1.setBounds(190,108,260,96);
		planned_action_field.setLineWrap(true);
		planned_action_field.setWrapStyleWord(true);
		planned_action_field.setNextFocusableComponent(add_system_button);
		planned_action_field.setToolTipText("<html>If boundary controls are not effective, then the security<br>of the systems under review will depend on the security of<br>the other systems connected to it.</html>");
		JScrollPane1.getViewport().add(planned_action_field);
		planned_action_field.setBounds(0,0,242,93);
		warning_label.setText("Warning:");
		new_system_panel.add(warning_label);
		warning_label.setBackground(java.awt.Color.red);
		warning_label.setForeground(java.awt.Color.red);
		warning_label.setBounds(10,0,420,40);
		warning_label.setVisible(false);
		current_system_panel.setBorder(etchedBorder1);
		current_system_panel.setLayout(new BoxLayout(current_system_panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(current_system_panel);
		current_system_panel.setBounds(2,24,463,213);
		current_system_panel.setVisible(false);
		JScrollPane2.setOpaque(true);
		current_system_panel.add(JScrollPane2);
		current_systems_table.setNextFocusableComponent(add_system_button);
		current_systems_table.setToolTipText("<html>Displays a list of connected systems defined from previous assessments you have saved</html>");
		JScrollPane2.getViewport().add(current_systems_table);
		current_systems_table.setBounds(0,0,456,0);
		JTabbedPane1.setSelectedIndex(0);
		JTabbedPane1.setSelectedComponent(new_system_panel);
		JTabbedPane1.setTitleAt(0,"Add New System");
		JTabbedPane1.setTitleAt(1,"Current Systems");
		cancel_button.setText("Cancel");
		cancel_button.setActionCommand("Cancel");
		cancel_button.setToolTipText("<html>Press this button to cancel the Add Connected system dialog</html>");
		cancel_button.setMnemonic((int)'C');
		getContentPane().add(cancel_button);
		cancel_button.setBounds(282,252,73,25);
		add_system_button.setText("Add System");
		add_system_button.setActionCommand("Add System");
		add_system_button.setNextFocusableComponent(cancel_button);
		add_system_button.setToolTipText("<html>Press this button to add the connected system information you have<br>defined to current list</html>");
		add_system_button.setMnemonic((int)'A');
		getContentPane().add(add_system_button);
		add_system_button.setBounds(114,252,102,24);
		//$$ etchedBorder1.move(0,297);
		//$$ systemNamePopup.move(24,297);
		systemCutMenuItem.setText("Cut");
		systemCutMenuItem.setActionCommand("Cut");
		systemCutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(systemCutMenuItem);
		systemCopyMenuItem.setText("Copy");
		systemCopyMenuItem.setActionCommand("Copy");
		systemCopyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(systemCopyMenuItem);
		systemPasteMenuItem.setText("Paste");
		systemPasteMenuItem.setActionCommand("Paste");
		systemPasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(systemPasteMenuItem);
		//$$ painPopup.move(48,297);
		painCutMenuItem.setText("Cut");
		painCutMenuItem.setActionCommand("Cut");
		painCutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		painPopup.add(painCutMenuItem);
		painCopyMenuItem.setText("Copy");
		painCopyMenuItem.setActionCommand("Copy");
		painCopyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		painPopup.add(painCopyMenuItem);
		painPasteMenuItem.setText("Paste");
		painPasteMenuItem.setActionCommand("Paste");
		painPasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		painPopup.add(painPasteMenuItem);
		boundary_controls_eff_choice.setSelectedIndex(0);
		//}}
	
		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		cancel_button.addActionListener(lSymAction);
		add_system_button.addActionListener(lSymAction);
		systemCutMenuItem.addActionListener(lSymAction);
		systemCopyMenuItem.addActionListener(lSymAction);
		systemPasteMenuItem.addActionListener(lSymAction);
		painCutMenuItem.addActionListener(lSymAction);
		painCopyMenuItem.addActionListener(lSymAction);
		painPasteMenuItem.addActionListener(lSymAction);
		SymKey aSymKey = new SymKey();
		cancel_button.addKeyListener(aSymKey);
		add_system_button.addKeyListener(aSymKey);
		planned_action_field.addKeyListener(aSymKey);
		boundary_controls_eff_choice.addKeyListener(aSymKey);
		current_systems_table.addKeyListener(aSymKey);
		//}}
		this.system_table_headers.addElement("System");
		this.system_table_headers.addElement("Boundary Controls Effective?");
		this.system_table_headers.addElement("Planned Action if Not");
		this.current_systems_table_model.setColumnIdentifiers(this.system_table_headers);
        this.current_systems_table.setModel(this.current_systems_table_model);
        
        SortButtonRenderer renderer = new SortButtonRenderer();    
        TableColumnModel model = this.current_systems_table.getColumnModel();
        for (int i = 0; i < this.current_systems_table.getColumnCount(); i++) {
            (model.getColumn(i)).setHeaderRenderer(renderer);
        }
        JTableHeader header = current_systems_table.getTableHeader();
        header.addMouseListener(new HeaderListener(header,renderer));        
        
        this.conn_system_name.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            systemNamePopup.show(conn_system_name, me.getX(), me.getY());  
		        }
		    }      
		 });
		 
		 this.planned_action_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            painPopup.show(planned_action_field, me.getX(), me.getY());  
		        }
		    }      
		 });
        
        this.current_systems_table.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
                if (me.getClickCount() == 2) {
                    usePreExistingSystem(me);
                }
		    }      
		 }); 
        
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension panelSize = this.getSize();
        setLocation(screenSize.width/2 - (panelSize.width/2),
        screenSize.height/2 - (panelSize.height/2));        
        
		this.conn_system_name.requestFocus();
	}

    // This method is the action handler for when the user double clicks on a row
    // that holds the data of a pre-existing system that they wish to add to the 
    // current assessment.
    // ---------------
    // Change Control:
    // 04/16/02 - Added code to verify that @me (the mouse event that powered this 
    //            action) was not null. If it was null then a user only single
    public void usePreExistingSystem(MouseEvent me) {
        Vector table_row = null;
        int selected_row = 0;
        try {
            if (me != null) {
                selected_row = this.current_systems_table.rowAtPoint(me.getPoint());
            }else {
                selected_row = this.current_systems_table.getSelectedRow();                
            }
            table_row = (Vector) (this.current_systems_table_model.getDataVector()).elementAt(selected_row);
            this.conn_system_name.setText((String) table_row.elementAt(0));
            this.boundary_controls_eff_choice.setSelectedItem((String) table_row.elementAt(1));
            this.planned_action_field.setText((String) table_row.elementAt(2));
            this.JTabbedPane1.setSelectedIndex(0);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    class HeaderListener extends MouseAdapter {
        JTableHeader   header;    
        SortButtonRenderer renderer;      
    
        HeaderListener(JTableHeader header,SortButtonRenderer renderer) {      
            this.header   = header;      
            this.renderer = renderer;
        }
    
        public void mousePressed(MouseEvent e) {
            int col = header.columnAtPoint(e.getPoint());
            int sortCol = header.getTable().convertColumnIndexToModel(col);
            renderer.setPressedColumn(col);
            renderer.setSelectedColumn(col);
            header.repaint();
            if (header.getTable().isEditing()) {
                header.getTable().getCellEditor().stopCellEditing();
            }            
            boolean isAscent;      
            if (SortButtonRenderer.DOWN == renderer.getState(col)) {        
                isAscent = true;      
            }else {
                isAscent = false;
            }
            ((SortableTableModel)header.getTable().getModel()).sortByColumn(sortCol, isAscent);        
        } 
     
        public void mouseReleased(MouseEvent e) {      
    
            int col = header.columnAtPoint(e.getPoint());      
            renderer.setPressedColumn(-1);
                // clear      
            header.repaint();    
        }  
    }/* end internal class HeaderListener() */	

	private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}	

    public void fillTable() {
        CallableStatement current_systems = null;
	    ResultSet systems = null;
	    Vector table_row = null;
	    try {
	       this.internal_setCursor("wait"); 
	       if (this.parent.conn != null) { 
	           current_systems =  this.parent.conn.prepareCall("{call get_conn_systems}");
	           systems = current_systems.executeQuery();
	       }	       
	       while (systems.next()) {
	           table_row = new Vector();
	           table_row.addElement((systems.getString("conn_component")).trim());
	           int bce = systems.getInt("bce");
	           if (bce == 1) {
	               table_row.addElement("Yes");   
	           }else {
	               table_row.addElement("No");
	           }
	           table_row.addElement((systems.getString("planned_action")).trim());

	           this.current_systems_table_model.addRow(table_row);
	       }
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
    }

	public AddSystemDialog()
	{
		this((Frame)null);
	}

	public AddSystemDialog(String sTitle)
	{
		this();
		setTitle(sTitle);
	}

    public AddSystemDialog(AssessmentWindow parent) {
        this((Frame) null);
        this.parent = parent;
    }
	
	public Vector assessembleNewSystem() {
	    Vector new_sys = new Vector();
	    try {
	        new_sys.addElement(conn_system_name.getText());
	        if (this.boundary_controls_eff_choice.getSelectedIndex() > 0) {
	            new_sys.addElement((String) this.boundary_controls_eff_choice.getSelectedItem());
	        }else {
	            System.err.println("Cannot select this choice when asked if boundary controls are effective!");    
                new_sys.addElement("No");
	        }
	        new_sys.addElement(this.planned_action_field.getText());
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return new_sys;
	}
	
	public boolean checkFields() {
	    boolean flag = true;
	    try {
	        if (this.conn_system_name.getText().length() < 2) {
	            this.JTabbedPane1.setSelectedIndex(0);
	            this.warning_label.setVisible(true);
	            this.warning_label.setText("You must enter a valid name!");
	            flag = false;
	            return flag;
	        }
	        if (this.boundary_controls_eff_choice.getSelectedIndex() == 0) {
	            this.JTabbedPane1.setSelectedIndex(0);
	            this.warning_label.setVisible(true);
	            this.warning_label.setText("You must specify if boundary controls are effective!");
                flag = false;
                return flag;
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return flag;
	}
	
	public void addNewSystem() {
	    if (checkFields()) {
            this.parent.addSystem(this.assessembleNewSystem());
            this.setVisible(false);
            this.dispose();
        }
	}

	public void addNotify()
	{
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	com.symantec.itools.javax.swing.borders.BevelBorder bevelBorder1 = new com.symantec.itools.javax.swing.borders.BevelBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel boundary_controls_effective_choices = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JPanel new_system_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel1 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	javax.swing.JTextField conn_system_name = new javax.swing.JTextField();
	javax.swing.JComboBox boundary_controls_eff_choice = new javax.swing.JComboBox();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JTextArea planned_action_field = new javax.swing.JTextArea();
	javax.swing.JLabel warning_label = new javax.swing.JLabel();
	javax.swing.JPanel current_system_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane2 = new javax.swing.JScrollPane();
	javax.swing.JTable current_systems_table = new javax.swing.JTable();
	javax.swing.JButton cancel_button = new javax.swing.JButton();
	javax.swing.JButton add_system_button = new javax.swing.JButton();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	javax.swing.JPopupMenu systemNamePopup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem systemCutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem systemCopyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem systemPasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu painPopup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem painCutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem painCopyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem painPasteMenuItem = new javax.swing.JMenuItem();
	//}}
	Vector system_table_headers = new Vector();
    AssessmentWindow parent = null;
    SortableTableModel current_systems_table_model =  new SortableTableModel() {        
	    public boolean isCellEditable(int row, int column) {
            if (column == 0) {
                return false;
            }
            return true;
        }
 
 	    public void setValueAt(Object aValue, int row, int column) {
            ((Vector)dataVector.elementAt(row)).setElementAt(aValue, column);
		    fireTableCellUpdated(row, column);
	    }        
    };
    
	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == cancel_button)
				cancelButton_actionPerformed(event);
			if (object == add_system_button)
				addSystemButton_actionPerformed(event);
			else if (object == systemCutMenuItem)
				systemCutMenuItem_actionPerformed(event);
			else if (object == systemCopyMenuItem)
				systemCopyMenuItem_actionPerformed(event);
			else if (object == systemPasteMenuItem)
				systemPasteMenuItem_actionPerformed(event);
			else if (object == painCutMenuItem)
				painCutMenuItem_actionPerformed(event);
			else if (object == painCopyMenuItem)
				painCopyMenuItem_actionPerformed(event);
			else if (object == painPasteMenuItem)
				painPasteMenuItem_actionPerformed(event);
		}
	}

	void cancelButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		cancel_button_actionPerformed_Interaction1(event);
	}

	void cancel_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.dispose();
		} catch (java.lang.Exception e) {
		}
	}

	void addSystemButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		add_system_button_actionPerformed_Interaction1(event);
	}

    // This method is the action handler for when the Add System button is pressed 
    // on the Add Inter-connected system dialog. It is designed to add a new row to
    // the Inter-Connected systems table.
    // ---------------
    // Change Control:
    // 04/17/02 - Added code to handle the case when a user clicks on a system in the
    //            pre-existing table and then clicks on the Add System button instead
    //            of double clicking on the row that represents the system.
	void add_system_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.JTabbedPane1.getSelectedIndex() == 0) {
			    this.addNewSystem();
			}else {
			    this.usePreExistingSystem(null);
			    this.addNewSystem();
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();		
		}
	}/* end method add_system_button_actionPerformed_Interaction1(java.awt.event.ActionEvent) */

	void systemCutMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		systemCutMenuItem_actionPerformed_Interaction1(event);
	}

	void systemCutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			conn_system_name.cut();
		} catch (java.lang.Exception e) {
		}
	}

	void systemCopyMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		systemCopyMenuItem_actionPerformed_Interaction1(event);
	}

	void systemCopyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			conn_system_name.copy();
		} catch (java.lang.Exception e) {
		}
	}

	void systemPasteMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		systemPasteMenuItem_actionPerformed_Interaction1(event);
	}

	void systemPasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			conn_system_name.paste();
		} catch (java.lang.Exception e) {
		}
	}

	void painCutMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		painCutMenuItem_actionPerformed_Interaction1(event);
	}

	void painCutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			planned_action_field.cut();
		} catch (java.lang.Exception e) {
		}
	}

	void painCopyMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		painCopyMenuItem_actionPerformed_Interaction1(event);
	}

	void painCopyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			planned_action_field.copy();
		} catch (java.lang.Exception e) {
		}
	}

	void painPasteMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		painPasteMenuItem_actionPerformed_Interaction1(event);
	}

	void painPasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			planned_action_field.paste();
		} catch (java.lang.Exception e) {
		}
	}
	
	// This method is the action handler for the add_system_button capturing a 
	// key pressed event. The method will check to see if the key that was pressed
	// was the Enter key at which point the program will act as if the
	// add_system_button generated an action event.
	private void proceedKeyEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        if (this.JTabbedPane1.getSelectedIndex() == 0) {
			        this.addNewSystem();
			    }else {
			        this.usePreExistingSystem(null);
			        this.addNewSystem();
			    }		        
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}	
	
	private void connectedSystemTableEnterPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
    	        this.usePreExistingSystem(null);    
			}	            
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
    private void proceedKeyCancelButtonPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.dispose();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void action_fieldTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.add_system_button.requestFocus();    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void choice_fieldTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.planned_action_field.requestFocus();    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }    

	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == cancel_button)
				cancelButton_keyTyped(event);
			else if (object == add_system_button)
				addSystemButton_keyTyped(event);
			else if (object == planned_action_field)
				plannedActionField_keyTyped(event);
			else if (object == boundary_controls_eff_choice)
				boundaryControlsEffChoice_keyTyped(event);
			else if (object == current_systems_table)
				currentSystemsTable_keyTyped(event);
		}
	}

	void cancelButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		cancel_button_keyTyped_Interaction1(event);
	}

	void cancel_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyCancelButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void addSystemButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		add_system_button_keyTyped_Interaction1(event);
	}

	void add_system_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedKeyEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void plannedActionField_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		planned_action_field_keyTyped_Interaction1(event);
	}

	void planned_action_field_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.action_fieldTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void boundaryControlsEffChoice_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		boundary_controls_eff_choice_keyTyped_Interaction1(event);
	}

	void boundary_controls_eff_choice_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.choice_fieldTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void currentSystemsTable_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		current_systems_table_keyTyped_Interaction1(event);
	}

	void current_systems_table_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.connectedSystemTableEnterPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
} /* end class AddSystemDialog() */