/************************************************************************************/
/* file - DATFilter.java                                                            */
/* ---------------------                                                            */
/* This class extends the FileFilter class of the Java IO package. This allows the  */
/* JFileChooser class to only display files with an extension as specified here.    */
/* In this case, an extension of 'dat'. These files are used to store backup info   */
/* about an active assessment.                                                      */
/************************************************************************************/
import java.io.File;
import javax.swing.*;
import javax.swing.filechooser.*;

public class DATFilter extends FileFilter {
    final static String csv = "dat";
    
    public boolean accept(File f) {
	    if (f.isDirectory()) {
	        return true;
	    }

	    String s = f.getName();
	    int i = s.lastIndexOf('.');

	    if (i > 0 &&  i < s.length() - 1) {
	        String extension = s.substring(i+1).toLowerCase();
	        if (csv.equals(extension)) {
		        return true;
	        } else {
		        return false;
	        }
	    }
	    return false;
    }
    
    // The description of this filter
    // References:
    // http://whatis.techtarget.com/definition/0,,sid9_gci213871,00.html
    public String getDescription() {
	    return "Binary Assessment Data File";
    }
}/* end class DATFilter.java */
