/***************************************************************************/
/* file - QuestionResponse.java                                            */
/* ----------------------------                                            */
/* This file encapsulates the responses to a assessment question. IT is the*/
/* parent class of AssessmentQuestionResponse which deals specifically     */
/* with subbordinate assessment questions due to the prescense of the ffr  */
/* and reviewer fields in that table.                                      */
/* ----------------------------                                            */
/* NIST Self-Assessment Tool                                               */
/* ----------------------------                                            */
/* Change Control:                                                         */
/* 02/13/02 - implemented Serializable interface to allow respones         */
/*            to be serialized when assessment data is saved locally       */
/***************************************************************************/
import java.util.*;
import java.io.Serializable;

public class QuestionResponse implements java.io.Serializable {
    
    protected QuestionResponse() {
    }

    public static QuestionResponse createNewResponse() {
        return new QuestionResponse();
    }

    protected QuestionResponse(String assessment_id) {        
        this.setAssessmentID(assessment_id);
    }

    public static QuestionResponse createNewResponse(String id) {
        return new QuestionResponse(id);
    }
    
    protected QuestionResponse(String ques_num, String assessment_id) {        
        this.setAssessmentID(assessment_id);
        this.setQuestionNumber(ques_num);
    }
 
    public static QuestionResponse createNewResponse(String ques_num, String id) {
        return new QuestionResponse(ques_num, id);
    }    

    public void setAssessmentID(String id) {
        this.assessment_id = id;
    }
    
    public String getAssessmentID() {
        return this.assessment_id;    
    }
    
    public void setAssessor(String assessor) {
        this.assessor = assessor;
    }
    
    public String getAssessor() {
        return this.assessor;
    }
    
    public void setVersion(int version) {
        this.version = version;
    }
    
    public int getVersion() {
        return this.version;
    }
    
    public int getRBDM() {
        return this.rbdm;
    }
    
    public void setRBDM(int flag) {        
        this.rbdm = flag;
    }
    
    public void setITSAF1(int value) {
        this.itsaf1 = value;
    }
    
    public int getITSAF1() {
        return this.itsaf1;
        
    }
    
    public void setITSAF2(int value) {
        this.itsaf2 = value;
    }
    
    public int getITSAF2() {
        return this.itsaf2;
        
    }
    
    public void setITSAF3(int value) {
        this.itsaf3 = value;
    }
    
    public int getITSAF3() {
        return this.itsaf3;
    }
    
    public void setITSAF4(int value) {
        this.itsaf4 = value;
    }
    
    public int getITSAF4() {
        return this.itsaf4;
    }
    
    public void setITSAF5(int value) {
        this.itsaf5 = value;
    }
    
    public int getITSAF5() {
        return this.itsaf5;
    }
    
    public void setComments(String cmnts) {
        this.comments = cmnts;
    }
    
    public String getComments() {
        return this.comments;
    }
    
    public void setQuestionNumber(String num) {
        this.question_number = num;
    }
    
    public String getQuestionNumber() {
        return this.question_number;
    }
    
    public void assignRespon(String who) {
        this.assign_respon = 1;
        this.respon = who;
    }
    
    public String getResponsibleParty() {
        return this.respon;
    }
    
    public int getAssignedResponsibility() {
        return this.assign_respon;
    }
    
    public void setNA(int na) {
        this.na = na;
    }
    
    public int getNA() {
        return this.na;    
    }
    
    // This method examines all of the various elements to the response to see if the response
    // is empty or not. If it is empty then the question being displayed has not been answered
    // yet
    // ---------------
    // Change Control:
    // 03/15/02 - Added code to also check to ensure that the flag question checkbox was not
    //            selected - getAssignedResponsibility() method performs this check or
    //            else if this box is checked then it is not seen as a proper response and
    //            dropped instead of stored in the question response block.
    // 03/18/02 - Added check to see if response was marked as completed, if a user does not 
    //            check any boxes but still checks the completed box then the response is dropped.
    // 04/17/02 - Needed to change conditional statement to ignore the status of ITSAF1 value since
    //            the user could never have access to it directly. If policy was set for the current
    //            section a particular instance of QuestionResponse was in, and the user attempted to
    //            jump to the next section, this method call would evaluate to not empty and the question
    //            progress would get incorrectly incremented.
    public boolean isEmpty() {
        try {
            if (this.getITSAF2() == 0 && this.getITSAF3() == 0 && this.getITSAF4() == 0 && this.getITSAF5() == 0 && this.getAssignedResponsibility() == 0 && this.getNA() == 0 && this.isCompleted() == 0) {
                if (this.getComments().equals("")) {
                    return true;
                }
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }
    
    public int isCompleted() {
        return completed;    
    }
    
    public void setCompleted(boolean flag) {
        if (flag) {
            this.completed = 1;
        }else {
            this.completed = 0;    
        }
    }
    
    protected int completed = 0;
    
    protected int rbdm = 0;
    protected int na = 0;
    
    protected int itsaf1 = 0;
    protected int itsaf2 = 0;
    protected int itsaf3 = 0;
    protected int itsaf4 = 0;
    protected int itsaf5 = 0;
    
    protected String comments = "";   
    protected String assessment_id = "";
    
    protected String assessor= "";
    protected int version = 0;
    
    protected String question_number = "";
    
    protected int assign_respon = 0;
    protected String respon = "";
}/* end class QuestionResponse() */