/*****************************************************************************/
/* file - SATUI.java                                                         */
/* -----------------                                                         */
/* This file is the main class for the NIST Self-Assessment Tool Client      */
/* It's main purpose is to create and manage assessment windows on its       */
/* desktop. It uses the Swing 1.1 interface and is written to run on the Java*/
/* 2 (jdk 1.3.1) platform                                                    */
/* -----------------                                                         */
/* NIST Self-Assessment Tool                                                 */
/* -----------------                                                         */
/* Author - Mark McLarnon                                                    */
/* Booz | Allen | Hamilton                                                   */
/* -----------------                                                         */
/* TO RECREATE THE ASSET CLIENT PROJECT:                                     */
/* This project requires files that are not in the standard source distrib   */
/* of the ASSET Client:                                                      */
/* 1. CSVFilter.java                                                         */
/* 2. HTMLLabel.java                                                         */
/* 3. AssessmentImporter.java                                                */
/* 4. SortButtonRenderer.java                                                */
/* 5. SortableTableModel.java                                                */
/* 6. TableSorter.java                                                       */
/* 7. BlankIcon.java                                                         */
/* 8. BevelArrowIcon.java                                                    */
/* IF you are going to rebuild this project within Visual Cafe you must make */
/* sure that these files are imported into the Project window. In addition   */
/* This project requires JAR libraries that are not part of the standard     */
/* distribution:                                                             */
/* 1. logger.jar (Offers logging functionality to the ASSET Client)          */
/* 2. xmlParserAPIs.jar                                                      */
/* 3. xercesImpl.jar                                                         */
/* You must ensure that these files are specified as input class libraries   */
/* within the projec toptions window of Visual Cafe.                         */
/* -----------------                                                         */
/* Change Control:                                                           */
/* 02/13/02- Added Code to change mouse pointer via a string parameter       */
/* 02/14/02- Added Code to set cursor to hourglass when displaying load dialg*/
/* 05/19/02- Pointed file open dialog box to parent directory of ASSET System*/
/*           by using new File(user.dir).getParent()                         */
/*****************************************************************************/
import java.awt.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.*;
import java.sql.*;
import java.io.*;
import java.net.URL;
import com.symantec.itools.net.*;
import symantec.itools.lang.Context;
import com.symantec.itools.beans.VetoableChangeSupport;
import com.symantec.itools.beans.PropertyChangeSupport;
import com.symantec.itools.javax.swing.JToolBarSeparator;
import com.symantec.itools.javax.swing.icons.ImageIcon;
import com.symantec.itools.javax.swing.borders.BevelBorder;
import com.symantec.itools.javax.swing.borders.EtchedBorder;

public class SATUI extends javax.swing.JFrame implements ASSET {
    
	public SATUI() {
	    props = ASSETClientPropertyManager.initializePropertyManager(this, "sat.conf"); 		
	    try {
		    Class.forName(this.props.getProperty("sat.data.driver"));
		}catch (Exception e) {
		    ;    
		}
		JPanel1.add(this.JDesktopPane1);
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setJMenuBar(SAT_Client_Menu);
		setTitle("NIST ASSET System");
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BorderLayout(0,0));
		setSize(696,521);
		setVisible(false);
		try {
			printIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/print.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ printIcon.move(684,528);
		try {
			newIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/new.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ newIcon.move(144,312);
		try {
			openIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/open.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ openIcon.move(120,312);
		try {
			saveIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/save.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ saveIcon.move(96,312);
		try {
			cutIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/cut.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ cutIcon.move(72,312);
		try {
			copyIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/copy.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ copyIcon.move(48,312);
		try {
			pasteIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/paste.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ pasteIcon.move(48,528);
		try {
			aboutIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/about.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ aboutIcon.move(96,528);
		toolbar_panel.setLayout(new FlowLayout(FlowLayout.LEFT,0,0));
		getContentPane().add(BorderLayout.NORTH, toolbar_panel);
		toolbar_panel.setBackground(new java.awt.Color(212,208,200));
		Status_Panel.setLayout(new BorderLayout(0,0));
		getContentPane().add(BorderLayout.SOUTH, Status_Panel);
		Status_Panel.setBackground(java.awt.Color.lightGray);
		JPanel4.setBorder(bevelBorder1);
		JPanel4.setLayout(new FlowLayout(FlowLayout.CENTER,5,0));
		Status_Panel.add(BorderLayout.WEST, JPanel4);
		status_mode_msg.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
		status_mode_msg.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		status_mode_msg.setText("  Idle...");
		status_mode_msg.setAlignmentX(0.5F);
		status_mode_msg.setToolTipText("<html>Shows the current activity of the SAT Client</html>");
		JPanel4.add(status_mode_msg);
		status_mode_msg.setForeground(java.awt.Color.black);
		status_mode_msg.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel5.setBorder(bevelBorder1);
		JPanel5.setToolTipText("<html>System status messages are displayed here.</html>");
		JPanel5.setLayout(new FlowLayout(FlowLayout.CENTER,5,0));
		Status_Panel.add(BorderLayout.CENTER, JPanel5);
		regular_status_msg.setText("Press CTRL-N to start a new system assessment");
		regular_status_msg.setToolTipText("<html>Displays the SAT status</html>");
		JPanel5.add(regular_status_msg);
		regular_status_msg.setForeground(java.awt.Color.black);
		regular_status_msg.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel2.setAlignmentY(0.466667F);
		JPanel2.setBorder(bevelBorder1);
		JPanel2.setLayout(new BoxLayout(JPanel2,BoxLayout.X_AXIS));
		Status_Panel.add(BorderLayout.EAST, JPanel2);
		primary_assessor_label.setText("Not Logged In");
		primary_assessor_label.setToolTipText("<html>Shows the user who has logged into the ASSET System</html>");
		JPanel2.add(primary_assessor_label);
		primary_assessor_label.setForeground(java.awt.Color.black);
		primary_assessor_label.setFont(new Font("Dialog", Font.PLAIN, 12));
		bevelBorder1.setBevelType(javax.swing.border.BevelBorder.LOWERED);
		//$$ bevelBorder1.move(0,522);
		//$$ etchedBorder1.move(24,522);
		JScrollPane1.setOpaque(true);
		getContentPane().add(BorderLayout.CENTER, JScrollPane1);
		JPanel1.setAlignmentY(0.0F);
		JPanel1.setBorder(etchedBorder1);
		JPanel1.setLayout(new BoxLayout(JPanel1,BoxLayout.X_AXIS));
		JScrollPane1.getViewport().add(JPanel1);
		JPanel1.setBackground(new java.awt.Color(218,208,200));
		JPanel1.setBounds(0,0,693,499);
		//$$ SAT_Client_Menu.move(660,528);
		fileMenu.setText("File");
		fileMenu.setActionCommand("File");
		fileMenu.setBorderPainted(false);
		fileMenu.setMnemonic((int)'F');
		SAT_Client_Menu.add(fileMenu);
		newItem.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		newItem.setText("New Assessment");
		newItem.setActionCommand("New");
		newItem.setBorderPainted(false);
		newItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_N, java.awt.Event.CTRL_MASK));
		newItem.setMnemonic((int)'N');
		fileMenu.add(newItem);
		openMenu.setText("Open assessment");
		openMenu.setActionCommand("Open assessment");
		fileMenu.add(openMenu);
		openItem.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		openItem.setText("Open assessment from database");
		openItem.setActionCommand("Open...");
		openItem.setBorderPainted(false);
		openItem.setToolTipText("<html>Open saved assessment</html>");
		openItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_O, java.awt.Event.CTRL_MASK));
		openItem.setMnemonic((int)'O');
		openMenu.add(openItem);
		importMenuItem.setText("Import assessment from file");
		importMenuItem.setActionCommand("Open assessment from file");
		importMenuItem.setToolTipText("<html>Loads assessment data from file on your hard drive</html>");
		importMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_I, java.awt.Event.CTRL_MASK));
		openMenu.add(importMenuItem);
		saveMenu.setText("Save Assessment");
		saveMenu.setActionCommand("Save Assessment");
		fileMenu.add(saveMenu);
		saveAssessmentMenuItem.setText("Save assessment to database");
		saveAssessmentMenuItem.setActionCommand("Save assessment to database");
		saveAssessmentMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_D, java.awt.Event.CTRL_MASK));
		saveMenu.add(saveAssessmentMenuItem);
		saveAssessmentLocalMenuItem.setText("Save assessment to file");
		saveAssessmentLocalMenuItem.setActionCommand("Export assessment to file");
		saveAssessmentLocalMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.Event.CTRL_MASK));
		saveMenu.add(saveAssessmentLocalMenuItem);
		fileMenu.add(JSeparator7);
		logoffMenuItem.setText("Logoff...");
		logoffMenuItem.setActionCommand("Logoff...");
		logoffMenuItem.setBorderPainted(false);
		logoffMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_L, java.awt.Event.CTRL_MASK));
		logoffMenuItem.setMnemonic((int)'L');
		fileMenu.add(logoffMenuItem);
		exitItem.setText("Exit");
		exitItem.setActionCommand("Exit");
		exitItem.setBorderPainted(false);
		exitItem.setMnemonic((int)'X');
		fileMenu.add(exitItem);
		editMenu.setText("Edit");
		editMenu.setActionCommand("Edit");
		editMenu.setMnemonic((int)'E');
		SAT_Client_Menu.add(editMenu);
		cutMenuItem.setText("Cut");
		cutMenuItem.setActionCommand("Cut");
		cutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		editMenu.add(cutMenuItem);
		copyMenuItem.setText("Copy");
		copyMenuItem.setActionCommand("Copy");
		copyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		editMenu.add(copyMenuItem);
		pasteMenuItem.setText("Paste");
		pasteMenuItem.setActionCommand("Paste");
		pasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		editMenu.add(pasteMenuItem);
		toolsMenu.setText("Tools");
		toolsMenu.setActionCommand("Tools");
		toolsMenu.setBorderPainted(false);
		toolsMenu.setMnemonic((int)'T');
		SAT_Client_Menu.add(toolsMenu);
		reportingMenuItem.setText("Reporting");
		reportingMenuItem.setActionCommand("Reporting");
		reportingMenuItem.setBorderPainted(false);
		reportingMenuItem.setToolTipText("<html>Opens the ASSET System reporting window</html>");
		reportingMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_R, java.awt.Event.CTRL_MASK));
		reportingMenuItem.setMnemonic((int)'R');
		toolsMenu.add(reportingMenuItem);
		helpMenu.setText("Help");
		helpMenu.setActionCommand("Help");
		helpMenu.setBorderPainted(false);
		helpMenu.setMnemonic((int)'H');
		SAT_Client_Menu.add(helpMenu);
		helpTopicsMenuItem.setText("Help Topics");
		helpTopicsMenuItem.setActionCommand("Help Topics");
		helpTopicsMenuItem.setBorderPainted(false);
		helpTopicsMenuItem.setToolTipText("<html>Opens the main ASSET System help window</html>");
		helpTopicsMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_H, java.awt.Event.CTRL_MASK));
		helpTopicsMenuItem.setMnemonic((int)'P');
		helpMenu.add(helpTopicsMenuItem);
		aboutItem.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		aboutItem.setText("About...");
		aboutItem.setActionCommand("About...");
		aboutItem.setBorderPainted(false);
		aboutItem.setToolTipText("<html>Displays ASSET System program information</html>");
		aboutItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_A, java.awt.Event.CTRL_MASK));
		aboutItem.setMnemonic((int)'A');
		helpMenu.add(aboutItem);
		helpMenu.add(JSeparator1);
		changeDefaultBrowserMenuItem.setText("Change default browser");
		changeDefaultBrowserMenuItem.setActionCommand("Change default browser");
		changeDefaultBrowserMenuItem.setToolTipText("<html>Runs the default browser wizard</html>");
		changeDefaultBrowserMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.SHIFT_MASK|java.awt.Event.CTRL_MASK));
		helpMenu.add(changeDefaultBrowserMenuItem);
		try {
			logIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/executionlog.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ logIcon.move(684,528);
		cutMenuItem.setIcon(cutIcon);
		helpTopicsMenuItem.setIcon(aboutIcon);
		pasteMenuItem.setIcon(pasteIcon);
		copyMenuItem.setIcon(copyIcon);
		openMenu.setIcon(openIcon);
		saveAssessmentMenuItem.setIcon(saveIcon);
		saveMenu.setIcon(saveIcon);
		saveAssessmentLocalMenuItem.setIcon(saveIcon);
		newItem.setIcon(newIcon);
		//}}

		//{{INIT_MENUS
		//}}

		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		SymAction lSymAction = new SymAction();
		openItem.addActionListener(lSymAction);
		exitItem.addActionListener(lSymAction);
		aboutItem.addActionListener(lSymAction);
		newItem.addActionListener(lSymAction);
		logoffMenuItem.addActionListener(lSymAction);
		SymComponent aSymComponent = new SymComponent();
		this.addComponentListener(aSymComponent);
		importMenuItem.addActionListener(lSymAction);
		saveAssessmentMenuItem.addActionListener(lSymAction);
		saveAssessmentLocalMenuItem.addActionListener(lSymAction);
		changeDefaultBrowserMenuItem.addActionListener(lSymAction);
		helpTopicsMenuItem.addActionListener(lSymAction);
		reportingMenuItem.addActionListener(lSymAction);
		cutMenuItem.addActionListener(lSymAction);
		copyMenuItem.addActionListener(lSymAction);
		pasteMenuItem.addActionListener(lSymAction);
		//}}		
		this.JDesktopPane1.setBackground(new java.awt.Color(204,204,204));
	    
        this.window_count++;
        this.logger.log("NIST Self-Assessment Tool Started");
        
        this.opener.addChoosableFileFilter(new DATFilter());
        this.opener.addChoosableFileFilter(new XMLFilter());
        this.opener.setCurrentDirectory((new File(System.getProperty("user.dir"))).getParentFile());
        this.saveMenu.setEnabled(false);
	}/* end default constructor SATUI() */
	
    public void openOldAssessment(String id, String name) {
        try {
            this.initiateAssessmentLoad(id, name);             
        }catch (Exception e) {
            e.printStackTrace();
        }
    }	
	
	public void openReportingFrame() {
	    this.openNewReportingWindow();
	}
	
    public ASSETPropertyManager getPropertyManager() {
        return this.props;           
    }

    public void startNewAssessment() {
        this.openNewAssessmentWindow();    
    }

    public void defineAction(String action) {
        this.execute(this.props.getProperty("sat.help.defaultbrowser") + " " + this.getFullPath(this.props.getProperty("sat.help.actiondocument"))+ "#" + action);        
    }
    
    public void defineTerm(String term) {
        this.execute(this.props.getProperty("sat.help.defaultbrowser") + " " + this.getFullPath(this.props.getProperty("sat.help.definitiondocument"))+ "#" + term);                
    }
    
    private void execute(String cmd) {
        try {
             Runtime subsystem = Runtime.getRuntime();
             subsystem.exec(cmd);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void checkDefaultBrowserSet() {
        try {
            if (props.getProperty("sat.help.defaultbrowser") == null) {
                ChooseBrowserWizard wiz = ChooseBrowserWizard.spawnNewChooseBrowserWizard(this, this.props);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public boolean verifyDefaultBrowserSet() {

        try {
            if (props.getProperty("sat.help.defaultbrowser") == null) {
                {
                    this.displayErrorDialog("You have not specified a default browser!");    
                }
                return false;                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return true;
    }    
    
    public void setNewDefaultBrowser() {
        try {
            ChooseBrowserWizard wiz = ChooseBrowserWizard.spawnNewChooseBrowserWizard(this, this.props);            
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public String getFullPath(String local_path) {
        StringBuffer file_name = new StringBuffer("");
        try {
            file_name.append((symantec.itools.net.RelativeURL.getURL(local_path)).toString());
        }catch (Exception e) {
            e.printStackTrace();
        }
        return file_name.toString();
    }
    
    public String getAbsolutePath(String local_path) {
        StringBuffer file_name = new StringBuffer("");
        try {
            file_name.append(System.getProperty("user.dir") + File.separator + local_path);
        }catch (Exception e) {
            e.printStackTrace();
        }
        return file_name.toString();        
    }

    public void openDefaultHelpFile() {
        try {
           Runtime subsystem = Runtime.getRuntime();
           
           if (this.verifyDefaultBrowserSet()) {
               subsystem.exec(this.props.getProperty("sat.help.defaultbrowser") + " " + getFullPath(this.props.getProperty("sat.help.defaultdocument")));
           }else {
               this.checkDefaultBrowserSet(); 
           }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Creates a new instance of JFrame1 with the given title.
     * @param sTitle the title for the new frame.
     * @see #JFrame1()
     */
	public SATUI(String sTitle)
	{
		this();
		setTitle(sTitle);
	}
	
	public void setServiceName(String name) {
	    this.logger.setServiceName(name);   
	}
	
	public void databaseSaveOptionActivated() {
	    try {
	        this.forceRepaint();
	        {
	            ASSETChild child = (ASSETChild) this.JDesktopPane1.getSelectedFrame();
	                if (child != null && child.getSupportsSave()) {
	                    child.store();
	                }else {
	                    this.displayErrorDialog("You cannot save anything at this time!");    
	                }
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void fileSaveOptionActivated() {
	    try {
	        
	        ASSETChild child = (ASSETChild) this.JDesktopPane1.getSelectedFrame();
	            if (child != null && child.getSupportsSave()) {
	                child.saveLocally();
	            }else {
	                this.displayErrorDialog("You cannot save anything at this time!");    
	            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void forceRepaint() {
	    try {
	        Graphics g = this.getGraphics();
	        this.update(g);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// This method opens a new assessment window. It creates and displays a new instance of 
	// the class AssessmentWindow on the instance of JDesktopPane within the class.
	// ---------------
	// Change Control:
	// 03/07/02 - Added code to maximize AssessmentWindow frame once it has been '
	//            added to the desktop pane.
	// 04/17/02 - Changed error where status mode had msg displayed in it that was meant
	//            for status message.
	public void openNewAssessmentWindow() {
	    try {
	        this.primary_assessor.setPrimaryAssessor(true);
	        this.assessment = null;
	        this.setStatusModeMsg(" AIP ");
	        this.setStatusMsg("Creating new assessment window now, please hold.");
	        this.assessment = new AssessmentWindow(this);
	        this.saveMenu.setEnabled(true);
	        this.assessment.setPrimaryAssessor(this.primary_assessor, this.primary_assessor.getDataVector());
            JDesktopPane1.add(this.assessment);
            this.assessment.setMaximum(true);
	        this.assessment.setVisible(true);	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public Connection connectionGenerator() {
        try {
            return DriverManager.getConnection(this.props.getProperty("sat.data.connstring"), this.props.getProperty("sat.data.username"), this.props.getProperty("sat.data.password"));
        }catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }  		
	
	public void openNewReportingWindow() {
	    try {
	        this.internal_setCursor("wait");
	        this.setStatusModeMsg(" RPRT ");
	        this.setStatusMsg("Opening reporting window now");
            this.reporter = new ClientReportingFrame(this);
            this.JDesktopPane1.add(this.reporter);
            this.reporter.setMaximum(true);
            this.reporter.setVisible(true);           
            this.setStatusMsg("ASSET System Reporting");
            this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	// Starts the extraction of asssessment information from the database based
	// on the assessment_id and system_name parameters passed in from the calling
	// method. This method is called either from the loadDialog class or from the
	// AssessmentWindow class method that handles the importing of an assessment xml
	// file
	// ---------------
	// Change Control:
	// 05/08/02 - Added code to forcibly set divider size to 9 pixels on assessment that
	//            is loaded from the database. Users complain of bug on JRE 1.4 where 
	//            JSplitPaneWrapper is extremely large.
	public void initiateAssessmentLoad(String assessment_id, String system_name) {
	    try {
	        // Force a repaint of the SATUI window because of delayed redrawing
	        // after the loadDialog is disposed but the assessment extrraction
	        // is occurring.
	        Graphics g = this.getGraphics();
	        this.update(g);
	        this.saveMenu.setEnabled(true);
	        this.assessment = new AssessmentWindow(this);
	        this.assessment.setSecondaryAssessor(this.primary_assessor);
	        this.assessment.extractFromDatabase(assessment_id, system_name);
            JDesktopPane1.add(this.assessment);
            this.assessment.setMaximum(true);
	        this.assessment.setVisible(true);
	        this.assessment.JSplitPaneWrapper1.setDividerSize(9);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
		
	public void setLookandFeel(String plaf) {
	    try {
		    UIManager.setLookAndFeel(plaf);
		    
            JRootPane topRoot = SwingUtilities.getRootPane(this);
            if (topRoot != null) {
                while (true) {
                    Container rootParent = topRoot.getParent();
                    if (rootParent == null)
                        break;
                
                    JRootPane possibleRoot = SwingUtilities.getRootPane(rootParent);
                    if (possibleRoot == null || possibleRoot == topRoot)
                        break;
                
                    topRoot = possibleRoot;
                }
            
                SwingUtilities.updateComponentTreeUI(topRoot);
            }		    
		} catch (Exception e) { 
            e.printStackTrace();
		}
	}
	
	public void setStatusModeMsg(String msg) {
        StringBuffer status_mode_msg = new StringBuffer();
        try {
            int length = msg.length();
            status_mode_msg.append(" ");
            status_mode_msg.append(msg);
            {
                this.status_mode_msg.setText("");
                Graphics g = this.status_mode_msg.getGraphics();
                this.status_mode_msg.update(g);                
            }
            {
                this.status_mode_msg.setText(status_mode_msg.toString());
                Graphics g = this.status_mode_msg.getGraphics();
                this.status_mode_msg.update(g);
            }
            Graphics g = this.status_mode_msg.getGraphics();
            this.status_mode_msg.update(g);
        }catch (Exception e) {
            e.printStackTrace();
        }
	}
	
	public void setStatusMsg(String msg) {
        StringBuffer status_mode_msg = new StringBuffer();
        try {
            status_mode_msg.append("  ");
            status_mode_msg.append(msg);
            {
                this.regular_status_msg.setText("");
                Graphics g = this.regular_status_msg.getGraphics();
                this.regular_status_msg.update(g);                
            }
            {
                this.regular_status_msg.setText(status_mode_msg.toString());
                Graphics g = this.regular_status_msg.getGraphics();
                this.regular_status_msg.update(g);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
	}	    
	
	/**
	 * The entry point for this application.
	 * Sets the Look and Feel to the System Look and Feel.
	 * Creates a new JFrame1 and makes it visible.
	 */
	// Change Control:
	// 03/27/02 - Changed instantiation of Splash Screen to before the instance of 
	//            SATUI is created. This will prevent the long delay before anything 
	//            happens when the application is started.
	static public void main(String args[]) {
		try {
		    
		    // Add the following code if you want the Look and Feel
		    // to be set to the Look and Feel of the native system.
		    // Change Control: 02/10/02
		    // Changed default look and feel to Metal (a.k.a Java) to utilize 
		    // multi-line labels for each critical element on the quesiton map of 
		    // AssessmentWindow class
		    try {
		        UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
		        //UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		    }catch (Exception e) { 
                System.err.println("ERROR: cannot set PLAF to native Windows look");
                e.printStackTrace();
                System.exit(1);
		    }
		    splash = new SplashScreen();
		    splash.setVisible(true);
		    SATUI client = new SATUI();
		    try {
		        Thread.sleep(screen_display_time);
		    }catch (Exception e) {
		        e.printStackTrace();
		    }
			//Create a new instance of our application's frame, and make it visible.			
			client.internal_setCursor("wait");

		    splash.setVisible(false);
		    client.internal_setCursor("default");
            splash.dispose();
            
			client.login = new LoginDialog(client);
			client.login.setVisible(true);
		}catch (Throwable t) {
			t.printStackTrace();
			//Ensure the application exits with an error condition.
			System.exit(1);
		}
	}
	
	public void setPrimaryAssessor(Assessor primary) {
        this.primary_assessor = primary;
        this.primary_assessor_label.setText(" " + primary.getFullName() + " ");
	}

    /**
     * Notifies this component that it has been added to a container
     * This method should be called by <code>Container.add</code>, and 
     * not by user code directly.
     * Overridden here to adjust the size of the frame if needed.
     * @see java.awt.Container#removeNotify
     */
	public void addNotify()
	{
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();
		
		super.addNotify();
		
		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;
		
		// Adjust size of frame according to the insets and menu bar
		javax.swing.JMenuBar menuBar = getRootPane().getJMenuBar();
		int menuBarHeight = 0;
		if (menuBar != null)
		    menuBarHeight = menuBar.getPreferredSize().height;
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height + menuBarHeight);
	}
	      

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	com.symantec.itools.javax.swing.icons.ImageIcon printIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon newIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon openIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon saveIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon cutIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon copyIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon pasteIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon aboutIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	javax.swing.JPanel toolbar_panel = new javax.swing.JPanel();
	javax.swing.JPanel Status_Panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel4 = new javax.swing.JPanel();
	javax.swing.JLabel status_mode_msg = new javax.swing.JLabel();
	javax.swing.JPanel JPanel5 = new javax.swing.JPanel();
	javax.swing.JLabel regular_status_msg = new javax.swing.JLabel();
	javax.swing.JPanel JPanel2 = new javax.swing.JPanel();
	javax.swing.JLabel primary_assessor_label = new javax.swing.JLabel();
	com.symantec.itools.javax.swing.borders.BevelBorder bevelBorder1 = new com.symantec.itools.javax.swing.borders.BevelBorder();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	javax.swing.JMenuBar SAT_Client_Menu = new javax.swing.JMenuBar();
	javax.swing.JMenu fileMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem newItem = new javax.swing.JMenuItem();
	javax.swing.JMenu openMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem openItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem importMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenu saveMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem saveAssessmentMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem saveAssessmentLocalMenuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator7 = new javax.swing.JSeparator();
	javax.swing.JMenuItem logoffMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem exitItem = new javax.swing.JMenuItem();
	javax.swing.JMenu editMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem cutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem copyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem pasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenu toolsMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem reportingMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenu helpMenu = new javax.swing.JMenu();
	javax.swing.JMenuItem helpTopicsMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem aboutItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator1 = new javax.swing.JSeparator();
	javax.swing.JMenuItem changeDefaultBrowserMenuItem = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.icons.ImageIcon logIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	//}}
	JFileChooser opener = new JFileChooser();
    JDesktopPane JDesktopPane1 = new JDesktopPane();
    ClientReportingFrame reporter = null;
	boolean first_time = true;
	AssessmentWindow assessment = null;
    Vector assessments = new Vector();
    Assessor primary_assessor = null;
    LoginDialog login = null;
    static SplashScreen splash = null;
    static ASSETClientPropertyManager props = null;
    static long screen_display_time = 6000;
    private Hashtable active_windows = new Hashtable();
    JTextComponent component = null;
    private boolean force_login = true;
    JMenuItem window_menu_item = null;
    int window_count = 0;
    
    JInternalFrame active_window = null;
    Connection conn = null;
    LogWindow logger = new LogWindow();
	//{{DECLARE_MENUS
	//}}
	
	public void setActiveTextComponent(JTextComponent component) {
	    try {
	        if (component != null) {
	            this.component = component;
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void fireMenuCutAction() {
	    try {
	        if (this.component != null) {
                this.component.cut();
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void fireMenuCopyAction() {
	    try {
	        if (this.component != null) {
                this.component.copy();
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	
	
	public void fireMenuPasteAction() {
	    try {
	        if (this.component != null) {
                this.component.paste();
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	
	
    static String parseExtension(String file_name) {
        StringTokenizer parser = new StringTokenizer(file_name, ".");
        try {
            parser.nextToken();            
        }catch (Exception e) {
            e.printStackTrace();
        }
        return parser.nextToken();
    }	
    
    public void log(String buffer) {
        this.logger.log(buffer);
    }

    public void saveLogOnException() {
            
    }
    
    public void openImportAssessment() {
        try {
            this.opener.setDialogTitle("Open incomplete assessment");
            this.saveMenu.setEnabled(true);
            int ret = this.opener.showOpenDialog(this);
            if (ret == this.opener.APPROVE_OPTION) {
                File assessment_file = this.opener.getSelectedFile();
                this.first_time = false;
                // Examine the extension of the file the user attemted to load 
                // if the extension is .dat then call the binary load method from
                // class AssessmentWindow()
                if (parseExtension(assessment_file.toString()).equals("dat")) {
                    this.assessment = new AssessmentWindow(this);
                    this.assessment.setSecondaryAssessor(this.primary_assessor);
                    this.assessment.loadAssessment(assessment_file);
                    this.JDesktopPane1.add(this.assessment);
                    this.assessment.setVisible(true);
                    this.assessment.setMaximum(true);
                }else if (parseExtension(assessment_file.toString()).equals("xml")) {                   
                    this.assessment = new AssessmentWindow(this);
                    this.assessment.setSecondaryAssessor(this.primary_assessor);
                    this.assessment.loadXMLAssessmentFile(assessment_file);
                    this.assessment.setVisible(true);
                    this.assessment.setMaximum(true);                    
                }else {
                    this.displayErrorDialog("You have selected an invalid file, please try again!");                   
                }
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	public void displayErrorDialog(String msg) {
        try {
            JOptionPane.showMessageDialog(this, msg, "Error:", JOptionPane.ERROR_MESSAGE);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
	public void displayStatusDialog(String msg) {
        try {
            JOptionPane.showMessageDialog(this, msg, "System Message:", JOptionPane.INFORMATION_MESSAGE);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    

    public boolean getForceLogin() {
        return this.force_login;
    }

    private void setForceLogin(boolean flag) {    
        this.force_login = flag;
    }

    public void setLogoffName() {
        try {
            logoffMenuItem.setText("Logoff " + primary_assessor.getFullName() + "...");
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
	// Logs the user off of ASSET System so that they may either quit the 
	// application or change the user name that ASSET System recognizes them 
	// as.
	// ---------------
	// Change Control:
	// 06/13/02 - Added code to kill the active assessment prompting for a save first.
	//          - Added check to prompt for save in all active windows at the time of
	//            logoff.
	// 08/07/02 - Forcibly set primary assessor to null durin logoff, the login procedure
	//            will reset it. Users were citing an error where they logged off, logged in
	//            again as a new user and upon creating a new assessment the old primary assessor
	//            information was present.
	public void logoff() {
	    JInternalFrame[] opened_frames = null;
	    ASSETChild child = null;	    
        try {
	    	Toolkit.getDefaultToolkit().beep();
	    	// Show a confirmation dialog
			// If the confirmation was affirmative, handle exiting.
				    	int reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "Are you sure you want to logoff?", 
	    	                                          "NIST Security Self-Assessment Tool - Logoff" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
			if (reply == JOptionPane.YES_OPTION) {            
	    	    Toolkit.getDefaultToolkit().beep();
	    	    // Show a confirmation dialog
	    	    opened_frames = this.JDesktopPane1.getAllFrames();
	    	    for (int i = 0; i < opened_frames.length; i++) {
	    	        this.JDesktopPane1.setPosition(opened_frames[i], 0);
	    	        child = (ASSETChild) opened_frames[i];
	                {
	    	            if (child != null) {
	    	            child.parentApplicationClosing();
	    	            }
	    	        }	    	    
	    	    }			    
			    this.setVisible(false);
                this.login.resetFields();
                this.login.setVisible(true);
		    	this.setVisible(false);    // hide the Frame
		    	this.primary_assessor = null;
			}            
        }catch (Exception e) {
            e.printStackTrace();
        }
	}    

	// This method is the action hanlder for when the user chooses to quite ASSET
	// System altogether. It prompts the user to save the active assessment.
	// ---------------
	// Change Control:
	// 06/13/02 - Added check to prompt for save in all active assessments
	void exitApplication() {
	    JInternalFrame[] opened_frames = null;
	    ASSETChild child = null;
		try {
	    	// Beep
	    	Toolkit.getDefaultToolkit().beep();
	    	// Show a confirmation dialog	   
	    	opened_frames = this.JDesktopPane1.getAllFrames();
	    	for (int i = 0; i < opened_frames.length; i++) {
	    	    this.JDesktopPane1.setPosition(opened_frames[i], 0);
	    	    child = (ASSETChild) opened_frames[i];
	            {
	    	        if (child != null) {
	    	            child.parentApplicationClosing();
	    	        }
	    	    }	    	    
	    	}
	    	System.exit(0);
		} catch (Exception e) {
		    System.err.println("ERROR: exiting application");
		    e.printStackTrace();
		}
	}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == SATUI.this)
				SATUI_windowClosing(event);
		}
	}

	void SATUI_windowClosing(java.awt.event.WindowEvent event)
	{
		// to do: code goes here.
			 
		SATUI_windowClosing_Interaction1(event);
	}

	void SATUI_windowClosing_Interaction1(java.awt.event.WindowEvent event) {
		try {
			this.exitApplication();
		} catch (Exception e) {
		}
	}

	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == openItem)
				openItem_actionPerformed(event);
			if (object == exitItem)
				exitItem_actionPerformed(event);
			else if (object == aboutItem)
				aboutItem_actionPerformed(event);
			
			if (object == newItem)
				newItem_actionPerformed(event);
			
			
			if (object == logoffMenuItem)
				logoffMenuItem_actionPerformed(event);
			else if (object == importMenuItem)
				importMenuItem_actionPerformed(event);
			else if (object == saveAssessmentMenuItem)
				saveAssessmentMenuItem_actionPerformed(event);
			else if (object == saveAssessmentLocalMenuItem)
				saveAssessmentLocalMenuItem_actionPerformed(event);
			else if (object == changeDefaultBrowserMenuItem)
				changeDefaultBrowserMenuItem_actionPerformed(event);
			else if (object == helpTopicsMenuItem)
				helpTopicsMenuItem_actionPerformed(event);
			else if (object == reportingMenuItem)
				reportingMenuItem_actionPerformed(event);
			else if (object == cutMenuItem)
				cutMenuItem_actionPerformed(event);
			else if (object == copyMenuItem)
				copyMenuItem_actionPerformed(event);
			else if (object == pasteMenuItem)
				pasteMenuItem_actionPerformed(event);								
		}
	}

	void openItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		openItem_actionPerformed_Interaction2(event);
	}

	void exitItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		exitItem_actionPerformed_Interaction1(event);
	}

	void exitItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.exitApplication();
		} catch (Exception e) {
		}
	}

	void aboutItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		aboutItem_actionPerformed_Interaction1(event);
	}

	void newItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		newItem_actionPerformed_Interaction1(event);
	}

	void newItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
		    this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
		    
			this.openNewAssessmentWindow();
		    this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
			
		} catch (java.lang.Exception e) {

		}
	}

	void logoffMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		logoffMenuItem_actionPerformed_Interaction1(event);
	}

	void logoffMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.logoff();
		} catch (java.lang.Exception e) {
		    ;
		}
	}

	void aboutItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// SplashScreen Create and show the SplashScreen
			(new SplashScreen()).setVisible(true);
		} catch (java.lang.Exception e) {
		}
	}

    public void openExportDialog() {
        try {			    
			    this.internal_setCursor("wait");
			    this.setStatusModeMsg("LOAD");
			    this.setStatusMsg("opening load dialog, please hold");
				loadDialog loadDialog1 = new loadDialog(this);
				loadDialog1.setModal(true);
				loadDialog1.show();
				this.internal_setCursor("default");
				this.setStatusMsg("");            
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

	void openItem_actionPerformed_Interaction2(java.awt.event.ActionEvent event)
	{
		try {
			// loadDialog Create and show as modal
            {
                this.openExportDialog();
            }
		} catch (java.lang.Exception e) {
		}
	}

	class SymComponent extends java.awt.event.ComponentAdapter {
		public void componentMoved(java.awt.event.ComponentEvent event)
		{
			Object object = event.getSource();
			if (object == SATUI.this)
				SATUI_componentMoved(event);
		}
	}
	
    private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void SATUI_componentMoved(java.awt.event.ComponentEvent event) {
		// to do: code goes here.
	}
	
	// Change Control
	// 02/17/02 - Added code to supply a username and password in addition to the connection
	//            string when connecting to the database
    public void openDataConnection() {
        try {
            this.conn = DriverManager.getConnection(this.props.getProperty("sat.data.connstring"), this.props.getProperty("sat.data.username"), this.props.getProperty("sat.data.password"));
        }catch (Exception e) {
            System.err.println("\nERROR: cannot open connection to SAT data store!");
            System.err.println("\nthis is probably due to the data store being defined \nincorrectly in the operating system settings!");            
            e.printStackTrace();
        }
    }
    
    public void closeDataConnection() {
        try {
            this.conn.close();
            logger.log("\nclosed connection to SAT data store...");
        }catch (Exception e) {
                e.printStackTrace();
        }
    }

	void importMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		importMenuItem_actionPerformed_Interaction1(event);
	}

	void importMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openImportAssessment();
		} catch (java.lang.Exception e) {
		}
	}

	void saveAssessmentMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		saveAssessmentMenuItem_actionPerformed_Interaction1(event);
	}

	void saveAssessmentMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.databaseSaveOptionActivated();
		} catch (java.lang.Exception e) {
		}
	}

	void saveAssessmentLocalMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		saveAssessmentLocalMenuItem_actionPerformed_Interaction1(event);
	}

	void saveAssessmentLocalMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.fileSaveOptionActivated();
		} catch (java.lang.Exception e) {
		}
	}

	void changeDefaultBrowserMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		changeDefaultBrowserMenuItem_actionPerformed_Interaction1(event);
	}

	void changeDefaultBrowserMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.setNewDefaultBrowser();
		} catch (java.lang.Exception e) {
		}
	}

	void helpTopicsMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		helpTopicsMenuItem_actionPerformed_Interaction1(event);
	}

	void helpTopicsMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openDefaultHelpFile();
		} catch (java.lang.Exception e) {
		}
	}

	void reportingMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		reportingMenuItem_actionPerformed_Interaction1(event);
	}

	void reportingMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.openNewReportingWindow();
		} catch (java.lang.Exception e) {
		}
	}

	void cutMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		cutMenuItem_actionPerformed_Interaction1(event);
	}

	void cutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.fireMenuCutAction();
		} catch (java.lang.Exception e) {
		}
	}

	void copyMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		copyMenuItem_actionPerformed_Interaction1(event);
	}

	void copyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.fireMenuCopyAction();
		} catch (java.lang.Exception e) {
		}
	}

	void pasteMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		pasteMenuItem_actionPerformed_Interaction1(event);
	}

	void pasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.fireMenuPasteAction();
		} catch (java.lang.Exception e) {
		}
	}
} /* end class SATUI() */
