@echo off
SET LOCALVAR="c:\Program Files\NISTASSET\ASSET System\sql"
SET ver=1.00.33
REM ---------------------------------------------------------------
REM This batch script is designed to create the SAT client database
REM using the MSDE osql command and the associated SQL scripts that 
REM were written for the datamanager utility
REM ------------
REM Version (see version number above)
REM Created on: 02/17/02
REM ------------
REM Author - Mark McLarnon
REM ---------------------------------------------------------------
REM ---------------------------------------------------------------
REM THIS STEP IS VERY IMPORTANT: You must ensure that your command 
REM prompt can find the location of the osql.exe binary or else the 
REM dbmanager script won't work We know that on all systems unless a 
REM user moves the binary out of the binn folder it will reside 
REM underneath of the MSSQL7\binn folder. This is usually installe 
REM on the C:\ drive, more commonly referred to with the %SystemDrive% 
REM environmental variable. If you have trouble running this script 
REM and you see blatant errors from the SQL server on the command 
REM line then check to ensure that the osql.exe binary is in your 
REM command prompt.
REM --------------------------------------------------------------- 
SET PATH=%SystemDrive%\MSSQL7\binn;%PATH%


echo ********************************************
echo * NIST Self-Assessment Tool                *
echo * Database Manager Version %ver%         *
echo * http://csrc.nist.gov/asset               *
echo ********************************************

if %1==usage goto usage
if %1==addsp goto addsp
if %1==deletesp goto deletesp
if %1==deletedb goto deletedb
if %1==createdb goto createdb
if %1==deletetable goto deletetable
if %1==listtables goto listtables
if %1==version goto version

:version
cls
echo ********************************************
echo * NIST Self-Assessment Tool                *
echo * Database Manager Version %ver%         *
echo * http://csrc.nist.gov                     *
echo ********************************************
goto end

:default
echo ERROR: Incorrect usage!
echo Please try again
echo.
goto end

:listtables
echo listing contents of SAT Client Database
osql -E -d SAT_Client -Q "select * from sysobjects"
goto end

:addsp
echo Adding stored procedure from file %2
echo.
osql -E -d SAT_Client -i %2
echo added stored procedure!
goto end

:deletesp
echo Deleting stored procedure %2
echo.
osql -E -d SAT_Client -Q "drop procedure %2"
echo finished!
goto end

:usage
echo Database Manager Usage:
echo.
echo C:\dbmanager [action] {[value]}
echo.
echo Description:
echo ------------
echo [action] denotes a directive for the dbmanager to execute. There are two
echo possible action types:
echo.
echo 1. informational
echo.
echo 2. active execution
echo.
echo Informational actions query information about the database whereas active 
echo execution actions modify/create and event delete information from the database
echo.
echo [value] is an optional value to supply to dbmanager that is directed at those
echo actions which deal with a specific table or stored procedure
echo.
pause
cls
echo Possible Informational Actions:
echo ------------------------------
echo listtables   - List the current tables stored within the SAT Client database
echo.
echo usage        - Prints this message to the screen
echo.
echo version      - Prints out the version header for the dbmanager to the screen
echo.
pause
cls
echo.
echo Possible Active Execution Actions:
echo ----------------------------------
echo addsp        - Add new stored procedure to SAT database. The stored 
echo                procedure must be supplied in a text file with a .sql
echo                extension immediately following the addsp directive
echo.
echo                NOTE: Take care when using this directive as each new stored
echo                      stored procedure that is added will not be added if the
echo                      database is rebuilt from scratch using the createdb 
echo                      command
echo.
echo createdb     - Creates and populates the SAT database using the SQL 
echo                provided in the installation program
echo.
echo deletesp     - Delete a stored procedure from the database. The name
echo                of the stored procedure must immediately follow the 
echo                deletesp command and appear exactly as it was entered into
echo                the database
echo.
echo deletetable  - Deletes the specified table. The table name must 
echo                immediately follow the deletetable action on the 
echo                command line
echo.
echo deletedb     - Deletes the SAT database from the local hard drive 
echo                completely
goto end

:deletetable
echo Deleting table %2 now
osql -E -d SAT_Client -Q "drop table %2"
goto end

:createdb
echo Creating SAT Client database now...
osql -E -Q "create database SAT_Client"
echo.
echo finished creating database, now creating tables
osql -E -d SAT_Client -i %LOCALVAR%\1_assessments.sql
osql -E -d SAT_Client -i %LOCALVAR%\29_assessment_questions.sql
osql -E -d SAT_Client -i %LOCALVAR%\3_assessment_question_responses.sql
osql -E -d SAT_Client -i %LOCALVAR%\31_sat_users.sql
osql -E -d SAT_Client -i %LOCALVAR%\42_assessors.sql
osql -E -d SAT_Client -i %LOCALVAR%\6_publications.sql
osql -E -d SAT_Client -i %LOCALVAR%\7_pubReferences.sql
osql -E -d SAT_Client -i %LOCALVAR%\8_components.sql
osql -E -d SAT_Client -i %LOCALVAR%\9_component_criticality.sql
osql -E -d SAT_Client -i %LOCALVAR%\91_conn_components.sql
osql -E -d SAT_Client -i %LOCALVAR%\sys_Component_Types.sql
osql -E -d SAT_Client -i %LOCALVAR%\sys_controlareas.sql
osql -E -d SAT_Client -i %LOCALVAR%\u_action_fillassess_ques.sql
osql -E -d SAT_Client -i %LOCALVAR%\v_action_fillComponentTypes.sql
osql -E -d SAT_Client -i %LOCALVAR%\w_action_fillControlAreas.sql
echo.
echo created and populated database tables, now creating stored procedures...
osql -E -d SAT_Client -i %LOCALVAR%\sp_CurrentControlAreas.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_CurrentQuestionMap.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_CurrentQuestionSet.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_DeleteSavedQuestion.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getAllComponentInformation.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getAssessorReviewersPerAssessment.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getAssessorsPerAssessment.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getComponentCriticalities.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getConnectedSystems.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getConnectedSystemsPerAssessment.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetCriticalListing.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetCriticalResults.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetNAQuestions.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetPolicyResults.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetPolicyResultsQuestionText.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getPrimaryAssessor.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetQuestionCount.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getQuestionResults.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getQuestionResultsPerPolicy.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getQuestionResultsPerSection.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getRBDMQuestions.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetSavedAssessments.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetSingleConnectedSystems.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetSingleSavedAssessment.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetSingleSavedAssessmentBYAssessmentID.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_GetStoredAssessors.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getSubmittedQuestionCount.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_getSummaryQuestionResults.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_InsertAssessmentQuestionResponse.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveAnsweredQuestion.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveAssessment.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveBookmark.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveComponent.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveComponentCriticalities.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveConnectedComponents.sql
osql -E -d SAT_Client -i %LOCALVAR%\sp_SaveNewAssessor.sql
echo.
echo finished creating stored procedures!
goto end

:deletedb
echo Deleting SAT Client database now
echo.
osql -E -Q "drop database SAT_Client"
echo.
echo finished!
goto end

:end
echo.