/******************************************************************************/
/* file - AssessmentWindow.java                                               */
/* ----------------------------                                               */
/* This class is the internal window that encapsulates all of the component   */
/* assessmen operations. It is opened within the SATUI main frame and several */
/* of these windows opened at the same time on the SATUI DesktopFrame.        */
/* ----------------------------                                               */
/* NIST Security Self-Assessment Tool                                         */
/* Author - Mark McLarnon                                                     */
/* ----------------------------                                               */
/* Change Control -                                                           */
/* 02/12/02 - Added sortable model to tables within the assessment window     */
/* 04/17/02 - Added method to set the active question responses based on the  */
/*            current critical element. This then can be done outside of the  */
/*            processResponse() method. The problem was that if a user hit a  */
/*            section that they did not like and jumped to a new section      */
/*            without answering any questions then the critical element for   */
/*            would be computed for the section they were just in but the     */
/*            question responses used would be those from the last section    */
/*            for which you supplied at least one response for.               */
/* 06/03/02 - Changed mnemonic for export results button to P.                */
/* 06/13/02 - Changed table model for connected systems to prevent users from */
/*            modifying system names.                                         */
/* 08/06/02 - Added code to catch response of last question when it is        */
/*            answered for the first time. It will always be saved each time  */
/*            See method questionForward( )                                   */
/* 08/07/02 - Added check to reset level 1 of each answer before saved to     */
/*            database if answer in memory is marked as NA first              */
/*            See method saveQuestionBlock                                    */
/* 08/08/02 - See method computeCriticalElement()                             */
/******************************************************************************/
import java.awt.*;
import java.util.Date;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.*;
import com.symantec.itools.javax.swing.*;
import com.symantec.itools.javax.swing.borders.*;
import com.symantec.itools.javax.swing.models.*;
import javax.swing.event.*;
import javax.swing.table.*;
import javax.swing.tree.*;
import java.text.DecimalFormat;
import java.sql.*;
import java.sql.ResultSet;
import java.io.*;
import com.symantec.itools.javax.swing.icons.ImageIcon;

public class AssessmentWindow extends javax.swing.JInternalFrame implements TreeSelectionListener, ASSETChild {
    
	/**
     * Default Constructor for AssessmentWindow. (Must be called at some point as
     * it contains layout management code for all user components.)
     */
	public AssessmentWindow() {
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setIconifiable(true);
		setMaximizable(true);
		setTitle("Self-Assessment");
		setResizable(true);
		setAlignmentY(0.0F);
		setAlignmentX(0.0F);
		setNextFocusableComponent(add_assessor_button);
		try {
			setSelected(true);
		}catch(java.beans.PropertyVetoException e) { 
		    e.printStackTrace();
		}
		setClosable(true);
		setDefaultCloseOperation(javax.swing.JFrame.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.X_AXIS));
		setSize(857,500);
		JSplitPaneWrapper1.setDividerSize(9);
		JSplitPaneWrapper1.setOneTouchExpandable(true);
		JSplitPaneWrapper1.setNextFocusableComponent(add_assessor_button);
		getContentPane().add(JSplitPaneWrapper1);
		progress_map_scroll_pane.setAutoscrolls(true);
		progress_map_scroll_pane.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		progress_map_scroll_pane.setOpaque(true);
		JSplitPaneWrapper1.add(progress_map_scroll_pane);
		progress_map_scroll_pane.setBounds(1,1,116,498);
		progress_map_panel.setAutoscrolls(true);
		progress_map_panel.setAlignmentY(0.0F);
		progress_map_panel.setAlignmentX(0.0F);
		progress_map_panel.setLayout(new BorderLayout(0,0));
		progress_map_scroll_pane.getViewport().add(progress_map_panel);
		progress_map_panel.setBackground(java.awt.Color.white);
		progress_map_panel.setBounds(0,0,98,495);
		progress_tree.setShowsRootHandles(true);
		progress_tree.setAutoscrolls(true);
		progress_tree.setToolTipText("<html>Allows you to control your position in the assessment questions</html>");
		progress_tree.setDoubleBuffered(true);
		progress_map_panel.add(BorderLayout.WEST, progress_tree);
		progress_tree.setVisible(false);
		JTabbedPane1.setBorder(etchedBorder1);
		JSplitPaneWrapper1.add(JTabbedPane1);
		JTabbedPane1.setFont(new Font("Dialog", Font.BOLD, 12));
		JTabbedPane1.setBounds(127,1,729,498);
		assessment_id_panel.setNextFocusableComponent(add_assessor_button);
		assessment_id_panel.setLayout(new BoxLayout(assessment_id_panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(assessment_id_panel);
		assessment_id_panel.setBounds(4,26,720,467);
		assessment_id_panel.setVisible(false);
		JScrollPane9.setAutoscrolls(true);
		JScrollPane9.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
		JScrollPane9.setOpaque(true);
		assessment_id_panel.add(JScrollPane9);
		JPanel10.setLayout(new BorderLayout(0,0));
		JScrollPane9.getViewport().add(JPanel10);
		JPanel10.setBounds(0,0,717,464);
		Assessors_Parent_Panel.setAlignmentX(0.498433F);
		Assessors_Parent_Panel.setBorder(titledBorder2);
		Assessors_Parent_Panel.setLayout(new BorderLayout(0,0));
		JPanel10.add(BorderLayout.NORTH, Assessors_Parent_Panel);
		assessor_table_panel.setBorder(assessor_table_border2);
		assessor_table_panel.setLayout(new BoxLayout(assessor_table_panel,BoxLayout.X_AXIS));
		Assessors_Parent_Panel.add(BorderLayout.CENTER, assessor_table_panel);
		JScrollPane2.setAutoscrolls(true);
		JScrollPane2.setOpaque(true);
		assessor_table_panel.add(JScrollPane2);
		assessor_table.setPreferredScrollableViewportSize(new java.awt.Dimension(200,100));
		assessor_table.setAutoResizeMode(javax.swing.JTable.AUTO_RESIZE_ALL_COLUMNS);
		assessor_table.setToolTipText("<html>Lists the assessors involved with current assessment</html>");
		assessor_table.setDoubleBuffered(true);
		JScrollPane2.getViewport().add(assessor_table);
		assessor_table.setBounds(0,0,674,0);
		assessor_button_panel.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		Assessors_Parent_Panel.add(BorderLayout.SOUTH, assessor_button_panel);
		add_assessor_button.setText("Add Assessor");
		add_assessor_button.setActionCommand("Delete Assessor");
		add_assessor_button.setToolTipText("<html>Press this button to add a new assessor to this list</html>");
		add_assessor_button.setMnemonic((int)'A');
		assessor_button_panel.add(add_assessor_button);
		addAssessor_help_button.setText("Help");
		addAssessor_help_button.setActionCommand("addassessor");
		addAssessor_help_button.setToolTipText("<html>Opens help for adding assessors</html>");
		addAssessor_help_button.setMnemonic((int)'H');
		assessor_button_panel.add(addAssessor_help_button);
		JPanel9.setBorder(titledBorder6);
		JPanel9.setLayout(new BoxLayout(JPanel9,BoxLayout.X_AXIS));
		JPanel10.add(BorderLayout.CENTER, JPanel9);
		JScrollPane8.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		JPanel9.add(JScrollPane8);
		JPanel11.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel10.add(BorderLayout.SOUTH, JPanel11);
		id_panel_proceed_button.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		id_panel_proceed_button.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		id_panel_proceed_button.setText("Next ");
		id_panel_proceed_button.setActionCommand("next");
		id_panel_proceed_button.setToolTipText("<html>Proceed to the next step in the assessment</html>");
		id_panel_proceed_button.setMnemonic((int)'N');
		JPanel11.add(id_panel_proceed_button);
		InfoGather_Parent_Panel.setBorder(etchedBorder1);
		InfoGather_Parent_Panel.setLayout(new BoxLayout(InfoGather_Parent_Panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(InfoGather_Parent_Panel);
		InfoGather_Parent_Panel.setBounds(4,26,720,467);
		InfoGather_Parent_Panel.setVisible(false);
		infoGather_scrollpane.setOpaque(true);
		InfoGather_Parent_Panel.add(infoGather_scrollpane);
		infoGather_panel.setLayout(new BorderLayout(0,0));
		infoGather_scrollpane.getViewport().add(infoGather_panel);
		infoGather_panel.setBounds(0,0,713,460);
		system_Name_parentPanel.setAlignmentY(0.497778F);
		system_Name_parentPanel.setLayout(new BoxLayout(system_Name_parentPanel,BoxLayout.X_AXIS));
		infoGather_panel.add(BorderLayout.NORTH, system_Name_parentPanel);
		component_identification_panel.setBorder(titledBorder1);
		component_identification_panel.setLayout(new GridLayout(5,2,0,20));
		system_Name_parentPanel.add(component_identification_panel);
		JLabel1.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel1.setText("System Name *:  ");
		component_identification_panel.add(JLabel1);
		JLabel1.setForeground(java.awt.Color.black);
		JLabel1.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_name_field.setNextFocusableComponent(system_number_field);
		system_name_field.setToolTipText("<html>Enter the name for the system you are about to assess in this field</html>");
		component_identification_panel.add(system_name_field);
		JLabel16.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel16.setText("System Number *:  ");
		component_identification_panel.add(JLabel16);
		JLabel16.setForeground(java.awt.Color.black);
		JLabel16.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_number_field.setNextFocusableComponent(system_type_box);
		system_number_field.setToolTipText("<html>Enter any system number you may have for the system you are assessing</html>");
		component_identification_panel.add(system_number_field);
		JLabel2.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel2.setText("System Type *:  ");
		component_identification_panel.add(JLabel2);
		JLabel2.setForeground(java.awt.Color.black);
		JLabel2.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_type_box.setModel(system_type_model);
		system_type_box.setNextFocusableComponent(aggrpdiv_text_field);
		system_type_box.setToolTipText("<html>Choose the appropriate type that describes the system you are assessing</html>");
		component_identification_panel.add(system_type_box);
		system_type_box.setFont(new Font("Dialog", Font.PLAIN, 12));
		JLabel4.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel4.setText("Agency/Division/Group *:  ");
		component_identification_panel.add(JLabel4);
		JLabel4.setForeground(java.awt.Color.black);
		JLabel4.setFont(new Font("Dialog", Font.PLAIN, 12));
		aggrpdiv_text_field.setNextFocusableComponent(assessment_date_field);
		aggrpdiv_text_field.setToolTipText("<html>Describe the location of the system you are assessing<br>within your enterprise</html>");
		component_identification_panel.add(aggrpdiv_text_field);
		JLabel3.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel3.setText("Assessment Start Date *:  ");
		component_identification_panel.add(JLabel3);
		JLabel3.setForeground(java.awt.Color.black);
		JLabel3.setFont(new Font("Dialog", Font.PLAIN, 12));
		assessment_date_field.setNextFocusableComponent(system_confidentiality_box);
		assessment_date_field.setToolTipText("<html>Shows the date that the current assessment was started</html>");
		component_identification_panel.add(assessment_date_field);
		criticality_panel.setBorder(titledBorder3);
		criticality_panel.setToolTipText("<html>It is important that the degree of sensitivity of information be<br>assessed by considering the requirements for availability, integrity,<br>and confidentiality of the information.</html>");
		criticality_panel.setLayout(new GridLayout(5,2,0,20));
		system_Name_parentPanel.add(criticality_panel);
		JLabel5.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel5.setText("Confidentiality *:  ");
		JLabel5.setToolTipText("<html>Requires protection from unauthorized exposure</html>");
		criticality_panel.add(JLabel5);
		JLabel5.setForeground(java.awt.Color.black);
		JLabel5.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_confidentiality_box.setModel(system_confidentiality_model);
		system_confidentiality_box.setNextFocusableComponent(system_integrity_box);
		system_confidentiality_box.setToolTipText("<html>High - critical concern of the system<br>Medium - important concern<br>Low - minimal level of concern</html>");
		criticality_panel.add(system_confidentiality_box);
		system_confidentiality_box.setFont(new Font("Dialog", Font.PLAIN, 12));
		JLabel6.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel6.setText("Integrity *:  ");
		JLabel6.setToolTipText("<html>Protected from unauthorized, unanticipated, or unintentional modification.</html>");
		criticality_panel.add(JLabel6);
		JLabel6.setForeground(java.awt.Color.black);
		JLabel6.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_integrity_box.setModel(system_integrity_model);
		system_integrity_box.setNextFocusableComponent(system_availability_box);
		system_integrity_box.setToolTipText("<html>High - critical concern of the system<br>Medium - important concern<br>Low - minimal level of concern</html>");
		criticality_panel.add(system_integrity_box);
		system_integrity_box.setFont(new Font("Dialog", Font.PLAIN, 12));
		JLabel7.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		JLabel7.setText("Availability *:  ");
		JLabel7.setToolTipText("<html>Must be available on a timely basis.</html>");
		criticality_panel.add(JLabel7);
		JLabel7.setForeground(java.awt.Color.black);
		JLabel7.setFont(new Font("Dialog", Font.PLAIN, 12));
		system_availability_box.setModel(system_availability_model);
		system_availability_box.setNextFocusableComponent(conn_system_add_button);
		system_availability_box.setToolTipText("<html>High - critical concern of the system<br>Medium - important concern<br>Low - minimal level of concern</html>");
		criticality_panel.add(system_availability_box);
		system_availability_box.setFont(new Font("Dialog", Font.PLAIN, 12));
		connectedSystemParent_panel.setAlignmentX(0.498305F);
		connectedSystemParent_panel.setBorder(titledBorder4);
		connectedSystemParent_panel.setLayout(new BoxLayout(connectedSystemParent_panel,BoxLayout.Y_AXIS));
		infoGather_panel.add(BorderLayout.CENTER, connectedSystemParent_panel);
		connected_system_panel.setAlignmentY(0.489796F);
		connected_system_panel.setBorder(assessor_table_border2);
		connected_system_panel.setLayout(new BoxLayout(connected_system_panel,BoxLayout.X_AXIS));
		connectedSystemParent_panel.add(connected_system_panel);
		JScrollPane3.setOpaque(true);
		connected_system_panel.add(JScrollPane3);
		connected_system_table.setPreferredScrollableViewportSize(new java.awt.Dimension(200,80));
		connected_system_table.setBorder(assessor_table_border);
		JScrollPane3.getViewport().add(connected_system_table);
		connected_system_table.setBounds(0,0,670,0);
		conn_system_button_panel.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		connectedSystemParent_panel.add(conn_system_button_panel);
		conn_system_add_button.setText("Add System");
		conn_system_add_button.setActionCommand("Add System");
		conn_system_add_button.setToolTipText("<html>Press this button to desrcribe a system that is connected to<br>the one you are assessing currently</html>");
		conn_system_add_button.setMnemonic((int)'A');
		conn_system_button_panel.add(conn_system_add_button);
		conn_system_help_button.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		conn_system_help_button.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		conn_system_help_button.setText("Help");
		conn_system_help_button.setActionCommand("addsystem");
		conn_system_help_button.setNextFocusableComponent(infoGather_previous_button);
		conn_system_help_button.setToolTipText("<html>Opens the help screen for connected systems</html>");
		conn_system_help_button.setMnemonic((int)'H');
		conn_system_button_panel.add(conn_system_help_button);
		proceed_to_assessment_panel.setAlignmentY(0.485714F);
		proceed_to_assessment_panel.setLayout(new GridLayout(2,1,0,0));
		infoGather_panel.add(BorderLayout.SOUTH, proceed_to_assessment_panel);
		JPanel23.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		proceed_to_assessment_panel.add(JPanel23);
		JLabel21.setText("All fields marked with an * above are required");
		JPanel23.add(JLabel21);
		JLabel21.setForeground(java.awt.Color.black);
		JPanel22.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		proceed_to_assessment_panel.add(JPanel22);
		infoGather_previous_button.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		infoGather_previous_button.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		infoGather_previous_button.setText("Previous");
		infoGather_previous_button.setActionCommand("Previous");
		infoGather_previous_button.setAlignmentX(0.5F);
		infoGather_previous_button.setMnemonic((int)'R');
		JPanel22.add(infoGather_previous_button);
		proceed_to_assessment_button.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		proceed_to_assessment_button.setText("Proceed To Assessment");
		proceed_to_assessment_button.setActionCommand("Proceed To Assessment...");
		proceed_to_assessment_button.setMnemonic((int)'P');
		JPanel22.add(proceed_to_assessment_button);
		policy_parent_panel.setNextFocusableComponent(policy_question_table);
		policy_parent_panel.setLayout(new BoxLayout(policy_parent_panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(policy_parent_panel);
		policy_parent_panel.setBounds(4,26,720,467);
		policy_parent_panel.setVisible(false);
		JScrollPane6.setOpaque(true);
		policy_parent_panel.add(JScrollPane6);
		JPanel28.setLayout(new BorderLayout(0,0));
		JScrollPane6.getViewport().add(JPanel28);
		JPanel28.setBounds(0,0,717,464);
		JPanel7.setLayout(new BorderLayout(0,0));
		JPanel28.add(BorderLayout.CENTER, JPanel7);
		policy_label.setText("Policy Definition:");
		policy_label.setBorder(emptyBorder10);
		policy_label.setToolTipText("<html>Click for a definition of policy</html>");
		JPanel7.add(BorderLayout.NORTH, policy_label);
		policy_label.setForeground(java.awt.Color.black);
		policy_label.setFont(new Font("Dialog", Font.PLAIN, 12));
		JScrollPane10.setOpaque(true);
		JScrollPane10.setBorder(emptyBorder11);
		JPanel7.add(BorderLayout.CENTER, JScrollPane10);
		policy_question_table.setPreferredScrollableViewportSize(new java.awt.Dimension(450,200));
		policy_question_table.setNextFocusableComponent(policy_previous_button);
		policy_question_table.setToolTipText("<html>Shows the major control objectives for which policy can be<br>defined</html>");
		JScrollPane10.getViewport().add(policy_question_table);
		policy_question_table.setBounds(0,0,712,0);
		JPanel6.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel28.add(BorderLayout.SOUTH, JPanel6);
		policy_previous_button.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		policy_previous_button.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		policy_previous_button.setText("Previous");
		policy_previous_button.setActionCommand("<< Previous");
		policy_previous_button.setNextFocusableComponent(policy_next_button);
		policy_previous_button.setAlignmentX(0.5F);
		policy_previous_button.setToolTipText("<html>Press this button to return to the information gathering screens</html>");
		policy_previous_button.setMnemonic((int)'P');
		JPanel6.add(policy_previous_button);
		policy_next_button.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		policy_next_button.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		policy_next_button.setText("Next");
		policy_next_button.setActionCommand("Proceed To Assessment...");
		policy_next_button.setToolTipText("<html>Press this button to proceed to answering checklist questions</html>");
		policy_next_button.setMnemonic((int)'N');
		JPanel6.add(policy_next_button);
		Question_Parent_Panel.setBorder(etchedBorder1);
		Question_Parent_Panel.setLayout(new BoxLayout(Question_Parent_Panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(Question_Parent_Panel);
		Question_Parent_Panel.setBounds(4,26,720,467);
		Question_Parent_Panel.setVisible(false);
		question_scrollpane.setOpaque(true);
		Question_Parent_Panel.add(question_scrollpane);
		question_panel.setAlignmentY(0.0F);
		question_panel.setAlignmentX(0.0F);
		question_panel.setLayout(new BorderLayout(0,0));
		question_scrollpane.getViewport().add(question_panel);
		question_panel.setBounds(0,0,1096,451);
		JPanel1.setLayout(new GridBagLayout());
		question_panel.add(BorderLayout.CENTER, JPanel1);
		question_presentation_panel.setAlignmentY(0.490909F);
		question_presentation_panel.setLayout(new GridLayout(1,1,0,0));
		JPanel1.add(question_presentation_panel, new com.symantec.itools.awt.GridBagConstraintsD(0,0,1,1,1.0,1.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.BOTH,new Insets(0,0,0,0),0,0));
		JPanel12.setLayout(new BorderLayout(0,0));
		question_presentation_panel.add(JPanel12);
		JPanel18.setAlignmentY(0.466667F);
		JPanel18.setBorder(emptyBorder9);
		JPanel18.setLayout(new BoxLayout(JPanel18,BoxLayout.X_AXIS));
		JPanel12.add(BorderLayout.NORTH, JPanel18);
		JLabel17.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JLabel17.setText("Question:");
		JPanel18.add(JLabel17);
		JLabel17.setForeground(java.awt.Color.black);
		JLabel17.setFont(new Font("Dialog", Font.BOLD, 12));
		question_number_label.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		question_number_label.setBorder(emptyBorder4);
		JPanel18.add(question_number_label);
		question_number_label.setForeground(java.awt.Color.black);
		question_number_label.setFont(new Font("Dialog", Font.BOLD, 12));
		JPanel21.setLayout(new BoxLayout(JPanel21,BoxLayout.X_AXIS));
		JPanel12.add(BorderLayout.CENTER, JPanel21);
		JScrollPane11.setOpaque(true);
		JPanel21.add(JScrollPane11);
		question_text_field.setLineWrap(true);
		question_text_field.setWrapStyleWord(true);
		question_text_field.setToolTipText("<html>The text of the current question</html>");
		question_text_field.setEditable(false);
		JScrollPane11.getViewport().add(question_text_field);
		question_text_field.setBackground(new java.awt.Color(204,204,204));
		question_text_field.setBounds(0,0,545,98);
		JPanel13.setAlignmentX(0.495495F);
		JPanel13.setLayout(new BoxLayout(JPanel13,BoxLayout.Y_AXIS));
		question_presentation_panel.add(JPanel13);
		JPanel17.setBorder(etchedBorder1);
		JPanel17.setToolTipText("<html>Shows the current section of questions you are in</html>");
		JPanel17.setLayout(new GridLayout(3,1,0,0));
		JPanel13.add(JPanel17);
		JPanel17.setBackground(new java.awt.Color(204,204,204));
		JLabel22.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		JLabel22.setText("Section:");
		JPanel17.add(JLabel22);
		JLabel22.setForeground(java.awt.Color.black);
		quesiton_control_area_label.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JPanel17.add(quesiton_control_area_label);
		quesiton_control_area_label.setForeground(java.awt.Color.black);
		JPanel17.add(question_section_label);
		question_section_label.setForeground(java.awt.Color.black);
		JPanel20.setBorder(etchedBorder1);
		JPanel20.setLayout(new BorderLayout(0,0));
		JPanel13.add(JPanel20);
		JLabel18.setText("Critical Element:");
		JLabel18.setBorder(emptyBorder9);
		JPanel20.add(BorderLayout.NORTH, JLabel18);
		JLabel18.setForeground(java.awt.Color.black);
		JScrollPane4.setOpaque(true);
		JPanel20.add(BorderLayout.CENTER, JScrollPane4);
		critical_element_field.setRows(3);
		critical_element_field.setLineWrap(true);
		critical_element_field.setWrapStyleWord(true);
		critical_element_field.setToolTipText("<html>Shows the critical element question the current question applies to</html>");
		critical_element_field.setEditable(false);
		JScrollPane4.getViewport().add(critical_element_field);
		critical_element_field.setBackground(new java.awt.Color(204,204,204));
		critical_element_field.setBounds(0,0,541,45);
		JPanel25.setOpaque(false);
		JPanel25.setLayout(new BorderLayout(0,0));
		JPanel1.add(JPanel25, new com.symantec.itools.awt.GridBagConstraintsD(0,1,1,1,1.0,1.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.BOTH,new Insets(0,0,0,0),0,79));
		ITSAF_Parent_Panel.setBorder(emptyBorder9);
		ITSAF_Parent_Panel.setLayout(new BorderLayout(0,0));
		JPanel25.add(BorderLayout.NORTH, ITSAF_Parent_Panel);
		JPanel19.setAlignmentY(0.466667F);
		JPanel19.setLayout(new BoxLayout(JPanel19,BoxLayout.X_AXIS));
		ITSAF_Parent_Panel.add(BorderLayout.NORTH, JPanel19);
		JPanel19.setFont(new Font("Dialog", Font.PLAIN, 14));
		JLabel9.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		JLabel9.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
		JLabel9.setText(" Indicate Your Responses:");
		JLabel9.setAlignmentX(0.5F);
		JLabel9.setDoubleBuffered(true);
		JPanel19.add(JLabel9);
		JLabel9.setForeground(java.awt.Color.black);
		JLabel9.setFont(new Font("Dialog", Font.BOLD, 14));
		JPanel16.setAlignmentY(0.0F);
		JPanel16.setAlignmentX(0.0F);
		JPanel16.setLayout(new BoxLayout(JPanel16,BoxLayout.X_AXIS));
		ITSAF_Parent_Panel.add(BorderLayout.CENTER, JPanel16);
		JPanel14.setLayout(new FlowLayout(FlowLayout.LEFT,5,0));
		JPanel16.add(JPanel14);
		ITSAF_level1_checkbox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		ITSAF_level1_checkbox.setText("Policy");
		ITSAF_level1_checkbox.setActionCommand("Policy");
		JPanel14.add(ITSAF_level1_checkbox);
		ITSAF_level1_checkbox.setForeground(java.awt.Color.black);
		ITSAF_level1_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		ITSAF_level2_checkbox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		ITSAF_level2_checkbox.setText("Procedures");
		ITSAF_level2_checkbox.setActionCommand("Procedures");
		ITSAF_level2_checkbox.setToolTipText("<html>IT security assessment framework level 2 procedures is defined in the help files</html>");
		ITSAF_level2_checkbox.setEnabled(false);
		JPanel14.add(ITSAF_level2_checkbox);
		ITSAF_level2_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		ITSAF_level3_checkbox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		ITSAF_level3_checkbox.setText("Implemented");
		ITSAF_level3_checkbox.setActionCommand("Implemented");
		ITSAF_level3_checkbox.setToolTipText("<html>IT security assessment framework level 3 implemented is defined in the help files</html>");
		ITSAF_level3_checkbox.setEnabled(false);
		JPanel14.add(ITSAF_level3_checkbox);
		ITSAF_level3_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		ITSAF_level4_checkbox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		ITSAF_level4_checkbox.setText("Tested");
		ITSAF_level4_checkbox.setActionCommand("Tested");
		ITSAF_level4_checkbox.setToolTipText("<html>IT security assessment framework level 4 tested is defined in the help files</html>");
		ITSAF_level4_checkbox.setEnabled(false);
		JPanel14.add(ITSAF_level4_checkbox);
		ITSAF_level4_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		ITSAF_level5_checkbox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		ITSAF_level5_checkbox.setText("Integrated");
		ITSAF_level5_checkbox.setActionCommand("Integrated");
		ITSAF_level5_checkbox.setToolTipText("<html>IT security assessment framework level 5 integrated is defined in the help files</html>");
		ITSAF_level5_checkbox.setEnabled(false);
		JPanel14.add(ITSAF_level5_checkbox);
		ITSAF_level5_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		JLabel14.setText("   ");
		JPanel14.add(JLabel14);
		rbdm_na_option.setText("Question not applicable");
		rbdm_na_option.setActionCommand("Not Applicable");
		JPanel14.add(rbdm_na_option);
		rbdm_na_option.setFont(new Font("Dialog", Font.BOLD, 12));
		rbdm_choice_panel.setAlignmentY(0.478261F);
		rbdm_choice_panel.setLayout(new BoxLayout(rbdm_choice_panel,BoxLayout.X_AXIS));
		ITSAF_Parent_Panel.add(BorderLayout.SOUTH, rbdm_choice_panel);
		JLabel11.setText("Risk Based Decision Made to Increase/Decrease/Omit Security Control?        ");
		rbdm_choice_panel.add(JLabel11);
		JLabel11.setForeground(java.awt.Color.black);
		JLabel11.setFont(new Font("Dialog", Font.BOLD, 12));
		rbdm_yes_option.setText("Yes  ");
		rbdm_yes_option.setActionCommand("Yes  ");
		rbdm_choice_panel.add(rbdm_yes_option);
		rbdm_yes_option.setFont(new Font("Dialog", Font.PLAIN, 12));
		rbdm_choice_panel.add(rbdm_warning_label);
		rbdm_warning_label.setForeground(java.awt.Color.red);
		rbdm_warning_label.setFont(new Font("Dialog", Font.BOLD, 12));
		rbdm_warning_label.setVisible(false);
		JPanel3.setLayout(new BorderLayout(0,0));
		JPanel25.add(BorderLayout.CENTER, JPanel3);
		JLabel8.setText("Comments:");
		JPanel3.add(BorderLayout.WEST, JLabel8);
		JLabel8.setForeground(java.awt.Color.black);
		JScrollPane1.setOpaque(true);
		JPanel3.add(BorderLayout.CENTER, JScrollPane1);
		comment_field.setRows(4);
		comment_field.setLineWrap(true);
		comment_field.setWrapStyleWord(true);
		comment_field.setNextFocusableComponent(assign_assessor_choicebox);
		comment_field.setToolTipText("<html>Enter any comments you have for your response to the current question in this field.<br>For example interviewees for this question may be documented here.</html>");
		JScrollPane1.getViewport().add(comment_field);
		comment_field.setBounds(0,0,1028,139);
		JPanel33.setLayout(new GridLayout(2,1,0,0));
		JPanel25.add(BorderLayout.SOUTH, JPanel33);
		question_options_panel.setAlignmentY(1.0F);
		question_options_panel.setLayout(new BoxLayout(question_options_panel,BoxLayout.X_AXIS));
		JPanel33.add(question_options_panel);
		JPanel5.setAlignmentY(0.0F);
		JPanel5.setAlignmentX(0.0F);
		JPanel5.setLayout(new FlowLayout(FlowLayout.LEFT,5,0));
		question_options_panel.add(JPanel5);
		JLabel10.setText("Answered By:");
		JLabel10.setAlignmentX(0.5F);
		JPanel5.add(JLabel10);
		JLabel10.setForeground(java.awt.Color.black);
		JLabel10.setFont(new Font("Dialog", Font.BOLD, 12));
		assign_assessor_choicebox.setModel(assign_assessor_model);
		assign_assessor_choicebox.setLightWeightPopupEnabled(false);
		assign_assessor_choicebox.setAlignmentX(0.5F);
		assign_assessor_choicebox.setToolTipText("<html>Determines the responsibility for the answer to the current question.</html>");
		JPanel5.add(assign_assessor_choicebox);
		assign_assessor_choicebox.setFont(new Font("Dialog", Font.PLAIN, 12));
		question_option_panel.setAlignmentY(0.458333F);
		question_option_panel.setAlignmentX(0.498765F);
		question_option_panel.setLayout(new BoxLayout(question_option_panel,BoxLayout.X_AXIS));
		JPanel33.add(question_option_panel);
		JPanel8.setAlignmentY(0.484848F);
		JPanel8.setLayout(new BoxLayout(JPanel8,BoxLayout.X_AXIS));
		question_option_panel.add(JPanel8);
		final_question_options_panel.setLayout(new FlowLayout(FlowLayout.CENTER,5,0));
		JPanel8.add(final_question_options_panel);
		question_complete_checkbox.setText("Question Complete?");
		question_complete_checkbox.setActionCommand("Question Complete");
		question_complete_checkbox.setToolTipText("<html>Check this box to indicate the question is answered correctly</html>");
		final_question_options_panel.add(question_complete_checkbox);
		question_complete_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		JLabel20.setText("      ");
		final_question_options_panel.add(JLabel20);
		flag_question_checkbox.setText("Assign to alternate");
		flag_question_checkbox.setActionCommand("Flag for review");
		flag_question_checkbox.setToolTipText("<html>Check this box to indicate an additional assesor to review the current question</html>");
		final_question_options_panel.add(flag_question_checkbox);
		flag_question_checkbox.setFont(new Font("Dialog", Font.PLAIN, 12));
		flag_for_review_box.setModel(flag_for_review_model);
		flag_for_review_box.setLightWeightPopupEnabled(false);
		flag_for_review_box.setToolTipText("<html>Choose an assessor to evaluate the current questions</html>");
		final_question_options_panel.add(flag_for_review_box);
		flag_for_review_box.setFont(new Font("Dialog", Font.PLAIN, 12));
		JPanel15.setLayout(new BorderLayout(0,0));
		question_panel.add(BorderLayout.SOUTH, JPanel15);
		JPanel26.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel15.add(BorderLayout.SOUTH, JPanel26);
		question_back_button.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
		question_back_button.setText("Back");
		question_back_button.setActionCommand("<< Back");
		question_back_button.setToolTipText("<html>Return to the previous question</html>");
		question_back_button.setMnemonic((int)'B');
		JPanel26.add(question_back_button);
		question_response_clear_button.setText("Clear");
		question_response_clear_button.setActionCommand("Clear");
		question_response_clear_button.setToolTipText("<html>Clear all responses to the current question</html>");
		question_response_clear_button.setMnemonic((int)'C');
		JPanel26.add(question_response_clear_button);
		questions_help_button.setText("Help");
		questions_help_button.setActionCommand("movequestion");
		questions_help_button.setToolTipText("<html>Open help screen</html>");
		questions_help_button.setMnemonic((int)'H');
		JPanel26.add(questions_help_button);
		question_next_button.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		question_next_button.setText("Next");
		question_next_button.setActionCommand("Next");
		question_next_button.setNextFocusableComponent(save_assessment_button);
		question_next_button.setToolTipText("<html>Advance to the next question</html>");
		question_next_button.setMnemonic((int)'N');
		JPanel26.add(question_next_button);
		Summary_Parent_Panel.setLayout(new BoxLayout(Summary_Parent_Panel,BoxLayout.X_AXIS));
		JTabbedPane1.add(Summary_Parent_Panel);
		Summary_Parent_Panel.setBounds(4,26,720,467);
		Summary_Parent_Panel.setVisible(false);
		JScrollPane5.setOpaque(true);
		Summary_Parent_Panel.add(JScrollPane5);
		summary_panel.setAlignmentX(0.49863F);
		summary_panel.setLayout(new BorderLayout(0,0));
		JScrollPane5.getViewport().add(summary_panel);
		summary_panel.setBounds(0,0,717,464);
		JPanel2.setBorder(emptyBorder6);
		JPanel2.setLayout(new BoxLayout(JPanel2,BoxLayout.X_AXIS));
		summary_panel.add(BorderLayout.NORTH, JPanel2);
	//	JLabel12.setText("Current Assessment Progress:    ");
		JPanel2.add(JLabel12);
		JLabel12.setForeground(java.awt.Color.black);
		JLabel12.setFont(new Font("Dialog", Font.BOLD, 12));
		assessment_progress_bar.setStringPainted(true);
		assessment_progress_bar.setString("0% Complete");
		assessment_progress_bar.setToolTipText("<html>Shows your current progress in this active assessment</html>");
	
	//	JPanel2.add(assessment_progress_bar);
		JLabel13.setText("              ");
		JPanel2.add(JLabel13);
		JPanel4.setBorder(emptyBorder7);
		JPanel4.setLayout(new BorderLayout(0,0));
		summary_panel.add(BorderLayout.CENTER, JPanel4);
		JPanel29.setAlignmentY(0.466667F);
		JPanel29.setLayout(new BoxLayout(JPanel29,BoxLayout.X_AXIS));
		JPanel4.add(BorderLayout.NORTH, JPanel29);
		JLabel15.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
		JLabel15.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		JLabel15.setText("Critical Element Response Table:");
		JLabel15.setAlignmentX(0.5F);
		JPanel29.add(JLabel15);
		JLabel15.setForeground(java.awt.Color.black);
		JLabel15.setFont(new Font("Dialog", Font.BOLD, 12));
		JScrollPane7.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
		JScrollPane7.setOpaque(true);
		JPanel4.add(BorderLayout.CENTER, JScrollPane7);
		crit_elem_resp_table.setPreferredScrollableViewportSize(new java.awt.Dimension(300,200));
		JScrollPane7.getViewport().add(crit_elem_resp_table);
		crit_elem_resp_table.setBounds(0,0,689,0);
		summary_options_panel.setAlignmentY(1.0F);
		summary_options_panel.setLayout(new BorderLayout(0,0));
		summary_panel.add(BorderLayout.SOUTH, summary_options_panel);
		JPanel27.setLayout(new BorderLayout(0,0));
		summary_options_panel.add(BorderLayout.CENTER, JPanel27);
		JPanel30.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		JPanel27.add(BorderLayout.CENTER, JPanel30);
		save_assessment_button.setText("Save Assessment to Database");
		save_assessment_button.setActionCommand("Save Assessment");
		save_assessment_button.setNextFocusableComponent(export_button);
		save_assessment_button.setToolTipText("<html>Store this active assessment in the database</html>");
		save_assessment_button.setMnemonic((int)'S');
		JPanel30.add(save_assessment_button);
		export_button.setText("Export Assessment");
		export_button.setActionCommand("Export Locally");
		export_button.setToolTipText("<html>Export this active assessment to XML</html>");
		export_button.setMnemonic((int)'P');
		JPanel30.add(export_button);
		JTabbedPane1.setSelectedIndex(1);
		JTabbedPane1.setSelectedComponent(InfoGather_Parent_Panel);
		JTabbedPane1.setTitleAt(0,"Assessment Identification");
		JTabbedPane1.setTitleAt(1,"System Identification");
		JTabbedPane1.setTitleAt(2,"Policy");
		JTabbedPane1.setTitleAt(3,"Assessment Questions");
		JTabbedPane1.setTitleAt(4,"Summary");
		titledBorder1.setTitle("System Identification");
		//$$ titledBorder1.move(24,507);
		try {
			printIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/print.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ printIcon.move(888,1460);
		//$$ etchedBorder1.move(0,507);
		titledBorder2.setTitle("System Assessors");
		//$$ titledBorder2.move(48,507);
		titledBorder3.setTitle("System Criticality");
		//$$ titledBorder3.move(72,507);
		titledBorder4.setTitle("Inter-Connected Systems");
		//$$ titledBorder4.move(96,507);
		{
			String[] tempString = new String[1];
			tempString[0] = "Please Choose Type...";
			system_type_model.setItems(tempString);
		}
		//$$ system_type_model.move(0,540);
		{
			String[] tempString = new String[4];
			tempString[0] = "Please choose a setting";
			tempString[1] = "High";
			tempString[2] = "Medium";
			tempString[3] = "Low";
			system_confidentiality_model.setItems(tempString);
		}
		//$$ system_confidentiality_model.move(24,540);
		{
			String[] tempString = new String[4];
			tempString[0] = "Please choose a setting";
			tempString[1] = "High";
			tempString[2] = "Medium";
			tempString[3] = "Low";
			system_integrity_model.setItems(tempString);
		}
		//$$ system_integrity_model.move(24,564);
		{
			String[] tempString = new String[4];
			tempString[0] = "Please choose a setting";
			tempString[1] = "High";
			tempString[2] = "Medium";
			tempString[3] = "Low";
			system_availability_model.setItems(tempString);
		}
		//$$ system_availability_model.move(0,564);
		assessor_table_border.setInsets(new java.awt.Insets(5,5,80,40));
		//$$ assessor_table_border.move(48,540);
		comment_pane_border.setInsets(new java.awt.Insets(5,30,1,30));
		//$$ comment_pane_border.move(48,564);
		bevelBorder1.setBevelType(javax.swing.border.BevelBorder.LOWERED);
		//$$ bevelBorder1.move(168,540);
		question_text_border.setInsets(new java.awt.Insets(0,35,0,35));
		//$$ question_text_border.move(192,540);
		button_panel.setInsets(new java.awt.Insets(50,50,50,50));
		//$$ button_panel.move(216,540);
		{
			String[] tempString = new String[3];
			tempString[0] = "Choose a repsonse";
			tempString[1] = "Yes";
			tempString[2] = "No";
			boundary_controls_model.setItems(tempString);
		}
		//$$ boundary_controls_model.move(0,1460);
		emptyBorder1.setInsets(new java.awt.Insets(3,15,3,15));
		//$$ emptyBorder1.move(24,1460);
		emptyBorder2.setInsets(new java.awt.Insets(15,0,0,0));
		//$$ emptyBorder2.move(48,1460);
		{
			String[] tempString = new String[2];
			tempString[0] = "Choose an assessor...";
			tempString[1] = "Add new assessor";
			assign_assessor_model.setItems(tempString);
		}
		//$$ assign_assessor_model.move(72,1460);
		emptyBorder3.setInsets(new java.awt.Insets(10,35,10,10));
		//$$ emptyBorder3.move(96,1460);
		{
			String[] tempString = new String[3];
			tempString[0] = "Publication 1";
			tempString[1] = "Publication 2";
			tempString[2] = "Publication 3";
			publication_reference_list_model.setItems(tempString);
		}
		//$$ publication_reference_list_model.move(120,1460);
		itsaf_panel_border.setInsets(new java.awt.Insets(10,0,0,0));
		//$$ itsaf_panel_border.move(144,1460);
		assessor_table_border2.setInsets(new java.awt.Insets(5,5,5,25));
		//$$ assessor_table_border2.move(168,1460);
		//$$ etchedBorder2.move(192,1460);
		titledBorder5.setTitle("Question Options");
		//$$ titledBorder5.move(216,1460);
		{
			String[] tempString = new String[2];
			tempString[0] = "Choose an assessor...";
			tempString[1] = "Add a new assessor";
			flag_for_review_model.setItems(tempString);
		}
		//$$ flag_for_review_model.move(240,1460);
		//$$ etchedBorder3.move(264,1460);
		emptyBorder4.setInsets(new java.awt.Insets(3,5,0,25));
		//$$ emptyBorder4.move(288,1460);
		emptyBorder5.setInsets(new java.awt.Insets(5,30,1,30));
		//$$ emptyBorder5.move(312,1460);
		progress_bar_border.setInsets(new java.awt.Insets(0,15,0,70));
		//$$ progress_bar_border.move(336,1460);
		//$$ text_popup.move(360,1460);
		JMenuItem3.setText("Cut");
		JMenuItem3.setActionCommand("Cut");
		JMenuItem3.setBorderPainted(false);
		JMenuItem3.setMnemonic((int)'U');
		text_popup.add(JMenuItem3);
		JMenuItem1.setText("Copy");
		JMenuItem1.setActionCommand("Copy");
		JMenuItem1.setBorderPainted(false);
		JMenuItem1.setMnemonic((int)'C');
		text_popup.add(JMenuItem1);
		JMenuItem2.setText("Paste");
		JMenuItem2.setActionCommand("Paste");
		JMenuItem2.setBorderPainted(false);
		JMenuItem2.setMnemonic((int)'P');
		text_popup.add(JMenuItem2);
		emptyBorder6.setInsets(new java.awt.Insets(10,5,0,5));
		//$$ emptyBorder6.move(480,1460);
		emptyBorder7.setInsets(new java.awt.Insets(15,5,15,5));
		//$$ emptyBorder7.move(504,1460);
		status_bar_border.setInsets(new java.awt.Insets(0,0,0,5));
		//$$ status_bar_border.move(552,1460);
		titledBorder6.setTitle("Assessment Objective");
		//$$ titledBorder6.move(576,1460);
		emptyBorder8.setInsets(new java.awt.Insets(0,5,20,0));
		//$$ emptyBorder8.move(600,1460);
		emptyBorder9.setInsets(new java.awt.Insets(10,5,10,10));
		//$$ emptyBorder9.move(624,1460);
		try {
			nextIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/next.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ nextIcon.move(648,1460);
		try {
			previousIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/previous.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ previousIcon.move(672,1460);
		try {
			helpIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/about.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ helpIcon.move(744,1460);
		try {
			deleteIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/delete.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ deleteIcon.move(744,1460);
		try {
			saveIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/save.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ saveIcon.move(696,1460);
		try {
			examineIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/examine.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ examineIcon.move(720,1460);
		try {
			plusIcon.setImageLocation(symantec.itools.net.RelativeURL.getURL("images/plus.gif"));
		}
		catch (java.net.MalformedURLException error) { }
		//$$ plusIcon.move(888,1460);
		emptyBorder10.setInsets(new java.awt.Insets(10,5,5,0));
		//$$ emptyBorder10.move(744,1460);
		emptyBorder11.setInsets(new java.awt.Insets(5,5,0,0));
		//$$ emptyBorder11.move(768,1460);
		//$$ assessment_objective_popup.move(324,744);
		cutMenuItem.setText("Cut");
		cutMenuItem.setActionCommand("Cut");
		cutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		assessment_objective_popup.add(cutMenuItem);
		copyMenuItem.setText("Copy");
		copyMenuItem.setActionCommand("Copy");
		copyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		assessment_objective_popup.add(copyMenuItem);
		pasteMenuItem.setText("Paste");
		pasteMenuItem.setActionCommand("Paste");
		pasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		assessment_objective_popup.add(pasteMenuItem);
		assessment_objective_popup.add(JSeparator1);
		selectAllMenuItem.setText("Select All");
		selectAllMenuItem.setActionCommand("Select All");
		selectAllMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.Event.SHIFT_MASK|java.awt.Event.CTRL_MASK));
		assessment_objective_popup.add(selectAllMenuItem);
		//$$ systemNamePopup.move(816,1460);
		system_name_cutMenuItem.setText("Cut");
		system_name_cutMenuItem.setActionCommand("Cut");
		system_name_cutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(system_name_cutMenuItem);
		system_name_copyMenuItem.setText("Copy");
		system_name_copyMenuItem.setActionCommand("Copy");
		system_name_copyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(system_name_copyMenuItem);
		system_name_pasteMenuItem.setText("Paste");
		system_name_pasteMenuItem.setActionCommand("Paste");
		system_name_pasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		systemNamePopup.add(system_name_pasteMenuItem);
		//$$ systemnum_popup_field.move(840,1460);
		systemnum_cut_menuitem.setText("Cut");
		systemnum_cut_menuitem.setActionCommand("Cut");
		systemnum_cut_menuitem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		systemnum_popup_field.add(systemnum_cut_menuitem);
		systemnum_copy_menuitem.setText("Copy");
		systemnum_copy_menuitem.setActionCommand("Copy");
		systemnum_copy_menuitem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		systemnum_popup_field.add(systemnum_copy_menuitem);
		systemnum_paste_menuitem.setText("Paste");
		systemnum_paste_menuitem.setActionCommand("Paste");
		systemnum_paste_menuitem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_V, java.awt.Event.CTRL_MASK));
		systemnum_popup_field.add(systemnum_paste_menuitem);
		//$$ aggrpdiv_popup.move(864,1460);
		aggrpdiv_cutMenuItem.setText("Cut");
		aggrpdiv_cutMenuItem.setActionCommand("Cut");
		aggrpdiv_cutMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_X, java.awt.Event.CTRL_MASK));
		aggrpdiv_popup.add(aggrpdiv_cutMenuItem);
		aggrpdiv_copyMenuItem.setText("Copy");
		aggrpdiv_copyMenuItem.setActionCommand("Copy");
		aggrpdiv_copyMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.Event.CTRL_MASK));
		aggrpdiv_popup.add(aggrpdiv_copyMenuItem);
		aggrpdiv_pasteMenuItem.setText("Paste");
		aggrpdiv_pasteMenuItem.setActionCommand("Paste");
		aggrpdiv_pasteMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_P, java.awt.Event.CTRL_MASK));
		aggrpdiv_popup.add(aggrpdiv_pasteMenuItem);
		//$$ emptyBorder12.move(888,1460);
		id_panel_proceed_button.setIcon(nextIcon);
		policy_previous_button.setIcon(previousIcon);
		addAssessor_help_button.setIcon(helpIcon);
		system_confidentiality_box.setSelectedIndex(0);
		system_integrity_box.setSelectedIndex(0);
		system_availability_box.setSelectedIndex(0);
		proceed_to_assessment_button.setIcon(nextIcon);
		flag_for_review_box.setSelectedIndex(0);
		export_button.setIcon(saveIcon);
		infoGather_previous_button.setIcon(previousIcon);
		system_type_box.setSelectedIndex(0);
		question_next_button.setIcon(nextIcon);
		conn_system_help_button.setIcon(helpIcon);
		question_back_button.setIcon(previousIcon);
		assign_assessor_choicebox.setSelectedIndex(0);
		add_assessor_button.setIcon(plusIcon);
		policy_next_button.setIcon(nextIcon);
		question_response_clear_button.setIcon(deleteIcon);
		conn_system_add_button.setIcon(plusIcon);
		questions_help_button.setIcon(helpIcon);
		//}}		
		assessment_objective_field.setRows(4);
		assessment_objective_field.setLineWrap(true);
		assessment_objective_field.setNextFocusableComponent(id_panel_proceed_button);
		assessment_objective_field.setBorder(etchedBorder1);
		assessment_objective_field.setToolTipText("<html>Describe your objective for the current assessment in this field</html>");
		JScrollPane8.getViewport().add(assessment_objective_field);
		assessment_objective_field.setBounds(0,0,703,224);		
	    this.setPanelSizes();
	    
		//{{REGISTER_LISTENERS
		SymMouse aSymMouse = new SymMouse();
		system_name_field.addMouseListener(aSymMouse);
		assessment_date_field.addMouseListener(aSymMouse);
		SymAction lSymAction = new SymAction();
		proceed_to_assessment_button.addActionListener(lSymAction);
		SymInternalFrame lSymInternalFrame = new SymInternalFrame();
		this.addInternalFrameListener(lSymInternalFrame);
		question_back_button.addActionListener(lSymAction);
		question_next_button.addActionListener(lSymAction);
		add_assessor_button.addActionListener(lSymAction);
		conn_system_add_button.addActionListener(lSymAction);
		question_response_clear_button.addActionListener(lSymAction);
		JLabel5.addMouseListener(aSymMouse);
		JLabel6.addMouseListener(aSymMouse);
		JLabel7.addMouseListener(aSymMouse);
		JLabel1.addMouseListener(aSymMouse);
		JLabel2.addMouseListener(aSymMouse);
		JLabel3.addMouseListener(aSymMouse);
		JLabel16.addMouseListener(aSymMouse);		
		id_panel_proceed_button.addActionListener(lSymAction);
		infoGather_previous_button.addActionListener(lSymAction);
		policy_next_button.addActionListener(lSymAction);
		policy_previous_button.addActionListener(lSymAction);
		system_name_cutMenuItem.addActionListener(lSymAction);
		copyMenuItem.addActionListener(lSymAction);
		pasteMenuItem.addActionListener(lSymAction);
		selectAllMenuItem.addActionListener(lSymAction);
		system_name_copyMenuItem.addActionListener(lSymAction);
		system_name_pasteMenuItem.addActionListener(lSymAction);
		systemnum_cut_menuitem.addActionListener(lSymAction);
		systemnum_copy_menuitem.addActionListener(lSymAction);
		systemnum_paste_menuitem.addActionListener(lSymAction);
		aggrpdiv_cutMenuItem.addActionListener(lSymAction);
		aggrpdiv_copyMenuItem.addActionListener(lSymAction);
		aggrpdiv_pasteMenuItem.addActionListener(lSymAction);
		save_assessment_button.addActionListener(lSymAction);
		export_button.addActionListener(lSymAction);
		assign_assessor_choicebox.addActionListener(lSymAction);
		flag_for_review_box.addActionListener(lSymAction);
		ITSAF_level2_checkbox.addActionListener(lSymAction);
		ITSAF_level3_checkbox.addActionListener(lSymAction);
		ITSAF_level4_checkbox.addActionListener(lSymAction);
		rbdm_na_option.addActionListener(lSymAction);
		rbdm_yes_option.addActionListener(lSymAction);
		conn_system_help_button.addActionListener(lSymAction);
		addAssessor_help_button.addActionListener(lSymAction);
		policy_label.addMouseListener(aSymMouse);
		ITSAF_level2_checkbox.addMouseListener(aSymMouse);
		ITSAF_level3_checkbox.addMouseListener(aSymMouse);
		ITSAF_level4_checkbox.addMouseListener(aSymMouse);
		ITSAF_level1_checkbox.addMouseListener(aSymMouse);
		ITSAF_level5_checkbox.addMouseListener(aSymMouse);
		questions_help_button.addActionListener(lSymAction);
		SymFocus aSymFocus = new SymFocus();
		assessment_objective_field.addFocusListener(aSymFocus);
		system_name_field.addFocusListener(aSymFocus);
		system_number_field.addFocusListener(aSymFocus);
		aggrpdiv_text_field.addFocusListener(aSymFocus);
		comment_field.addFocusListener(aSymFocus);
		SymKey aSymKey = new SymKey();
		this.addKeyListener(aSymKey);
		JLabel4.addMouseListener(aSymMouse);
		assessment_objective_field.addKeyListener(aSymKey);
		comment_field.addKeyListener(aSymKey);
		add_assessor_button.addKeyListener(aSymKey);
		addAssessor_help_button.addKeyListener(aSymKey);
		conn_system_add_button.addKeyListener(aSymKey);
		conn_system_help_button.addKeyListener(aSymKey);
		infoGather_previous_button.addKeyListener(aSymKey);
		proceed_to_assessment_button.addKeyListener(aSymKey);
		policy_next_button.addKeyListener(aSymKey);
		policy_previous_button.addKeyListener(aSymKey);
		system_availability_box.addKeyListener(aSymKey);
		policy_question_table.addKeyListener(aSymKey);
		id_panel_proceed_button.addKeyListener(aSymKey);
		question_next_button.addKeyListener(aSymKey);
		save_assessment_button.addKeyListener(aSymKey);
		export_button.addKeyListener(aSymKey);
		assessor_table.addKeyListener(aSymKey);
		policy_question_table.addMouseListener(aSymMouse);
		//}}
		this.setTableHeaders();
		progress_tree.setModel(this.progress_model);					
		progress_tree.addTreeSelectionListener(this);				    
		    
        this.system_name_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            systemNamePopup.show(system_name_field, me.getX(), me.getY());
		        }
		    }      
		 });
		 
		 this.system_number_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            systemnum_popup_field.show(system_number_field, me.getX(), me.getY());
		        }
		    }      
		 });
		 
         this.assessment_objective_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            assessment_objective_popup.show(assessment_objective_field, me.getX(), me.getY());
		        }
		    }      
		 }); 
		 
         this.aggrpdiv_text_field.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
		        if (SwingUtilities.isRightMouseButton(me)) {              
		            aggrpdiv_popup.show(aggrpdiv_text_field, me.getX(), me.getY());
		        }
		    }      
		 }); 
		 
		 this.assessor_table.addMouseListener(new MouseAdapter() {         
		    public void mouseClicked(MouseEvent me) {            
                if (me.getClickCount() == 2) {
                }
		    }      
		 }); 
		 
		// Ugly approach but definte way to ensure that the selected tab is 
		// visible when the new Assessment window opens for the first time.
		this.JTabbedPane1.setSelectedIndex(0);
		
		this.JTabbedPane1.setSize(new Dimension(630, 492));
		this.prgMonitor = new ProgressDialog();
		this.prgMonitor.setVisible(false);
		this.saver.setDialogTitle("Save unfinished assessment");
		this.saver.setCurrentDirectory((new File(System.getProperty("user.dir"))).getParentFile());
        this.saver.setSelectedFile(new File("untitled.xml"));
        // Change Control:
        // 03/26/02 - Changed order in which file filters are added to the file saver dialog
        //            since the XML filter is preferred first this is the one that should
        //            show up first when the file dialog box pops up, users should not have
        //            to choose the second in the list if it is preferred.
        this.saver.addChoosableFileFilter(new XMLFilter());        

		this.pack();
	    this.assessment_start = new Date();
	    this.useTodaysDate();
	    this.add_assessor_button.requestDefaultFocus();
	} /* end AssessmentWindow() default constructor*/
	 
    // The next series of methods are reactive to when a user presses a key on the keyboard.
    // They way to tell which key press each method looks for is to look for the syntax:
    // KeyEvent.VK_<key name> where <key name> is the key on the keyboard that the user presses
    private void obj_fieldTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.id_panel_proceed_button.requestFocus();    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method obj_fieldTabKeyPressed(event) */
    
    private void ques_NextTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                this.questionForward();   
            }else if (event.getKeyChar() == KeyEvent.VK_S) {
                JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() + 1);   
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method ques_NextTabKeyPressed() */    
    
    private void availability_fieldTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.conn_system_add_button.requestFocus();  
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method availability_fieldTabKeyPressed() */
    
    private void assessorTableTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.add_assessor_button.requestFocus();
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method assessorTableTabKeyPressed() */    
    
    private void policyTableTabFieldPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_ENTER) {
                int selected_row = this.policy_question_table.getSelectedRow();
                (this.policy_question_table.getModel()).setValueAt(new Boolean(true), selected_row, 2);   
            }            
        }catch (Exception e) {
            e.printStackTrace();
        }        
    }/* end method policyTableTabFieldPressed() */
    
    private void cmnt_fieldTabKeyPressed(java.awt.event.KeyEvent event) {
        try {
            if (event.getKeyChar() == KeyEvent.VK_TAB) {
                this.assign_assessor_choicebox.requestFocus();    
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method cmnt_fieldTabKeyPressed() */    
	// This ends the section of methods that react to a user pressing a key on the keyboard.
	
	// This method sets the active text component for the Edit menu of the parent class SATUI
	// This method uses the parent object of the class, it is an instance of interface ASSET.
	// Interface ASSET is explained in more detail in its class definition, ASSET.java.
	private void setActiveTextComponent(JTextComponent cmp) {
	    try {
	        this.parent.setActiveTextComponent(cmp);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}/* end method setActiveTextComponent() */	
	
	// The next section of methods are action handlers for the help methods throughout an assessment
	// window. They make extensive use of the parent object, again an instance of the ASSET
	// inteface.
	private void showHelpQuestions() {
	    this.parent.defineAction(this.questions_help_button.getActionCommand());     
	}
	
	private void showHelpAddAssessors() {
	    this.parent.defineAction(this.addAssessor_help_button.getActionCommand());    
	}
	
	private void defineConfidentiality() {
	    this.parent.defineTerm("confidentiality");    
	}
	
	private void defineSystemName() {
	    this.parent.defineTerm("systemname");    
	}
	
	private void defineSystemNumber() {
	    this.parent.defineTerm("systemnumber"); 
	}
	
	private void defineSystemType() {
	   this.parent.defineTerm("systemtype");  
	}
	
	private void defineLocation() {
	    this.parent.defineTerm("agencygroup");    
	}
	
	private void defineIntegrity() {
	    this.parent.defineTerm("integrity");
	}
	
	private void defineAvailability() {
	    this.parent.defineTerm("availability");    
	}
	
	private void showHelpAddConnectedSystem() {
	    this.parent.defineAction(this.conn_system_help_button.getActionCommand());    
	}
	// This ends the section of methods that are the action handlers for the help actions
	// of ASSET system.
	
	// This method is the action handler for the export assessment button at the bottom of the
	// of the fifth summary tab. Its task is to spawn an instance of the class AssessmentXMLGenerator
	// 
	private void exportAssessment(String file_name) {
	    Vector assessment_list = new Vector();
	    try {
	        if (this.getAssessmentSaveStatus()) {
	            assessment_list.addElement(this.system_name_field.getText()+"^^"+this.assessment_date_field.getText());
	            AssessmentXMLGenerator gen = AssessmentXMLGenerator.spawnNewXMLGenerator(assessment_list, this.parent.getPropertyManager());
                gen.setExportFileName(file_name);
                gen.resetOutputWriter();
                gen.run();
                this.parent.setStatusMsg("");
            }else {
	    	    int reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "In order to export this assessment you must store it in the database first. Would you like to store this assessment now?", 
	    	                                          "Export Assessment Information" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
                if (reply == JOptionPane.YES_OPTION) {
                    {
                        this.saveAssessment();
                    }
	                assessment_list.addElement(this.system_name_field.getText()+"^^"+this.assessment_date_field.getText());
	                AssessmentXMLGenerator gen = AssessmentXMLGenerator.spawnNewXMLGenerator(assessment_list, this.parent.getPropertyManager());
                    gen.setExportFileName(file_name);
                    gen.resetOutputWriter();
                    gen.run();
                    this.parent.setStatusMsg("");                    
                }
            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void openAssessmentHelpWindow() {
	    try {
	        Runtime subsystem = Runtime.getRuntime();
	        subsystem.exec((this.parent.getPropertyManager()).getProperty("sat.help.defaultbrowser") + " " + this.parent.getPropertyManager().getProperty("sat.help.assessmentpage"));
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void parentApplicationClosing() {
	    try {
	        this.AssessmentWindow_internalFrameClosing(null);
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	public void definePolicy() {
	    this.parent.defineTerm("policy");    
	}
	
	public void defineProcedures() {
	    this.parent.defineTerm("procedures");   
	}
	
	public void defineImplemented() {
	   this.parent.defineTerm("");  
	}
	
	public void defineTested() {
	  this.parent.defineTerm("");   
	}
	
	public void defineIntegrated() {
	  this.parent.defineTerm("");   
	}
	
	public boolean getSupportsSave() {
	    return true;    
	}
	
	public void store() {
	    this.saveAssessment();    
	}
	
	public void saveLocally() {
	    this.saveUnfinishedAssessment();    
	}
	
    class HeaderListener extends MouseAdapter {
        JTableHeader   header;    
        SortButtonRenderer renderer;      
    
        HeaderListener(JTableHeader header,SortButtonRenderer renderer) {      
            this.header   = header;      
            this.renderer = renderer;
        }
    
        public void mousePressed(MouseEvent e) {
            int col = header.columnAtPoint(e.getPoint());
            int sortCol = header.getTable().convertColumnIndexToModel(col);
            renderer.setPressedColumn(col);
            renderer.setSelectedColumn(col);
            header.repaint();
            if (header.getTable().isEditing()) {
                header.getTable().getCellEditor().stopCellEditing();
            }            
            boolean isAscent;      
            if (SortButtonRenderer.DOWN == renderer.getState(col)) {        
                isAscent = true;      
            }else {
                isAscent = false;
            }
            ((SortableTableModel)header.getTable().getModel()).sortByColumn(sortCol, isAscent);        
        } 
     
        public void mouseReleased(MouseEvent e) {      
    
            int col = header.columnAtPoint(e.getPoint());      
            renderer.setPressedColumn(-1);
                // clear      
            header.repaint();    
        }  
    }/* end internal class HeaderListener() */	
	
	private String padWithNewLines(String unpadded_string, int spaces) {
	    StringBuffer buffer = new StringBuffer("");
        StringTokenizer parser = new StringTokenizer(unpadded_string, " ");
	    int token_count = 0;
	    int remainder = 0;
	    try {
	        token_count = parser.countTokens();
	        remainder = token_count % spaces;
            for (int i = 0; i < (token_count/spaces); i++) {
                for (int j = 0; j < spaces; j++) {
                    buffer.append(parser.nextToken() + " ");
                }
                buffer.append("\n");
            }
            for (int k = 0; k < remainder; k++) {
                buffer.append(parser.nextToken() + " ");
            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return buffer.toString();
	}
	
	// This logic allows you to delete an assessor from the assessor table. It first
	// checks to see that the assessor that you are trying to delete is not the primary
	// if it is, it throws an error dialog and prevents the deletion.
	// ---------------
	// Change Control:
	// 05/01/02 - added check to ensure that user selected a valid row first by seperating
	//            out code that determines which row was selected. If the row selected was 
	//            -1 then you can't delete anything since nothing was selected.
	private void deleteAssessor(MouseEvent e) {
        int row = -1;
	    try {
            if (e != null) {
                row = this.assessor_table.rowAtPoint(e.getPoint());
            }else {
                row = this.assessor_table.getSelectedRow();
            }
            if (row != -1) {
                if (!((Boolean) this.assessor_table.getValueAt(row, 0)).booleanValue()) {
                    int save_reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "Are you sure you want to delete this assessor?", 
	    	                                          "Delete Assessor" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
			        if (save_reply == JOptionPane.YES_OPTION) {
			        this.assessor_table_model.removeRow(row);            
			        }                                                                            
                }else {
                    this.parent.displayErrorDialog("You cannot remove the primary assessor from this assessment!");
                }   
            }else {
                this.parent.displayErrorDialog("You must select an assessor first!");    
            }
	    }catch (Exception ex) {
	        ex.printStackTrace();
	    }
	}/* end method deleteAssessor(MouseEvent) */
	
	// This method is responsible for deleting a connected system from the connected
	// system table. It is called by the action handlers for Mouse events that are
	// generated and for action events that are generated when buttons are pressed.
	// --------------
	// Change Control:
	// 05/01/02 - Added selected_row method variable so that if selected row is -1
	//            this means that the delete button was pressed when no valid row
	//            was selected.
    private void deleteConnectedSystem(MouseEvent e) {
	    int selected_row = -1;
	    try {	        
            if (e != null) {
                selected_row = this.connected_system_table.rowAtPoint(e.getPoint());
            }else {
                selected_row = this.connected_system_table.getSelectedRow(); 
            }
            if (selected_row != -1) {
                int save_reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "Are you sure you want to delete this inter-connected system?", 
	    	                                          "Delete Inter-connected System" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
			    if (save_reply == JOptionPane.YES_OPTION) {
                    this.connected_system_model.removeRow(selected_row);			                       
			    }                  
			}else {
			    this.parent.displayErrorDialog("You must select a valid system to delete first!");        
			}
	    }catch (Exception ex) {
	        ex.printStackTrace();
	    }
	}/* end method deleteConnectedSystem(MouseEvent) */
	
	// Set the table headers for the policy element table. Make sure that since this
	// method must be available to execute more than once that the first step in the
	// method is always to reinitialize the vector that holds the column headers	
	private void setPolicyTableColumnHeaders() {	    
	    try {		   
	        this.policy_table_column_headers = new Vector();
		    this.policy_table_column_headers.addElement("Number");
		    this.policy_table_column_headers.addElement("Control Objective");
		    this.policy_table_column_headers.addElement("Policy Defined?");
		    this.policyModel.setColumnIdentifiers(this.policy_table_column_headers);			    
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	// Set the table headers for the critical element table. Make sure that since this
	// method must be available to execute more than once that the first step in the
	// method is always to reinitialize the vector that holds the column headers
    private void setCriticalElementTableColumnHeaders() {
	    try {
	        this.critical_table_column_headers = new Vector();
		    critical_table_column_headers.addElement("Critical Element");
		    critical_table_column_headers.addElement("N/A");
		    critical_table_column_headers.addElement("Risk-based Decision?");
		    critical_table_column_headers.addElement("Policy");
		    critical_table_column_headers.addElement("Procedures");
		    critical_table_column_headers.addElement("Implemented");
		    critical_table_column_headers.addElement("Tested");
		    critical_table_column_headers.addElement("Integrated");
		    this.criticalElementModel.setColumnIdentifiers(critical_table_column_headers);	        
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
			
	private void prepareCriticalElementTable() {
	    try {	        
	        this.parent.log("preparing critical element table now...");
	        this.setCriticalElementTableColumnHeaders();
	        this.crit_elem_resp_table.setModel(this.criticalElementModel);
	       	        
	        (this.crit_elem_resp_table.getColumn("N/A")).setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Risk-based Decision?").setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Policy").setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Procedures").setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Implemented").setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Tested").setCellRenderer(new CheckBoxRenderer());
	        this.crit_elem_resp_table.getColumn("Integrated").setCellRenderer(new CheckBoxRenderer());
	    }catch (Exception e) {
	        this.parent.log("ERROR: while trying to prepare the critical element table: " + e.toString());
	    }
	}
		
	// Prepare the policy table to allow the use of a checbox as a cell editor
	// for the policy defined? column. This method is called from buildTree
	private void preparePolicyTable() {
	    try {
	        this.setPolicyTableColumnHeaders();
	        this.policy_question_table.setModel(this.policyModel);
	        this.checkbox_editor.setHorizontalAlignment(JLabel.CENTER);
	        	        
	        DefaultCellEditor checkBoxEditor = new DefaultCellEditor(this.checkbox_editor);
	        CheckBoxRenderer checkBoxRenderer = new CheckBoxRenderer();
	        policy_question_table.getColumn("Policy Defined?").setCellRenderer(checkBoxRenderer);
	        policy_question_table.getColumn("Policy Defined?").setCellEditor(checkBoxEditor);	    	        
	    }catch (Exception e) {
	        this.parent.log("ERROR: while trying to prepare the policy question table: " + e.toString());
	    }
	}
	
	private void setPanelSizes() {
	    try {
		    assessment_id_panel.setPreferredSize(new Dimension(630, 497));
		    assessment_id_panel.setMaximumSize(new Dimension(630, 497));
		    InfoGather_Parent_Panel.setPreferredSize(new Dimension(630, 497));
		    InfoGather_Parent_Panel.setMaximumSize(new Dimension(630, 497));
		    Question_Parent_Panel.setPreferredSize(new Dimension(630, 497));
		    Question_Parent_Panel.setMaximumSize(new Dimension(630, 497));
		    Summary_Parent_Panel.setPreferredSize(new Dimension(630, 497));
		    Summary_Parent_Panel.setMaximumSize(new Dimension(630, 497));
		    
	        question_panel.setPreferredSize(new Dimension(630, 497));
		    question_panel.setMaximumSize(new Dimension(630, 497));
		    this.question_presentation_panel.setPreferredSize(new Dimension(630, 497));
		    this.question_presentation_panel.setMaximumSize(new Dimension(630, 497));
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	private void setSystemTypeBox() {
        try {
            StringBuffer sql_buffer = new StringBuffer();
            sql_buffer.append("select * from sys_Component_Types");
            Statement stmt = this.conn.createStatement();
            ResultSet sys_types = stmt.executeQuery(sql_buffer.toString());
            
            while (sys_types.next()) {
                this.system_type_model.addElement(sys_types.getString("component_type"));   
            }
            sys_types.close();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }  
	}
	
	private void setTableHeaders() {
	    try {
	        this.assessor_table_headers.addElement("Primary");
	        this.assessor_table_headers.addElement("Name");
	        this.assessor_table_headers.addElement("Email");
	        this.assessor_table_headers.addElement("Phone");
	        this.assessor_table_model.setColumnIdentifiers(this.assessor_table_headers);
	        this.assessor_table.setModel(this.assessor_table_model);
	        
	        this.assessor_table.getColumn("Primary").setCellRenderer(new CheckBoxRenderer());
	        
            this.system_table_headers.addElement("System");
	        this.system_table_headers.addElement("Boundary Controls Effective?");
	        this.system_table_headers.addElement("Planned Action if Not");
	        this.connected_system_model.setColumnIdentifiers(this.system_table_headers);
            this.connected_system_table.setModel(this.connected_system_model);
                        
 	    }catch (Exception e) {
	        e.printStackTrace();    
	    }
	}
	
	public void questionBack() {
	    HybridTreeNode next_node = null;
        try {
            if (this.checkQuestionStateBoxes()) {
                this.selectNode(this.findPreviousChild(this.findQuestionNode(this.question_number_label.getText())));                                                            
            }       
            this.ITSAF_level2_checkbox.requestFocus();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
	}
	
	public void assembleAssesmentInfo() {
	    try {
	        this.insertNewAssessmentRecord();
	        this.insertNewComponentRecord();
	        this.insertNewAssessorRecords();
	        this.insertNewCriticalitiesRecords();
	        this.insertNewConnectedSystemsRecords();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	// This method imports assessment information from an XML file. Once the 
	// assessment information has been imported it will display the load dialog box. 
	// ---------------
	// Change Control:
	// 04/12/02 - Added code to create and display assessment load dialog box once
	//            import assessment process has completed.
	// 05/19/02 - Added more \n to dialog box that gets displayed. Otherwise too much
	//            information was on one line and took up the entire width of the screen
	public void loadXMLAssessmentFile(File assessment) {
	    try {
	    	int reply = JOptionPane.showConfirmDialog(this, 
	    	            ("Do you want to import the information\nin " + assessment.toString() + "\ninto the assessment database? Please be aware\nthat this operation may take a few minutes.\nOnce completed you must click:\n \"Open->\"Open from database\" (or CRTRL-O)\nto open the assessment(s) you imported." ), 
	    	             "Import Assessments" , 
	    	             JOptionPane.YES_NO_OPTION, 
	    	             JOptionPane.QUESTION_MESSAGE);	        	        
            if (reply == JOptionPane.YES_OPTION) {
	            AssessmentImporter import_thread = AssessmentImporter.spawnAssessmentImporter(this.parent, assessment.toString());
                {
                    import_thread.run();                
                }
	        }else if (reply == JOptionPane.NO_OPTION) {	            
	            this.dispose();
	        }	   
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("ERROR ! Could not import/open assessment file:\n" + assessment.toString());
	        e.printStackTrace();
	        System.exit(1);
	    }
	}
	
	// This method performs the ALL IMPORTANT loading of an assessment from the database
	// It uses the assessment_id field set within the loadXMLAssessmentFile() method
	// to call the appropriate stored procedures.
	// ------------------------------------------
	// It is important to note that this method is designed to take the place of any static
	// methods that are called by having a user start a new assessment and press the next buttons
	// to proceed to answering questions. The main method in question is of course proceedToAssessment()
	// ------------------------------------------
	// Change Control:
	// 04/15/02 - Changed extraction of system information to include the start timestamp
	//            otherwise ASSET System would think the start date of the old assessment
	//            was the time when the application was opened. This caused multiple assessments
	//            to be in the database for the old information.
	// 05/01/02 - Added code to set the divider size of the split pane wrapper to be 9, the same
	//            size it was set to be at when the AssessmentWindow class is first instantiated.
	public void extractFromDatabase(String assessment_id, String name) {
        CallableStatement assessor_query = null;
        CallableStatement assessment_query = null;
        CallableStatement criticality_query = null;
        CallableStatement connected_sys_query = null;
        CallableStatement policy_results_query= null;
        CallableStatement critical_results_query = null;
        CallableStatement critical_element_listing = null;
        CallableStatement questions = null;
        ResultSet assessors = null;
        ResultSet assessment = null;
        ResultSet criticalities = null;
        ResultSet connected_sys = null;
        ResultSet policy_results = null;
        ResultSet critical_results = null;
        ResultSet critical_elements = null;
        ResultSet question_listing = null;
        Connection conn = null;
        String primary = "";
        String num = "";
        int system_number = 0;
        Vector table_row = null;
        boolean add_logged_in_user = true;
	    try {
	        this.prgMonitor.setProgressMax(100);
	        this.parent.setStatusModeMsg("IMPRT");
	        this.parent.setStatusMsg("Opening assessment " + assessment_id + "now, please hold");
	        this.prgMonitor.setStatusBusyMessage("Now opening assessment of " + name);
            this.prgMonitor.setVisible(true);
            
            // Begin code to fill assessors table, first extract primary assessor information
            // From the assessment table inner joined with the SAT_Users  table.
            conn = this.parent.connectionGenerator();
            assessor_query = conn.prepareCall("{call get_primary_assessor(?)}");
	        assessor_query.setString(1, assessment_id);
	        assessors = assessor_query.executeQuery();
	        Assessor primary_local = null;
	        String phone = "";
	        String email = "";
	        // Extract primary assessor information from the database and set the class 
	        // variable primary with an instance of the Assessor class. There is no need to 
	        // explicitly add a row to the assesors table since calling the setPrimaryAssessor
	        // method will do that for us.
	        while (assessors.next()) {
	            primary = (assessors.getString("full_name")).trim();
	            if (primary.equals((this.getSecondaryAssessor()).getFullName())) {
	                add_logged_in_user = false;    
	            }
	            email = (assessors.getString("email")).trim();
	            phone = (assessors.getString("phone")).trim();
	            primary_local = Assessor.createNewAssessor(primary, email, phone, true);

	            this.setPrimaryAssessor(primary_local, primary_local.getDataVector());
	        }
	        conn.close();
	        this.prgMonitor.setNormalizedProgress(5);
        
            // Set the question count to allow all indications of progress 
            // completed to be painted correctly.
            this.initializeQuestionCount();
            
          	// Next extract all other assessors from the assessors table inner joined
        	// with the SAT_Users table
	        conn = this.parent.connectionGenerator();
	        assessor_query = conn.prepareCall("{call get_assessors_per_assessment(?)}");
	        assessor_query.setString(1, assessment_id);
	        assessors = assessor_query.executeQuery();
            String full_name_comparison = "";
	        while (assessors.next()) {
	            table_row = new Vector();
	            
	            full_name_comparison = (assessors.getString("full_name")).trim();
	            if (! full_name_comparison.equals(primary)) {
	                table_row.addElement(new Boolean(false));
	                table_row.addElement(full_name_comparison);
	                table_row.addElement((assessors.getString("email")).trim());
	                table_row.addElement((assessors.getString("phone")).trim());
	                this.assessor_table_model.addRow(table_row);
	            }
	            if (full_name_comparison.equals((this.getSecondaryAssessor()).getFullName())) {
	               add_logged_in_user = false;    
	            }
	        }
	        if (add_logged_in_user) {
	            this.assessor_table_model.addRow((this.getSecondaryAssessor()).getDataVector());
	        }
	        conn.close();   
	        
	        conn = this.parent.connectionGenerator();
	        assessor_query = conn.prepareCall("{call get_assessorreviewers_per_assessment(?)}");
	        assessor_query.setString(1, assessment_id);
	        assessors = assessor_query.executeQuery();
            full_name_comparison = "";
	        while (assessors.next()) {
	            table_row = new Vector();
	            
	            full_name_comparison = (assessors.getString("full_name")).trim();
	            if (! full_name_comparison.equals(primary)) {
	                table_row.addElement(new Boolean(false));
	                table_row.addElement(full_name_comparison);
	                table_row.addElement((assessors.getString("email")).trim());
	                table_row.addElement((assessors.getString("phone")).trim());
	                this.assessor_table_model.addRow(table_row);
	            }
	            if (full_name_comparison.equals((this.getSecondaryAssessor()).getFullName())) {
	               add_logged_in_user = false;    
	            }
	        }
	        if (add_logged_in_user) {
	            this.assessor_table_model.addRow((this.getSecondaryAssessor()).getDataVector());
	        }
	        conn.close();   	        
	        this.prgMonitor.setNormalizedProgress(17);
	        this.assessor_table.setModel(this.assessor_table_model);
	        this.assessor_table.getColumn("Primary").setCellRenderer(new CheckBoxRenderer());    	            	        
	        // End code to fill assessors table.	        
	        
	        // Begin code to fill in information gathering fields on tabbed pane 1 and 2
	        conn = this.parent.connectionGenerator();
	        assessment_query = conn.prepareCall("{call get_single_saved_assessment_by_id(?)}");
            assessment_query.setString(1, assessment_id);
            assessment = assessment_query.executeQuery();
            assessment.next();
            // When extracting fields from the database be sure to call the trim() method
            // on strings to make sure that whitespace is not carried along with the field you
            // are after
            SystemtoAssess sys = null;
            String system_name = "";
            String loc = "";
            String type = "";
            system_name = (assessment.getString("component_name")).trim();
            this.system_name_field.setText(system_name);
            num = (assessment.getString("component_num")).trim();
            this.system_number_field.setText(num);
            loc = (assessment.getString("component_location").trim());
            this.aggrpdiv_text_field.setText(loc);
            type = (String) (assessment.getString("component_type")).trim();
            this.system_type_box.setSelectedItem(type);
                        
            // Re-create the intance of SystemtoAssess, the class that encapsulates all
            // of the identification about the system you are assessing within this 
            // instance of AssessmentWindow
            this.system = SystemtoAssess.createNewSystem(num, loc, system_name, type);
            
            this.assessment_objective_field.setText((assessment.getString("component_assessment_obj")).trim());
            this.assessment_date_field.setText((assessment.getString("start_timestamp")).trim());
            this.setCompleted(assessment.getInt("completed"));        
            // Call the trim method to trim out any white space on the bookmark.
            this.setBookmark((assessment.getString("bookmark")).trim());
            this.setQuestionProgress((assessment.getInt("progress")) - 1);            
            this.incrementQuestionProgress();
            
            this.setAssessmentName(assessment_id);            
	        this.assessembleAssessorResponBox();
    		this.assessembleReviewerResponBox();
	        this.setAssessmentStatus(true);            
            this.setAssessmentType(false);
            this.parent.setServiceName("Self-Assessment");
            this.prgMonitor.setNormalizedProgress(23);
		    this.setLocalSaveFileName();
		    this.setAssessmentSaveTimer();            
            conn.close();
            
            //Begin code to to recreate component criticality fields
            conn = this.parent.connectionGenerator();
            criticality_query = conn.prepareCall("{call get_component_criticalities(?, ?)}");
            criticality_query.setString(1, num);
            criticality_query.setString(2, assessment_id);
            criticalities = criticality_query.executeQuery();
            criticalities.next();
            String confiden = (String) criticalities.getString("confidentiality");
            String integrit = (String) criticalities.getString("integrity");
            String avail = (String) criticalities.getString("availability");
            this.system_confidentiality_box.setSelectedItem(confiden.trim());
            this.system_integrity_box.setSelectedItem(integrit.trim());
            this.system_availability_box.setSelectedItem(avail.trim());
            conn.close();
            this.prgMonitor.setNormalizedProgress(35);
            // End code to recreate component criticality fields
            
            // Begin code to fill in connected system table, make sure that the items
            // you add to the instance of Vector are directly out of the result set columns
            // or else nothing will display on the table within the user interface
            conn = this.parent.connectionGenerator();
            connected_sys_query = conn.prepareCall("{call get_conn_systems_per_assessment(?, ?)}");
            connected_sys_query.setString(1, num);
            connected_sys_query.setString(2, assessment_id);
            connected_sys = connected_sys_query.executeQuery();
            system_name = "";
            int bce = 0;
            String planned_action = "";
            while (connected_sys.next()) {
                table_row = new Vector();
                system_name = connected_sys.getString("conn_component");
                table_row.addElement(system_name.trim());
                bce = connected_sys.getInt("bce");
                if (bce == 0) {
                    table_row.addElement("No");
                }else {
                    table_row.addElement("Yes");    
                }
                planned_action = connected_sys.getString("planned_action");
                table_row.addElement(planned_action.trim());
                this.connected_system_model.addRow(table_row);
            }
            this.connected_system_table.setModel(this.connected_system_model);
            this.prgMonitor.setNormalizedProgress(42);
            conn.close();
            // end code to fill in connected system table
            
            // Forcibly set the divider size of the split pane wrapper to be the same
            // size as when it was instantiated within the default constructor of the
            // AssessmentWindow class.
            JSplitPaneWrapper1.setDividerSize(9);            
            this.buildTree();            
            JSplitPaneWrapper1.setDividerSize(9);
            this.prgMonitor.setNormalizedProgress(46);
            
            // Begin code to set policy results table.
            Vector policy_results_data = new Vector();
            
            conn = this.parent.connectionGenerator();
            policy_results_query = conn.prepareCall("{call get_policy_results_and_text(?)}");
            policy_results_query.setString(1, assessment_id);
            policy_results =  policy_results_query.executeQuery();
            String text_of_ques = "";
            StringBuffer number = null;
            while (policy_results.next()) {
                table_row = new Vector();
                number = new StringBuffer("");
                text_of_ques = policy_results.getString("question_text");
                number.append(policy_results.getInt("major_section") + "." + policy_results.getInt("minor_section") + "." + policy_results.getInt("question_number"));        
                table_row.addElement(number.toString());
                table_row.addElement(text_of_ques.trim());
                if (policy_results.getInt("level1") == 1) {
                    table_row.addElement(new Boolean(true));
                }else {
                    table_row.addElement(new Boolean(false));
                }
                policy_results_data.addElement(table_row);
            }
            // Make explicit call to set the headers of the policy table, this is done to
            // ensure that when the third column is set to be rendered with a CheckBox no
            // ArrayIndexOutOfBoundsException is thrown
            this.setPolicyTableColumnHeaders();
            
            this.policyModel.setDataVector(policy_results_data, this.policy_table_column_headers);
            this.preparePolicyTable();
            // Must add this call in order to ensure that the vector that holds 
            // policy results is properly setup
            conn.close();
            this.prgMonitor.setNormalizedProgress(53);
            // End code to set policy results table
            
            // Begin code to set critical elements table
            conn = this.parent.connectionGenerator();
            critical_results_query = conn.prepareCall("{call get_critical_results(?)}");
            critical_results_query.setString(1, assessment_id);
            critical_results =  critical_results_query.executeQuery();
            this.setCriticalElementTableColumnHeaders();
            Vector critical_element_data = new Vector();
            int na = 0;
            int rbdm = 0;
            int policy = 0;
            int procedures = 0;
            int implemented = 0;
            int tested = 0;
            int integrated = 0;
            QuestionResponse critical_response = null;
            // When putting the critical_element_repsonse back into the appropriate
            // table make sure that you assessemble a QuestionResponse instance for
            // the critical element and insert it in to the class variable:
            // this.critical_element_responses
            while (critical_results.next()) {
                table_row = new Vector();
                number = new StringBuffer("");
                number.append(critical_results.getInt("major_section") + "." + critical_results.getInt("minor_section") + "." + critical_results.getInt("question_number"));
                table_row.addElement(number.toString());
                critical_response = QuestionResponse.createNewResponse(number.toString(), this.getAssessmentName());
                policy = critical_results.getInt("level1");
                procedures = critical_results.getInt("level2");
                implemented = critical_results.getInt("level3");
                tested = critical_results.getInt("level4");
                integrated = critical_results.getInt("level5");
                rbdm = critical_results.getInt("rbdm");
                na = critical_results.getInt("na");
                if (na == 1) {
                    critical_response.setNA(1);
                    table_row.addElement(new Boolean(true));
                }else {
                     table_row.addElement(new Boolean(false));
                }
                if (rbdm == 1) {
                    critical_response.setRBDM(1);
                    table_row.addElement(new Boolean(true));
                }else {
                    table_row.addElement(new Boolean(false));
                }
                if (policy == 1) {
                    critical_response.setITSAF1(1);
                    table_row.addElement(new Boolean(true));
                }else {
                    table_row.addElement(new Boolean(false));
                }
                if (procedures == 1) {
                    critical_response.setITSAF2(1);
                    table_row.addElement(new Boolean(true));
                }else {
                    table_row.addElement(new Boolean(false));
                }
                if (implemented == 1) {
                    critical_response.setITSAF3(1);
                   table_row.addElement(new Boolean(true)); 
                }else {
                   table_row.addElement(new Boolean(false)); 
                }
                if (tested == 1) {
                    critical_response.setITSAF4(1);
                   table_row.addElement(new Boolean(true));  
                }else {
                   table_row.addElement(new Boolean(false)); 
                }
                if (integrated == 1) {
                    critical_response.setITSAF5(1);
                  table_row.addElement(new Boolean(true));   
                }else {
                  table_row.addElement(new Boolean(false));  
                }
                critical_element_data.addElement(table_row);
                // Make sure that you mark this critical element block as completed
                this.question_responseblock_state.put(number.toString(), new Boolean(true));
                this.critical_element_responses.put(number.toString(), critical_response);
            }
            // Make explicit call to set the values of the critical element table headers
            // Even though we call the prepare method after we set the data vectors we still
            // may get an ArrayIndexOutOfBoundsException error when trying to display the table
            // 
            this.setCriticalElementTableColumnHeaders();
            this.criticalElementModel.setDataVector(critical_element_data, critical_table_column_headers);
            this.prepareCriticalElementTable();
            conn.close();
            this.prgMonitor.setNormalizedProgress(65);
            // End code to set critical elements table
            
            // Begin code to set question response hashtable
            conn = this.parent.connectionGenerator();           
            critical_element_listing = conn.prepareCall("{call get_critical_listing(?)}");
            critical_element_listing.setString(1, assessment_id);
            critical_elements = critical_element_listing.executeQuery();
            this.prgMonitor.setNormalizedProgress(74);
            Vector question_responses = null;
            QuestionResponse resp = null;
            int ar = 0;
            StringBuffer number2 = null;
            int maj = 0;
            int min = 0;
            system_number = 0;
            while (critical_elements.next()) {
                Connection conn2 = this.parent.connectionGenerator();
                questions = conn2.prepareCall("{call get_question_results_per_section(?, ?, ?, ?)}");
                questions.setString(1, assessment_id);
                maj = critical_elements.getInt("major_section");
                min = critical_elements.getInt("minor_section");
                system_number = critical_elements.getInt("question_number");
                number2 = new StringBuffer("");
                number2.append(maj + "." + min + "." + system_number);
                questions.setInt(2, maj);
                questions.setInt(3, min);
                questions.setInt(4, system_number);
                question_listing = questions.executeQuery();
                question_responses = new Vector();
                while (question_listing.next()) {                    
                    number = new StringBuffer("");
                    number.append(question_listing.getInt("major_section") + "." + question_listing.getInt("minor_section") + "." + question_listing.getInt("question_number"));
                    resp = QuestionResponse.createNewResponse(number.toString(), this.getAssessmentName());
                    resp.setITSAF1(question_listing.getInt("level1"));
                    resp.setITSAF2(question_listing.getInt("level2"));
                    resp.setITSAF3(question_listing.getInt("level3"));
                    resp.setITSAF4(question_listing.getInt("level4"));
                    resp.setITSAF5(question_listing.getInt("level5"));
                    resp.setRBDM(question_listing.getInt("rbdm"));
                    resp.setComments((question_listing.getString("cmnts")).trim());
                    ar = question_listing.getInt("ar");
                    
                    resp.setNA(question_listing.getInt("na"));
                    if (ar == 1) {
                        // CUT OUT WHITESPACE WITH TRIM() METHOD!
                        resp.assignRespon((question_listing.getString("reviewer")).trim());
                    }
                    
                    if (question_listing.getInt("completed") == 1) {
                        resp.setCompleted(true);    
                    }else {
                        resp.setCompleted(false); 
                    }
                    
                    // When extracting name of assessor who answered question, 
                    // ensure that whitespace is cut out by calling the trim()
                    // method.
                    resp.setAssessor((question_listing.getString("full_name")).trim());
                    question_responses.addElement(resp);
                }
                this.question_responses.put(number2.toString(), question_responses);
                conn2.close();
            }
            conn.close();
            this.prgMonitor.setNormalizedProgress(100);
            // End code to set question_response hashtable
            this.prgMonitor.setVisible(false);
            // display bookmarked question
            if (this.isInformationGatheringComplete()) {
                this.displayQuestion(this.getBookmark());
            }
            JSplitPaneWrapper1.setDividerSize(9);
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("There was a problem importing the assessment you selected.\nThe text of the error is: " + e.toString());
	        e.printStackTrace();
	    }
	}/* end method extractFromDatabase() */
	
	// This file loads an assessment from a binary file with a .dat extension. 
	// It is the same process that is used to backup assessment data to the data
	// directory. The assessment information is contained within an instance of Vector
	// stored in a serialized outfile. So loading the assessment just means reading in 
	// the stored information and setting the appropriate class variables from the 
	// read in values, then displaying the last question on the question map.
	// ---------------	
    // Change Control:
    // 04/17/02 - Had to change spot where assessor who was originally set as primary
    //            when assessment was saved, was being recreated as the secondary assessor
    //            and the person who loaded the assessment (who should have been secondary)
    //            was being though of as primary.
	public void loadAssessment(File file) {
	    try {
	        if (file.exists()) {
	            FileInputStream fis = new FileInputStream(file);
	            ObjectInputStream ois = new ObjectInputStream(fis);
	        
	            Vector save_data = (Vector) ois.readObject();
	            ois.close();
	        
	            this.question_responses = (Hashtable) save_data.elementAt(0);
	            this.question_responseblock_state = (Hashtable) save_data.elementAt(1);
	            this.critical_element_responses = (Hashtable) save_data.elementAt(2);
	            this.assessmentName = (String) save_data.elementAt(3);
	            this.assessment_date_field.setText((String) save_data.elementAt(4));
	        
	            this.primary = (Assessor)  save_data.elementAt(5);
	            this.system = (SystemtoAssess) save_data.elementAt(6);
	            this.system_name_field.setText(this.system.getSystemName());
	            this.system_number_field.setText(this.system.getSystemNumber());
	            this.system_type_box.setSelectedItem((String) this.system.getSystemType());
	            this.aggrpdiv_text_field.setText(this.system.getAgencyGroupDivision());
	        
	            Vector assessor_data_model = (Vector) save_data.elementAt(7);
	            
	            this.assessor_table_model.setDataVector(assessor_data_model, this.assessor_table_headers);       
	            this.assessor_table.setModel(this.assessor_table_model);
	            this.assessor_table.getColumn("Primary").setCellRenderer(new CheckBoxRenderer());    	            
	            this.primary.togglePrimaryAssessor();
	            
	            if (! (this.secondary.getFullName()).equals(this.primary.getFullName())) {
	                this.assessor_table_model.addRow(this.primary.getDataVector());
	            }
	            
	            this.connected_system_model.setDataVector((Vector) save_data.elementAt(8), this.system_table_headers);
	            this.connected_system_table.setModel(this.connected_system_model);
	        
	            this.policy_results = (Vector) save_data.elementAt(9);

                this.progress_model = (DefaultTreeModel) save_data.elementAt(10);                
                this.progress_tree.setCellRenderer(custom_renderer);
                this.progress_tree.setModel(this.progress_model);
                this.setMapStatus(true);
                this.progress_tree.setVisible(true);

	            this.setPolicyTableColumnHeaders();
	            this.policyModel.setDataVector((Vector) save_data.elementAt(11), this.policy_table_column_headers);
	            this.preparePolicyTable();
	            
	            this.setCriticalElementTableColumnHeaders();
	            this.criticalElementModel.setDataVector((Vector) save_data.elementAt(12), this.critical_table_column_headers);
                this.prepareCriticalElementTable();	
            
                this.assessment_objective_field.setText((String) save_data.elementAt(13));	            
	            	                    
                this.system_availability_model.setSelectedItem((String) save_data.elementAt(14));
	            this.system_confidentiality_model.setSelectedItem((String) save_data.elementAt(15));
	            this.system_integrity_model.setSelectedItem((String) save_data.elementAt(16));

	            this.setBookmark((String) save_data.elementAt(17));
	            this.setQuestionProgress(((Integer) save_data.elementAt(18)).intValue() - 1);
	            
	            this.node_map = (Hashtable) save_data.elementAt(19);
	            
	            this.initializeQuestionCount();
	            this.incrementQuestionProgress();
                                
                this.assessembleAssessorResponBox();
		        this.assessembleReviewerResponBox();
                this.setAssessmentType(true);
                if (this.isInformationGatheringComplete()) {
                    this.displayQuestion(this.getBookmark());
                }
                this.setAssessmentType(false);
	            this.setAssessmentStatus(true);            

                this.parent.setServiceName("Self-Assessment");                
                this.setAssessmentName();
                this.setLocalSaveFileName();
                this.setAssessmentSaveTimer();
            }else {
                this.parent.displayErrorDialog("The file you have selected does not seem to exist anymore. Please try again!");    
            }
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not load assessment: " + file.getName() + "!\nThe save data file appears to be corrupted");
	        e.printStackTrace();
	        this.assessment_local_save_timer.stop();
	        this.dispose();
	    }
	}/* end mehtod loadAssessment() */
	
	private void insertNewAssessmentRecord() {
        CallableStatement save_new_assessment = null;
	    try {
            save_new_assessment = this.conn.prepareCall("{call save_assessment (?, ?, ?, ?, ?, ?)}");	        
	    
	        save_new_assessment.setString(1, this.getAssessmentName());
	        save_new_assessment.setString(2, this.assessment_date_field.getText());
	        save_new_assessment.setInt(3, this.getCompleted());
	        save_new_assessment.setString(4, this.getBookmark());
	        save_new_assessment.setString(5, this.primary.getFullName());
	        save_new_assessment.setInt(6, this.getQuestionProgress());
	        save_new_assessment.executeUpdate();
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not save assessment information for " + this.system_name_field.getText() + "\nThe text of the error is:\n" + e.toString());	        
	        this.parent.log(e.toString());
	    }
	}
	
	// Change Control: 02/13/02
	// Added code to take the parameters to this stored procedure and create an instance of
	// SystemtoAssess class out of it. This makes storing the information about the class 
	// easiser
	private void insertNewComponentRecord() {
	    CallableStatement save_new_component = null;
	    try {
            save_new_component = this.conn.prepareCall("{call save_component (?, ?, ?, ?, ?, ?)}");
	    
	        save_new_component.setString(1, this.system_number_field.getText());
	        save_new_component.setString(2, this.getAssessmentName());
	        save_new_component.setString(3, this.aggrpdiv_text_field.getText());
	        save_new_component.setString(4, this.system_name_field.getText());
	        save_new_component.setString(5, ((String) this.system_type_box.getSelectedItem()));
	        save_new_component.setString(6, this.assessment_objective_field.getText());
	        	        
	        save_new_component.executeUpdate();
	        this.system = SystemtoAssess.createNewSystem(this.system_number_field.getText(), this.aggrpdiv_text_field.getText(), this.system_name_field.getText(), (String) this.system_type_box.getSelectedItem());
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not save component information for " + this.system_name_field.getText() + "\nThe text of the error is:\n" + e.toString());
	        e.printStackTrace();
	        this.parent.log(e.toString());
	    }
	}
	
	private void insertNewAssessorRecords() {
        StringBuffer sql = null;
	    CallableStatement save_assessor = null;
	    Vector row = new Vector();
	    
	    StringTokenizer parser = null;
	    try {
            for (int i = 0; i < this.assessor_table_model.getRowCount(); i++) {
                save_assessor = this.conn.prepareCall("{call save_new_assessor (?, ?, ?, ?)}");
                row = (Vector) (this.assessor_table_model.getDataVector()).elementAt(i);
                
                for (int j = 1; j < row.size(); j++) {
                    save_assessor.setString(j, (String) row.elementAt(j));
                }
                save_assessor.setString(4, "N/A");
                save_assessor.executeUpdate();
            }
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not save assessor information! " + e.toString());
	        this.parent.log(e.toString());
	    }
	}
	
	private void insertNewCriticalitiesRecords() {
	    CallableStatement save_criticalities = null;
	    try {
            save_criticalities = this.conn.prepareCall("{call save_component_criticalities (?, ?, ?, ?, ?) }");

            save_criticalities.setString(1, this.getAssessmentName());
            save_criticalities.setString(2, this.system_number_field.getText());
            
            save_criticalities.setString(3, ((String) this.system_confidentiality_model.getSelectedItem()));
            save_criticalities.setString(4, ((String) this.system_integrity_model.getSelectedItem()));
            save_criticalities.setString(5, ((String) this.system_availability_model.getSelectedItem()));
            
            save_criticalities.executeUpdate();
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not store criticality information for " + this.system_name_field.getText() + "\n The text of the error is:\n" + e.toString());
	        this.parent.log(e.toString());
	        e.printStackTrace();
	    }
	}
	
	// Save the contents of the connected system table from the information gathering
	// portion to the database table conn_components by calling the appropriate stored 
	// procedure
	// ---------
	// Change Control:
	// 03/19/02 - Added insertion of assessment_id into the stored procedure parameter list
	//            because the database integrity would be violated the first time someone
	//            tried to assess the same component twice.
	private void insertNewConnectedSystemsRecords() {
	    CallableStatement connected_system = null;
	    String row = "";
	    int bce = 0;
	    StringTokenizer parser = null;
	    Vector table_row = new Vector();
	    String component_name = "";
	    try {
            for (int i = 0; i < this.connected_system_model.getRowCount(); i++) {
                connected_system = this.conn.prepareCall("{call save_connected_components (?, ?, ?, ?, ?)}");
                table_row = (Vector) (this.connected_system_model.getDataVector()).elementAt(i);
                
                connected_system.setString(1, this.getAssessmentName());
                connected_system.setString(2, this.system_number_field.getText());
                component_name = (String) table_row.elementAt(0);
                connected_system.setString(3, component_name);
                
                if (table_row.elementAt(1).equals("Yes")) {
                    bce = 1;
                }
                
                connected_system.setInt(4, bce);
                connected_system.setString(5, (String) table_row.elementAt(2));
                
                connected_system.executeUpdate();
            }
	    }catch (SQLException e) {
	        if ((e.toString()).indexOf("insert duplicate key") != -1) {
	            this.parent.displayErrorDialog("You have already attempted to insert " + component_name + "\ninto the database, it will not be saved now");	     
	            e.printStackTrace();
	            this.parent.log(e.toString());
	        }
	        this.parent.displayErrorDialog("Error encountered when trying to save connected\nsystem information to the database The text of the error is\n" + e.toString());
	        e.printStackTrace();
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("Could not store connected system information for " + this.system_name_field.getText()+ " " + e.toString());	     
	        this.parent.log(e.toString());
	    }
	}/* end method insertNewConnectedSystems() */
	
	public HybridTreeNode findPreviousChild(HybridTreeNode node) {
        HybridTreeNode next_node = null;
        try {
            next_node = (HybridTreeNode) node.getPreviousLeaf();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
        return next_node;
	}
	
	public HybridTreeNode findNextChild(HybridTreeNode node) {
	    HybridTreeNode next_node = null;
	    try {
            next_node = (HybridTreeNode) node.getNextLeaf();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return next_node;
	}
	
	// This method is responsible for inserting a question response into its correct
	// response vector. There are two types of responses that make it to this method 
	// as the parameter @resp, either a brand new response or one that has been modified 
	// already.
	// ---------------
	// Change Control:
	// 05/01/02 - Moved code that set save status of current assessment to true no 
	//            matter what type of response made it into the method as the param resp
	private void processResponse(HybridTreeNode node, QuestionResponse resp) {
        String current_critical_element = "";
        boolean answer_exists = false;
        
        String next_critical_element = "";  
        HybridTreeNode next_node = null;
	    try {
                this.parent.log("processing response for " + resp.getQuestionNumber());                	            
                current_critical_element = this.trimNodeLabel((this.findCriticalElement(node.getFullQuestionNumber())));                
                this.parent.log("the current critical element is: " + this.trimNodeLabel(current_critical_element));                
                if (this.checkPolicyEntry(current_critical_element) && resp.getNA() == 0) {
	                resp.setITSAF1(1);
	            }
	            
	            this.setActiveQuestionResponseVector(current_critical_element);
                answer_exists = questionResponseExists(current_critical_element, resp.getQuestionNumber());
                                
                // Check to see if the response to the current question does not exist, if so
                // then create a response object and store it in the active response vector
                // NOTE: if the active response vector was null to begin with then the response
                //       could not exist.
                if (! answer_exists) {                    
                    this.active_question_responses.addElement(resp);
                    this.question_responses.put(current_critical_element, this.active_question_responses);
                    this.incrementQuestionProgress();
                }else {                    
                    // In this case the response already existed in the response vector                    
                    // Check to see if the question's response has been modified from the
                    // original answer saved, if so, then save the new response overtop
                    // of the old one
                    if (questionResponseModified(this.active_question_responses, resp)) {
                        Boolean block_state = (Boolean) this.question_responseblock_state.get(current_critical_element);
                        if (block_state == null) {
                            this.question_responseblock_state.put(current_critical_element, new Boolean(false));
                        }else {
                            this.question_responseblock_state.remove(current_critical_element);
                            this.question_responseblock_state.put(current_critical_element, new Boolean(false));
                        }                        
                        // Only remove the response vector in question from the response store if the 
                        // response has been modified.
                        this.question_responses.remove(current_critical_element);    
                        this.active_question_responses.remove(this.locateResponse(this.active_question_responses, resp));
                        this.active_question_responses.addElement(resp);
                        this.question_responses.put(current_critical_element, this.active_question_responses);                    
                    }
                }
                this.setAssessmentSaveStatus(true);
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	private void setActiveQuestionResponseVector(String current_critical_element) {
	    try {
            // Get the current active question response vector from memory by critical
            // element number (from the hashtable)
            this.active_question_responses = (Vector) this.question_responses.get(current_critical_element);

            // Check to see if the current active response vector is null
            if (this.active_question_responses == null) {                    
                // If the current response vector is null then this means this question 
                // block has not been answered yet so create a new response vector
                this.parent.log("active question responses are null, creating new response vector now...");
                this.active_question_responses = new Vector(); 
                this.question_responses.put(current_critical_element, this.active_question_responses);
            }	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private QuestionResponse accessCompletedReponse(String question_number) {
	    StringTokenizer parser = new StringTokenizer(question_number, ".");
        StringBuffer critical_element = new StringBuffer("");
        QuestionResponse completed_response = null;
	    try {
	        critical_element.append(parser.nextToken() + "." + parser.nextToken() + ".0");
            Vector response_block = (Vector) this.question_responses.get(critical_element.toString());
            completed_response = (QuestionResponse) response_block.elementAt(this.locateResponse(response_block, question_number));
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return completed_response;
	}
	
	// This method is responsible for determining the index of the instance of
	// question response in the active response vector that matches the gived 
	// question number contained in the parameter @question_number. If no response
	// is located then -1 is returned.
	private int locateResponse(Vector responses, String question_number) {
        int index = -1;
        QuestionResponse resp2 = null;
        try {
            for (int i = 0; i < responses.size(); i++) {
                resp2 = (QuestionResponse) responses.elementAt(i);
                if (resp2 != null) {
                    // Compare the index of the current response you have extracted from
                    // the response store to the question number in question. If they are
                    // equal then you have found your response and return it to the calling
                    // method right away.
                    if (resp2.getQuestionNumber().equals(question_number)) {
                        index = i;
                        return index;
                    }
                }
            }            
        }catch (Exception e) {
            this.parent.log(e.toString());
        }        
        return index;
	}
		
	private int locateResponse(Vector responses, QuestionResponse resp) {
        int index = 0;
        QuestionResponse resp2 = null;
        try {
            for (int i = 0; i < responses.size(); i++) {
                resp2 = (QuestionResponse) responses.elementAt(i);
                if (resp2 != null) {
                    if (resp2.getQuestionNumber().equals(resp.getQuestionNumber())) {
                        index = i;
                    }
                }
            }            
        }catch (Exception e) {
            this.parent.log(e.toString());
        }        
        return index;
	}
	
	private QuestionResponse assessembleResponse(HybridTreeNode node) {
	    QuestionResponse resp =  null;
	    try {
            resp = QuestionResponse.createNewResponse(node.toString(), this.getAssessmentName());	        

            if (this.ITSAF_level1_checkbox.isSelected()) {
                resp.setITSAF1(1);
            }
            if (this.ITSAF_level2_checkbox.isSelected()) {
                resp.setITSAF2(1);
            }
            if (this.ITSAF_level3_checkbox.isSelected()) {
                resp.setITSAF3(1);
            }
            if (this.ITSAF_level4_checkbox.isSelected()) {
                resp.setITSAF4(1);
            }
            if (this.ITSAF_level5_checkbox.isSelected()) {
                resp.setITSAF5(1);
            }                    
            if (this.rbdm_yes_option.isSelected()) {
                resp.setRBDM(1);    
            }
            if (this.rbdm_na_option.isSelected()) {
                resp.setNA(1);
            }
            // Get the value of the comments field but TRIM OUT ANY WHITE SPACE!!!
            resp.setComments((this.comment_field.getText()).trim());
            
            // You must set the person who answered this question every time even if the
            // question complete box was not checked. If they interacted with the question
            // in some way the system must know about that.
            resp.setAssessor((String) this.assign_assessor_choicebox.getSelectedItem());
            
            resp.setVersion(this.getQuestionVersion());
                    
            if (flag_question_checkbox.isSelected()) {                                
                resp.assignRespon((String) flag_for_review_box.getSelectedItem());
            }
                           
            resp.setCompleted(this.question_complete_checkbox.isSelected());    
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return resp;
	}
	
	private boolean questionResponseModified(Vector responses, QuestionResponse resp) {
	    QuestionResponse resp2 = null;
	    boolean flag = false;
	    try {
            for (int i = 0; i < responses.size(); i++) {
                resp2 = (QuestionResponse) responses.elementAt(i);
                if (resp2 != null) {
                    if (resp2.getQuestionNumber().equals(resp.getQuestionNumber())) {
                        if (! (resp2.getAssessor()).equals(resp.getAssessor())) {
                            flag = true;
                        }
                        if (resp2.getRBDM() != resp.getRBDM()) {
                            flag = true;
                        }
                        if (resp2.getITSAF1() != resp.getITSAF1()) {
                            flag = true;
                        }
                        if (resp2.getITSAF2() != resp.getITSAF2()) {
                            flag = true;
                        }
                        if (resp2.getITSAF3() != resp.getITSAF3()) {
                            flag = true;
                        }
                        if (resp2.getITSAF4() != resp.getITSAF4()) {
                            flag = true;
                        }
                        if (resp2.getITSAF5() != resp.getITSAF5()) {
                            flag = true;
                        }
                        if (! (resp2.getComments()).equals(resp.getComments())) {
                            flag = true;
                        }
                        if (resp2.getAssignedResponsibility() != resp.getAssignedResponsibility()) {
                            flag = true;
                        }
                    }
                }
            } 
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return flag;
	}
	
	// This method moves the question pointer forward one space in the assessment
	// Two possible operations should occur here:
	// 1. IF the question has been completed properly than save it in the active response 
	//    store
	// 1a. If the question happens to be the last question in the block then save the block 
	//     out to the database (call the appropriate method), checking to make sure that 
	//     the block was not already saved.
	// 1b. Check the next question number and search the current block for a response. If 
	//     the response exists then load the response answers from memory.
	// 1c. If the next question is in a new block then check the memory store of response 
	//     blocks for the appropriate object. If such an object exists then check that 
	//     response block to see if the next question has been compelted. If so then display 
	//     its answers (call the app. method) 
    // NOTE: all three display possibilities, forward, backwards and random use the same 
    //       internal method to display a question, _displayQuestion( )  
    // ---------------
    // Change Control:
    // 08/06/02 - Added check to prompt for a save when the last question is reached.
    //          - Moved requestFocus of checkbox for ITSAF level 2 to if/then block where
    //            next_node is not null (when end of assessment has not yet been reached)
    //          - inserted code to forcibly store the last active response and compute the 
    //            critical element when the last question has been answered and the next 
    //            button is pressed.
    //          - Added code to set active index of tabs to 4 (the last tab).
    public void questionForward() {        
        QuestionResponse resp = null;   
        HybridTreeNode node = null;
        String current_critical_element = "";
        Boolean block_state = null;
        try {            
            // Check to see if the current question has been completed
            if (this.checkQuestionStateBoxes()) {
                this.internal_setCursor("wait");
                node = this.findQuestionNode(this.question_number_label.getText());
                HybridTreeNode next_node = this.findNextChild(node);
                if (next_node != null) {
                    this.selectNode(this.findNextChild(node));
                    this.ITSAF_level2_checkbox.requestFocus();
                }else {
                    // This next series of steps is designed ONLY to process the response of the
                    // VERY LAST question in the assessment and make sure that it gets saved to 
                    // the last active response vector. It then forcibly computes the critical
                    // element 
                    node = this.findQuestionNode(this.question_number_label.getText());
                    resp = this.assessembleResponse(node);
                    this.clearResponseFields();
                    this.processResponse(node, resp);
                    current_critical_element = this.trimNodeLabel(this.findCriticalElement(node.getFullQuestionNumber()));            
                    this.setActiveQuestionResponseVector(current_critical_element);
                    this.computeCriticalElement(current_critical_element, this.active_question_responses);
                    block_state = new Boolean(true);
                    this.question_responseblock_state.put(current_critical_element, block_state);

                    this.parent.log("when trying to advance to next node, next node was null, assessment is over!!!");
                    int save_reply = JOptionPane.showConfirmDialog(this, 
	    	                         "You have reached the end of the assessment questions, do you want to save your progress?", 
	    	                         "Save Assessment Progress?" , 
	    	                         JOptionPane.YES_NO_OPTION, 
	    	                         JOptionPane.QUESTION_MESSAGE);
                    if (save_reply == JOptionPane.YES_OPTION) {
                        this.saveAssessment();                                                    
                    }
                    this.displayQuestion( node.full_question_number );
                    this.JTabbedPane1.setSelectedIndex(4);
                    
                }
                this.internal_setCursor("default");
            }
        }catch (Exception e) {
            this.parent.displayErrorDialog("ERROR: Encountered when moving current question forward!\n The text of the error is:\n" + e.toString());
            this.parent.log(e.toString());
        }
	} /* end method questionForward() */
	
	boolean questionResponseExists(String critical_element, String next_question_num) {
	    QuestionResponse temp_resp = null;
	    boolean flag = false;
	    try {
	        Vector pertinent_response = (Vector) question_responses.get(this.trimNodeLabel(critical_element));
	        if (pertinent_response != null) {
                for (int i = 0; i < pertinent_response.size(); i++) {
                    temp_resp = (QuestionResponse) pertinent_response.elementAt(i);
                    if (temp_resp != null) {
                        if (temp_resp.getQuestionNumber().equals(next_question_num)) {
                            flag = true;
                            return flag;
                        }
                    }
                }
            }
        }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return flag;
	}
	
	// This method is designed to encapsulate changing the cursor type
	// it is used to show the user that an action is occurring that needs 
	// to pause for.
	private void internal_setCursor(String cursor_type) {
	    try {
	        if (cursor_type.equals("wait")) {
                this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.WAIT_CURSOR));
	        }else  if (cursor_type.equals("default")) {
	            this.setCursor(java.awt.Cursor.getPredefinedCursor(java.awt.Cursor.DEFAULT_CURSOR));
	        }
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}

	private void internalSaveResponse(QuestionResponse resp) {
	    CallableStatement  save_question_block = null;
	    
	    int respon = 0;
	    String who = "";
	    
	    String major = "";
	    String minor = "";
	    String num = "";
	    
	    StringTokenizer parser = null;
	    try {
	        	parser = new StringTokenizer(resp.getQuestionNumber(), ".");
	            
                save_question_block = this.conn.prepareCall("{call insert_assessment_question_response (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)}");	        
            
                save_question_block.setString(1, this.getAssessmentName());
                
                major = parser.nextToken();
                minor = parser.nextToken();
                num = parser.nextToken();
                
                save_question_block.setInt(2, Integer.parseInt(major));
                save_question_block.setInt(3, Integer.parseInt(minor));
                save_question_block.setInt(4, Integer.parseInt(num));
                
                save_question_block.setInt(5, this.getQuestionVersion());
                save_question_block.setInt(6, resp.getITSAF1());
                save_question_block.setInt(7, resp.getITSAF2());
                save_question_block.setInt(8, resp.getITSAF3());
                save_question_block.setInt(9, resp.getITSAF4());
                save_question_block.setInt(10, resp.getITSAF5());
                
                save_question_block.setInt(11, resp.getRBDM());
                save_question_block.setString(12, resp.getComments());
                               
                save_question_block.setInt(13, respon);
                save_question_block.setInt(14, resp.getNA());
                save_question_block.setString(15, who);
                save_question_block.setInt(16, 0);
                save_question_block.executeUpdate();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	} /* end method saveQuestionBlock(Vector block) */
	
	// This method saves a block of question respones to the database. It 
	// is designed to make all of the necessary calls to both the question 
	// responses tables and the assessor accountability table as well.
	//
	// This method only saves the block which is supplied to it. The concept is 
	// that questions must be permitted to be updated an infinite number of times
	// Once a question is saved, if it is updated, it is to be removed from the 
	// active reponse block that it applies to.
	// ----------------------------------------
	// Change Control:
	// 03/16/02 - Added code to save state of Not applicable radio button with question 
	//            response
	// 03/20/02 - Forced to add code to execute insertion into assessor table (tracks who
	//            answered what question) so that assessments could be properly loaded
	//            again from the database.
	// 04/17/02 - Added check when ITSAF level 1 was set to make sure that it still 
	//            had a corresponding policy entry or else the level 1 of the current 
	//            response was reset to null
	// 08/07/02 - Changed code that initially set policy to 1 in database to include a check to
	//            to ensure that response class object was not set to NA first.
	private void saveQuestionBlock(Vector block) {
	    CallableStatement  save_question_block = null;
	    CallableStatement  save_assessor_response = null;
	    QuestionResponse resp = null;
	    
	    int respon = 0;
	    String who = "";
	    
	    String major = "";
	    String minor = "";
	    String num = "";
	    
	    StringTokenizer parser = null;
	    try {
	        this.internal_setCursor("wait");
	        this.parent.setStatusMsg("Saving question block now, please hold");
	        for (int i = 0; i < block.size(); i++) {
	            respon = 0;
	            who = "";
	            resp = (QuestionResponse) block.elementAt(i);
	            
	            parser = new StringTokenizer(resp.getQuestionNumber(), " ");
	            
	            if (parser == null) {
	                parser = new StringTokenizer(resp.getQuestionNumber(), ".");
	            }else {
	               String bare_number = parser.nextToken();
	               parser = new StringTokenizer(bare_number, ".");
	            }
	            
                save_question_block = this.conn.prepareCall("{call insert_assessment_question_response (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)}");	        
                save_assessor_response = this.conn.prepareCall("{call save_answered_question (?, ?, ?, ?, ?, ?)}");	        
            
                save_question_block.setString(1, this.getAssessmentName());
                
                major = parser.nextToken();
                minor = parser.nextToken();
                num = parser.nextToken();

                save_question_block.setInt(2, Integer.parseInt(major));
                save_question_block.setInt(3, Integer.parseInt(minor));
                save_question_block.setInt(4, Integer.parseInt(num));
                
                save_question_block.setInt(5, this.getQuestionVersion());   
                
                // Check the associated policy definition for the question number 
                // currently being saved. If there is suddenly no policy defined 
                // then set ITSAF level1 at 0 instead of 1 and vice versa.
                if (this.checkPolicyEntry(this.trimNodeLabel(this.findCriticalElement(resp.getQuestionNumber()))) && (resp.getNA() != 1)) {
                    resp.setITSAF1(1);
                    save_question_block.setInt(6, resp.getITSAF1());
                }else {
                    resp.setITSAF1(0);
                    save_question_block.setInt(6, resp.getITSAF1());                  
                }

                save_question_block.setInt(7, resp.getITSAF2());
                save_question_block.setInt(8, resp.getITSAF3());
                save_question_block.setInt(9, resp.getITSAF4());
                save_question_block.setInt(10, resp.getITSAF5());
                
                save_question_block.setInt(11, resp.getRBDM());
                save_question_block.setString(12, (resp.getComments()).trim());
                
                if (resp.getAssignedResponsibility() == 1) {
                    respon = 1;
                    who = resp.getResponsibleParty();
                }
                save_assessor_response.setString(1, resp.getAssessor());
                save_assessor_response.setString(2, this.getAssessmentName());
                save_assessor_response.setInt(3, Integer.parseInt(major));
                save_assessor_response.setInt(4, Integer.parseInt(minor));
                save_assessor_response.setInt(5, Integer.parseInt(num));
                save_assessor_response.setInt(6, this.getQuestionVersion());
                save_assessor_response.executeUpdate();              
                
                save_question_block.setInt(13, respon);
                save_question_block.setInt(14, resp.getNA());
                
                if (resp.getNA() == 1) {
                }
                
                save_question_block.setString(15, who);
                save_question_block.setInt(16, resp.isCompleted());
                
                save_question_block.executeUpdate();                
            }            
            this.parent.setStatusMsg("");
            this.internal_setCursor("default");
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("ERROR: Could not save assessment response " + resp.getQuestionNumber() + "!\n The text of the error is:\n" + e.toString());
            e.printStackTrace();
	        this.parent.log(e.toString());
	    }
	} /* end method saveQuestionBlock(Vector block) */
    
    // Set the section label with the current control objective and control area
    // uses Symantec JWrappingLabel object
    // Version 2.00 Change:
    // use string tokenizer and \n to put each entry on its own line
    // Version 3.00 Change:
    // added new label to separate control area and control objective into their
    // own labels, one on top of the other.
    public void setSectionLabel(String new_txt) {
        StringTokenizer parser = null;
        StringBuffer updated_label = new StringBuffer("");
        try {            
            parser = new StringTokenizer(new_txt, ":");
            quesiton_control_area_label.setText(parser.nextToken());
            question_section_label.setText(parser.nextToken());
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    public void setQuestionNumberLabel(String txt) {
        try {
            this.question_number_label.setText(txt);    
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    public void setQuestionText(String txt) {
        try {
            this.question_text_field.setText(txt);
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    public void setCriticalElementLabel(String txt) {
        try {
            this.critical_element_field.setText(this.findCriticalElement(txt));
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    public String findCriticalElement(String question_number) {
        String critical_elem = "";
        StringTokenizer parser = new StringTokenizer(question_number, ".");
        try { 
            String major = parser.nextToken();
            String minor = parser.nextToken();
            if (parser.hasMoreTokens()) {
                String num   = parser.nextToken();
                if (! num.equals("0") || (num.equals("0")&& (minor.equals("0")))) {
                    if (minor.equals("0")) {
                        minor = "1";
                    }
                    HybridTreeNode critical = (HybridTreeNode) this.node_map.get(major + "." + minor + "." + 0);
                    return (critical.getFullQuestionNumber() + " " + critical.getQuestionText());
                }
            }
            
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
        return null;
    }
    
    public void updateBookMark(String new_bookmark, String assessment_id) {
        CallableStatement  bookmark = null;
        try {
            this.parent.log("updating bookmark for assessment now...");
            bookmark = this.conn.prepareCall("{call save_bookmark (?, ?)}");
                        
            
            bookmark.setString(1, new_bookmark);
            bookmark.setString(2, assessment_id);
            
            bookmark.executeUpdate();
        }catch (Exception e) {
            this.parent.log("ERROR: while trying to update the assessment bookmark" + e.toString());
        }
    }    
    
    private HybridTreeNode findQuestionNode(String question_num) {
        HybridTreeNode node = null;
        try {
            node = (HybridTreeNode) this.node_map.get(question_num);
        }catch (Exception e) {
            this.parent.log("ERROR: node does not exist");
            this.parent.log(e.toString());
        }
        return node;
    }     
    
    // internal method to graphically select a node, this is done to show which
    // node is the current question the user is on.
    private void selectNode(HybridTreeNode node) {
        try {
            if (node != null) {
                this.progress_tree.scrollPathToVisible(new TreePath(node.getPath()));
                this.progress_tree.setSelectionPath(new TreePath(node.getPath()));
            }else {
            }
        }catch (Exception e) {
            this.parent.log(e.toString());    
        }
    }
    
    // This method is called when a user wants to look at a question that has 
    // alreay been completed.
    // NOTE: we must allow for the possibility that the user will change their 
    //       answer.
    // Change Control:
    // 03/16/02 - Added code to check to see if NA option was selected and if so 
    //            then to set the radio button appropriately
    private void _displayCompletedQuestion(QuestionResponse resp) {
        try {
            this.parent.log("displaying completed question " + resp.getQuestionNumber());
            HybridTreeNode node = this.findQuestionNode(resp.getQuestionNumber());
            this.setQuestionNumberLabel(node.getFullQuestionNumber());
            this.setQuestionText(node.getQuestionText());
            this.setSectionLabel(node.getSection());
            if (node.isSubordinate()) {
                this.setCriticalElementLabel(resp.getQuestionNumber());    
            }
            this.setITSAFLevels(node);

            if ((resp.getITSAF1() == 1) && (this.checkPolicyEntry(this.trimNodeLabel(this.findCriticalElement(resp.getQuestionNumber()))))) {
                this.ITSAF_level1_checkbox.setSelected(true);
            }

            if (resp.getITSAF2() == 1) {
                this.ITSAF_level2_checkbox.setEnabled(true);
                this.ITSAF_level2_checkbox.setSelected(true);
            }
            if (resp.getITSAF3() == 1) {
                this.ITSAF_level3_checkbox.setEnabled(true);
                this.ITSAF_level3_checkbox.setSelected(true);
            }
            if (resp.getITSAF4() == 1) {
                this.ITSAF_level4_checkbox.setEnabled(true);
                this.ITSAF_level4_checkbox.setSelected(true);
            }
            if (resp.getITSAF5() == 1) {
                this.ITSAF_level5_checkbox.setEnabled(true);
                this.ITSAF_level5_checkbox.setSelected(true);
            }
            
            if (resp.getRBDM() == 1) {
                this.rbdm_yes_option.setSelected(true);
                this.displayRBDMWarning("Risk-based decision made");
            }else {
                this.rbdm_yes_option.setSelected(false);
            }
            
            // When setting the NA radio button ensure that if NA was in fact set that each/
            // ITSAF checkbox must be greyed out so as not to allow a user to select an ITSAF
            // level and NA in the same answer. The action listener attached to the NA radio
            // button will re-enable the checkboxes if the NA radio button is toggled by the user
            if (resp.getNA() == 1) {
                this.displayRBDMWarning("Question non-applicable");
                this.rbdm_na_option.setSelected(true);
                this.toggleQuestionBoxes();
            }else {
                this.rbdm_na_option.setSelected(false);    
            }
            
            this.comment_field.setText(resp.getComments());
            if (resp.getAssignedResponsibility() == 1) {
                resp.setCompleted(false);
                this.flag_question_checkbox.setSelected(true);
                this.flag_for_review_box.setSelectedItem((String) resp.getResponsibleParty());
            }
            if (resp.isCompleted() == 1) {
                this.question_complete_checkbox.setSelected(true);
                this.assign_assessor_choicebox.setSelectedItem((String) resp.getAssessor());
            }
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }/* end method _displayCompletedQuestion(QuestionResponse) */
    
    // This is the method that displays arbitrary questions based on a question number
    // Currently there are 4 operations involved in displaying a question:
    // 1. Set the question number
    // 2. Set the question text
    // 3. set the critical element number/text field based on the question number
    // 4. set the section label    
    private void _displayQuestion(String question_num, HybridTreeNode node) {
        StringTokenizer parser = new StringTokenizer(question_num, " ");
        String bare_question_num = "";
        try { 
            if (parser != null) {
                bare_question_num = parser.nextToken();
                node = this.findQuestionNode(bare_question_num);
                
            }else {
                bare_question_num = question_num;    
            }            
            this.setQuestionNumberLabel(node.getFullQuestionNumber());
            this.setQuestionText(node.getQuestionText());
            this.setSectionLabel(node.getSection());
            
            if (this.checkPolicyEntry(this.trimNodeLabel(this.findCriticalElement(question_num)))) {
                this.ITSAF_level1_checkbox.setSelected(true);
            }
            else
            //// FIX by Vlad... hope it helps.....
            {
                this.ITSAF_level1_checkbox.setSelected(false);	
            }
            
            this.setITSAFLevels(node);    
                
            if (node.isSubordinate()) {
                this.setCriticalElementLabel(bare_question_num);    
            }
            this.selectNode(node);            
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    private void setITSAFLevels(HybridTreeNode node) {
        try {
            if (node.getLevel1() == 1) {
                this.ITSAF_level1_checkbox.setEnabled(false);
            }else {
                this.ITSAF_level1_checkbox.setEnabled(true);
            }
            if (node.getLevel2() == 1) {
                this.ITSAF_level2_checkbox.setEnabled(false);
            }else {
                this.ITSAF_level2_checkbox.setEnabled(true);
                this.ITSAF_level3_checkbox.setEnabled(false);
                this.ITSAF_level4_checkbox.setEnabled(false);
                this.ITSAF_level5_checkbox.setEnabled(false);
            }
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }

    public void level2CheckboxToggled() {
        try {
            if (this.ITSAF_level2_checkbox.isSelected()) {
                this.ITSAF_level2_checkbox.setSelected(true);
                this.ITSAF_level3_checkbox.setEnabled(true);
            }else {                
                this.ITSAF_level2_checkbox.setSelected(false);
                this.ITSAF_level3_checkbox.setSelected(false);
                this.ITSAF_level3_checkbox.setEnabled(false);
                this.ITSAF_level4_checkbox.setSelected(false);
                this.ITSAF_level4_checkbox.setEnabled(false);
                this.ITSAF_level5_checkbox.setSelected(false);
                this.ITSAF_level5_checkbox.setEnabled(false);                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public void level3CheckboxToggled() {
        try {
            if (this.ITSAF_level3_checkbox.isSelected()) {
                this.ITSAF_level3_checkbox.setSelected(true);
                this.ITSAF_level4_checkbox.setEnabled(true);
            }else {
                this.ITSAF_level3_checkbox.setSelected(false);
                this.ITSAF_level4_checkbox.setSelected(false);
                this.ITSAF_level4_checkbox.setEnabled(false);
                this.ITSAF_level5_checkbox.setSelected(false);
                this.ITSAF_level5_checkbox.setEnabled(false);                
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public void level4CheckboxToggled() {
        try {
            if (this.ITSAF_level4_checkbox.isSelected()) {
                this.ITSAF_level4_checkbox.setSelected(true);
                this.ITSAF_level5_checkbox.setEnabled(true);
            }else {
                this.ITSAF_level4_checkbox.setSelected(false);
                this.ITSAF_level5_checkbox.setSelected(false);
                this.ITSAF_level5_checkbox.setEnabled(false);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    } 
    
    // The purpose of this method is to determine which type of question must be displayed 
    // next the choices are either:
    // 1. A question that has been completed
    // 2. A Question that as not been completed yet.
    // This is also the spot when the current question block will be saved if necessary.
    // The parameters to this method are the question numbers that represent the question
    // currently being displayed and the next question to be displayed. If the next question
    // does not have a matching critical element to the current question then the current
    // question block will be saved. 
    // ---------------
    // Change Contorl:
    // 04/17/02 - Added code to set the active question response vector to the 
    //            correct one based on the current critical element. This can then
    //            handle the case when a user has jumped from a section without 
    //            answering any of the questions in it.
    // 05/07/02 - Moved line of code that sets active question response vector outside
    //            of section that was executed only when response did not exist yet other
    //            wise if the question response alreayd existed the critical element was 
    //            computed with the response vector from the previous seciton of questions.
    private void determineQuestionTypeToDisaply(String current_question_num, QuestionResponse current_question_response, String next_question_num) {
        HybridTreeNode next_node = null;
        HybridTreeNode current_node = null;
        QuestionResponse temp_resp = null;
        QuestionResponse completed_resp = null;
        String current_critical_element = "";
        String next_critical_element = "";
        try {
            this.parent.log("determining question type to display now...");
            next_node = this.findQuestionNode(next_question_num);
            next_critical_element = this.trimNodeLabel(this.findCriticalElement(next_node.getFullQuestionNumber()));
            if (current_question_num.length() > 1) {
                current_node = this.findQuestionNode(current_question_num);
                current_critical_element = this.trimNodeLabel(this.findCriticalElement(current_node.getFullQuestionNumber()));            
                this.setActiveQuestionResponseVector(current_critical_element);
            }else {
                this.setActiveQuestionResponseVector(next_critical_element);    
            }
            
            // We must set the active question response vector to the current 
            // seciton of questions no matter what type of reponse has been 
            // computed.
            
            // Check to see if the response to be displayed exists yet, if it does not
            // simply display the text of the question and not the completed response
            if (!this.questionResponseExists(next_critical_element, next_question_num)) {
                this.parent.log("question response does not exist yet");                
                this.parent.log("next critical element is: " + next_critical_element);                
                this.setBookmark(next_node.getFullQuestionNumber());
                this.parent.log("accessing question block save status now...");
                Boolean block_state = (Boolean) this.question_responseblock_state.get(current_critical_element);
                if ((!current_critical_element.equals(next_critical_element)) || (! block_state.booleanValue())) {                    
                    this.computeCriticalElement(current_critical_element, this.active_question_responses);
                    this.parent.log("saving question responses now, question block has not yet been saved et...");
                    block_state = new Boolean(true);
                    this.parent.log("resetting question response block completed status to true");
                    this.question_responseblock_state.put(current_critical_element, block_state);
                }
                this._displayQuestion(next_question_num, next_node); 
            }else {
                // Here the response already exists so you must display the text of
                // the question in addition to the reponse fields.
                this.parent.log("QUESTION RESPONSE ALREADY EXISTS!!");
                this.parent.log("accessing question response vector for " + next_critical_element);
                
                // Begin block of code to locate the response of the question to be displayed
                // from the response vector that corresponds to that section of questions.
                Vector pertinent_response = (Vector) question_responses.get(next_critical_element);                
                if (pertinent_response != null) {
                    for (int i = 0; i < pertinent_response.size(); i++) {
                        temp_resp = (QuestionResponse) pertinent_response.elementAt(i);
                        if (temp_resp != null) {
                              if (temp_resp.getQuestionNumber().equals(next_question_num)) {
                                  this.parent.log("accessed complete response from memory");
                                  completed_resp = temp_resp;
                              }
                         }
                    }
                 // End block of code to access response of question to be displayed from
                 // the response vector that corresponds to the section of questions.
                    this.parent.log("next critical element is: " + next_critical_element);                
                    this.setBookmark(next_node.getFullQuestionNumber());
                    if (current_question_num.length() > 1) {
                        if (!current_critical_element.equals(next_critical_element)) {
                            this.parent.log("saving question responses now...");
                            this.computeCriticalElement(current_critical_element, this.active_question_responses);
                        }
                    }
                    this._displayCompletedQuestion(completed_resp);                    
                }else {
                    this.parent.log("ERROR: cannot access memory store for pre-completed question " + next_question_num);
                    this.parent.log("valid response store for " + next_question_num + " has not been located...");
                }
             }                
        }catch (Exception e) {            
            this.parent.log(e.toString());
        }       
    }/* end method determineQuestionTypeToDisaply(String, String) */
    
    // Method to display random question, chosen by a user from the Assessment map
    // There are 3 possible scenarios in which this method should called:
    // 1. Display a random question at the beginning of the assessment
    // 2. Display a random question during the assessment but you did nothing
    //    to the question you are on.
    // 3. Display a random question during the assessment but you have completed the
    //    question you are on currently.
    //
    // displayQuestion should determine if the question that is to be displayed 
    // has a corresponding answer alredy or not
    //
    // the param @question_num holds the value of the next question to display
    // if the question screen is not empty then the quesiton label holds the value
    // of the current question
    // No matter what happens, the current question must be processed before the 
    // next question is to be displayed
    // ---------------
    // Change Control:
    // 05/06/02 - Changed access of block_state variable to reflect current critical element
    //            instead of next critical element becasuse if block state was found to be
    //            null for next critical element then than an instance of block state was 
    //            saved as false for the current critical element.
    public void displayQuestion(String next_question_num) {        
        String current_question_number = "";
        QuestionResponse resp = null;
        HybridTreeNode node = null;
        String current_critical_element = "";
        String next_critical_element = "";
        HybridTreeNode next_node = null;
        try {       
            if (this.checkQuestionStateBoxes()) {
                // Find the question node that represents the currently displayed question
                // the following instance of node represents the question that is currently on the screen
                this.JTabbedPane1.setSelectedIndex(3);
                node = this.findQuestionNode(this.question_number_label.getText()); 
                current_question_number = this.question_number_label.getText();
                
                this.parent.log("question " + current_question_number + " is completed");
                this.parent.log("about to display new question number " + next_question_num);
                if (current_question_number.equals(next_question_num) || (node == null)) {
                    node = null;
                    next_node = this.findQuestionNode(next_question_num);
                    next_critical_element = this.trimNodeLabel(this.findCriticalElement(next_node.getFullQuestionNumber()));                    
                }else {                    
                    current_critical_element = this.trimNodeLabel(this.findCriticalElement(current_question_number));                                                        
                    next_node = this.findQuestionNode(next_question_num);
                    next_critical_element = this.trimNodeLabel(this.findCriticalElement(next_node.getFullQuestionNumber()));
                    this.parent.log("determining if question block save state has been created yet");
                    Boolean block_state = (Boolean) this.question_responseblock_state.get(current_critical_element);
                    if (block_state == null) {
                        this.parent.log("question block save state has not been created yet, creating now...");                        
                        this.question_responseblock_state.put(current_critical_element, new Boolean(false));
                    }

                }
                if (node != null) {
                    this.parent.log("assessmbling response for current question");
                    resp = this.assessembleResponse(node);
                    this.parent.log("clearing response fields from current response");
                    this.clearResponseFields();
                    // Check to see if the response that represents the user's answer
                    // to the current question has been filled at all
                    if (! resp.isEmpty()) {
                        this.parent.log("about to process response for current question " + current_question_number);
                        this.processResponse(node, resp);
                        this.parent.log("about to determine which type of next question to display");
                        this.determineQuestionTypeToDisaply(current_question_number, resp, next_question_num);                        
                    }else {
                        this.parent.log("current response was empty, cannot process");
                        this.parent.log("about to determine that question to display must be empty");
                        this.determineQuestionTypeToDisaply(current_question_number, resp, next_question_num);
                    }                    
                }else {
                    // No node could be located for the currently displayed question
                    // This should mean that it is the start of the assessment.
                    if (!this.questionResponseExists(next_critical_element, next_question_num)) {
                        this._displayQuestion(next_question_num, next_node);                        
                    }else {
                        this.determineQuestionTypeToDisaply(current_question_number, resp, next_question_num);
                    }
                }
		    }else {
		        this.parent.log("cannot proceed to question: " + next_question_num + " without indicating if you are finished the current question");    
		    }
		}catch (Exception e) {
		    this.parent.displayErrorDialog("Could not display question: " + next_question_num + ". Error message is : " + e.toString());
		    this.parent.log(e.toString());
		    e.printStackTrace();
		}		
    } /* end method displayQuestion(String next_question_num) */

    // Alternate constructor, takes a parameter sTitle, which becomes 
    // the title of the JInternalFrame instance.
	public AssessmentWindow(String sTitle) {
		this();
		setTitle(sTitle);		
	}
	
	public void setVisible(boolean b) {
	    try {
	        if (b) {
	            this.openDataConnection();	            
                this.parent.setStatusModeMsg("AIP");
                this.parent.setStatusMsg("New assessment active...");
	        }	        
	        super.setVisible(b);
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
		
	// Alternate constructor used to set the parent of the current assessment window
	// this is done to take advantage of the functions that the SAT parent provides
	// such as:
	// --------
	// Clipboard access
	// Saving assessments with the familiar save icon
	// Reporting
	// Setting options in real time
	// etc.
	public AssessmentWindow(ASSET parent) {
        this();        
        this.parent = parent;
        this.openDataConnection();
        this.setSystemTypeBox();
	}
	
	public boolean checkPolicyEntry(String critical_element) {
	    boolean flag = false;
	    StringTokenizer parser = null;
	    int policy_number = 0;
	    Vector policy_result = null;
	    try {
	        parser = new StringTokenizer(critical_element, ".");
	        policy_number = Integer.parseInt(parser.nextToken());
	        policy_result = (Vector) (this.policyModel.getDataVector()).elementAt(policy_number - 1);
            if (((Boolean) policy_result.elementAt(2)).booleanValue()) {
                flag = true;
            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return flag;
	}
	
	// This method is responsible for the computation and the display of the critical 
	// element once a subbordinate question section has been completed. The critical
	// element is then stored in the hashtable critical_element_responses variable.
	// ---------------
	// Change Control: 
	// ---------------
	// 02/12/02 - Added in line to remove critical element from hash table if it 
	//            had already been computed this way, two entries cannot end up 
	//            in the table for the same critical element response
	// 04/16/02 - Added code to only insert response into critical element table
	//            if there was one or more respones in the response vector represented
	//            by the @param responses.
	// 05/19/02 - Added line to explicitly set the critical element response NA value to
	//            0 unless a subbordinate response was marked as 1 whereas it would be set
	//            to 1.
	// 05/20/02 - Added to int counters marked_rbdm and marked_na. These track the number ot
	//            responses marked as rbdm and na. After all subbordinate responses are looked
	//            at if these values are greater than or equal to 1 then the critical element
	//            response is automatically set to rbdm and/or na.
	//          - added check that if size of response vector was 0 then critical element shoudl
	//            automatically be set all empty responses.
	// 08/08/02 - Added check for when all questions in section are marked as NA then critical
	//            element is marked as having reached level 0
	public void computeCriticalElement(String critical_element, Vector responses) {
        Vector critical_element_result = new Vector();
        QuestionResponse critical_element_resp = null;
        QuestionResponse temp_resp = null;
        int level2 = 0;
        int level3 = 0;
        int level4 = 0;
        int level5 = 0;
        int marked_rbdm = 0;
        int marked_na = 0;
        int goal_count = responses.size();
        Vector temp1 = new Vector();
        int index = -1;
        try {
            this.internal_setCursor("wait");
            this.parent.setStatusModeMsg("BUSY");
            this.parent.setStatusMsg("Computing critical element now");
            this.prgMonitor.setProgressMax(100);
            this.prgMonitor.clear();

            this.prgMonitor.setStatusBusyMessage("Computing critical element " + critical_element);
            
            critical_element_result.addElement(critical_element);
            
            // First attempt access of the current critical element from the store of 
            // critical element responses...
            critical_element_resp = (QuestionResponse) this.critical_element_responses.get(critical_element);

            // If critical_element_resp is null then create a new instance of it 
            // based on the current critical element otherwise remove it from the 
            // critical element response table.
            if (critical_element_resp == null) {
                critical_element_resp = QuestionResponse.createNewResponse(critical_element, this.getAssessmentName());               
            }else {
                this.critical_element_responses.remove(critical_element);    
            }
            
            if (responses.size() >= 1) {
                this.prgMonitor.setVisible(true);
            }else {
                this.prgMonitor.setVisible(false);
                critical_element_resp.setNA(0);
                critical_element_resp.setRBDM(0);  
                critical_element_resp.setITSAF2(0);
                critical_element_resp.setITSAF4(0);
                critical_element_resp.setITSAF3(0);                    
                critical_element_resp.setITSAF5(0);                
            }            
            
            // Check the policy response table for the current critical element, if
            // a policy is "still" defined then set the policy define setting to 1 
            if (this.checkPolicyEntry(critical_element)) {
                critical_element_resp.setITSAF1(1);
            }else {
                critical_element_resp.setITSAF1(0);
            }
            
            this.prgMonitor.setNormalizedProgress(20);
            for (int i = 0; i < responses.size(); i++) {
                temp_resp = (QuestionResponse) responses.elementAt(i);    
                // First check to see if the stored response was marked as Not applicable
                // If it was then ignore its responses to any ITSAF levels as they should
                // not figure in to the totals
                if (temp_resp.getNA() == 0) {
                    if (temp_resp.getITSAF2() == 1) {
                        level2++;    
                    }                
                    if (temp_resp.getITSAF3() == 1) {
                        level3++;    
                    }                
                    if (temp_resp.getITSAF4() == 1) {
                        level4++;    
                    }                
                    if (temp_resp.getITSAF5() == 1) {
                        level5++;    
                    }                        
                    if (temp_resp.getRBDM() == 1) {
                        marked_rbdm++;
                    }
                }else {
                    // This means that the question being examine currently was marked as NA
                    // This should lower the the number of checkboxes a user must have checked
                    // at a certain ITSAF level in order to have the critical element marked at
                    // that level
                    marked_na++;
                    goal_count--;    
                }
            }
            critical_element_resp.setNA(0);
            critical_element_resp.setRBDM(0);  
            if (marked_rbdm >= 1) {
                critical_element_resp.setRBDM(1);    
            }
            if (marked_na >= 1) {
                critical_element_resp.setNA(1);    
            }
            
            // For the situation where all questions are marked as NA then the policy should
            // not be checked at all, the section should be marked as not having reached any
            // level - This should only occur when all of the subbordinate questions in a 
            //         section have been marked as NA
            if (responses.size() == marked_na) {
                critical_element_resp.setITSAF1(0);
            }
            
            this.prgMonitor.setNormalizedProgress(60);
            if (critical_element_resp.getNA() == 1) {
                critical_element_result.addElement(new Boolean(true));
            }else {
                critical_element_result.addElement(new Boolean(false));
            }
            
            if (critical_element_resp.getRBDM() == 1) {
                critical_element_result.addElement(new Boolean(true));
            }else {
                critical_element_result.addElement(new Boolean(false));
            }
            
            // When checking the totals of how many subbordinate questions have reached the
            // goal level make sure that goal level is not 0 or else all subbordinate questions
            // were marked as NA in their response. In this case the highest level a critical 
            // element can reach is Policy assuming it was checked on the policy tab.
            if (critical_element_resp.getITSAF1() == 1) {
                critical_element_result.addElement(new Boolean(true));
                if ((level2 == goal_count) && (goal_count != 0)) {
                    critical_element_resp.setITSAF2(1);
                    critical_element_result.addElement(new Boolean(true));
                }else {
                    critical_element_resp.setITSAF2(0);
                    critical_element_result.addElement(new Boolean(false));
                }
                this.prgMonitor.setNormalizedProgress(80);
               if ((level3 == goal_count) && (goal_count != 0)) {
                    critical_element_resp.setITSAF3(1);
                    critical_element_result.addElement(new Boolean(true));
                }else {
                    critical_element_resp.setITSAF3(0);
                    critical_element_result.addElement(new Boolean(false));
                }
                this.prgMonitor.setNormalizedProgress(84);
                if ((level4 == goal_count) && (goal_count != 0)) {
                    critical_element_resp.setITSAF4(1);
                    critical_element_result.addElement(new Boolean(true));
                }else {
                    critical_element_resp.setITSAF4(0);
                    critical_element_result.addElement(new Boolean(false));
                }
                this.prgMonitor.setNormalizedProgress(87);
                if ((level5 == goal_count) && (goal_count != 0)) {
                    critical_element_resp.setITSAF5(1);
                    critical_element_result.addElement(new Boolean(true));
                }else {
                    critical_element_resp.setITSAF5(0);
                    critical_element_result.addElement(new Boolean(false));
                }
                this.prgMonitor.setNormalizedProgress(93);
            }else {
                critical_element_result.addElement(new Boolean(false));
                critical_element_result.addElement(new Boolean(false));
                critical_element_resp.setITSAF2(0);
                critical_element_result.addElement(new Boolean(false));
                critical_element_resp.setITSAF3(0);
                critical_element_result.addElement(new Boolean(false));
                critical_element_resp.setITSAF4(0);
                critical_element_result.addElement(new Boolean(false));
                critical_element_resp.setITSAF5(0);
            }
            
            this.prgMonitor.setNormalizedProgress(100);
            this.prgMonitor.setStatusBusyMessage("finalizing...");
            
            index = this.locateCriticalElementInDisplay(this.criticalElementModel.getDataVector(), critical_element);
            if (index == -1) {
                if (responses.size() >= 1) {
                    this.criticalElementModel.addRow(critical_element_result);
                }
            }else {
                if (index == 0) {
                        temp1 = new Vector();
                        temp1.addElement(critical_element_result);
                        for (int i = 1; i < this.criticalElementModel.getDataVector().size(); i++) {
                            temp1.addElement((this.criticalElementModel.getDataVector()).elementAt(i));
                        }                                            
                }else if (index == this.criticalElementModel.getDataVector().size() - 1) {
                        temp1 = new Vector();
                        for (int i = 0; i < (index); i++) {
                            temp1.addElement((this.criticalElementModel.getDataVector()).elementAt(i));    
                        }
                        temp1.addElement(critical_element_result);
                }else {
                        temp1 = new Vector();
                        for (int i = 0; i < index; i++) {
                            temp1.addElement((this.criticalElementModel.getDataVector()).elementAt(i));    
                        }
                        temp1.addElement(critical_element_result);
                        for (int j = (index + 1); j < this.criticalElementModel.getDataVector().size(); j++) {
                            temp1.addElement((this.criticalElementModel.getDataVector()).elementAt(j));
                        }
                }
                this.criticalElementModel.setDataVector(temp1, this.critical_table_column_headers);
                this.prepareCriticalElementTable();
            }
            
            this.critical_element_responses.put(critical_element, critical_element_resp);
            this.prgMonitor.setVisible(false);
            this.parent.setStatusModeMsg("ASMNT");
            this.parent.setStatusMsg("");
            
            Graphics g = this.getGraphics();
            this.update(g);
            this.internal_setCursor("default");
        }catch (Exception e) {
            this.parent.displayErrorDialog("ERROR! The system could not compute critical element\n The text of the error is: " + e.toString());
            e.printStackTrace();
            this.parent.log(e.toString()); 
        }
	}/* end method computeCriticalElement() */
	
	private int locateCriticalElementInDisplay(Vector dataVector, String critical_element) {
	    int flag = -1;
	    Vector temp = null;
	    try {
	        for (int i = 0; i < dataVector.size(); i++) {
	            temp = (Vector) dataVector.elementAt(i);
	            if (((String) temp.elementAt(0)).equals(critical_element)) {
	                flag = i;
	                return flag;
	            }
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	    return flag;
	}

    private void toggleQuestionBoxes() {
        try {
            this.ITSAF_level1_checkbox.setSelected(false);
            this.ITSAF_level2_checkbox.setSelected(false);
            this.ITSAF_level3_checkbox.setSelected(false);
            this.ITSAF_level4_checkbox.setSelected(false);
            this.ITSAF_level5_checkbox.setSelected(false);
            this.rbdm_yes_option.setEnabled(true);
            if (this.rbdm_na_option.isSelected()) {
                this.rbdm_yes_option.setEnabled(false);
                this.ITSAF_level2_checkbox.setEnabled(false);                
                this.ITSAF_level3_checkbox.setEnabled(false);                
                this.ITSAF_level4_checkbox.setEnabled(false);                
                this.ITSAF_level5_checkbox.setEnabled(false);  
                this.question_complete_checkbox.setSelected(true);
            }else {
                if (this.question_number_label.getText().length() > 1) {
                    if (this.checkPolicyEntry(this.trimNodeLabel(this.findCriticalElement(this.question_number_label.getText())))) {
                        this.ITSAF_level1_checkbox.setSelected(true);   
                    }                    
                }
                this.question_complete_checkbox.setSelected(false);
                this.ITSAF_level2_checkbox.setEnabled(true);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    // This method is tasked with actually setting up the connection to the database
    // The connection is held in the class variable this.conn. This method calls the propertyu
    // manager to extract the appropriate variables such as connection string, user name, and
    // password.
    // ---------
    // Change Control 
    // 02/17/02 - Added code to supply the JDBC connection with a user name and password in
    //            addition to the actual connection string.
    // 03/17/02 - Added code to show error dialog when connection could not be established.
    //            When this error occurs the application exits.
    private void openDataConnection() {
        try {
            if (this.parent != null) {
                this.conn = DriverManager.getConnection(this.parent.getPropertyManager().getProperty("sat.data.connstring"), this.parent.getPropertyManager().getProperty("sat.data.username"), this.parent.getPropertyManager().getProperty("sat.data.password"));
            }else {
                this.parent.displayErrorDialog("Could not open connection to ASSET database, exiting now.");
                System.exit(1);
            }
        }catch (Exception e) {
            this.parent.displayErrorDialog("Could not open connection to ASSET database, exiting now.");            
            System.err.println("\nERROR: cannot open connection to SAT data store!");
            System.err.println("\nthis is probably due to the data store being defined \nincorrectly in the operating system settings!");            
            e.printStackTrace();
            this.parent.log(e.toString());
            System.exit(1);
        }
    }/* end method openDataConnection() */
    
    // Change Control 
    // 02/17/02 - Added code to supply the JDBC connection with a user name and password in
    //            addition to the actual connection string.
    private Connection openNewDataConnection() {
        Connection new_conn = null;
        try {
            if (this.parent != null) {
                new_conn = DriverManager.getConnection(this.parent.getPropertyManager().getProperty("sat.data.connstring"), this.parent.getPropertyManager().getProperty("sat.data.username"), this.parent.getPropertyManager().getProperty("sat.data.password"));
            }else {
                System.err.println("cannot initialize new data connection");
                System.exit(1);
            }
        }catch (Exception e) {
             this.parent.displayErrorDialog("\nERROR: cannot open new connection to SAT data store!");
            System.err.println("\nthis is probably due to the data store being defined \nincorrectly in the operating system settings!");            
            this.parent.log(e.toString());
            System.exit(1);
        }
        return new_conn;
    }
    
    public void closeDataConnection() {
        try {
            this.conn.close();
            this.parent.log("\nclosed connection to SAT data store...");
        }catch (Exception e) {
                this.parent.log(e.toString());
        }
    }

    // This is the main method that is called to build/display the assessment map
    // it first checks to see if the associated map file, map.dat exists. If the map
    // exists then the data is de-serialized and displayed on screen in the split 
    // pane else the map must be rebuilt from scratch by calling rebuildTree() below
    public void buildTree() {
        Vector cache_data = null;
        try {
            this.parent.log("checking to see if map data already exists...");
            File check_exists = new File(this.parent.getPropertyManager().getProperty("sat.map.path"));
            if (check_exists.exists()) {
                this.prgMonitor.resetProgress();
                this.prgMonitor.setVisible(true);
                this.prgMonitor.setProgressMax(100);
                this.prgMonitor.setStatusBusyMessage("Accessing question map local cache data to improve performance");
                this.parent.log("map data exists, using pre-cached map data to speed computation");
                this.prgMonitor.progress_bar.setValue(30);
                
                FileInputStream fis = new FileInputStream(this.parent.getPropertyManager().getProperty("sat.map.path"));
                ObjectInputStream ois = new ObjectInputStream(fis);
                this.prgMonitor.progress_bar.setValue(50);

                cache_data = (Vector) ois.readObject();
              
                this.progress_model = (DefaultTreeModel) cache_data.elementAt(0);
                this.progress_tree.setCellRenderer(custom_renderer);
                this.progress_tree.setModel(this.progress_model);
                this.setMapStatus(true);
                
                this.prgMonitor.progress_bar.setValue(70);
                
                this.node_map = (Hashtable) cache_data.elementAt(1);

                this.setPolicyTableColumnHeaders();
                this.policyModel.setDataVector((Vector) cache_data.elementAt(2), this.policy_table_column_headers);
                this.preparePolicyTable();

                this.prgMonitor.progress_bar.setValue(80);
                
                this.prgMonitor.progress_bar.setValue(90);
                
                this.progress_tree.setVisible(true);
                this.parent.log("completed building assessment map, please hold");
                this.prgMonitor.progress_bar.setValue(100);
                    
                this.root_node = (DefaultMutableTreeNode) this.progress_model.getRoot();
            }else {
                this.parent.log("map data does not exist, rebuilding map from scratch");
                this.rebuildTree();
            }
            this.prgMonitor.setVisible(false);
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }/* end method buildTree() */

    // This method builds the data for the assessment question map from scratch. It will 
    // be called when the associated map.dat file is not found, the system is first run, 
    // or the question set has been updated
    // ------------------------------------
    // Change Control:
    // 02/18/02 - Added code to create policy entry in the assessment map. It will be inserted
    //            before the first actual major control area as per a 02/14/02 meeting with NIST
    public void rebuildTree() {
        this.prgMonitor.resetProgress();
        this.prgMonitor.setProgressMax(this.getQuestionCount());
        this.prgMonitor.setVisible(true);
        this.prgMonitor.setStatusBusyMessage("Beginning question map construction...");
        int major_section = 0;
        int minor_section = 0;
        int question_number = 0;
        int control_area_index   = 0;       
        
        int control_obj_count    = 0;
        int cntrl_area_cnt       = 1;
        int critical_elem_count  = 0;
        int question_count       = 0;
        int node_count           = 0;
        
        HybridTreeNode cntrl_area_node  = null;
        HybridTreeNode cntrl_obj        = null;
        HybridTreeNode critical_element = null;
        HybridTreeNode question         = null;
        
        String control_area = "";
        String cntrl_obj_txt    = "";
        String critical_element_text  = "";
        String question_text          = "";
    
        StringBuffer temp = null;
    
        ResultSet cntrl_areas = null;
        ResultSet questions   = null;
        
        Vector cache_data = new Vector();
        Vector cntrl_obj_placeholder = null;
        Vector cntrl_obj_elem_placeholder = new Vector();
        HybridTreeNode policy_node = HybridTreeNode.createNewHybridNode("Policy");
        try {
            this.prgMonitor.setVisible(true);
            this.preparePolicyTable();            
            this.progress_tree.setCellRenderer(custom_renderer);
            this.setMapStatus(true);
            // Instantiate root node and tree model;        
            this.root_node = new DefaultMutableTreeNode("Assessment map");
            // Set root node of tree model
            this.progress_model = new DefaultTreeModel(this.root_node);            

            CallableStatement  cstmt_cntrlareaset = this.conn.prepareCall("{call current_control_areas}");
            cntrl_areas = cstmt_cntrlareaset.executeQuery();
            
            CallableStatement cstmt_questionset = null;
            
            this.progress_model.insertNodeInto(policy_node, this.root_node, 0);
            Connection new_conn = this.openNewDataConnection();
            // Enter into the parent while loop for each of the 3 major control areas
            while (cntrl_areas.next()) {
                this.prgMonitor.setStatusBusyMessage("Extracted question information from data store, assesmbling question map now");
                control_area = cntrl_areas.getString("area_name");
                control_area_index = cntrl_areas.getInt("area_index");
                
                cntrl_area_node = HybridTreeNode.createNewHybridNode(control_area);
                this.progress_model.insertNodeInto(cntrl_area_node, this.root_node, cntrl_area_cnt);
                cntrl_area_cnt += 1;
                
                cstmt_questionset = new_conn.prepareCall("{call current_question_map (?)}");
                cstmt_questionset.setInt(1, control_area_index);
                questions = cstmt_questionset.executeQuery();
                control_obj_count = 0;
                // Enter into the child while loop for each of the questions
                critical_elem_count = 0;
                while (questions.next()) {
                     
                     major_section   = questions.getInt("major_section");
                     minor_section   = questions.getInt("minor_section");
                     question_number = questions.getInt("question_number");
                     question_text   = questions.getString("question_text");
                     
                     temp = new StringBuffer("");
                     temp.append(major_section + ".");
                     temp.append(minor_section + "." + question_number);                     
                     // Conditional Test to determine if the question being processed is a
                     // control objective
                     if ((minor_section == 0)  && (question_number == 0)) {
                         cntrl_obj_elem_placeholder = new Vector();
                         cntrl_obj_elem_placeholder.addElement(temp.toString());
                         cntrl_obj_txt = question_text;
                         cntrl_obj_elem_placeholder.addElement(question_text);
                         cntrl_obj_elem_placeholder.addElement(new Boolean(false)); 
                                                                         
                         cntrl_obj = HybridTreeNode.createNewHybridNode(temp.toString());
                         this.node_map.put(temp.toString(), cntrl_obj);
                         temp.append(" " + question_text);
                         cntrl_obj.setUserObject(temp.toString());
                         cntrl_obj.setFullQuestionNumber(major_section + "." + minor_section + "." + question_number);
                         cntrl_obj.setQuestionText(question_text);
                         cntrl_obj.setSection(control_area + ":" + question_text);
                         
                         cntrl_obj.setLevel1(questions.getInt("itsaf_level1"));
                         cntrl_obj.setLevel2(questions.getInt("itsaf_level2"));
                         cntrl_obj.setLevel3(questions.getInt("itsaf_level3"));
                         cntrl_obj.setLevel4(questions.getInt("itsaf_level4"));
                         cntrl_obj.setLevel5(questions.getInt("itsaf_level5"));
                                                 
                         // 02/09/02 CHANGE CONTROL:
                         // Control objectives are no longer displayed within the tree/
                         // They have been moved to the policy tab, this instruction adds
                         // The appropriate data to the data model for the policy question
                         // table
                         // And then to reload the table with the new changes                         
                         this.policyModel.addRow(cntrl_obj_elem_placeholder);
                         
                         control_obj_count++;                         
                         this.prgMonitor.setNormalizedProgress(node_count++);
                     }else if ((minor_section != 0) && (question_number == 0)) {
                         question_count = 0;
                         critical_element = HybridTreeNode.createNewHybridNode(temp.toString());
                         
                         this.node_map.put(temp.toString(), critical_element); 
                         temp.append(" " + this.padWithNewLines(question_text, 4));
                         critical_element.setUserObject(temp.toString());
                         critical_element.setFullQuestionNumber(major_section + "." + minor_section + "." + question_number);
                         critical_element.setQuestionText(question_text);
                         critical_element.setSection(control_area + ":" +cntrl_obj_txt);

                         critical_element.setLevel1(questions.getInt("itsaf_level1"));
                         critical_element.setLevel2(questions.getInt("itsaf_level2"));
                         critical_element.setLevel3(questions.getInt("itsaf_level3"));
                         critical_element.setLevel4(questions.getInt("itsaf_level4"));
                         critical_element.setLevel5(questions.getInt("itsaf_level5"));
    
                         // 02/09/02 CHANGE CONTROL:
                         // All subordinate questions must be now inserted within their 
                         // corres major control area, the control objectives are now 
                         // going to be presented on their own tab
                         this.progress_model.insertNodeInto(critical_element, cntrl_area_node, critical_elem_count);
                         critical_elem_count += 1;                                                  
                         this.prgMonitor.setNormalizedProgress(node_count++);                         
                     }else if ((minor_section != 0) && (question_number != 0)) {
                         question = HybridTreeNode.createNewHybridNode(temp.toString());
                         this.node_map.put(temp.toString(), question);
                         question.setFullQuestionNumber(major_section + "." + minor_section + "." + question_number);
                         question.setQuestionText(question_text);
                         question.setSection(control_area + ":" +cntrl_obj_txt);
                         question.setisSubordinate(true);
                         
                         question.setLevel1(questions.getInt("itsaf_level1"));
                         question.setLevel2(questions.getInt("itsaf_level2"));
                         question.setLevel3(questions.getInt("itsaf_level3"));
                         question.setLevel4(questions.getInt("itsaf_level4"));
                         question.setLevel5(questions.getInt("itsaf_level5"));
                         
                         this.progress_model.insertNodeInto(question, critical_element, question_count);
                         question_count++;
                         this.node_map.put(temp.toString(), question);
                         this.prgMonitor.setNormalizedProgress(node_count++);                        
                     }
                }
                cstmt_questionset.close();
                control_obj_count = 0;
                critical_elem_count = 0;
            }
            this.prgMonitor.setStatusBusyMessage("Finalizing, please hold");
            cache_data.addElement(this.progress_model);
            cache_data.addElement(this.node_map);
            
            // Dont serialize the policy model to the outfile, only serialize the data vector
            // with the call the .getDataVector()
            cache_data.addElement(this.policyModel.getDataVector());
            
            // When the map has been built it is serialized to the following outfile
            // map.dat. Users must not delete this file to ensure that they don't
            // have to rebuild the map each time they perform an assessment
            FileOutputStream fos = new FileOutputStream("map.dat");
            ObjectOutputStream oos = new ObjectOutputStream(fos);
            oos.writeObject(cache_data);
            oos.close();
            
            this.progress_tree.setModel(this.progress_model);
            new_conn.close();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
        
        this.prgMonitor.setVisible(false);
        this.prgMonitor.clear();
    } /* end rebuildTree() */

	public void addNotify() {
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets and menu bar
		Insets insets = getInsets();
		javax.swing.JMenuBar menuBar = getRootPane().getJMenuBar();
		int menuBarHeight = 0;
		if (menuBar != null)
			menuBarHeight = menuBar.getPreferredSize().height;
		int offset = 0;
		Component comp[] = getComponents();
		for(int i = 0; i < comp.length; ++i) {
			if (comp[i] instanceof javax.swing.JRootPane)
				continue;
			offset += comp[i].getPreferredSize().height;
		}
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height + menuBarHeight + offset);
	}
	
	public void useTodaysDate() {
	    this.assessment_date_field.setText(this.getTodaysDate());
	}

    public String getTodaysDate() {
        java.util.Date today = null;
        try {
            today = new java.util.Date();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
        return today.toString();
    }
    
    public void setPrimaryAssessor(Assessor primary_assessor, Vector data) {
        this.primary = primary_assessor;
        this.assessor_table_model.addRow(data);
    }
    
    private boolean assessorExists(Vector new_assessor) {
        boolean flag = false;
        Vector current_assessors = null;
        Vector assessor_to_examine = null;
        try {
            current_assessors = this.assessor_table_model.getDataVector();
            for (int i = 0; i < current_assessors.size(); i++) {
                assessor_to_examine = (Vector) current_assessors.elementAt(i);
                if (((String) new_assessor.elementAt(1)).equals((String) assessor_to_examine.elementAt(1))) {
                    flag = true;
                    return flag;
                }
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
    }
    
    // This method is designed to check and ensure that the same connected system is
    // not added to a specific assessment. It is used in conjunction with an updated
    // version of the stored procedure that fills the connected system table. The updated
    // version makes use of the DISTINCT keyword.
    private boolean systemExists(Vector new_system) {
        boolean flag = false;
        Vector current_systems = null;
        Vector system_to_examine = null;
        try {
            current_systems = this.connected_system_model.getDataVector();
            for (int i = 0; i < current_systems.size(); i++) {
                system_to_examine = (Vector) current_systems.elementAt(i);
                if (((String) new_system.elementAt(0)).equals((String) system_to_examine.elementAt(0))) {
                    flag = true;
                    return flag;
                }
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        return flag;
    }/* end method systemExists() */  
    
    public void addAssessor(Vector new_assessor) {
        this.parent.setStatusMsg("");
        if (! assessorExists(new_assessor)) {
            this.assessor_table_model.addRow(new_assessor);
        }else {
            this.parent.displayErrorDialog("You have already added this assessor's information\nto this assessment! They will not be added now.");    
        }
    }
    
    // This method is used to add a connected system to the connected system table 
    // for the current assessment. It is called by an instance of the class
    // AddSystemDialog. 
    // ----------------
    // Change Control:
    // 04/30/02 - Added check to ensure that user does not add the same connected
    //            system information more than once.
    public void addSystem(Vector new_system) {
        this.parent.setStatusMsg("");
        if (! systemExists(new_system)) {
            this.connected_system_model.addRow(new_system);
        }else {
            this.parent.displayErrorDialog("You have already added this system's information\nto this assessment! It will not be added now.");
        }
    }
    
    private void displayStatusDialog(String msg) {
        try {
            JOptionPane.showMessageDialog(this, msg, "System Message:", JOptionPane.INFORMATION_MESSAGE);
        }catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    // This method is responsible for saving the entire assessment which in reality once the 
    // information gathering portion of the assessment has been completed only amounts to 
    // saving the answers to each of the questions.
    // ---------------------
    // This method calls the saveQuestionBlock method on each vector of question responses
    // ---------------------
    // Change Control :
    // 02/18/02 - Added call to displayStatusDialog to visually inform the user of the success
    //            of saving the assessment once it has completed...
    // 05/01/02 - Added code to check and see that all information fields where completed before
    //            assessment gets saved. Check calls method isInformationGatheringComplete()
    // 05/08/02 - Added code to set status message and status mode message of parent to reflect 
    //            the save process.
    // 05/11/02 - Added call to compute the critical element of the section that the user was
    //            on right before they pressed the save button. This way if they don't complete
    //            the section they are on or jump to a new section (forcing the critical element
    //            to be computed anyway) it will at least be computed for them.
    public void saveAssessment() {
        Vector local_block = null;
        String critical_element = this.trimNodeLabel(this.findCriticalElement(this.question_number_label.getText()));
        try {
            
            if (isInformationGatheringComplete()) {
                this.setActiveQuestionResponseVector(critical_element);
                this.computeCriticalElement(critical_element, this.active_question_responses);
                this.prgMonitor.clear();
                this.parent.setStatusModeMsg("SAVE");
                this.parent.setStatusMsg("saving assessments results to database, please be patient!");
                this.prgMonitor.setStatusBusyMessage("saving assessments results to database, please be patient!");
                this.prgMonitor.setProgressMax(this.question_responses.size() + this.critical_element_responses.size());
                this.prgMonitor.setVisible(true);
                this.internal_setCursor("wait");            
                this.parent.log("saving entire assessment now...");
                this.assembleAssesmentInfo();
                this.computePolicyResults();

                this.updateBookMark(this.getBookmark(), this.getAssessmentName());

                this.parent.log("saving policy responses now!!");
            
                QuestionResponse resp = null;
                for (int n = 0; n < this.policy_results.size(); n++) {
                    this.parent.log("saving policy response " + (n+1));
                    resp = (QuestionResponse) this.policy_results.elementAt(n);
                    this.internalSaveResponse(resp);
                }
            
                this.parent.log("completed saving policy responses now!!");

                this.parent.log("saving critical element responses now!!");
                Enumeration e1 = this.critical_element_responses.elements();
                int i = 0;
                while (e1.hasMoreElements()) {
                    this.parent.log("about to save response " + i);
                    this.internalSaveResponse((QuestionResponse) e1.nextElement());
                    this.prgMonitor.setNormalizedProgress(i);
                    i++;
                }

                Enumeration e2 = this.question_responses.elements();

                while (e2.hasMoreElements()) {
                    this.parent.log("about to save block " + i);
                    this.saveQuestionBlock((Vector) e2.nextElement());
                    this.prgMonitor.setNormalizedProgress(i);
                    i++;
                }
                this.prgMonitor.setVisible(false);
                this.internal_setCursor("default");
                this.parent.setStatusModeMsg("Idle...");
                this.parent.setStatusMsg("");
                
                this.displayStatusDialog("Assessment saved at: " + new Date().toString());
                this.parent.log("completed save of assessment!");
            }else {
                this.parent.displayErrorDialog("You cannot save an assessment unless you have completed all of the\n necessary information fields describing the system you are assessing.");    
            }
        }catch (Exception e) {
            this.parent.log(e.toString());
            this.parent.displayErrorDialog("CRITICAL ERROR: cannot save assessment, the text of the error is:\ne.toString()");
            {
                this.parent.displayErrorDialog("ASSET System will now exit");
            }
            System.exit(0);
        }
    }/* end method saveAssessment() */
    
    // This method is responsible for accessing the current time from the system clock.
    // It is used in the creation of backup file for the backup file filename.
    // ---------------
    // Change Control: 
    // 02/13/02 - Modified to use the date and time that the assessment actually started
    //            otherwise the local saves would keep creating new files each save 
    //            interval               
    private String getTime() {
        StringBuffer time_stamp = new StringBuffer("");
        try {
            GregorianCalendar calendar = new GregorianCalendar();
            calendar.setTime(this.assessment_start);	
            DecimalFormat twoDigitFormat = new DecimalFormat();
	        twoDigitFormat.setMinimumIntegerDigits(2);

            int hour = calendar.get(calendar.HOUR_OF_DAY);
	        int minute = calendar.get(calendar.MINUTE);
	        int second = calendar.get(calendar.SECOND);
	        int milli_second = calendar.get(calendar.MILLISECOND);
            time_stamp.append(twoDigitFormat.format((hour)) + twoDigitFormat.format((minute)) + twoDigitFormat.format((second)));
       }catch (Exception e) {
           e.printStackTrace();
       }
       return time_stamp.toString();
    }/* end method getTime() */
    
    // Source Code to save assessment data locally before the end of an assessment.
    // This will use the predefined save directory and the name of the assessment
    // to save the serialized question responses and critical element responses to
    // an outfile.
    // -----------
    // What must be saved from this class to properly store the results of an assessment 
    // should the computer crash ? (locally, not to the database in the end)
    // 1. critical_element_responses    - this is the Vector that holds the instances of 
    //    QuestionResponse for the Critical Element questions
    // 2. question_responses            - this is the Hashtable that holds the Vectors for
    //    the subbordinate questions (organized by critical element)
    // 3. question_responseblock_state  - this is the hashtable that holds the status of
    //    saves for each of the question blocks 
    // 4. The assessment name this.getAssessmentName()
    // 5. The start date of the assessment
    // 6. The primary assessor object
    // 7. The object that represents the system being assessed
    // 8. The assessors involved.
    // 9. The connected systems to the system being assessed.
    // 10. Those control objectives the user indicated they had established policy for
    // 11-13. The security ratings for the system (conf, integ, avail);
    //        delivered in alph order.
    // -------------------------------
    // Change Control -
    // 02/18/02 - Added code to check to see if the components that are to be saved are null
    //            and prevent a NullPointerException
    // 03/14/02 - Added code to centralize actions that performs local saves into one file
    //            since more than one method needs to ask for the same type of functionality
    private void saveAssessmentLocally() {        
        String assessment_save_file_name = null;
        try {
            this.internal_setCursor("wait");
            this.parent.setStatusMsg("please hold, backing up assessment data");
            this.parent.log("please hold, backing up assessment data");
            
            this.internalSaveLogic(new File(this.getLocalSaveFileName()));
        
            this.parent.setStatusMsg("");
            this.internal_setCursor("default");
        }catch (Exception e) {
            this.parent.log("ERROR: cannot save assessment data locally.");
            e.printStackTrace();
        }
    }/* end method saveAssessmentLocally() */
    
    // The basic idea behind this method is that in our user interface the data that
    // the user operates on is contained within separate objects, text boxes, strings,
    // hashtables, vectors, etc. We can grab these data objects and serialize them to
    // an outfile very easily. And in reverse reading them back in from the outfile is 
    // also easy to code.
    // ------------------
    // This method is called when the assessment data is to be backed up OR when the user
    // chooses a place to save the assessment data to a serialized outfile.
    private void internalSaveLogic(File save_target) {
        Vector local_save_data = new Vector();        
        try {
            this.parent.setStatusMsg("please hold, backing up assessment data");
            this.parent.log("please hold, backing up assessment data");
            if (this.question_responses != null) {
                    this.parent.log("saving up question responses");
                    local_save_data.addElement(this.question_responses);
            }else {
                    this.parent.log("could not back up question responses since no respones exist yet");    
            }
            
            if (this.question_responseblock_state != null) {
                    this.parent.log("saving up in-memory question response storage");
                    local_save_data.addElement(this.question_responseblock_state);
            }
            
            if (this.critical_element_responses != null) {
                    this.parent.log("saving up critical element responses");
                    local_save_data.addElement(this.critical_element_responses);
           }
            
            if (this.getAssessmentName() != null) {
                    this.parent.log("saving up assessment name");
                    local_save_data.addElement(this.getAssessmentName());
            }
            
            if (this.assessment_date_field.getText() != null) {
                    this.parent.log("saving up assessment start date");
                    local_save_data.addElement(this.assessment_date_field.getText());
            }
            
            if (this.primary != null) {
                    this.parent.log("saving up primary assessor");
                    local_save_data.addElement(this.primary);
            }
            
            if (this.system != null) {
                    this.parent.log("saving up system information");
                    local_save_data.addElement(this.system);
            }
            
            if (this.assessor_table_model != null) {
                    this.parent.log("saving up assessor information");
                    local_save_data.addElement(this.assessor_table_model.getDataVector());
            }

            if (this.connected_system_model != null) {
                    this.parent.log("saving up connected system information");
                    local_save_data.addElement(this.connected_system_model.getDataVector());
            }
            
            if (this.policy_results != null) {
                    this.parent.log("saving up policy question results");
                    local_save_data.addElement(this.policy_results);
            }
            
            if (this.progress_model != null) {
                    this.parent.log("saving up question map model results");
                    local_save_data.addElement(this.progress_model);
            }
            
            if (this.policyModel != null) {
                    this.parent.log("saving up policy question results");
                    local_save_data.addElement(this.policyModel.getDataVector());
            }            
            
            if (this.criticalElementModel != null) {
                local_save_data.addElement(this.criticalElementModel.getDataVector());
            }
            
            local_save_data.addElement(this.assessment_objective_field.getText());
                        
            // The following three elements are the component criticalities being stored
            // they are delivered to the local storage vector in alphabetical order. a-i
            this.parent.log("saving up component criticalities");
       
            local_save_data.addElement((String) this.system_availability_model.getSelectedItem());
            local_save_data.addElement((String) this.system_confidentiality_model.getSelectedItem());
            local_save_data.addElement((String) this.system_integrity_model.getSelectedItem());
            
            local_save_data.addElement(this.getBookmark());
            local_save_data.addElement(new Integer(this.getQuestionProgress()));
                
            local_save_data.addElement(this.node_map);    
                
            FileOutputStream fos = new FileOutputStream(save_target);
            ObjectOutputStream oos = new ObjectOutputStream(fos);
            
            oos.writeObject(local_save_data);
            oos.close();
            this.parent.log("local save now completed, continuing...");            
        }catch (Exception e) {
            this.parent.displayErrorDialog("An error has occurred while trying to save your assessment.\nThe text of the error is: " + e.toString());
            e.printStackTrace();    
        }
    }/* end method internalSaveLogic(File) */
    
    // This static method is designed to parse the extension out of a file name 
    // string using an instance of StringTokenizer.
    static String parseExtension(String file_name) {
        StringTokenizer parser = new StringTokenizer(file_name, ".");
        if (parser.countTokens() < 2) {
            return null;    
        }
        try {
            parser.nextToken();            
        }catch (Exception e) {
            e.printStackTrace();
        }
        return parser.nextToken();
    }
    
    // This method is responsible for asking the user for a name of the file where they
    // wish to save their assessment information. It also checks to see if the file
    // where they want to save their information exists or not. If not they are prompted
    // to save to a different location.
    // ---------------
    // Change Control:
    // 03/14/02 - Added code to move actual logic that saves assessment data to an 
    //            outfile into a separate method since more than one method will call it
    // 05/01/02 - Added code to immediately begin save in else clause if it was determined
    //            that file where user wants to export xml information to does not exist
    private void saveUnfinishedAssessment() {
        String assessment_save_file_name = null;
        Vector local_save_data = new Vector();
        File save_target = null;
        try {
            this.internal_setCursor("wait");
            
            int choice = this.saver.showSaveDialog(this);
            
            // Force a repaint of the user interface so that the spot 
            // where the file chooser dialog was is not grayed out by 
            // delayed repainting.
            Graphics g = this.getGraphics();
            this.update(g);
            
            if (choice == this.saver.APPROVE_OPTION) {
                save_target = this.saver.getSelectedFile();
                
                // Check to see the extension of the file that the user choose to save
                // the assessment with. If the extension is .dat then perform a save in
                // binary format. 
                if (parseExtension(save_target.toString()) == null) {
                    {
                        this.parent.displayErrorDialog("You must include a file extension");    
                        this.saveUnfinishedAssessment();
                    }                    
                }else {
                    if (parseExtension(save_target.toString()).equals("xml")) {
                        // The extension of the file that the user wants to save the assessment
                        // under was xml so perform an XML export.
                        if (save_target.exists()) {
                            int save_reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "This file already exists, are you sure you want to replace it?", 
	    	                                          "Export Active Assessment?" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
			                if (save_reply == JOptionPane.YES_OPTION) {
			                    this.exportAssessment(save_target.toString());    
			                }                                                        
                        }else {
                            // Since the target file the user chose did not exist then simply 
                            // being the save function as planned.
                            this.exportAssessment(save_target.toString());    
                        }
                    } 
                }
            }            
            this.parent.setStatusMsg("");
            this.internal_setCursor("default");            
        }catch (Exception e) {
            this.parent.log("ERROR: cannot save assessment data locally.");
            e.printStackTrace();
        }
    }/* end method saveAssessmentLocally() */    
    
    public void addAssessor(Assessor new_assessor) {
        this.parent.setStatusMsg("");
        
        this.assessor_table_model.addRow(new_assessor.getDataVector());
    }

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	com.symantec.itools.javax.swing.JSplitPaneWrapper JSplitPaneWrapper1 = new com.symantec.itools.javax.swing.JSplitPaneWrapper();
	javax.swing.JScrollPane progress_map_scroll_pane = new javax.swing.JScrollPane();
	javax.swing.JPanel progress_map_panel = new javax.swing.JPanel();
	javax.swing.JTree progress_tree = new javax.swing.JTree();
	javax.swing.JTabbedPane JTabbedPane1 = new javax.swing.JTabbedPane();
	javax.swing.JPanel assessment_id_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane9 = new javax.swing.JScrollPane();
	javax.swing.JPanel JPanel10 = new javax.swing.JPanel();
	javax.swing.JPanel Assessors_Parent_Panel = new javax.swing.JPanel();
	javax.swing.JPanel assessor_table_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane2 = new javax.swing.JScrollPane();
	javax.swing.JTable assessor_table = new javax.swing.JTable();
	javax.swing.JPanel assessor_button_panel = new javax.swing.JPanel();
	javax.swing.JButton add_assessor_button = new javax.swing.JButton();
	javax.swing.JButton addAssessor_help_button = new javax.swing.JButton();
	javax.swing.JPanel JPanel9 = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane8 = new javax.swing.JScrollPane();
	javax.swing.JPanel JPanel11 = new javax.swing.JPanel();
	javax.swing.JButton id_panel_proceed_button = new javax.swing.JButton();
	javax.swing.JPanel InfoGather_Parent_Panel = new javax.swing.JPanel();
	javax.swing.JScrollPane infoGather_scrollpane = new javax.swing.JScrollPane();
	javax.swing.JPanel infoGather_panel = new javax.swing.JPanel();
	javax.swing.JPanel system_Name_parentPanel = new javax.swing.JPanel();
	javax.swing.JPanel component_identification_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel1 = new javax.swing.JLabel();
	javax.swing.JTextField system_name_field = new javax.swing.JTextField();
	javax.swing.JLabel JLabel16 = new javax.swing.JLabel();
	javax.swing.JTextField system_number_field = new javax.swing.JTextField();
	javax.swing.JLabel JLabel2 = new javax.swing.JLabel();
	javax.swing.JComboBox system_type_box = new javax.swing.JComboBox();
	javax.swing.JLabel JLabel4 = new javax.swing.JLabel();
	javax.swing.JTextField aggrpdiv_text_field = new javax.swing.JTextField();
	javax.swing.JLabel JLabel3 = new javax.swing.JLabel();
	javax.swing.JTextField assessment_date_field = new javax.swing.JTextField();
	javax.swing.JPanel criticality_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel5 = new javax.swing.JLabel();
	javax.swing.JComboBox system_confidentiality_box = new javax.swing.JComboBox();
	javax.swing.JLabel JLabel6 = new javax.swing.JLabel();
	javax.swing.JComboBox system_integrity_box = new javax.swing.JComboBox();
	javax.swing.JLabel JLabel7 = new javax.swing.JLabel();
	javax.swing.JComboBox system_availability_box = new javax.swing.JComboBox();
	javax.swing.JPanel connectedSystemParent_panel = new javax.swing.JPanel();
	javax.swing.JPanel connected_system_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane3 = new javax.swing.JScrollPane();
	javax.swing.JTable connected_system_table = new javax.swing.JTable();
	javax.swing.JPanel conn_system_button_panel = new javax.swing.JPanel();
	javax.swing.JButton conn_system_add_button = new javax.swing.JButton();
	javax.swing.JButton conn_system_help_button = new javax.swing.JButton();
	javax.swing.JPanel proceed_to_assessment_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel23 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel21 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel22 = new javax.swing.JPanel();
	javax.swing.JButton infoGather_previous_button = new javax.swing.JButton();
	javax.swing.JButton proceed_to_assessment_button = new javax.swing.JButton();
	javax.swing.JPanel policy_parent_panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane6 = new javax.swing.JScrollPane();
	javax.swing.JPanel JPanel28 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel7 = new javax.swing.JPanel();
	javax.swing.JLabel policy_label = new javax.swing.JLabel();
	javax.swing.JScrollPane JScrollPane10 = new javax.swing.JScrollPane();
	javax.swing.JTable policy_question_table = new javax.swing.JTable();
	javax.swing.JPanel JPanel6 = new javax.swing.JPanel();
	javax.swing.JButton policy_previous_button = new javax.swing.JButton();
	javax.swing.JButton policy_next_button = new javax.swing.JButton();
	javax.swing.JPanel Question_Parent_Panel = new javax.swing.JPanel();
	javax.swing.JScrollPane question_scrollpane = new javax.swing.JScrollPane();
	javax.swing.JPanel question_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel1 = new javax.swing.JPanel();
	javax.swing.JPanel question_presentation_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel12 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel18 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel17 = new javax.swing.JLabel();
	javax.swing.JLabel question_number_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel21 = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane11 = new javax.swing.JScrollPane();
	javax.swing.JTextArea question_text_field = new javax.swing.JTextArea();
	javax.swing.JPanel JPanel13 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel17 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel22 = new javax.swing.JLabel();
	javax.swing.JLabel quesiton_control_area_label = new javax.swing.JLabel();
	javax.swing.JLabel question_section_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel20 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel18 = new javax.swing.JLabel();
	javax.swing.JScrollPane JScrollPane4 = new javax.swing.JScrollPane();
	javax.swing.JTextArea critical_element_field = new javax.swing.JTextArea();
	javax.swing.JPanel JPanel25 = new javax.swing.JPanel();
	javax.swing.JPanel ITSAF_Parent_Panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel19 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel9 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel16 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel14 = new javax.swing.JPanel();
	javax.swing.JCheckBox ITSAF_level1_checkbox = new javax.swing.JCheckBox();
	javax.swing.JCheckBox ITSAF_level2_checkbox = new javax.swing.JCheckBox();
	javax.swing.JCheckBox ITSAF_level3_checkbox = new javax.swing.JCheckBox();
	javax.swing.JCheckBox ITSAF_level4_checkbox = new javax.swing.JCheckBox();
	javax.swing.JCheckBox ITSAF_level5_checkbox = new javax.swing.JCheckBox();
	javax.swing.JLabel JLabel14 = new javax.swing.JLabel();
	javax.swing.JRadioButton rbdm_na_option = new javax.swing.JRadioButton();
	javax.swing.JPanel rbdm_choice_panel = new javax.swing.JPanel();
	javax.swing.JLabel JLabel11 = new javax.swing.JLabel();
	javax.swing.JRadioButton rbdm_yes_option = new javax.swing.JRadioButton();
	javax.swing.JLabel rbdm_warning_label = new javax.swing.JLabel();
	javax.swing.JPanel JPanel3 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel8 = new javax.swing.JLabel();
	javax.swing.JScrollPane JScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JTextArea comment_field = new javax.swing.JTextArea();
	javax.swing.JPanel JPanel33 = new javax.swing.JPanel();
	javax.swing.JPanel question_options_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel5 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel10 = new javax.swing.JLabel();
	javax.swing.JComboBox assign_assessor_choicebox = new javax.swing.JComboBox();
	javax.swing.JPanel question_option_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel8 = new javax.swing.JPanel();
	javax.swing.JPanel final_question_options_panel = new javax.swing.JPanel();
	javax.swing.JCheckBox question_complete_checkbox = new javax.swing.JCheckBox();
	javax.swing.JLabel JLabel20 = new javax.swing.JLabel();
	javax.swing.JCheckBox flag_question_checkbox = new javax.swing.JCheckBox();
	javax.swing.JComboBox flag_for_review_box = new javax.swing.JComboBox();
	javax.swing.JPanel JPanel15 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel26 = new javax.swing.JPanel();
	javax.swing.JButton question_back_button = new javax.swing.JButton();
	javax.swing.JButton question_response_clear_button = new javax.swing.JButton();
	javax.swing.JButton questions_help_button = new javax.swing.JButton();
	javax.swing.JButton question_next_button = new javax.swing.JButton();
	javax.swing.JPanel Summary_Parent_Panel = new javax.swing.JPanel();
	javax.swing.JScrollPane JScrollPane5 = new javax.swing.JScrollPane();
	javax.swing.JPanel summary_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel2 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel12 = new javax.swing.JLabel();
	javax.swing.JProgressBar assessment_progress_bar = new javax.swing.JProgressBar();
	javax.swing.JLabel JLabel13 = new javax.swing.JLabel();
	javax.swing.JPanel JPanel4 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel29 = new javax.swing.JPanel();
	javax.swing.JLabel JLabel15 = new javax.swing.JLabel();
	javax.swing.JScrollPane JScrollPane7 = new javax.swing.JScrollPane();
	javax.swing.JTable crit_elem_resp_table = new javax.swing.JTable();
	javax.swing.JPanel summary_options_panel = new javax.swing.JPanel();
	javax.swing.JPanel JPanel27 = new javax.swing.JPanel();
	javax.swing.JPanel JPanel30 = new javax.swing.JPanel();
	javax.swing.JButton save_assessment_button = new javax.swing.JButton();
	javax.swing.JButton export_button = new javax.swing.JButton();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder1 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon printIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder1 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder2 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder3 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder4 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel system_type_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.models.StringComboBoxModel system_confidentiality_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.models.StringComboBoxModel system_integrity_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.models.StringComboBoxModel system_availability_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.borders.EmptyBorder assessor_table_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder comment_pane_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.BevelBorder bevelBorder1 = new com.symantec.itools.javax.swing.borders.BevelBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder question_text_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder button_panel = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel boundary_controls_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder1 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder2 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel assign_assessor_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder3 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.models.StringListModel publication_reference_list_model = new com.symantec.itools.javax.swing.models.StringListModel();
	com.symantec.itools.javax.swing.borders.EmptyBorder itsaf_panel_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder assessor_table_border2 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder2 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder5 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.models.StringComboBoxModel flag_for_review_model = new com.symantec.itools.javax.swing.models.StringComboBoxModel();
	com.symantec.itools.javax.swing.borders.EtchedBorder etchedBorder3 = new com.symantec.itools.javax.swing.borders.EtchedBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder4 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder5 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder progress_bar_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	javax.swing.JPopupMenu text_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem JMenuItem3 = new javax.swing.JMenuItem();
	javax.swing.JMenuItem JMenuItem1 = new javax.swing.JMenuItem();
	javax.swing.JMenuItem JMenuItem2 = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder6 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder7 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder status_bar_border = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.TitledBorder titledBorder6 = new com.symantec.itools.javax.swing.borders.TitledBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder8 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder9 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.icons.ImageIcon nextIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon previousIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon helpIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon deleteIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon saveIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon examineIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.icons.ImageIcon plusIcon = new com.symantec.itools.javax.swing.icons.ImageIcon();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder10 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder11 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	javax.swing.JPopupMenu assessment_objective_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem cutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem copyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem pasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JSeparator JSeparator1 = new javax.swing.JSeparator();
	javax.swing.JMenuItem selectAllMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu systemNamePopup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem system_name_cutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem system_name_copyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem system_name_pasteMenuItem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu systemnum_popup_field = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem systemnum_cut_menuitem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem systemnum_copy_menuitem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem systemnum_paste_menuitem = new javax.swing.JMenuItem();
	javax.swing.JPopupMenu aggrpdiv_popup = new javax.swing.JPopupMenu();
	javax.swing.JMenuItem aggrpdiv_cutMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem aggrpdiv_copyMenuItem = new javax.swing.JMenuItem();
	javax.swing.JMenuItem aggrpdiv_pasteMenuItem = new javax.swing.JMenuItem();
	com.symantec.itools.javax.swing.borders.EmptyBorder emptyBorder12 = new com.symantec.itools.javax.swing.borders.EmptyBorder();
	//}}
	javax.swing.JTextArea assessment_objective_field = new javax.swing.JTextArea() {
	
	    public boolean isManagingFocus() {
	        return true;    
	    }
	
	};	
	Vector policy_table_column_headers = new Vector();
	Vector critical_table_column_headers = new Vector();
	int completed = 0;
	DefaultTableModel connected_system_model = new DefaultTableModel() {
	    public boolean isCellEditable(int row, int column) {
            if (column == 0) {
                return false;
            }
            return true;
        }
 
 	    public void setValueAt(Object aValue, int row, int column) {
            ((Vector)dataVector.elementAt(row)).setElementAt(aValue, column);
		    fireTableCellUpdated(row, column);
	    }	    
	};
	DefaultTableModel assessor_table_model = new DefaultTableModel() {
	    public boolean isCellEditable(int row, int column) {
            if (column == 0) {
                return false;
            }else if (column == 1) {
                return false;
            }
            return true;
        }
 
 	    public void setValueAt(Object aValue, int row, int column) {
            ((Vector)dataVector.elementAt(row)).setElementAt(aValue, column);
		    fireTableCellUpdated(row, column);
	    }
	};	    
	JFileChooser saver = new JFileChooser();
	String bookmark = "1.1.1";
    DefaultMutableTreeNode root_node = new DefaultMutableTreeNode("Assessment Questions");
    DefaultTreeModel progress_model = new DefaultTreeModel(root_node);
    AddAssessorDialog assessor_record_window = null;
    ASSET parent = null;
    Connection conn = null;
    ProgressDialog prgMonitor = null;
    Assessor primary = null;
    Assessor secondary = null;
    DefaultTableModel policyModel = new DefaultTableModel() {
        public boolean isCellEditable(int row, int column) {
            if (column == 2) {
                return true;
            }
            return false;
        }
    };
    DefaultTableModel criticalElementModel = new DefaultTableModel() {
        public boolean isCellEditable(int row, int column) {
            return false;
        }        
    };
    private int total_ques_count = 0;
    private int ques_progress    = 1;
    static int acceptable_comment_length = 10;
    JCheckBox checkbox_editor = new JCheckBox();
    boolean new_assessment = true;
    String local_save_file_name = "";
    private int version = 0;
    public final static int ONE_SECOND = 1000;
    public final static int ONE_MINUTE = 60;
    public String assessmentName = "";
    SystemtoAssess system = null;
    private boolean map_status = false;
    public Hashtable node_map = new Hashtable();
    Date assessment_start = null;
    public Hashtable question_responses = new Hashtable();
    public Hashtable critical_element_responses = new Hashtable();
    Vector policy_results = new Vector();
    Vector active_question_responses = new Vector();
    javax.swing.Timer assessment_local_save_timer = null;
    private boolean assessment_active = false;
    Hashtable question_responseblock_state = new Hashtable();
    private boolean assessment_save_state = false;
    QuestionCellRender custom_renderer = new QuestionCellRender();
    Vector assessor_table_headers = new Vector();
    Vector system_table_headers = new Vector();
    boolean policy_completed = false;
    //
    
    public void setPolicyCompleted(boolean flag) {
        this.policy_completed = flag;    
    }
    
    public boolean getPolicyCompleted() {
        return this.policy_completed;    
    }
    
    public int getCompleted() {
        return this.completed;    
    }
    
    public void setCompleted(int iscompleted) {
        this.completed = iscompleted;    
    }
    
    public void setBookmark(String bookmark) {
        this.bookmark = bookmark;    
    }
    
    public String getBookmark() {
        return this.bookmark;    
    }
    
    public void setSecondaryAssessor(Assessor secondary) {
        this.secondary = secondary;    
        this.secondary.setPrimaryAssessor(false);
    }
    
    public Assessor getSecondaryAssessor() {
        return this.secondary;
    }
    // This method grabs the responses that users enter for the policy tab prior to answering
    // assessment questions. The checkbox is represented by an instance of Boolean where true
    // equals a checked box and false equals an unchecked box.
    // Change Control:
    // 02/19/02 - Changed instantiation of temporary question response that holds policy
    //            response entererd by user. Used explicit call to setQuestionNumber() to
    //            remove StringTokenizer NoSuchElementExceptions within internalSaveRepsonse()
    private void computePolicyResults() {
        StringTokenizer parser = null;
        Vector temp_vector = null;
        QuestionResponse temp_resp = null;
        try {
            this.parent.log("computing policy results now...");
            if ((policy_results = (Vector) this.question_responses.get("policy")) == null) {
                policy_results = new Vector();
                this.parent.log("policy results don't exist in response store yet");
                this.parent.log("creating new instance of it");
            }else {
                this.parent.log("removing current policy answers from response store now!");
                this.question_responses.remove("policy");
                policy_results = new Vector();
            }
            for (int i = 0; i < this.policyModel.getRowCount(); i++) {
                this.parent.log("processing policy number " + (i + 1));
                temp_vector = ((Vector) this.policyModel.getDataVector().elementAt(i));
                temp_resp = QuestionResponse.createNewResponse(this.getAssessmentName());
                temp_resp.setQuestionNumber((String) temp_vector.elementAt(0));
                
                temp_resp.setAssessor(this.primary.getFullName());
                temp_resp.setAssessmentID(this.getAssessmentName());
                if (((Boolean) temp_vector.elementAt(2)).booleanValue()) {
                    temp_resp.setITSAF1(1);
                }
                policy_results.addElement(temp_resp);
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }/* end method computePolicuResults() */
    
    private void setAssessmentSaveTimer() {
        try {
            // Set the save interval 
            this.parent.log("setting Timer to save assessment locally now...");
            int elapsed_time = (ONE_SECOND * ONE_MINUTE) * (Integer.parseInt(this.parent.getPropertyManager().getProperty("sat.assessment.save.interval")));
            this.assessment_local_save_timer = new javax.swing.Timer(elapsed_time, new SymRepeatAction());
            this.assessment_local_save_timer.start();
        }catch (Exception e) {
            this.parent.displayErrorDialog("Could not start backup timer, the text of the error is\n" + e.toString());
            e.printStackTrace();    
        }           
    }
    
    public String getLocalSaveFileName() {
        return this.local_save_file_name;    
    }
    
    public void setLocalSaveFileName() {
        this.local_save_file_name = this.parent.getAbsolutePath(this.parent.getPropertyManager().getProperty("sat.assessment.save.path") + File.separator + this.primary.getFullName() + this.system.getSystemName() + this.getTime() + ".dat");   
    }
    
    public boolean getAssessmentStatus() {
        return this.assessment_active;
    }
    
    public boolean getAssessmentSaveStatus() {
        return this.assessment_save_state;    
    }
    
    public void setAssessmentSaveStatus(boolean new_status) {
        this.assessment_save_state = new_status;
    }
    
    public void setAssessmentStatus(boolean status) {
        this.assessment_active = status;
    }
    
    public boolean getMapStatus() {
        return this.map_status;
    }
    
    public void setMapStatus(boolean new_state) {
        this.map_status = new_state;
    }
    
    public void setAssessmentName() {
        this.assessmentName = this.primary.getFullName() + this.system_name_field.getText() + this.assessment_date_field.getText();
    }
    
    public void setAssessmentName(String new_name) {
        this.assessmentName = new_name;    
    }
    
    public String getAssessmentName() {
        return this.assessmentName;
    }
    
    private int getQuestionVersion() {
        return this.version;    
    }

    private void setQuestionVersion(int ver) {
        this.version = ver;    
    }

    public void setTitle() {
        try {
            this.setTitle(this.system_name_field.getText() + " assessment in progress...");            
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
    }
    
    private void setAssessmentType(boolean flag) {
        this.new_assessment = flag;   
    }
    
    private boolean getAssessmentType() {
        return this.new_assessment;
    }
    
    private void setQuestionCount(int count) {
        this.total_ques_count = count;   
    }
    
    int getQuestionCount() {
        return this.total_ques_count;
    }
    
    private void setQuestionProgress(int count) {
        this.ques_progress = count;   
    }
    
    private void incrementQuestionProgress() {
        this.ques_progress++;
        if (this.ques_progress == this.getQuestionCount()) {
            this.setCompleted(1);
        }
        float percent_complete = (float) ques_progress / this.getQuestionCount();
        int value = (int) (percent_complete * 100);                
        
        this.assessment_progress_bar.setString("");
        
        this.question_next_button.setToolTipText("<html>Advance to the next question" + ", " + this.assessment_progress_bar.getString() + "</html>");
        this.question_back_button.setToolTipText("<html>Return to the previous question" + ", " + this.assessment_progress_bar.getString() + "</html>");

        this.setTitle(this.system_name_field.getText() + " assessment in progress " + this.assessment_progress_bar.getString());

        this.assessment_progress_bar.setValue(value);
        this.assessment_progress_bar.repaint();
    }
    
    private int getQuestionProgress() {
        return this.ques_progress;
    }
    
    private void decrementQuestionProgress() {
        this.ques_progress--;
        if (this.ques_progress == this.getQuestionCount()) {
            this.setCompleted(1);
        }
        float percent_complete = (float) ques_progress / this.getQuestionCount();
        int value = (int) (percent_complete * 100);                
        
        this.assessment_progress_bar.setString("");
        
        this.question_next_button.setToolTipText("<html>Advance to the next question" + ", " + this.assessment_progress_bar.getString() + "</html>");
        this.question_back_button.setToolTipText("<html>Return to the previous question" + ", " + this.assessment_progress_bar.getString() + "</html>");

        this.setTitle(this.system_name_field.getText() + " assessment in progress " + this.assessment_progress_bar.getString());

        this.assessment_progress_bar.setValue(value);
        this.assessment_progress_bar.repaint();        
    }
    
	class SymMouse extends java.awt.event.MouseAdapter {
	    
		public void mouseExited(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == JLabel5)
				JLabel5_mouseExited(event);
			else if (object == JLabel6)
				JLabel6_mouseExited(event);
			else if (object == JLabel7)
				JLabel7_mouseExited(event);
			else if (object == JLabel1)
				JLabel1_mouseExited(event);
			else if (object == JLabel2)
				JLabel2_mouseExited(event);
			else if (object == JLabel3)
				JLabel3_mouseExited(event);
			else if (object == JLabel16)
				JLabel16_mouseExited(event);
			else if (object == policy_label)
				policyLabel_mouseExited(event);
			else if (object == ITSAF_level2_checkbox)
				ITSAFLevel2Checkbox_mouseExited(event);
			else if (object == ITSAF_level3_checkbox)
				ITSAFLevel3Checkbox_mouseExited(event);
			else if (object == ITSAF_level4_checkbox)
				ITSAFLevel4Checkbox_mouseExited(event);
			else if (object == ITSAF_level1_checkbox)
				ITSAFLevel1Checkbox_mouseExited(event);
			else if (object == ITSAF_level5_checkbox)
				ITSAFLevel5Checkbox_mouseExited(event);
			else if (object == JLabel4)
				JLabel4_mouseExited(event);
			
		}

		public void mouseEntered(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == JLabel5)
				JLabel5_mouseEntered(event);
			else if (object == JLabel6)
				JLabel6_mouseEntered(event);
			else if (object == JLabel7)
				JLabel7_mouseEntered(event);
			else if (object == JLabel1)
				JLabel1_mouseEntered(event);
			else if (object == JLabel2)
				JLabel2_mouseEntered(event);
			else if (object == JLabel3)
				JLabel3_mouseEntered(event);
			else if (object == JLabel16)
				JLabel16_mouseEntered(event);
			else if (object == policy_label)
				policyLabel_mouseEntered(event);
			else if (object == ITSAF_level2_checkbox)
				ITSAFLevel2Checkbox_mouseEntered(event);
			else if (object == ITSAF_level3_checkbox)
				ITSAFLevel3Checkbox_mouseEntered(event);
			else if (object == ITSAF_level4_checkbox)
				ITSAFLevel4Checkbox_mouseEntered(event);
			else if (object == ITSAF_level1_checkbox)
				ITSAFLevel1Checkbox_mouseEntered(event);
			else if (object == ITSAF_level5_checkbox)
				ITSAFLevel5Checkbox_mouseEntered(event);
			else if (object == JLabel4)
				JLabel4_mouseEntered(event);
			
		}/* end inner-class method mouseEntered(MouseEvent)*/

		public void mouseClicked(java.awt.event.MouseEvent event) {
			Object object = event.getSource();
			if (object == JLabel5)
				JLabel5_mouseClicked(event);
			else if (object == JLabel6)
				JLabel6_mouseClicked(event);
			else if (object == JLabel7)
				JLabel7_mouseClicked(event);
			else if (object == ITSAF_level1_checkbox)
				ITSAFLevel1Checkbox_mouseClicked(event);
			else if (object == ITSAF_level2_checkbox)
				ITSAFLevel2Checkbox_mouseClicked(event);
			else if (object == JLabel16)
				JLabel16_mouseClicked(event);
			else if (object == JLabel4)
				JLabel4_mouseClicked(event);
			else if (object == JLabel1)
				JLabel1_mouseClicked(event);
			else if (object == JLabel2)
				JLabel2_mouseClicked(event);
			else if (object == policy_label)
				policyLabel_mouseClicked(event);
			else if (object == policy_question_table)
				policyQuestionTable_mouseClicked(event);
						
		}
	}/* end inner-class SymMouse() */
	
	public void setRBDMWarningLabel(String warning_txt) {
	    this.rbdm_warning_label.setText(warning_txt);
	    this.rbdm_warning_label.setVisible(! this.rbdm_warning_label.isVisible());
	}
		
	private String trimNodeLabel(String full_label) {
        String trimmed_label = "";
        StringTokenizer parser = null;
        try {
            parser = new StringTokenizer(full_label, " ");
            if (parser == null) {
               return full_label;
            }
            trimmed_label = parser.nextToken();   
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
        return trimmed_label;
	}
		 
	// This method implements the TreeSelectionListener interface It is called when a 
	// new node in the Assessment question map is selected either by the user or program
	// --------------------------
	// Change Control:
	// 02/18/02 - Added capability to listen for when the user selects the Policy node in the
	//            assessment question map. This action will cause the policy tab to become 
	//            visible.
    public void valueChanged(TreeSelectionEvent tse) {        
        String value = "";
        TreePath tp = tse.getNewLeadSelectionPath();
        if (tp != null) {
		    DefaultMutableTreeNode ques = (DefaultMutableTreeNode) tp.getLastPathComponent();
		    if (ques != null) {
		        this.internal_setCursor("wait");
		        value = (String) ques.getUserObject();
		        if (ques.isLeaf() && !(value.equals("Policy"))) {
		            String question_num = (String) ques.getUserObject();
		            this.parent.log("captured question map event for question " + question_num);
		            this.displayQuestion(question_num);
		        }else {		        
		            if (value.equals("Policy")) {
		                this.JTabbedPane1.setSelectedIndex(2);
		            }
		        }
		        this.internal_setCursor("default");
		    }else {
		        this.parent.log("ERROR: Null pointer encountered when trying to display an element from the question map");    
		    }
		}
	}/* end method valueChanged() */    

	class SymRepeatAction implements java.awt.event.ActionListener {
	    public void actionPerformed(java.awt.event.ActionEvent event) {
	        Object object = event.getSource();
	        if (object == assessment_local_save_timer) {
	            saveAssessmentLocally();
	        }
	    }
	}/* end inner-class SymRepeatAction() */

	class SymAction implements java.awt.event.ActionListener {
	    
		public void actionPerformed(java.awt.event.ActionEvent event) {
			Object object = event.getSource();
			if (object == proceed_to_assessment_button)
				proceed_to_assessment_button_actionPerformed(event);
			else if (object == question_back_button)
				questionBackButton_actionPerformed(event);
			else if (object == question_next_button)
				questionNextButton_actionPerformed(event);
			else if (object == add_assessor_button)
				addAssessorButton_actionPerformed(event);
			else if (object == conn_system_add_button)
				connSystemAddButton_actionPerformed(event);
			
			if (object == question_response_clear_button)
				questionResponseClearButton_actionPerformed(event);
			
			if (object == id_panel_proceed_button)
				id_panel_proceed_button_actionPerformed(event);
			else if (object == infoGather_previous_button)
				infoGather_previous_button_actionPerformed(event);
			else if (object == policy_next_button)
				policy_next_button_actionPerformed(event);
			else if (object == policy_previous_button)
				policy_previous_button_actionPerformed(event);
			else if (object == system_name_cutMenuItem)
				system_name_cutMenuItem_actionPerformed(event);
			else if (object == copyMenuItem)
				copyMenuItem_actionPerformed(event);
			else if (object == pasteMenuItem)
				pasteMenuItem_actionPerformed(event);
			else if (object == selectAllMenuItem)
				selectAllMenuItem_actionPerformed(event);
			else if (object == system_name_copyMenuItem)
				systemNameCopyMenuItem_actionPerformed(event);
			else if (object == system_name_pasteMenuItem)
				systemNamePasteMenuItem_actionPerformed(event);
			else if (object == systemnum_cut_menuitem)
				systemnumCutMenuitem_actionPerformed(event);
			else if (object == systemnum_copy_menuitem)
				systemnumCopyMenuitem_actionPerformed(event);
			else if (object == systemnum_paste_menuitem)
				systemnumPasteMenuitem_actionPerformed(event);
			else if (object == aggrpdiv_cutMenuItem)
				aggrpdivCutMenuItem_actionPerformed(event);
			else if (object == aggrpdiv_copyMenuItem)
				aggrpdivCopyMenuItem_actionPerformed(event);
			else if (object == aggrpdiv_pasteMenuItem)
				aggrpdivPasteMenuItem_actionPerformed(event);
			if (object == save_assessment_button)
				saveAssessmentButton_actionPerformed(event);
			else if (object == export_button)
				exportButton_actionPerformed(event);
			if (object == assign_assessor_choicebox)
				assignAssessorChoicebox_actionPerformed(event);
			else if (object == flag_for_review_box)
				flagForReviewBox_actionPerformed(event);
			else if (object == ITSAF_level2_checkbox)
				ITSAFLevel2Checkbox_actionPerformed(event);
			else if (object == ITSAF_level3_checkbox)
				ITSAFLevel3Checkbox_actionPerformed(event);
			else if (object == ITSAF_level4_checkbox)
				ITSAFLevel4Checkbox_actionPerformed(event);
			else if (object == rbdm_na_option)
				rbdmNaOption_actionPerformed(event);
			else if (object == rbdm_yes_option)
				rbdmYesOption_actionPerformed(event);
			else if (object == cutMenuItem)
				cutMenuItem_actionPerformed(event);
			else if (object == conn_system_help_button)
				connSystemHelpButton_actionPerformed(event);
			else if (object == addAssessor_help_button)
				addAssessorHelpButton_actionPerformed(event);
			else if (object == questions_help_button)
				helpButton_actionPerformed(event);			
		} /* end method actionPerformed(ActionEvent) */
		
	}/* end internal class SymAction() */

    // This method is used to examine all of the required fields within the second tab of
    // the assessment window. If any of the fields are set to a point that may results in an
    // error when trying to write to the database, the method will display an error
    private boolean isInformationGatheringCompleteSuppressMsg() {
        boolean flag = true;
        try {
            if ((this.system_availability_box.getSelectedIndex() < 1) || (this.system_confidentiality_box.getSelectedIndex() < 1) || (this.system_integrity_box.getSelectedIndex() < 1)) {
                flag = false;              
            }
            if (this.system_name_field.getText().length() < 1) {
                flag = false;
            }
            if (this.system_number_field.getText().length() < 1) {
                flag = false;
            }
            if (this.system_type_box.getSelectedIndex() < 1) {
                flag = false;
            }                
            if (this.aggrpdiv_text_field.getText().length() < 1) {
                flag = false;
            }
        }catch (Exception e) {
            e.printStackTrace();
        }              
        return flag;
    }/* end method isInformationGatheringCompleteSuppressMsg() */

    // This method is used to examine all of the required fields within the second tab of
    // the assessment window. If any of the fields are set to a point that may results in an
    // error when trying to write to the database, the method will display an error
    private boolean isInformationGatheringComplete() {
        boolean flag = true;
        StringBuffer error_text = new StringBuffer("");
        try {
            error_text.append("The following error(s) were encountered\nwhen trying to process your information to be saved:\n");
            if ((this.system_availability_box.getSelectedIndex() < 1) || (this.system_confidentiality_box.getSelectedIndex() < 1) || (this.system_integrity_box.getSelectedIndex() < 1)) {
                error_text.append("You must choose a valid setting for all the system criticality fields\n");
                flag = false;              
            }
            if (this.system_name_field.getText().length() < 1) {
                error_text.append("You must choose a valid name for the system you are assessing!\n");
                flag = false;
            }
            if (this.system_number_field.getText().length() < 1) {
                flag = false;
                error_text.append("You must choose a valid number for the system you are assessing!\n");
            }
            if (this.system_type_box.getSelectedIndex() < 1) {
                error_text.append("You must select a valid system type!\n");
                flag = false;
            }                
            if (this.aggrpdiv_text_field.getText().length() < 1) {
                flag = false;
                error_text.append("You must choose a valid location for the system you are assessing!\n");
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
            {
                if (! flag) {                    
                    this.parent.displayErrorDialog(error_text.toString());
                    this.JTabbedPane1.setSelectedIndex(1);
                }
            }                
        return flag;
    }/* end method isInformationGatheringComplete() */

    // This method is very important, it is called when a user has completed the info
    // gathering portion and is about to move on the answering policy questions and 
    // answering the actual questions in the checklist. Without this method the Assessment
    // concept does not work properly.
	// --------------
	// 05/01/02 - Added code to set assessment save status to true if information gathting
	//            was set as completed. This is done so that if someone wants to save after
	//            completing policy section the save will successfully capture their responses
	//            to the policy questions.
	void proceed_to_assessment_button_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
		if (this.isInformationGatheringComplete()) {
		    this.policy_question_table.setRowSelectionAllowed(true);
		      
		    this.setAssessmentName();
		    this.setAssessmentStatus(true);
		    this.internal_setCursor("wait");
		    this.initializeQuestionCount();
		    this.parent.setServiceName("Self-Assessment");
		    proceed_to_assessment_button_actionPerformed_Interaction4(event);	 
		
		    proceed_to_assessment_button_actionPerformed_Interaction2(event);	 
		    proceed_to_assessment_button_actionPerformed_Interaction3(event);
		
		    this.setAssessmentType(false);
		    this.setAssessmentSaveStatus(true);
		
		    this.assessembleAssessorResponBox();
		    this.assessembleReviewerResponBox();
		    this.prepareCriticalElementTable();
		
		    this.JTabbedPane1.setSelectedIndex(2);
		    this.policy_question_table.setRowSelectionInterval(0, 0);  
		    this.setLocalSaveFileName();
		    this.setAssessmentSaveTimer();
		    this.parent.setStatusMsg("");
		    this.internal_setCursor("default");
		}
	}/* end method proceed_to_assessment_button_actionPerformed(event) */
	
	// The method that determines the total number of questions to answer by calling
	// the appropriate stored proecedure - get_question_count from the database
	// It is called from the proceed_to_assessment_button_actionPerformed()
	// method
	// Change Control:
    // 02/17/02 - Changed code to call stored procedure instead of executing a prepared
    //            SQL string for better execution time
    // 02/18/02 - Changed code to add call to ResultSet.next() before accessing count val
    //            as it was eliciting a JDBC invalid cursor state error
    //            http://p2p.wrox.com/archive/java_databases/2001-01/13.asp
	private void initializeQuestionCount() {	    
	    CallableStatement question_count = null;
	    ResultSet count = null;
	    try {
	       this.parent.log("computing question count now");
	       this.internal_setCursor("wait"); 
	       if (this.conn != null) { 
	           question_count =  this.conn.prepareCall("{call get_question_count}");
	           count = question_count.executeQuery();
	           count.next();	          
    	       this.setQuestionCount(count.getInt("QuestionCount"));
    	       count.close();
	       }else {
	           this.parent.log("database connection was null while trying to compute question count!"); 
	       }           
	       this.internal_setCursor("default");
	    }catch (Exception e) {
	        this.parent.displayErrorDialog("ERROR: cannot compute question count! The text of the error is:\n" + e.toString());
	        this.parent.log("ERROR: cannot compute question count!");
	        this.parent.log("ERROR MSG: " + e.toString());
	        this.internal_setCursor("default");
	    }
	}/* end method initializeQuestionCount() */

	void proceed_to_assessment_button_actionPerformed_Interaction2(java.awt.event.ActionEvent event)
	{
		try {
			this.setTitle();
		} catch (java.lang.Exception e) {
		    this.parent.log(e.toString());
		}
	}

	void proceed_to_assessment_button_actionPerformed_Interaction3(java.awt.event.ActionEvent event) {
		Graphics g1 = null;
		try {	
		    if (! this.getMapStatus()) {
			    this.buildTree();
			    this.assembleAssesmentInfo();
			}
			this.progress_tree.setVisible(true);
			g1 = this.progress_tree.getGraphics();
			this.progress_tree.update(g1);
		    this.progress_map_scroll_pane.setVisible(true);		    
		    g1 = this.progress_map_scroll_pane.getGraphics();
		    this.progress_map_scroll_pane.update(g1);
		    this.progress_map_panel.setVisible(true);
		    g1 = this.progress_map_panel.getGraphics();
		    this.progress_map_panel.update(g1);  
		    g1 = this.JSplitPaneWrapper1.getGraphics();
		    this.JSplitPaneWrapper1.update(g1);
		}catch (java.lang.Exception e) {
            this.parent.log(e.toString());
		}
	}

	class SymInternalFrame implements javax.swing.event.InternalFrameListener {
	    
		public void internalFrameOpened(javax.swing.event.InternalFrameEvent event)
		{
			Object object = event.getSource();
			if (object == AssessmentWindow.this)
				AssessmentWindow_internalFrameOpened(event);
		}

		public void internalFrameDeiconified(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameIconified(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameDeactivated(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosed(javax.swing.event.InternalFrameEvent event)
		{
		}

		public void internalFrameClosing(javax.swing.event.InternalFrameEvent event)
		{
		    Object object = event.getSource();
			if (object == AssessmentWindow.this)
				AssessmentWindow_internalFrameClosing(event);
		}

		public void internalFrameActivated(javax.swing.event.InternalFrameEvent event)
		{
		}
		
	} /* end internal class SymInternalFrame() */

	void AssessmentWindow_internalFrameOpened(javax.swing.event.InternalFrameEvent event)
	{
		// to do: code goes here.
		
	}
	
    // This method is the event handler when the internal frame of AssessmentWindow 
    // has its close button pushed. It is responsible for making sure that the user
    // knows that they should save their data that was active.
    // --------------
    // Change Control:
    // 05/01/02 - Added else block to if conditional which checks to see if assessment
    //            should be saved by calling getAssessmentSaveStatus() if the method 
    //            returns true then the data needs to be saved otherwise just kill the 
    //            class instance.
    // 05/06/02 - Changed call from isInformationGatheringComplete() to 
    //            isInformationGatheringCompleteSupressFlag() to aviod the annoying error msg
    //            that is displayed when a user quits without filling in any fields of
    //            a brand new assessment
    void AssessmentWindow_internalFrameClosing(javax.swing.event.InternalFrameEvent event) {
	    try {
		// to do: code goes here. 
			if (this.getAssessmentSaveStatus()) {
                    int save_reply = JOptionPane.showConfirmDialog(this, 
	    	                                          "Do you want to store your active assessment?", 
	    	                                          "Store Active Assessment?" , 
	    	                                          JOptionPane.YES_NO_OPTION, 
	    	                                          JOptionPane.QUESTION_MESSAGE);
			        if (save_reply == JOptionPane.YES_OPTION) {
                        this.parent.setStatusMsg("Saving assessment to database now");
                        this.parent.setStatusModeMsg("SAVE");
                        this.saveAssessment();
			        }
			        this.parent.setStatusMsg("");
			        this.parent.setStatusModeMsg("Idle...");
			        this.setVisible(false);
			        this.conn.close();
			        this.assessment_local_save_timer.stop();
			        this.dispose();
			}else {
			    if (isInformationGatheringCompleteSuppressMsg()) {
			        this.conn.close();
			        this.assessment_local_save_timer.stop();
			        this.dispose();			    
			    }else {

			    }
			}
		}catch (Exception e) {
		    this.parent.log(e.toString());
		}
	}/* end internal method AssessmentWindow_internalFrameClosing(InternalFrameEvent event)*/

	void questionBackButton_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		question_back_button_actionPerformed_Interaction1(event);
	}

	void question_back_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.questionBack();
		} catch (java.lang.Exception e) {
		
		}
	}

	void questionNextButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		question_next_button_actionPerformed_Interaction1(event);
	}

	void question_next_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.questionForward();
		} catch (java.lang.Exception e) {
		    ;
		}
	}

	void addAssessorButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		add_assessor_button_actionPerformed_Interaction1(event);
	}

	void connSystemAddButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.	 
			 
		conn_system_add_button_actionPerformed_Interaction1(event);
	}
	
	public void paintCheckbox(JCheckBox checkbox) {
        try {
            Font f = new Font("Dialog", Font.PLAIN, 12);
			checkbox.setForeground(Color.blue);
			checkbox.setFont(f);
			checkbox.setCursor(new Cursor(Cursor.HAND_CURSOR));
			checkbox.repaint();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
	}
	
	public void unpaintCheckbox(JCheckBox box) {
	    try {
	        box.setFont(new Font("Dialog", Font.PLAIN, 12));
			box.setForeground(Color.black);
			box.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
			this.parent.setStatusMsg("");
			box.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	public void paintLabel(JLabel checkbox) {
        try {
            Font f = new Font("Dialog", Font.PLAIN, 12);
			checkbox.setForeground(Color.blue);
			checkbox.setFont(f);
			checkbox.setCursor(new Cursor(Cursor.HAND_CURSOR));
			checkbox.repaint();
        }catch (Exception e) {
            this.parent.log(e.toString());
        }
	}
	
	public void unpaintLabel(JLabel box) {
	    try {
	        box.setFont(new Font("Dialog", Font.PLAIN, 12));
			box.setForeground(Color.black);
			box.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
			this.parent.setStatusMsg("");
			box.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}

	// This method is the Java action handler for the event that gets generated when
	// the add assessor button is pressed. Its responsibility is to create and show the
	// add assessor dialog to allow a user to add assessor information.
    // ---------------
	// Change Control:
	// 05/01/02 - Moved actual dialog instantiation to internal method so that action
	//            handler for when enter key is typed on button same code is activated.
	void add_assessor_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// JDialog2 Create and show as modal
            this.addAssessorButtonActionHandler();
		} catch (java.lang.Exception e) {
		    this.parent.log(e.toString());
		}
	}
	
	private void addAssessorButtonActionHandler() {
	    try {
	        this.internal_setCursor("wait");
	        this.parent.setStatusMsg("Opening add assessor dialog now, please hold.");
	        AddAssessorDialog JDialog21 = new AddAssessorDialog(this);
			JDialog21.setModal(true);
			JDialog21.show();
			this.parent.setStatusMsg("");
			this.internal_setCursor("default");
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	// This method is the action handler for the add connected system button. It is
	// responsible for creating and showing the add system button.
	// ---------------
	// Change Control:
	// 05/01/02 - Moved code that instantiates connected system dialog to separate 
	//            method.
	void conn_system_add_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// AddSystemDialog Create and show as modal
            this.addConnectedSystemButtonActionHandler();
		} catch (java.lang.Exception e) {
		    this.parent.log(e.toString());
		}
	}
	
    // This method is the actual code that creates and dispalys the add connected
    // system dialog. 
    // --------------
    // Change Control:
    // 05/02/02 - Added code to set cursor to hourglass and set status msg when 
    //            dialog is first opened to show user that something is happening.
    //            Once dialog is opened everything is reset.
	private void addConnectedSystemButtonActionHandler() {
	    try {
			{
			    this.internal_setCursor("wait");
			    this.parent.setStatusMsg("Opening add inter-connected system dialog now");
				AddSystemDialog AddSystemDialog1 = new AddSystemDialog(this);
				AddSystemDialog1.setModal(true);
				AddSystemDialog1.fillTable();
				AddSystemDialog1.show();
				this.internal_setCursor("default");
				this.parent.setStatusMsg("");
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	void assessmentStartStatusMsg() {
	    this.parent.setStatusMsg("Building assessment question list, please hold...");   
	}
	

	void proceed_to_assessment_button_actionPerformed_Interaction4(java.awt.event.ActionEvent event)
	{
		try {
			this.assessmentStartStatusMsg();
		} catch (java.lang.Exception e) {
		    
		}
	}
	
	void displayRBDMWarning(String msg) {
	    try {
	        this.setRBDMWarningLabel(msg);	        
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	// Programming logic to verify that assessment answer components are in a state 
	// that is sufficient enough to allow the user to move to an alternate question. 
	// This method is called when a user moves back or forward or jumps to a arbitrary 
	// question.
	boolean checkQuestionStateBoxes() {
	    boolean flag = false;
	    try {
	        StringBuffer msg = new StringBuffer("");
	        
	        if (! this.getAssessmentType()) {
	            flag = true;
	            
                if ((this.question_complete_checkbox.isSelected() == false) && (this.flag_question_checkbox.isSelected() == false)) {
	                if (this.anyLevelsSelected()) {
	                    flag = false; 
	                    msg.append("You must indicate that question is either complete or assigned to an alternate assessor\n");
	                }
	            }
	        
	            if (this.flag_question_checkbox.isSelected() && this.flag_for_review_box.getSelectedIndex() < 2) {
	                flag = false;
	                msg.append("If you assign a question to another assessor, you must specify a valid assessor");
	            }
	            
	            if (this.assign_assessor_choicebox.getSelectedIndex() < 2) {
	                flag = false;
	                msg.append("You must assign the answer of this question to a valid assessor! Choose a different assessor from the drop-down list.");
	            }
	        
	            if (this.question_complete_checkbox.isSelected() && this.flag_question_checkbox.isSelected()) {
	                flag = false;
	                msg.append("You cannot flag the question as complete and assign it to an alternate assessor as well\n");
	            }
	            
	            if (this.rbdm_yes_option.isSelected() == true && (((! this.question_complete_checkbox.isSelected())) && (! this.flag_question_checkbox.isSelected()))) {
	                flag = false;
	                msg.append("If you flag a question with a risk-based decision being made, you must\nindicate the question is complete or assigned to an alternate assessor\n");
	            }
	            
	            if (rbdm_na_option.isSelected() == true && this.comment_field.getText().length() < acceptable_comment_length) {
                    flag = false;
                    msg.append("You entered insufficient comments regarding a non-applicable question.\n");
	            }	            
	            
	            if (rbdm_yes_option.isSelected() == true && this.comment_field.getText().length() < acceptable_comment_length) {
                    flag = false;
                    msg.append("You entered insufficient comments regarding a risk based decision\n");
	            }
	            	            	            
	            if (flag == false) {
	                JOptionPane.showMessageDialog(this, msg.toString(), "There was an error(s) in your response:", JOptionPane.WARNING_MESSAGE);
	            }
	        }else {
	            flag = true;    
	        }
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return flag;
	}
	
	boolean anyLevelsSelected() {
	    boolean flag = false;
	    try {
	        if (this.ITSAF_level2_checkbox.isSelected()) {
	            flag = true;
	        }
	        if (this.ITSAF_level3_checkbox.isSelected()) {
	            flag = true;
	        }
	        if (this.ITSAF_level4_checkbox.isSelected()) {
	            flag = true;
	        }
	        if (this.ITSAF_level5_checkbox.isSelected()) {
	            flag = true;
	        }
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    return flag;
	}
	
	// Change Control:
	// 03/21/02 - Changed method that calls the AddAssessorDialog to allow the dialog to
	//            center itself on the screen rather than have this calling class do it
	void assignNewResponAction() {
        if (this.assign_assessor_choicebox.getSelectedIndex() == 1) {
				AddAssessorDialog JDialog21 = new AddAssessorDialog(this, true);
				JDialog21.setModal(true);
				JDialog21.show();
        }
	}

	// Change Control:
	// 03/21/02 - Changed method that calls the AddAssessorDialog to allow the dialog to
	//            center itself on the screen rather than have this calling class do it	
	void assignNewReviewerAction() {
        if ( this.flag_for_review_box.getSelectedIndex() == 1) {
				AddAssessorDialog JDialog21 = new AddAssessorDialog(this, true);
				JDialog21.setModal(true);
				JDialog21.show();
        }
	}
	
    void assembleNewReviewerPostInfoGather(String new_assessor) {
	    StringTokenizer parser = null;
	    try {
	        int index = 0;
	        if (! this.flag_for_review_model.contains(new_assessor)) {
                this.flag_for_review_model.addElement(new_assessor);
            }
	        this.flag_for_review_box.setModel(this.flag_for_review_model);
	        this.flag_for_review_box.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    
	}
	
	void assessembleReviewerResponBox() {
	    StringTokenizer parser = null;
	    try {
	        String assessor_info = "";
	        String assessor_name = "";
	        String primary = "";
	        int index = 0;
	        Vector assessor_row = null;
	        for (int i = 0; i < (this.assessor_table_model.getDataVector()).size(); i++) {	            
	            assessor_row = (Vector) (this.assessor_table_model.getDataVector()).elementAt(i);
                primary = ((Boolean) assessor_row.elementAt(0)).toString();  
                if (! this.flag_for_review_model.contains((String) assessor_row.elementAt(1))) {
                    if (primary.equals("Y")) {
                        this.parent.log((String) assessor_row.elementAt(1));
	                    this.flag_for_review_model.insertElementAt((String) assessor_row.elementAt(1), 2);	                
	                }else {	            
	                    this.flag_for_review_model.addElement((String) assessor_row.elementAt(1));
	                }
	            }
	            this.flag_for_review_box.setSelectedIndex(2);
	        }
	        this.flag_for_review_box.setModel(flag_for_review_model);
	        this.flag_for_review_box.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	void assembleNewAssessorPostInfoGather(String new_assessor) {
	    StringTokenizer parser = null;
	    try {
	        int index = 0;
	        if (! this.assign_assessor_model.contains(new_assessor)) {
                this.assign_assessor_model.addElement(new_assessor);
            }
	        this.assign_assessor_choicebox.setModel(this.assign_assessor_model);
	        this.assign_assessor_choicebox.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	    
	}
	
	// Sets the assessor choice box on the question tab. This box is responsible for
	// denoting who answered a particular question. The primary assessor is destined to
	// always be set at the index 2. 
	void assessembleAssessorResponBox() {
	    try {
	        String assessor_info = "";
	        String assessor_name = "";
	        String primary = "";
	        int index = 0;
	        Vector assessor_row = new Vector();
	        for (int i = 0; i < (this.assessor_table_model.getDataVector()).size(); i++) {
	            assessor_row = (Vector) (this.assessor_table_model.getDataVector()).elementAt(i);
	            primary = ((Boolean) assessor_row.elementAt(0)).toString();
	            assessor_name = (String) assessor_row.elementAt(1);
                // First check to ensure that the combo box you are inserting this name
                // assessor_name into does not already contain the name, if it does then
                // don't insert it.
                if (! this.assign_assessor_model.contains(assessor_name)) {
                    if (primary.equals("Y")) {
	                    this.assign_assessor_model.insertElementAt(assessor_name, 2);
	                    this.assign_assessor_choicebox.setSelectedIndex(2);
	                }else {	            
	                    this.assign_assessor_model.addElement(assessor_name);
	                }	            
	            }
	        }
	        this.assign_assessor_choicebox.setSelectedIndex(2);
	        this.assign_assessor_choicebox.setModel(this.assign_assessor_model);
	        this.assign_assessor_choicebox.repaint();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}

	void questionResponseClearButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
        this.clearResponseFields();			 
			 
		question_response_clear_button_actionPerformed_Interaction1(event);
	}
	
	// THis method is responsible for clearing the current response values from the
	// screen. Any of the user interface elements that were checked as a part of 
	// a response are reset to their original state. Once the response values are
	// cleared from the screen, if a response is found to exist for the current
	// question then the response is also deleted from memory as well. 
	// ---------------
	// Change Control:
	// 05/02/02 - Added code that searches the active response vector to see if a 
	//            instance of QuestionResponse exists for the response currently
	//            on screen being cleared. If such an instance is found then it is
	//            removed and the question progress is then decremented by 1 count.
	//            The idea being if I press the clear button multiple times then the
	//            progress is only decrement if a response is found.
	// 05/08/02 - Added code to if/then block where response is found to exist within 
	//            active question response vector and then deleted. Now immediately following
	//            this, the active question response vector is reinserted in to the hashtable
	//            of response vectors on the off chance that someone will immediately save
	//            and quit an assessment right after they have deleted an assessment.
	// 05/11/02 - Added code to delete question response from database with stored procedure
	//            delete_saved_question no matter if it exists or not. The stored procedure
	//            first checks to see if it exists before attempting to delete it.
	// 05/13/02 - Removed code to check for and delete question response into seperate method
	//            because display button action handling 
	private void clearResponseFields() {
        String curr_question_number = this.question_number_label.getText();
        String critical_element = this.trimNodeLabel(this.findCriticalElement(curr_question_number));
        StringTokenizer parser = null;
        CallableStatement delete_query = null;  
        Connection conn = null;
        try {            
            this.setAssessmentSaveStatus(true);
            
            this.parent.log("clearing response fields now...");
            question_complete_checkbox.setSelected(false);
            flag_question_checkbox.setSelected(false);
            ITSAF_level3_checkbox.setSelected(false);
            ITSAF_level3_checkbox.setEnabled(false);
            if (this.question_number_label.getText().length() > 1) {
                if (this.checkPolicyEntry(this.trimNodeLabel(this.findCriticalElement(this.question_number_label.getText())))) {
                    this.ITSAF_level1_checkbox.setSelected(true);   
                }else {
                    this.ITSAF_level1_checkbox.setSelected(false); 
                }
            }
            ITSAF_level2_checkbox.setSelected(false);
            ITSAF_level2_checkbox.setEnabled(true);
            ITSAF_level4_checkbox.setSelected(false);
            ITSAF_level4_checkbox.setEnabled(false);
            ITSAF_level5_checkbox.setSelected(false);
            ITSAF_level5_checkbox.setEnabled(false);
            comment_field.setText("");
            rbdm_yes_option.setSelected(false);
            rbdm_yes_option.setEnabled(true);
            rbdm_na_option.setSelected(false);
            this.rbdm_warning_label.setVisible(false);
            this.assign_assessor_choicebox.setSelectedIndex(2);
            this.flag_for_review_box.setSelectedIndex(2);
        }catch (Exception e) {
            e.printStackTrace();
            this.parent.displayErrorDialog("ERROR: cannot delete saved question ! The text of the error is:\n" + e.toString());
            this.parent.log(e.toString());
        }
	}/* end method clearResponseFields() */

	// This method is designed to ask the active question response vector in memory
	// and ask the database to delete the existing response from memory but only if the
	// response first exists.
	// ---------------
	// Change Control:
	// 05/19/02 - Added call to set the active question response vector to the correct 
	//            section before it is searched to see if the response exists or not.
	private void clearButtonPressed() {
        String curr_question_number = this.question_number_label.getText();
        String critical_element = this.trimNodeLabel(this.findCriticalElement(curr_question_number));
        StringTokenizer parser = null;
        CallableStatement delete_query = null;  
        Connection conn = null;
        try {            
            // First check to see if the active question response vector exists
            // Also check to make sure that there is valid current question being
            // displayed
            this.setActiveQuestionResponseVector(critical_element);
            if (this.active_question_responses != null && curr_question_number.length() > 1) {
                int index_of_resp = this.locateResponse(this.active_question_responses, curr_question_number);
                // Now obtain the exact index of where the response in question is located within the 
                // active response vector. If it is -1 then the response has not been saved yet
                // so you don't need to remove it from the active questoin response vector
                if (index_of_resp != -1) {
                    this.internal_setCursor("wait");
                    this.parent.setStatusModeMsg("BUSY");
                    this.parent.setStatusMsg("Deleting question from ASSET System database now, please hold");
                    parser = new StringTokenizer(curr_question_number, ".");
                    conn = this.parent.connectionGenerator();
                    delete_query = conn.prepareCall("{call delete_saved_question(?, ?, ?, ?)}");
                    delete_query.setString(1, this.getAssessmentName());
                    delete_query.setInt(2, Integer.parseInt(parser.nextToken()));
                    delete_query.setInt(3, Integer.parseInt(parser.nextToken()));
                    delete_query.setInt(4, Integer.parseInt(parser.nextToken()));
            
                    delete_query.executeUpdate();
                    conn.close();
                    
                    this.active_question_responses.remove(index_of_resp);
                    this.question_responses.remove(critical_element);
                    this.question_responses.put(critical_element, this.active_question_responses);
                    this.setActiveQuestionResponseVector(critical_element);
                    this.decrementQuestionProgress();
                    this.parent.setStatusMsg("");
                    this.parent.setStatusModeMsg("AIP");
                    this.internal_setCursor("default");
                }
            }
            this.clearResponseFields();            
        }catch (Exception e) {
            e.printStackTrace();
            this.parent.displayErrorDialog("ERROR: cannot delete saved question ! The text of the error is:\n" + e.toString());
            this.parent.log(e.toString());
        }
	}/* end method clearResponseFields() */

	void JLabel5_mouseEntered(java.awt.event.MouseEvent event) {
		// to do: code goes here.
			 
		JLabel5_mouseEntered_Interaction1(event);
	}

	void JLabel5_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel5);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel5_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel5_mouseExited_Interaction1(event);
	}

	void JLabel5_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel5);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel6_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel6_mouseEntered_Interaction1(event);
	}

	void JLabel6_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel6);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel6_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel6_mouseExited_Interaction1(event);
	}

	void JLabel6_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel6);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel7_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel7_mouseEntered_Interaction1(event);
	}

	void JLabel7_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel7);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel7_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel7_mouseExited_Interaction1(event);
	}

	void JLabel7_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel7);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel1_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel1_mouseEntered_Interaction1(event);
	}

	void JLabel1_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel1);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel2_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel2_mouseEntered_Interaction1(event);
	}

	void JLabel2_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel2);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel3_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel3_mouseEntered_Interaction1(event);
	}

	void JLabel3_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel3);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel1_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel1_mouseExited_Interaction1(event);
	}

	void JLabel1_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel1);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel2_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel2_mouseExited_Interaction1(event);
	}

	void JLabel2_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel2);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel3_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel3_mouseExited_Interaction1(event);
	}

	void JLabel3_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel3);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel16_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel16_mouseEntered_Interaction1(event);
	}

	void JLabel16_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel16);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel16_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel16_mouseExited_Interaction1(event);
	}

	void JLabel16_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel16);
		} catch (java.lang.Exception e) {
		    ;
		}
	}

	void id_panel_proceed_button_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		id_panel_proceed_button_actionPerformed_Interaction1(event);
	}

	void id_panel_proceed_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// JTabbedPane1 Increment the selected tab
			JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() + 1);
		} catch (java.lang.Exception e) {
		}
	}

	void infoGather_previous_button_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		infoGather_previous_button_actionPerformed_Interaction1(event);
	}

	void infoGather_previous_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// JTabbedPane1 Decrement the selected tab
			JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() - 1);
		} catch (java.lang.Exception e) {
		
		}
	}

	void policy_next_button_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		policy_next_button_actionPerformed_Interaction1(event);
	}

    // This method increments the policy tab when its next button is pressed. The
    // challenge here is that once the tab is incremented, what is to be the current
    // question should be displayed. Originally it was question 1.1.1 that was called
    // for diplay no matter what stage of the assessment a user was in. That obviously
    // does not work if the user has already passed question 1.1.1.
    // Change Control:
    // 04/09/02 - Changed call to displayQuestion() to reflect the current bookmark 
    //            by calling getBookmark() instead of question 1.1.1
	// 04/09/02 - Added call to incrementQuestionProgress() after first time policy 
	//            questions are completed. The method is called for each policy 
	//            element there is (initially 17).
	void policy_next_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			// JTabbedPane1 Increment the selected tab
			if (! this.getPolicyCompleted()) {
			    this.setPolicyCompleted(true);
			    for (int i = 0; i < this.policyModel.getDataVector().size(); i++) {
			        this.incrementQuestionProgress();
			    }
			}
			this.displayQuestion(this.getBookmark());
			JTabbedPane1.setSelectedIndex(3);
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void policy_previous_button_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		policy_previous_button_actionPerformed_Interaction1(event);
	}

	void policy_previous_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			// JTabbedPane1 Decrement the selected tab
			JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() - 1);
		} catch (java.lang.Exception e) {
		}
	}
	
	void assessmentObjectiveMenuItemCut() {
	    try {
	        this.assessment_objective_field.cut();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
    void assessmentObjectiveMenuItemCopy() {
	    try {
	        this.assessment_objective_field.copy();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
    void assessmentObjectiveMenuItemPaste() {
	    try {
	        this.assessment_objective_field.paste();
	    }catch (Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	
	void assessmentObjectiveMenuSelectAll() {
	    try {
	        this.assessment_objective_field.select(0, (this.assessment_objective_field.getText()).length());
	    }catch(Exception e) {
	        this.parent.log(e.toString());
	    }
	}
	

	void system_name_cutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		system_name_cutMenuItem_actionPerformed_Interaction2(event);
	}


	void copyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		copyMenuItem_actionPerformed_Interaction1(event);
	}

	void copyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.assessmentObjectiveMenuItemCopy();
		} catch (java.lang.Exception e) {
		}
	}

	void pasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		pasteMenuItem_actionPerformed_Interaction1(event);
	}

	void pasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.assessmentObjectiveMenuItemPaste();
		} catch (java.lang.Exception e) {
		}
	}

	void selectAllMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		selectAllMenuItem_actionPerformed_Interaction1(event);
	}

	void selectAllMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.assessmentObjectiveMenuSelectAll();
		} catch (java.lang.Exception e) {
		}
	}

	void system_name_cutMenuItem_actionPerformed_Interaction2(java.awt.event.ActionEvent event) {
		try {
			system_name_field.cut();
		} catch (java.lang.Exception e) {
		}
	}

	void systemNameCopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		system_name_copyMenuItem_actionPerformed_Interaction1(event);
	}

	void system_name_copyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			system_name_field.copy();
		} catch (java.lang.Exception e) {
		}
	}

	void systemNamePasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		system_name_pasteMenuItem_actionPerformed_Interaction1(event);
	}

	void system_name_pasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			system_name_field.paste();
		} catch (java.lang.Exception e) {
		}
	}

	void systemnumCutMenuitem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		systemnum_cut_menuitem_actionPerformed_Interaction1(event);
	}

	void systemnum_cut_menuitem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			system_number_field.cut();
		} catch (java.lang.Exception e) {
		}
	}

	void systemnumCopyMenuitem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		systemnum_copy_menuitem_actionPerformed_Interaction1(event);
	}

	void systemnum_copy_menuitem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			system_number_field.copy();
		} catch (java.lang.Exception e) {
		}
	}

	void systemnumPasteMenuitem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		systemnum_paste_menuitem_actionPerformed_Interaction1(event);
	}

	void systemnum_paste_menuitem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			system_number_field.paste();
		} catch (java.lang.Exception e) {
		}
	}

	void aggrpdivCutMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		aggrpdiv_cutMenuItem_actionPerformed_Interaction1(event);
	}

	void aggrpdiv_cutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			aggrpdiv_text_field.cut();
		} catch (java.lang.Exception e) {
		}
	}

	void aggrpdivCopyMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		aggrpdiv_copyMenuItem_actionPerformed_Interaction1(event);
	}

	void aggrpdiv_copyMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			aggrpdiv_text_field.copy();
		} catch (java.lang.Exception e) {
		}
	}

	void aggrpdivPasteMenuItem_actionPerformed(java.awt.event.ActionEvent event) {
		// to do: code goes here.
			 
		aggrpdiv_pasteMenuItem_actionPerformed_Interaction1(event);
	}

	void aggrpdiv_pasteMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			aggrpdiv_text_field.paste();
		} catch (java.lang.Exception e) {
		}
	}

	void saveAssessmentButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		save_assessment_button_actionPerformed_Interaction1(event);
	}

	void save_assessment_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.saveAssessment();
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}

	void exportButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		export_button_actionPerformed_Interaction1(event);
	}

	void export_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.saveUnfinishedAssessment();
		} catch (java.lang.Exception e) {
		}
	}


	void assignAssessorChoicebox_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		assign_assessor_choicebox_actionPerformed_Interaction1(event);
	}

	void assign_assessor_choicebox_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.assignNewResponAction();
		} catch (java.lang.Exception e) {
		}
	}

	void flagForReviewBox_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		flag_for_review_box_actionPerformed_Interaction1(event);
	}

	void flag_for_review_box_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.assignNewReviewerAction();
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel2Checkbox_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level2_checkbox_actionPerformed_Interaction1(event);
	}

	void ITSAF_level2_checkbox_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.level2CheckboxToggled();
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel3Checkbox_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level3_checkbox_actionPerformed_Interaction1(event);
	}

	void ITSAF_level3_checkbox_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.level3CheckboxToggled();
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel4Checkbox_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level4_checkbox_actionPerformed_Interaction1(event);
	}

	void ITSAF_level4_checkbox_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.level4CheckboxToggled();
		} catch (java.lang.Exception e) {
		}
	}

	void rbdmNaOption_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		rbdm_na_option_actionPerformed_Interaction1(event);
	}

	void rbdm_na_option_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
		    if (this.rbdm_na_option.isSelected()) {
		       this.displayRBDMWarning("You must explain");
			   this.toggleQuestionBoxes();
			}else {
			   this.toggleQuestionBoxes();
			   this.displayRBDMWarning("");
			   this.rbdm_warning_label.setVisible(false); 
			}
		} catch (java.lang.Exception e) {
		    e.printStackTrace();
		}
	}
	
	private void riskBasedDecisionMade() {
	    try {
	        if (this.rbdm_yes_option.isSelected()) {
	            this.displayRBDMWarning("You must explain");    
	        }else {
	            this.rbdm_warning_label.setVisible(false);    
	        }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void rbdmYesOption_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		rbdm_yes_option_actionPerformed_Interaction1(event);
	}

	void rbdm_yes_option_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.riskBasedDecisionMade();
		} catch (java.lang.Exception e) {
		}
	}

	void cutMenuItem_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		cutMenuItem_actionPerformed_Interaction1(event);
	}

	void cutMenuItem_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.assessmentObjectiveMenuItemCut();
		} catch (java.lang.Exception e) {
		}
	}

	void connSystemHelpButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		conn_system_questions_help_button_actionPerformed_Interaction1(event);
	}

	void conn_system_questions_help_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.showHelpAddConnectedSystem();
		} catch (java.lang.Exception e) {
		}
	}

	void addAssessorHelpButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		addAssessor_questions_help_button_actionPerformed_Interaction1(event);
	}

	void addAssessor_questions_help_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.showHelpAddAssessors();
		} catch (java.lang.Exception e) {
		}
	}

	void helpButton_actionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		questions_help_button_actionPerformed_Interaction1(event);
	}

	void questions_help_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.showHelpQuestions();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel5_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel5_mouseClicked_Interaction1(event);
	}

	void JLabel5_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineConfidentiality();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel6_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel6_mouseClicked_Interaction1(event);
	}

	void JLabel6_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineIntegrity();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel7_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel7_mouseClicked_Interaction1(event);
	}

	void JLabel7_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineAvailability();
		} catch (java.lang.Exception e) {
		}
	}

	void policyLabel_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		policy_label_mouseEntered_Interaction1(event);
	}

	void policy_label_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(policy_label);
		} catch (java.lang.Exception e) {
		}
	}

	void policyLabel_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		policy_label_mouseExited_Interaction1(event);
	}

	void policy_label_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(policy_label
);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel2Checkbox_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level2_checkbox_mouseEntered_Interaction1(event);
	}

	void ITSAF_level2_checkbox_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintCheckbox(ITSAF_level2_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel2Checkbox_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level2_checkbox_mouseExited_Interaction1(event);
	}

	void ITSAF_level2_checkbox_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintCheckbox(ITSAF_level2_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel3Checkbox_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level3_checkbox_mouseEntered_Interaction1(event);
	}

	void ITSAF_level3_checkbox_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintCheckbox(ITSAF_level3_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel3Checkbox_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level3_checkbox_mouseExited_Interaction1(event);
	}

	void ITSAF_level3_checkbox_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintCheckbox(ITSAF_level3_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel4Checkbox_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level4_checkbox_mouseEntered_Interaction1(event);
	}

	void ITSAF_level4_checkbox_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintCheckbox(ITSAF_level4_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel4Checkbox_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level4_checkbox_mouseExited_Interaction1(event);
	}

	void ITSAF_level4_checkbox_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintCheckbox(ITSAF_level4_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel1Checkbox_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level1_checkbox_mouseEntered_Interaction1(event);
	}

	void ITSAF_level1_checkbox_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintCheckbox(ITSAF_level1_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel1Checkbox_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level1_checkbox_mouseExited_Interaction1(event);
	}

	void ITSAF_level1_checkbox_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintCheckbox(ITSAF_level2_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel1Checkbox_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level1_checkbox_mouseClicked_Interaction1(event);
	}

	void ITSAF_level1_checkbox_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
		    if (SwingUtilities.isRightMouseButton(event)) {
			this.definePolicy();
			}
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel2Checkbox_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level2_checkbox_mouseClicked_Interaction1(event);
	}

	void ITSAF_level2_checkbox_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
		    if (SwingUtilities.isRightMouseButton(event)) {
			    this.defineProcedures();
			}
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel5Checkbox_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level5_checkbox_mouseEntered_Interaction1(event);
	}

	void ITSAF_level5_checkbox_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintCheckbox(ITSAF_level5_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

	void ITSAFLevel5Checkbox_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		ITSAF_level5_checkbox_mouseExited_Interaction1(event);
	}

	void ITSAF_level5_checkbox_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintCheckbox(ITSAF_level5_checkbox);
		} catch (java.lang.Exception e) {
		}
	}

    // This method is the action handler for the clear button on the question panel
    // It must check the database for a response for the question number and delete
    // it if necessary
    // --------------
    // Change Control:
    // 05/13/02 - Change method that gets called to clearButtonPressed() which has the 
    //            database code in it. The other method, clearResponseFields() should just
    //            clear the UI elements not check the database because the action handler
    //            for displaying questions also calls the clearResponseFields() method.
	void question_response_clear_button_actionPerformed_Interaction1(java.awt.event.ActionEvent event) {
		try {
			this.clearButtonPressed();
		} catch (java.lang.Exception e) {
		}
	}

	class SymFocus extends java.awt.event.FocusAdapter
	{
		public void focusLost(java.awt.event.FocusEvent event)
		{
			Object object = event.getSource();
			if (object == assessment_objective_field)
				assessmentObjectiveField_focusLost(event);
			else if (object == system_name_field)
				systemNameField_focusLost(event);
			else if (object == system_number_field)
				systemNumberField_focusLost(event);
			else if (object == aggrpdiv_text_field)
				aggrpdivTextField_focusLost(event);
			else if (object == comment_field)
				commentField_focusLost(event);
		}

		public void focusGained(java.awt.event.FocusEvent event)
		{
			Object object = event.getSource();
			if (object == assessment_objective_field)
				assessmentObjectiveField_focusGained(event);
			else if (object == system_name_field)
				systemNameField_focusGained(event);
			else if (object == system_number_field)
				systemNumberField_focusGained(event);
			else if (object == aggrpdiv_text_field)
				aggrpdivTextField_focusGained(event);
			else if (object == comment_field)
				commentField_focusGained(event);
		}
	}

	void assessmentObjectiveField_focusGained(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		assessment_objective_field_focusGained_Interaction1(event);
	}

	void assessment_objective_field_focusGained_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(assessment_objective_field);
		} catch (java.lang.Exception e) {
		}
	}

	void assessmentObjectiveField_focusLost(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		assessment_objective_field_focusLost_Interaction1(event);
	}

	void assessment_objective_field_focusLost_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(null);
		} catch (java.lang.Exception e) {
		}
	}

	void systemNameField_focusGained(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		system_name_field_focusGained_Interaction1(event);
	}

	void system_name_field_focusGained_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(system_name_field);
		} catch (java.lang.Exception e) {
		}
	}

	void systemNameField_focusLost(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		system_name_field_focusLost_Interaction1(event);
	}

	void system_name_field_focusLost_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(system_name_field);
		} catch (java.lang.Exception e) {
		}
	}

	void systemNumberField_focusGained(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		system_number_field_focusGained_Interaction1(event);
	}

	void system_number_field_focusGained_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(system_number_field);
		} catch (java.lang.Exception e) {
		}
	}

	void systemNumberField_focusLost(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		system_number_field_focusLost_Interaction1(event);
	}

	void system_number_field_focusLost_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(null);
		} catch (java.lang.Exception e) {
		}
	}

	void aggrpdivTextField_focusGained(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		aggrpdiv_text_field_focusGained_Interaction1(event);
	}

	void aggrpdiv_text_field_focusGained_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(aggrpdiv_text_field);
		} catch (java.lang.Exception e) {
		}
	}

	void aggrpdivTextField_focusLost(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		aggrpdiv_text_field_focusLost_Interaction1(event);
	}

	void aggrpdiv_text_field_focusLost_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(null);
		} catch (java.lang.Exception e) {
		}
	}

	void commentField_focusGained(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		comment_field_focusGained_Interaction1(event);
	}

	void comment_field_focusGained_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(comment_field);
		} catch (java.lang.Exception e) {
		}
	}

	void commentField_focusLost(java.awt.event.FocusEvent event)
	{
		// to do: code goes here.
			 
		comment_field_focusLost_Interaction1(event);
	}

	void comment_field_focusLost_Interaction1(java.awt.event.FocusEvent event)
	{
		try {
			this.setActiveTextComponent(null);
		} catch (java.lang.Exception e) {
		}
	}

	class SymKey extends java.awt.event.KeyAdapter
	{
		public void keyTyped(java.awt.event.KeyEvent event)
		{
			Object object = event.getSource();
			if (object == AssessmentWindow.this)
				AssessmentWindow_keyTyped(event);
			else if (object == assessment_objective_field)
				assessmentObjectiveField_keyTyped(event);
			else if (object == comment_field)
				commentField_keyTyped(event);
			else if (object == add_assessor_button)
				addAssessorButton_keyTyped(event);
			if (object == addAssessor_help_button)
				addAssessorHelpButton_keyTyped(event);
			else if (object == conn_system_add_button)
				connSystemAddButton_keyTyped(event);
			if (object == conn_system_help_button)
				connSystemHelpButton_keyTyped(event);
			else if (object == infoGather_previous_button)
				infoGatherPreviousButton_keyTyped(event);
			else if (object == proceed_to_assessment_button)
				proceedToAssessmentButton_keyTyped(event);
			else if (object == policy_next_button)
				policyNextButton_keyTyped(event);
			else if (object == policy_previous_button)
				policyPreviousButton_keyTyped(event);
			else if (object == system_availability_box)
				systemAvailabilityBox_keyTyped(event);
			else if (object == policy_question_table)
				policyQuestionTable_keyTyped(event);
			else if (object == id_panel_proceed_button)
				idPanelProceedButton_keyTyped(event);
			else if (object == question_next_button)
				questionNextButton_keyTyped(event);
			else if (object == save_assessment_button)
				saveAssessmentButton_keyTyped(event);
			else if (object == export_button)
				exportButton_keyTyped(event);
			else if (object == assessor_table)
				assessorTable_keyTyped(event);
		}
	}

	void AssessmentWindow_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		AssessmentWindow_keyTyped_Interaction1(event);
	}

	void AssessmentWindow_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{

	}
	
	private void locateContextSpecificHelp(java.awt.event.KeyEvent event, String command) {
	    try {
            if (event.getKeyChar() == KeyEvent.VK_F1) { 
                
            }
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void JLabel16_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel16_mouseClicked_Interaction1(event);
	}

	void JLabel16_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineSystemNumber();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel4_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel4_mouseClicked_Interaction1(event);
	}

	void JLabel4_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineLocation();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel4_mouseEntered(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel4_mouseEntered_Interaction1(event);
	}

	void JLabel4_mouseEntered_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.paintLabel(JLabel4);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel4_mouseExited(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel4_mouseExited_Interaction1(event);
	}

	void JLabel4_mouseExited_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.unpaintLabel(JLabel4);
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel1_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel1_mouseClicked_Interaction1(event);
	}

	void JLabel1_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineSystemName();
		} catch (java.lang.Exception e) {
		}
	}

	void JLabel2_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		JLabel2_mouseClicked_Interaction1(event);
	}

	void JLabel2_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.defineSystemType();
		} catch (java.lang.Exception e) {
		}
	}

	void policyLabel_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		policy_label_mouseClicked_Interaction1(event);
	}

	void policy_label_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.definePolicy();
		} catch (java.lang.Exception e) {
		}
	}

	void assessmentObjectiveField_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		assessment_objective_field_keyTyped_Interaction1(event);
	}

	void assessment_objective_field_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.obj_fieldTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void commentField_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		comment_field_keyTyped_Interaction1(event);
	}

	void comment_field_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.cmnt_fieldTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void addAssessorButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.addAssessorButtonActionHandler();
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	private void deleteAssessorButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.deleteAssessor(null);   
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}
	
	private void addAssessorHelpButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.showHelpAddAssessors();      
			}
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}

	void addAssessorButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		add_assessor_button_keyTyped_Interaction1(event);
	}

	void add_assessor_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.addAssessorButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void addAssessorHelpButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		addAssessor_help_button_keyTyped_Interaction1(event);
	}

	void addAssessor_help_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.addAssessorHelpButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void assessmentIDNextButtonPressed(java.awt.event.KeyEvent event) {
		try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() + 1);	    
			    this.parent.setStatusMsg("Now entering system indentification information.");
			}		    		    
		}catch (java.lang.Exception e) {
            e.printStackTrace();
		}	    
	}
	
	private void addConnectedSystemButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.addConnectedSystemButtonActionHandler();          
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	
	
	private void deleteConnectedSystemButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.deleteConnectedSystem(null);   
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	
	
	private void addConnectedSystemHelpButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    this.showHelpAddConnectedSystem();       
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	

	void connSystemAddButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		conn_system_add_button_keyTyped_Interaction1(event);
	}

	void conn_system_add_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.addConnectedSystemButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void connSystemHelpButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		conn_system_help_button_keyTyped_Interaction1(event);
	}

	void conn_system_help_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.addConnectedSystemHelpButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void infoGatherPreviousButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
			    JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() - 1);          
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void infoGatherPreviousButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		infoGather_previous_button_keyTyped_Interaction1(event);
	}

	void infoGather_previous_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.infoGatherPreviousButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void proceedToAssessmentButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        proceed_to_assessment_button_actionPerformed(null);    
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void proceedToAssessmentButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		proceed_to_assessment_button_keyTyped_Interaction1(event);
	}

	void proceed_to_assessment_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.proceedToAssessmentButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void policyProceedToAssessmentButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        this.policy_next_button_actionPerformed(null);    
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}

	void policyNextButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		policy_next_button_keyTyped_Interaction1(event);
	}

	void policy_next_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.policyProceedToAssessmentButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void policyPreviousButtonPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        JTabbedPane1.setSelectedIndex(JTabbedPane1.getSelectedIndex() - 1);    
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }
	}
	
	void policyPreviousButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		policy_previous_button_keyTyped_Interaction1(event);
	}

	void policy_previous_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.policyPreviousButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void systemAvailabilityBox_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		system_availability_box_keyTyped_Interaction1(event);
	}

	void system_availability_box_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.availability_fieldTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void policyQuestionTable_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		policy_question_table_keyTyped_Interaction1(event);
			 
		policy_question_table_keyTyped_Interaction2(event);
			 
		policy_question_table_keyTyped_Interaction3(event);
	}

	void policy_question_table_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.policyTableTabFieldPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void idPanelProceedButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		id_panel_proceed_button_keyTyped_Interaction1(event);
	}

	void id_panel_proceed_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.assessmentIDNextButtonPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void questionNextButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		question_next_button_keyTyped_Interaction1(event);
	}

	void question_next_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.ques_NextTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
	
	private void saveAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        this.saveAssessment();       
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}
	
	private void exportAssessmentButtonEnterKeyPressed(java.awt.event.KeyEvent event) {
	    try {
		    if (event.getKeyChar() == KeyEvent.VK_ENTER) {
		        this.saveUnfinishedAssessment();           
			}	        
	    }catch (Exception e) {
	        e.printStackTrace();
	    }	    
	}	

	void saveAssessmentButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		save_assessment_button_keyTyped_Interaction1(event);
	}

	void save_assessment_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.saveAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void exportButton_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		export_button_keyTyped_Interaction1(event);
	}

	void export_button_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.exportAssessmentButtonEnterKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void assessorTable_keyTyped(java.awt.event.KeyEvent event)
	{
		// to do: code goes here.
			 
		assessor_table_keyTyped_Interaction1(event);
	}

	void assessor_table_keyTyped_Interaction1(java.awt.event.KeyEvent event)
	{
		try {
			this.assessorTableTabKeyPressed(event);
		} catch (java.lang.Exception e) {
		}
	}

	void policyQuestionTable_mouseClicked(java.awt.event.MouseEvent event)
	{
		// to do: code goes here.
			 
		policy_question_table_mouseClicked_Interaction1(event);
	}

	void policy_question_table_mouseClicked_Interaction1(java.awt.event.MouseEvent event)
	{
		try {
			this.setAssessmentSaveStatus(true);
		} catch (java.lang.Exception e) {
		}
	}

	void policy_question_table_keyTyped_Interaction2(java.awt.event.KeyEvent event)
	{
		try {
			this.setAssessmentSaveStatus(true);
		} catch (java.lang.Exception e) {
		}
	}

	void policy_question_table_keyTyped_Interaction3(java.awt.event.KeyEvent event)
	{
		try {
			this.policyTableTabFieldPressed(event);
		} catch (java.lang.Exception e) {
		}
	}
} /* end class AssessmentWindow() */